// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_PipeImpl__
#define __gnu_java_nio_PipeImpl__

#pragma interface

#include <java/nio/channels/Pipe.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class Pipe$SourceChannel;
        class Pipe$SinkChannel;
        namespace spi
        {
          class SelectorProvider;
        }
      }
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        class PipeImpl;
        class PipeImpl$SourceChannelImpl;
        class PipeImpl$SinkChannelImpl;
      }
    }
  }
}

class gnu::java::nio::PipeImpl : public ::java::nio::channels::Pipe
{
public:
  PipeImpl (::java::nio::channels::spi::SelectorProvider *);
  virtual ::java::nio::channels::Pipe$SinkChannel *sink () { return reinterpret_cast< ::java::nio::channels::Pipe$SinkChannel *> (sink__); }
  virtual ::java::nio::channels::Pipe$SourceChannel *source () { return reinterpret_cast< ::java::nio::channels::Pipe$SourceChannel *> (source__); }
private:
  ::gnu::java::nio::PipeImpl$SinkChannelImpl * __attribute__((aligned(__alignof__( ::java::nio::channels::Pipe )))) sink__;
  ::gnu::java::nio::PipeImpl$SourceChannelImpl *source__;

  friend class gnu_java_nio_PipeImpl$SinkChannelImpl;
  friend class gnu_java_nio_PipeImpl$SourceChannelImpl;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_PipeImpl__ */
