// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_Selector__
#define __java_nio_channels_Selector__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        namespace spi
        {
          class SelectorProvider;
        }
        class Selector;
      }
    }
  }
}

class java::nio::channels::Selector : public ::java::lang::Object
{
public:  // actually protected
  Selector ();
public:
  static ::java::nio::channels::Selector *open ();
  virtual void close () = 0;
  virtual jboolean isOpen () = 0;
  virtual ::java::util::Set *keys () = 0;
  virtual ::java::nio::channels::spi::SelectorProvider *provider () = 0;
  virtual jint select () = 0;
  virtual jint select (jlong) = 0;
  virtual ::java::util::Set *selectedKeys () = 0;
  virtual jint selectNow () = 0;
  virtual ::java::nio::channels::Selector *wakeup () = 0;

  static ::java::lang::Class class$;
};

#endif /* __java_nio_channels_Selector__ */
