// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_UndoableEditEvent__
#define __javax_swing_event_UndoableEditEvent__

#pragma interface

#include <java/util/EventObject.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class UndoableEditEvent;
      }
      namespace undo
      {
        class UndoableEdit;
      }
    }
  }
}

class javax::swing::event::UndoableEditEvent : public ::java::util::EventObject
{
public:
  UndoableEditEvent (::java::lang::Object *, ::javax::swing::undo::UndoableEdit *);
  virtual ::javax::swing::undo::UndoableEdit *getEdit () { return edit; }
private:
  static const jlong serialVersionUID = 4418044561759134484LL;
  ::javax::swing::undo::UndoableEdit * __attribute__((aligned(__alignof__( ::java::util::EventObject )))) edit;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_UndoableEditEvent__ */
