// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_accessibility_AccessibleState__
#define __javax_accessibility_AccessibleState__

#pragma interface

#include <javax/accessibility/AccessibleBundle.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleState;
    }
  }
}

class javax::accessibility::AccessibleState : public ::javax::accessibility::AccessibleBundle
{
public:  // actually protected
  AccessibleState (::java::lang::String *);
public:
  static ::javax::accessibility::AccessibleState *ACTIVE;
  static ::javax::accessibility::AccessibleState *PRESSED;
  static ::javax::accessibility::AccessibleState *ARMED;
  static ::javax::accessibility::AccessibleState *BUSY;
  static ::javax::accessibility::AccessibleState *CHECKED;
  static ::javax::accessibility::AccessibleState *EDITABLE;
  static ::javax::accessibility::AccessibleState *EXPANDABLE;
  static ::javax::accessibility::AccessibleState *COLLAPSED;
  static ::javax::accessibility::AccessibleState *EXPANDED;
  static ::javax::accessibility::AccessibleState *ENABLED;
  static ::javax::accessibility::AccessibleState *FOCUSABLE;
  static ::javax::accessibility::AccessibleState *FOCUSED;
  static ::javax::accessibility::AccessibleState *ICONIFIED;
  static ::javax::accessibility::AccessibleState *INDETERMINATE;
  static ::javax::accessibility::AccessibleState *MANAGES_DESCENDANTS;
  static ::javax::accessibility::AccessibleState *MODAL;
  static ::javax::accessibility::AccessibleState *OPAQUE;
  static ::javax::accessibility::AccessibleState *RESIZABLE;
  static ::javax::accessibility::AccessibleState *MULTISELECTABLE;
  static ::javax::accessibility::AccessibleState *SELECTABLE;
  static ::javax::accessibility::AccessibleState *SELECTED;
  static ::javax::accessibility::AccessibleState *SHOWING;
  static ::javax::accessibility::AccessibleState *TRUNCATED;
  static ::javax::accessibility::AccessibleState *VISIBLE;
  static ::javax::accessibility::AccessibleState *VERTICAL;
  static ::javax::accessibility::AccessibleState *HORIZONTAL;
  static ::javax::accessibility::AccessibleState *SINGLE_LINE;
  static ::javax::accessibility::AccessibleState *MULTI_LINE;
  static ::javax::accessibility::AccessibleState *TRANSIENT;

  static ::java::lang::Class class$;
};

#endif /* __javax_accessibility_AccessibleState__ */
