// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_UnsupportedLookAndFeelException__
#define __javax_swing_UnsupportedLookAndFeelException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class UnsupportedLookAndFeelException;
    }
  }
}

class javax::swing::UnsupportedLookAndFeelException : public ::java::lang::Exception
{
public:
  UnsupportedLookAndFeelException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_UnsupportedLookAndFeelException__ */
