// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_management_MemoryMXBeanImpl__
#define __gnu_java_lang_management_MemoryMXBeanImpl__

#pragma interface

#include <gnu/java/lang/management/BeanImpl.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        namespace management
        {
          class MemoryMXBeanImpl;
        }
      }
    }
  }
  namespace javax
  {
    namespace management
    {
      class MBeanNotificationInfo;
      class NotificationFilter;
      class NotificationListener;
      namespace openmbean
      {
        class CompositeType;
      }
    }
  }
}

class gnu::java::lang::management::MemoryMXBeanImpl : public ::gnu::java::lang::management::BeanImpl
{
public:
  MemoryMXBeanImpl ();
  virtual void gc ();
  virtual ::java::lang::management::MemoryUsage *getHeapMemoryUsage ();
  virtual ::java::lang::management::MemoryUsage *getNonHeapMemoryUsage ();
  virtual jint getObjectPendingFinalizationCount ();
  virtual jboolean isVerbose ();
  virtual void setVerbose (jboolean);
  virtual void addNotificationListener (::javax::management::NotificationListener *, ::javax::management::NotificationFilter *, ::java::lang::Object *);
  virtual JArray< ::javax::management::MBeanNotificationInfo *> *getNotificationInfo ();
  virtual void removeNotificationListener (::javax::management::NotificationListener *);
  virtual void removeNotificationListener (::javax::management::NotificationListener *, ::javax::management::NotificationFilter *, ::java::lang::Object *);
public: // actually package-private
  virtual void fireNotification (::java::lang::String *, ::java::lang::String *, jlong, jlong, jlong, jlong, jlong);
  virtual void fireThresholdExceededNotification (::java::lang::String *, jlong, jlong, jlong, jlong, jlong);
  virtual void fireCollectionThresholdExceededNotification (::java::lang::String *, jlong, jlong, jlong, jlong, jlong);
private:
  ::java::util::List * __attribute__((aligned(__alignof__( ::gnu::java::lang::management::BeanImpl )))) listeners;
  jlong notificationCount;
public:
  static ::javax::management::openmbean::CompositeType *notifType;
  static ::javax::management::openmbean::CompositeType *usageType;

  friend class gnu_java_lang_management_MemoryMXBeanImpl$ListenerData;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_lang_management_MemoryMXBeanImpl__ */
