// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_SimpleAttributeSet__
#define __javax_swing_text_SimpleAttributeSet__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class SimpleAttributeSet;
        class AttributeSet;
      }
    }
  }
}

class javax::swing::text::SimpleAttributeSet : public ::java::lang::Object
{
public:
  SimpleAttributeSet ();
  SimpleAttributeSet (::javax::swing::text::AttributeSet *);
  virtual void addAttribute (::java::lang::Object *, ::java::lang::Object *);
  virtual void addAttributes (::javax::swing::text::AttributeSet *);
  virtual ::java::lang::Object *clone ();
  virtual jboolean containsAttribute (::java::lang::Object *, ::java::lang::Object *);
public: // actually package-private
  virtual jboolean containsAttributeLocally (::java::lang::Object *, ::java::lang::Object *);
public:
  virtual jboolean containsAttributes (::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::AttributeSet *copyAttributes ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::Object *getAttribute (::java::lang::Object *);
  virtual jint getAttributeCount ();
  virtual ::java::util::Enumeration *getAttributeNames ();
  virtual ::javax::swing::text::AttributeSet *getResolveParent ();
  virtual jint hashCode ();
  virtual jboolean isDefined (::java::lang::Object *);
  virtual jboolean isEmpty ();
  virtual jboolean isEqual (::javax::swing::text::AttributeSet *);
  virtual void removeAttribute (::java::lang::Object *);
  virtual void removeAttributes (::javax::swing::text::AttributeSet *);
  virtual void removeAttributes (::java::util::Enumeration *);
  virtual void setResolveParent (::javax::swing::text::AttributeSet *);
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = 8267656273837665219LL;
public:
  static ::javax::swing::text::AttributeSet *EMPTY;
public: // actually package-private
  ::java::util::Hashtable * __attribute__((aligned(__alignof__( ::java::lang::Object )))) tab;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_SimpleAttributeSet__ */
