// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_IKeyring__
#define __gnu_javax_crypto_keyring_IKeyring__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class IKeyring;
          class Entry;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::IKeyring : public ::java::lang::Object
{
public:
  virtual void load (::java::util::Map *) = 0;
  virtual void store (::java::util::Map *) = 0;
  virtual void reset () = 0;
  virtual jint size () = 0;
  virtual ::java::util::Enumeration *aliases () = 0;
  virtual jboolean containsAlias (::java::lang::String *) = 0;
  virtual ::java::util::List *get (::java::lang::String *) = 0;
  virtual void add (::gnu::javax::crypto::keyring::Entry *) = 0;
  virtual void remove (::java::lang::String *) = 0;
  static ::java::lang::String *KEYRING_DATA_IN;
  static ::java::lang::String *KEYRING_DATA_OUT;
  static ::java::lang::String *KEYRING_PASSWORD;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_keyring_IKeyring__ */
