// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_EncryptedEntry__
#define __gnu_javax_crypto_keyring_EncryptedEntry__

#pragma interface

#include <gnu/javax/crypto/keyring/MaskableEnvelopeEntry.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace mode
        {
          class IMode;
        }
        namespace keyring
        {
          class EncryptedEntry;
          class Properties;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::EncryptedEntry : public ::gnu::javax::crypto::keyring::MaskableEnvelopeEntry
{
public:
  EncryptedEntry (::java::lang::String *, ::java::lang::String *, ::gnu::javax::crypto::keyring::Properties *);
private:
  EncryptedEntry ();
public:
  static ::gnu::javax::crypto::keyring::EncryptedEntry *decode (::java::io::DataInputStream *);
  virtual void decrypt (jbyteArray, jbyteArray);
  virtual void encrypt (jbyteArray, jbyteArray);
  virtual void encodePayload ();
private:
  ::gnu::javax::crypto::mode::IMode *getMode (jbyteArray, jbyteArray, jint);
public:
  static const jint TYPE = 0L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_EncryptedEntry__ */
