// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_RenderingHints__
#define __java_awt_RenderingHints__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class RenderingHints;
      class RenderingHints$Key;
    }
  }
}

class java::awt::RenderingHints : public ::java::lang::Object
{
public:
  RenderingHints (::java::util::Map *);
  RenderingHints (::java::awt::RenderingHints$Key *, ::java::lang::Object *);
  virtual jint size ();
  virtual jboolean isEmpty ();
  virtual jboolean containsKey (::java::lang::Object *);
  virtual jboolean containsValue (::java::lang::Object *);
  virtual ::java::lang::Object *get (::java::lang::Object *);
  virtual ::java::lang::Object *put (::java::lang::Object *, ::java::lang::Object *);
  virtual void add (::java::awt::RenderingHints *);
  virtual void clear ();
  virtual ::java::lang::Object *remove (::java::lang::Object *);
  virtual void putAll (::java::util::Map *);
  virtual ::java::util::Set *keySet ();
  virtual ::java::util::Collection *values ();
  virtual ::java::util::Set *entrySet ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::Object *clone ();
  virtual ::java::lang::String *toString ();
private:
  ::java::util::HashMap * __attribute__((aligned(__alignof__( ::java::lang::Object )))) hintMap;
public:
  static ::java::awt::RenderingHints$Key *KEY_ANTIALIASING;
  static ::java::lang::Object *VALUE_ANTIALIAS_ON;
  static ::java::lang::Object *VALUE_ANTIALIAS_OFF;
  static ::java::lang::Object *VALUE_ANTIALIAS_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_RENDERING;
  static ::java::lang::Object *VALUE_RENDER_SPEED;
  static ::java::lang::Object *VALUE_RENDER_QUALITY;
  static ::java::lang::Object *VALUE_RENDER_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_DITHERING;
  static ::java::lang::Object *VALUE_DITHER_DISABLE;
  static ::java::lang::Object *VALUE_DITHER_ENABLE;
  static ::java::lang::Object *VALUE_DITHER_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_TEXT_ANTIALIASING;
  static ::java::lang::Object *VALUE_TEXT_ANTIALIAS_ON;
  static ::java::lang::Object *VALUE_TEXT_ANTIALIAS_OFF;
  static ::java::lang::Object *VALUE_TEXT_ANTIALIAS_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_FRACTIONALMETRICS;
  static ::java::lang::Object *VALUE_FRACTIONALMETRICS_OFF;
  static ::java::lang::Object *VALUE_FRACTIONALMETRICS_ON;
  static ::java::lang::Object *VALUE_FRACTIONALMETRICS_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_INTERPOLATION;
  static ::java::lang::Object *VALUE_INTERPOLATION_NEAREST_NEIGHBOR;
  static ::java::lang::Object *VALUE_INTERPOLATION_BILINEAR;
  static ::java::lang::Object *VALUE_INTERPOLATION_BICUBIC;
  static ::java::awt::RenderingHints$Key *KEY_ALPHA_INTERPOLATION;
  static ::java::lang::Object *VALUE_ALPHA_INTERPOLATION_SPEED;
  static ::java::lang::Object *VALUE_ALPHA_INTERPOLATION_QUALITY;
  static ::java::lang::Object *VALUE_ALPHA_INTERPOLATION_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_COLOR_RENDERING;
  static ::java::lang::Object *VALUE_COLOR_RENDER_SPEED;
  static ::java::lang::Object *VALUE_COLOR_RENDER_QUALITY;
  static ::java::lang::Object *VALUE_COLOR_RENDER_DEFAULT;
  static ::java::awt::RenderingHints$Key *KEY_STROKE_CONTROL;
  static ::java::lang::Object *VALUE_STROKE_DEFAULT;
  static ::java::lang::Object *VALUE_STROKE_NORMALIZE;
  static ::java::lang::Object *VALUE_STROKE_PURE;

  friend class java_awt_RenderingHints$KeyImpl;
  friend class java_awt_RenderingHints$Key;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_RenderingHints__ */
