// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_RecordingInputStream__
#define __gnu_javax_net_ssl_provider_RecordingInputStream__

#pragma interface

#include <java/io/FilterInputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class RecordingInputStream;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::RecordingInputStream : public ::java::io::FilterInputStream
{
public: // actually package-private
  RecordingInputStream (::java::io::InputStream *);
  RecordingInputStream (::java::io::InputStream *, ::java::io::ByteArrayOutputStream *);
public:
  virtual jint read ();
  virtual jint read (jbyteArray, jint, jint);
  virtual jint read (jbyteArray);
  virtual jlong skip (jlong);
public: // actually package-private
  virtual jbyteArray getBytes ();
  virtual void resetSink ();
public:  // actually protected
  ::java::io::ByteArrayOutputStream * __attribute__((aligned(__alignof__( ::java::io::FilterInputStream )))) sink;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_RecordingInputStream__ */
