// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_WritableRenderedImage__
#define __java_awt_image_WritableRenderedImage__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Point;
      namespace image
      {
        class WritableRenderedImage;
        class Raster;
        class WritableRaster;
        class TileObserver;
      }
    }
  }
}

class java::awt::image::WritableRenderedImage : public ::java::lang::Object
{
public:
  virtual void addTileObserver (::java::awt::image::TileObserver *) = 0;
  virtual void removeTileObserver (::java::awt::image::TileObserver *) = 0;
  virtual ::java::awt::image::WritableRaster *getWritableTile (jint, jint) = 0;
  virtual void releaseWritableTile (jint, jint) = 0;
  virtual jboolean isTileWritable (jint, jint) = 0;
  virtual JArray< ::java::awt::Point *> *getWritableTileIndices () = 0;
  virtual jboolean hasTileWriters () = 0;
  virtual void setData (::java::awt::image::Raster *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_image_WritableRenderedImage__ */
