// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppDelimiterTag__
#define __gnu_javax_print_ipp_IppDelimiterTag__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          class IppDelimiterTag;
        }
      }
    }
  }
}

class gnu::javax::print::ipp::IppDelimiterTag : public ::java::lang::Object
{
private:
  IppDelimiterTag ();
public:
  static jboolean isDelimiterTag (jbyte);
  static const jint OPERATION_ATTRIBUTES_TAG = 1L;
  static const jint JOB_ATTRIBUTES_TAG = 2L;
  static const jint END_OF_ATTRIBUTES_TAG = 3L;
  static const jint PRINTER_ATTRIBUTES_TAG = 4L;
  static const jint UNSUPPORTED_ATTRIBUTES_TAG = 5L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_IppDelimiterTag__ */
