// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_DefaultEditorKit__
#define __javax_swing_text_DefaultEditorKit__

#pragma interface

#include <javax/swing/text/EditorKit.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class DefaultEditorKit;
        class ViewFactory;
        class Document;
        class Caret;
      }
      class Action;
    }
  }
}

class javax::swing::text::DefaultEditorKit : public ::javax::swing::text::EditorKit
{
public:
  DefaultEditorKit ();
  virtual ::javax::swing::text::Caret *createCaret ();
  virtual ::javax::swing::text::Document *createDefaultDocument ();
  virtual JArray< ::javax::swing::Action *> *getActions ();
  virtual ::java::lang::String *getContentType ();
  virtual ::javax::swing::text::ViewFactory *getViewFactory () { return 0; }
  virtual void read (::java::io::InputStream *, ::javax::swing::text::Document *, jint);
  virtual void read (::java::io::Reader *, ::javax::swing::text::Document *, jint);
  virtual void write (::java::io::OutputStream *, ::javax::swing::text::Document *, jint, jint);
  virtual void write (::java::io::Writer *, ::javax::swing::text::Document *, jint, jint);
private:
  static const jlong serialVersionUID = 9017245433028523428LL;
public:
  static ::java::lang::String *backwardAction;
  static ::java::lang::String *beepAction;
  static ::java::lang::String *beginAction;
  static ::java::lang::String *beginLineAction;
  static ::java::lang::String *beginParagraphAction;
  static ::java::lang::String *beginWordAction;
  static ::java::lang::String *copyAction;
  static ::java::lang::String *cutAction;
  static ::java::lang::String *defaultKeyTypedAction;
  static ::java::lang::String *deleteNextCharAction;
  static ::java::lang::String *deletePrevCharAction;
  static ::java::lang::String *downAction;
  static ::java::lang::String *endAction;
  static ::java::lang::String *endLineAction;
  static ::java::lang::String *EndOfLineStringProperty;
  static ::java::lang::String *endParagraphAction;
  static ::java::lang::String *endWordAction;
  static ::java::lang::String *forwardAction;
  static ::java::lang::String *insertBreakAction;
  static ::java::lang::String *insertContentAction;
  static ::java::lang::String *insertTabAction;
  static ::java::lang::String *nextWordAction;
  static ::java::lang::String *pageDownAction;
  static ::java::lang::String *pageUpAction;
  static ::java::lang::String *pasteAction;
  static ::java::lang::String *previousWordAction;
  static ::java::lang::String *readOnlyAction;
  static ::java::lang::String *selectAllAction;
  static ::java::lang::String *selectionBackwardAction;
  static ::java::lang::String *selectionBeginAction;
  static ::java::lang::String *selectionBeginLineAction;
  static ::java::lang::String *selectionBeginParagraphAction;
  static ::java::lang::String *selectionBeginWordAction;
  static ::java::lang::String *selectionDownAction;
  static ::java::lang::String *selectionEndAction;
  static ::java::lang::String *selectionEndLineAction;
  static ::java::lang::String *selectionEndParagraphAction;
  static ::java::lang::String *selectionEndWordAction;
  static ::java::lang::String *selectionForwardAction;
  static ::java::lang::String *selectionNextWordAction;
  static ::java::lang::String *selectionPreviousWordAction;
  static ::java::lang::String *selectionUpAction;
  static ::java::lang::String *selectLineAction;
  static ::java::lang::String *selectParagraphAction;
  static ::java::lang::String *selectWordAction;
  static ::java::lang::String *upAction;
  static ::java::lang::String *writableAction;
private:
  static JArray< ::javax::swing::Action *> *defaultActions;

  friend class javax_swing_text_DefaultEditorKit$InsertTabAction;
  friend class javax_swing_text_DefaultEditorKit$InsertContentAction;
  friend class javax_swing_text_DefaultEditorKit$InsertBreakAction;
  friend class javax_swing_text_DefaultEditorKit$DefaultKeyTypedAction;
  friend class javax_swing_text_DefaultEditorKit$PasteAction;
  friend class javax_swing_text_DefaultEditorKit$CutAction;
  friend class javax_swing_text_DefaultEditorKit$CopyAction;
  friend class javax_swing_text_DefaultEditorKit$BeepAction;
  friend class javax_swing_text_DefaultEditorKit$EndAction;
  friend class javax_swing_text_DefaultEditorKit$BeginAction;
  friend class javax_swing_text_DefaultEditorKit$BeginLineAction;
  friend class javax_swing_text_DefaultEditorKit$EndLineAction;
  friend class javax_swing_text_DefaultEditorKit$DeleteNextCharAction;
  friend class javax_swing_text_DefaultEditorKit$DeletePrevCharAction;
  friend class javax_swing_text_DefaultEditorKit$BackwardAction;
  friend class javax_swing_text_DefaultEditorKit$ForwardAction;
  friend class javax_swing_text_DefaultEditorKit$UpAction;
  friend class javax_swing_text_DefaultEditorKit$DownAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionBackwardAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionForwardAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionUpAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionDownAction;
  friend class javax_swing_text_DefaultEditorKit$SelectWordAction;
  friend class javax_swing_text_DefaultEditorKit$SelectLineAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionEndLineAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionBeginLineAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionEndAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionBeginAction;
  friend class javax_swing_text_DefaultEditorKit$SelectAllAction;
  friend class javax_swing_text_DefaultEditorKit$NextWordAction;
  friend class javax_swing_text_DefaultEditorKit$PreviousWordAction;
  friend class javax_swing_text_DefaultEditorKit$EndWordAction;
  friend class javax_swing_text_DefaultEditorKit$BeginWordAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionEndWordAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionBeginWordAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionNextWordAction;
  friend class javax_swing_text_DefaultEditorKit$SelectionPreviousWordAction;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_DefaultEditorKit__ */
