// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_der_BitString__
#define __gnu_java_security_der_BitString__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace der
        {
          class BitString;
        }
      }
    }
  }
}

class gnu::java::security::der::BitString : public ::java::lang::Object
{
public:
  BitString (jbyteArray, jint, jboolean);
  BitString (jbyteArray, jint, jint, jint, jboolean);
  BitString (jbyteArray, jint, jint, jint);
  BitString (jbyteArray, jint);
  BitString (jbyteArray, jint, jint);
  BitString (jbyteArray);
  virtual jbyteArray toByteArray ();
  virtual jbyteArray getShiftedByteArray ();
  virtual jint getIgnoredBits () { return ignoredBits; }
  virtual jint size ();
  virtual jbooleanArray toBooleanArray ();
  virtual ::java::lang::Object *clone ();
  virtual jint compareTo (::java::lang::Object *);
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
private:
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  bytes;
  jbyteArray externBytes;
  jint ignoredBits;
  jbooleanArray boolVal;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_der_BitString__ */
