// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Context__
#define __gnu_javax_net_ssl_provider_Context__

#pragma interface

#include <javax/net/ssl/SSLContextSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class SecureRandom;
    }
  }
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class TrustManager;
        class KeyManager;
        class SSLSocketFactory;
        class SSLServerSocketFactory;
        class SSLSessionContext;
        class X509TrustManager;
        class X509KeyManager;
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          class SRPTrustManager;
          namespace provider
          {
            class Context;
            class SessionContext;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Context : public ::javax::net::ssl::SSLContextSpi
{
public:
  Context ();
public:  // actually protected
  virtual ::javax::net::ssl::SSLSessionContext *engineGetClientSessionContext () { return reinterpret_cast< ::javax::net::ssl::SSLSessionContext *> (clientSessions); }
  virtual ::javax::net::ssl::SSLSessionContext *engineGetServerSessionContext () { return reinterpret_cast< ::javax::net::ssl::SSLSessionContext *> (serverSessions); }
  virtual ::javax::net::ssl::SSLServerSocketFactory *engineGetServerSocketFactory ();
  virtual ::javax::net::ssl::SSLSocketFactory *engineGetSocketFactory ();
  virtual void engineInit (JArray< ::javax::net::ssl::KeyManager *> *, JArray< ::javax::net::ssl::TrustManager *> *, ::java::security::SecureRandom *);
private:
  ::javax::net::ssl::X509KeyManager *defaultKeyManager ();
  ::javax::net::ssl::X509TrustManager *defaultTrustManager ();
  ::java::security::SecureRandom *defaultRandom ();
  ::gnu::javax::net::ssl::provider::SessionContext * __attribute__((aligned(__alignof__( ::javax::net::ssl::SSLContextSpi )))) clientSessions;
  ::gnu::javax::net::ssl::provider::SessionContext *serverSessions;
  ::javax::net::ssl::X509KeyManager *keyManager;
  ::javax::net::ssl::X509TrustManager *trustManager;
  ::gnu::javax::net::ssl::SRPTrustManager *srpTrustManager;
  ::java::security::SecureRandom *random;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Context__ */
