// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_Pointer64__
#define __gnu_classpath_Pointer64__

#pragma interface

#include <gnu/classpath/Pointer.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      class Pointer64;
    }
  }
}

class gnu::classpath::Pointer64 : public ::gnu::classpath::Pointer
{
public:
  Pointer64 (jlong);
public: // actually package-private
  jlong __attribute__((aligned(__alignof__( ::gnu::classpath::Pointer ))))  data;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_Pointer64__ */
