// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_SecretKey__
#define __javax_crypto_SecretKey__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      class SecretKey;
    }
  }
}

class javax::crypto::SecretKey : public ::java::lang::Object
{
public:
  static const jlong serialVersionUID = -4795878709595146952LL;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_crypto_SecretKey__ */
