// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_ietf_jgss_GSSException__
#define __org_ietf_jgss_GSSException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace org
  {
    namespace ietf
    {
      namespace jgss
      {
        class GSSException;
      }
    }
  }
}

class org::ietf::jgss::GSSException : public ::java::lang::Exception
{
public:
  GSSException (jint);
  GSSException (jint, jint, ::java::lang::String *);
  virtual jint getMajor () { return major; }
  virtual jint getMinor () { return minor; }
  virtual ::java::lang::String *getMajorString ();
  virtual ::java::lang::String *getMinorString () { return minorString; }
  virtual void setMinor (jint, ::java::lang::String *);
  virtual ::java::lang::String *toString ();
  virtual ::java::lang::String *getMessage ();
private:
  ::java::lang::String *getMsg (::java::lang::String *, ::java::lang::String *);
  static const jlong serialVersionUID = -2706218945227726672LL;
public:
  static const jint BAD_BINDINGS = 1L;
  static const jint BAD_MECH = 2L;
  static const jint BAD_NAME = 3L;
  static const jint BAD_NAMETYPE = 4L;
  static const jint BAD_STATUS = 5L;
  static const jint BAD_MIC = 6L;
  static const jint CONTEXT_EXPIRED = 7L;
  static const jint CREDENTIALS_EXPIRED = 8L;
  static const jint DEFECTIVE_CREDENTIAL = 9L;
  static const jint DEFECTIVE_TOKEN = 10L;
  static const jint FAILURE = 11L;
  static const jint NO_CONTEXT = 12L;
  static const jint NO_CRED = 13L;
  static const jint BAD_QOP = 14L;
  static const jint UNAUTHORIZED = 15L;
  static const jint UNAVAILABLE = 16L;
  static const jint DUPLICATE_ELEMENT = 17L;
  static const jint NAME_NOT_MN = 18L;
  static const jint DUPLICATE_TOKEN = 19L;
  static const jint OLD_TOKEN = 20L;
  static const jint UNSEQ_TOKEN = 21L;
  static const jint GAP_TOKEN = 22L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Exception ))))  major;
  jint minor;
  ::java::lang::String *minorString;
  ::java::util::ResourceBundle *messages;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_ietf_jgss_GSSException__ */
