// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_undo_AbstractUndoableEdit__
#define __javax_swing_undo_AbstractUndoableEdit__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace undo
      {
        class AbstractUndoableEdit;
        class UndoableEdit;
      }
    }
  }
}

class javax::swing::undo::AbstractUndoableEdit : public ::java::lang::Object
{
public:
  AbstractUndoableEdit ();
  virtual void undo ();
  virtual jboolean canUndo ();
  virtual void redo ();
  virtual jboolean canRedo ();
  virtual void die ();
  virtual jboolean addEdit (::javax::swing::undo::UndoableEdit *);
  virtual jboolean replaceEdit (::javax::swing::undo::UndoableEdit *);
  virtual jboolean isSignificant ();
  virtual ::java::lang::String *getPresentationName ();
  virtual ::java::lang::String *getUndoPresentationName ();
  virtual ::java::lang::String *getRedoPresentationName ();
  virtual ::java::lang::String *toString ();
public: // actually package-private
  static const jlong serialVersionUID = 580150227676302096LL;
public:  // actually protected
  static ::java::lang::String *UndoName;
  static ::java::lang::String *RedoName;
private:
  jboolean __attribute__((aligned(__alignof__( ::java::lang::Object ))))  hasBeenDone;
  jboolean alive;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_undo_AbstractUndoableEdit__ */
