// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_SSLRSASignature__
#define __gnu_javax_net_ssl_provider_SSLRSASignature__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class SSLRSASignature;
          }
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace hash
        {
          class IMessageDigest;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace interfaces
      {
        class RSAPrivateKey;
        class RSAPublicKey;
      }
    }
  }
}

class gnu::javax::net::ssl::provider::SSLRSASignature : public ::java::lang::Object
{
public: // actually package-private
  SSLRSASignature ();
  SSLRSASignature (::gnu::java::security::hash::IMessageDigest *, ::gnu::java::security::hash::IMessageDigest *);
public:
  virtual ::java::lang::String *name ();
  virtual void setupVerify (::java::util::Map *);
  virtual void setupSign (::java::util::Map *);
  virtual void update (jbyte);
  virtual void update (jbyteArray, jint, jint);
  virtual ::java::lang::Object *sign ();
  virtual jboolean verify (::java::lang::Object *);
  virtual ::java::lang::Object *clone ();
private:
  ::java::security::interfaces::RSAPublicKey * __attribute__((aligned(__alignof__( ::java::lang::Object )))) pubkey;
  ::java::security::interfaces::RSAPrivateKey *privkey;
  ::gnu::java::security::hash::IMessageDigest *md5;
  ::gnu::java::security::hash::IMessageDigest *sha;
  jboolean initVerify;
  jboolean initSign;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_SSLRSASignature__ */
