// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_openmbean_TabularData__
#define __javax_management_openmbean_TabularData__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      namespace openmbean
      {
        class TabularData;
        class TabularType;
        class CompositeData;
      }
    }
  }
}

class javax::management::openmbean::TabularData : public ::java::lang::Object
{
public:
  virtual JArray< ::java::lang::Object *> *calculateIndex (::javax::management::openmbean::CompositeData *) = 0;
  virtual void clear () = 0;
  virtual jboolean containsKey (JArray< ::java::lang::Object *> *) = 0;
  virtual jboolean containsValue (::javax::management::openmbean::CompositeData *) = 0;
  virtual jboolean equals (::java::lang::Object *) = 0;
  virtual ::javax::management::openmbean::CompositeData *get (JArray< ::java::lang::Object *> *) = 0;
  virtual ::javax::management::openmbean::TabularType *getTabularType () = 0;
  virtual jint hashCode () = 0;
  virtual jboolean isEmpty () = 0;
  virtual ::java::util::Set *keySet () = 0;
  virtual void put (::javax::management::openmbean::CompositeData *) = 0;
  virtual void putAll (JArray< ::javax::management::openmbean::CompositeData *> *) = 0;
  virtual ::javax::management::openmbean::CompositeData *remove (JArray< ::java::lang::Object *> *) = 0;
  virtual jint size () = 0;
  virtual ::java::lang::String *toString () = 0;
  virtual ::java::util::Collection *values () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_management_openmbean_TabularData__ */
