// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_rtf_RTFEditorKit__
#define __javax_swing_text_rtf_RTFEditorKit__

#pragma interface

#include <javax/swing/text/StyledEditorKit.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace rtf
        {
          class RTFEditorKit;
        }
        class Document;
      }
    }
  }
}

class javax::swing::text::rtf::RTFEditorKit : public ::javax::swing::text::StyledEditorKit
{
public:
  RTFEditorKit ();
  virtual ::java::lang::String *getContentType ();
  virtual void read (::java::io::InputStream *, ::javax::swing::text::Document *, jint);
  virtual void read (::java::io::Reader *, ::javax::swing::text::Document *, jint);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_rtf_RTFEditorKit__ */
