// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_BRView__
#define __javax_swing_text_html_BRView__

#pragma interface

#include <javax/swing/text/html/NullView.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class BRView;
        }
        class Element;
      }
    }
  }
}

class javax::swing::text::html::BRView : public ::javax::swing::text::html::NullView
{
public:
  BRView (::javax::swing::text::Element *);
  virtual jint getBreakWeight (jint, jfloat, jfloat);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_BRView__ */
