// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_management_RuntimeMXBeanImpl__
#define __gnu_java_lang_management_RuntimeMXBeanImpl__

#pragma interface

#include <gnu/java/lang/management/BeanImpl.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        namespace management
        {
          class RuntimeMXBeanImpl;
        }
      }
    }
  }
}

class gnu::java::lang::management::RuntimeMXBeanImpl : public ::gnu::java::lang::management::BeanImpl
{
public:
  RuntimeMXBeanImpl ();
  virtual ::java::lang::String *getBootClassPath ();
  virtual ::java::lang::String *getClassPath ();
  virtual ::java::util::List *getInputArguments ();
  virtual ::java::lang::String *getLibraryPath ();
  virtual ::java::lang::String *getManagementSpecVersion ();
  virtual ::java::lang::String *getName ();
  virtual ::java::lang::String *getSpecName ();
  virtual ::java::lang::String *getSpecVendor ();
  virtual ::java::lang::String *getSpecVersion ();
  virtual jlong getStartTime ();
  virtual ::java::util::Map *getSystemProperties ();
  virtual jlong getUptime ();
  virtual ::java::lang::String *getVmName ();
  virtual ::java::lang::String *getVmVendor ();
  virtual ::java::lang::String *getVmVersion ();
  virtual jboolean isBootClassPathSupported ();
private:
  static ::java::lang::String *SUN_BOOT_CLASS_PATH;
  static ::java::lang::String *JAVA_BOOT_CLASS_PATH;
  jlong __attribute__((aligned(__alignof__( ::gnu::java::lang::management::BeanImpl ))))  startTime;
  ::java::lang::String *bootClassPath;
  jboolean bootClassPathSupported;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_lang_management_RuntimeMXBeanImpl__ */
