// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_CupsMediaMapping__
#define __gnu_javax_print_CupsMediaMapping__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        class CupsMediaMapping;
      }
    }
  }
}

class gnu::javax::print::CupsMediaMapping : public ::java::lang::Object
{
public:
  static ::java::lang::String *getIppName (::java::lang::String *);
  static ::java::util::Map *getMappingMap ();
private:
  CupsMediaMapping ();
  static ::java::util::HashMap *ippByCups;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_CupsMediaMapping__ */
