// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_sig_rsa_EMSA_PSS__
#define __gnu_java_security_sig_rsa_EMSA_PSS__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace sig
        {
          namespace rsa
          {
            class EMSA_PSS;
          }
        }
        namespace hash
        {
          class IMessageDigest;
        }
      }
    }
  }
}

class gnu::java::security::sig::rsa::EMSA_PSS : public ::java::lang::Object
{
private:
  EMSA_PSS (::gnu::java::security::hash::IMessageDigest *);
public:
  static ::gnu::java::security::sig::rsa::EMSA_PSS *getInstance (::java::lang::String *);
  virtual ::java::lang::Object *clone ();
  virtual jbyteArray encode (jbyteArray, jint, jbyteArray);
  virtual jboolean decode (jbyteArray, jbyteArray, jint, jint);
private:
  jbyteArray MGF (jbyteArray, jint);
  static ::java::util::logging::Logger *log;
  ::gnu::java::security::hash::IMessageDigest * __attribute__((aligned(__alignof__( ::java::lang::Object )))) hash;
  jint hLen;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_sig_rsa_EMSA_PSS__ */
