// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_StreamPrintService__
#define __javax_print_StreamPrintService__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class StreamPrintService;
    }
  }
}

class javax::print::StreamPrintService : public ::java::lang::Object
{
public:  // actually protected
  StreamPrintService (::java::io::OutputStream *);
public:
  virtual void dispose ();
  virtual ::java::lang::String *getOutputFormat () = 0;
  virtual ::java::io::OutputStream *getOutputStream () { return out; }
  virtual jboolean isDisposed () { return disposed; }
private:
  jboolean __attribute__((aligned(__alignof__( ::java::lang::Object ))))  disposed;
  ::java::io::OutputStream *out;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_StreamPrintService__ */
