// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_login_FailedLoginException__
#define __javax_security_auth_login_FailedLoginException__

#pragma interface

#include <javax/security/auth/login/LoginException.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace login
        {
          class FailedLoginException;
        }
      }
    }
  }
}

class javax::security::auth::login::FailedLoginException : public ::javax::security::auth::login::LoginException
{
public:
  FailedLoginException ();
  FailedLoginException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 802556922354616286LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_login_FailedLoginException__ */
