// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_rtf_RTFParseException__
#define __javax_swing_text_rtf_RTFParseException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace rtf
        {
          class RTFParseException;
        }
      }
    }
  }
}

class javax::swing::text::rtf::RTFParseException : public ::java::lang::RuntimeException
{
public:
  RTFParseException ();
  RTFParseException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_rtf_RTFParseException__ */
