// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_UUID__
#define __java_util_UUID__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::util::UUID : public ::java::lang::Object
{
public:
  UUID (jlong, jlong);
  virtual jint clockSequence ();
  virtual jint compareTo (::java::lang::Object *);
  virtual jint compareTo (::java::util::UUID *);
  virtual jboolean equals (::java::lang::Object *);
  static ::java::util::UUID *fromString (::java::lang::String *);
  virtual ::java::lang::String *toString ();
  virtual jlong getLeastSignificantBits () { return leastSigBits; }
  virtual jlong getMostSignificantBits () { return mostSigBits; }
  virtual jint hashCode ();
  static ::java::util::UUID *nameUUIDFromBytes (jbyteArray);
  virtual jlong node ();
  virtual jlong timestamp ();
  static ::java::util::UUID *randomUUID ();
private:
  ::java::lang::String *padHex (jlong, jint);
public:
  virtual jint variant ();
  virtual jint version ();
private:
  static const jlong serialVersionUID = -4856846361193249489LL;
  jlong __attribute__((aligned(__alignof__( ::java::lang::Object ))))  mostSigBits;
  jlong leastSigBits;
  static ::java::util::Random *r;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_UUID__ */
