// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_ClosedByInterruptException__
#define __java_nio_channels_ClosedByInterruptException__

#pragma interface

#include <java/nio/channels/AsynchronousCloseException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class ClosedByInterruptException;
      }
    }
  }
}

class java::nio::channels::ClosedByInterruptException : public ::java::nio::channels::AsynchronousCloseException
{
public:
  ClosedByInterruptException ();
private:
  static const jlong serialVersionUID = -4488191543534286750LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_channels_ClosedByInterruptException__ */
