// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_ImageCapabilities__
#define __java_awt_ImageCapabilities__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class ImageCapabilities;
    }
  }
}

class java::awt::ImageCapabilities : public ::java::lang::Object
{
public:
  ImageCapabilities (jboolean);
  virtual jboolean isAccelerated () { return accelerated; }
  virtual jboolean isTrueVolatile ();
  virtual ::java::lang::Object *clone ();
private:
  jboolean __attribute__((aligned(__alignof__( ::java::lang::Object ))))  accelerated;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_ImageCapabilities__ */
