// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_mac_OMacImpl__
#define __gnu_javax_crypto_jce_mac_OMacImpl__

#pragma interface

#include <gnu/javax/crypto/jce/mac/MacAdapter.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace mac
          {
            class OMacImpl;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::mac::OMacImpl : public ::gnu::javax::crypto::jce::mac::MacAdapter
{
public:  // actually protected
  OMacImpl (::java::lang::String *);

  friend class gnu_javax_crypto_jce_mac_OMacImpl$Twofish;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$TripleDES;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Square;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Serpent;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Rijndael;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Khazad;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$DES;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Cast5;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Blowfish;
  friend class gnu_javax_crypto_jce_mac_OMacImpl$Anubis;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_mac_OMacImpl__ */
