// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_SaslEncodingException__
#define __gnu_javax_crypto_sasl_SaslEncodingException__

#pragma interface

#include <javax/security/sasl/SaslException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          class SaslEncodingException;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::SaslEncodingException : public ::javax::security::sasl::SaslException
{
public:
  SaslEncodingException ();
  SaslEncodingException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_SaslEncodingException__ */
