// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_util_VariableTable__
#define __gnu_classpath_jdwp_util_VariableTable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        namespace util
        {
          class VariableTable;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::util::VariableTable : public ::java::lang::Object
{
public:
  VariableTable (jint, jint, jlongArray, JArray< ::java::lang::String *> *, JArray< ::java::lang::String *> *, jintArray, jintArray);
  virtual void write (::java::io::DataOutputStream *);
private:
  jlong __attribute__((aligned(__alignof__( ::java::lang::Object ))))  argCnt;
  jlong slots;
  jlongArray lineCI;
  jintArray slot;
  jintArray lengths;
  JArray< ::java::lang::String *> *sigs;
  JArray< ::java::lang::String *> *names;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_util_VariableTable__ */
