// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_srp_KDF__
#define __gnu_javax_crypto_sasl_srp_KDF__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace srp
          {
            class KDF;
          }
        }
        namespace prng
        {
          class UMacGenerator;
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class PRNG;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::srp::KDF : public ::java::lang::Object
{
private:
  KDF (jbyteArray, jint);
public: // actually package-private
  static ::gnu::javax::crypto::sasl::srp::KDF *getInstance (jbyteArray);
private:
  static jint nextByte ();
public:
  virtual jbyteArray derive (jint);
private:
  static const jint AES_BLOCK_SIZE = 16L;
  static const jint AES_KEY_SIZE = 16L;
  static jbyteArray buffer;
  static ::gnu::java::security::util::PRNG *prng;
  ::gnu::javax::crypto::prng::UMacGenerator * __attribute__((aligned(__alignof__( ::java::lang::Object )))) umac;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_srp_KDF__ */
