// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_directory_BasicAttribute__
#define __javax_naming_directory_BasicAttribute__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace directory
      {
        class BasicAttribute;
        class DirContext;
      }
      class NamingEnumeration;
    }
  }
}

class javax::naming::directory::BasicAttribute : public ::java::lang::Object
{
private:
  BasicAttribute ();
public:
  BasicAttribute (::java::lang::String *);
  BasicAttribute (::java::lang::String *, jboolean);
  BasicAttribute (::java::lang::String *, ::java::lang::Object *);
  BasicAttribute (::java::lang::String *, ::java::lang::Object *, jboolean);
  virtual void add (jint, ::java::lang::Object *);
  virtual jboolean add (::java::lang::Object *);
  virtual void clear ();
  virtual ::java::lang::Object *clone ();
  virtual jboolean contains (::java::lang::Object *);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::Object *get ();
  virtual ::java::lang::Object *get (jint);
  virtual ::javax::naming::NamingEnumeration *getAll ();
  virtual ::javax::naming::directory::DirContext *getAttributeDefinition ();
  virtual ::javax::naming::directory::DirContext *getAttributeSyntaxDefinition ();
  virtual ::java::lang::String *getID () { return attrID; }
  virtual jint hashCode ();
  virtual jboolean isOrdered () { return ordered; }
  virtual ::java::lang::Object *remove (jint);
  virtual jboolean remove (::java::lang::Object *);
  virtual ::java::lang::Object *set (jint, ::java::lang::Object *);
  virtual jint size ();
  virtual ::java::lang::String *toString ();
private:
  jboolean equals (::java::lang::Object *, ::java::lang::Object *);
  void readObject (::java::io::ObjectInputStream *);
  void writeObject (::java::io::ObjectOutputStream *);
  static const jlong serialVersionUID = 6743528196119291326LL;
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) attrID;
  jboolean ordered;
  ::java::util::Vector *values;

  friend class javax_naming_directory_BasicAttribute$BasicAttributeEnumeration;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_directory_BasicAttribute__ */
