// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_spec_PBEKeySpec__
#define __javax_crypto_spec_PBEKeySpec__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      namespace spec
      {
        class PBEKeySpec;
      }
    }
  }
}

class javax::crypto::spec::PBEKeySpec : public ::java::lang::Object
{
public:
  PBEKeySpec (jcharArray);
  PBEKeySpec (jcharArray, jbyteArray, jint);
  PBEKeySpec (jcharArray, jbyteArray, jint, jint);
  virtual void clearPassword ();
  virtual jint getIterationCount () { return iterationCount; }
  virtual jint getKeyLength () { return keyLength; }
  virtual jcharArray getPassword ();
  virtual jbyteArray getSalt ();
private:
  void setPassword (jcharArray);
  void setSalt (jbyteArray);
  void setIterationCount (jint);
  void setKeyLength (jint);
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  iterationCount;
  jint keyLength;
  jcharArray password;
  jbyteArray salt;
  jboolean passwordValid;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_spec_PBEKeySpec__ */
