// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_ListSelectionEvent__
#define __javax_swing_event_ListSelectionEvent__

#pragma interface

#include <java/util/EventObject.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class ListSelectionEvent;
      }
    }
  }
}

class javax::swing::event::ListSelectionEvent : public ::java::util::EventObject
{
public:
  ListSelectionEvent (::java::lang::Object *, jint, jint, jboolean);
  virtual jint getFirstIndex () { return firstIndex; }
  virtual jint getLastIndex () { return lastIndex; }
  virtual jboolean getValueIsAdjusting () { return isAdjusting; }
  virtual ::java::lang::String *toString ();
private:
  jint __attribute__((aligned(__alignof__( ::java::util::EventObject ))))  firstIndex;
  jint lastIndex;
  jboolean isAdjusting;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_ListSelectionEvent__ */
