// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppMultiDocPrintService__
#define __gnu_javax_print_ipp_IppMultiDocPrintService__

#pragma interface

#include <gnu/javax/print/ipp/IppPrintService.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          class IppMultiDocPrintService;
        }
      }
    }
  }
  namespace javax
  {
    namespace print
    {
      class MultiDocPrintJob;
    }
  }
  namespace java
  {
    namespace net
    {
      class URI;
    }
  }
}

class gnu::javax::print::ipp::IppMultiDocPrintService : public ::gnu::javax::print::ipp::IppPrintService
{
public:
  IppMultiDocPrintService (::java::net::URI *, ::java::lang::String *, ::java::lang::String *);
  virtual ::javax::print::MultiDocPrintJob *createMultiDocPrintJob ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::gnu::javax::print::ipp::IppPrintService )))) user;
  ::java::lang::String *passwd;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_IppMultiDocPrintService__ */
