// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_reflect_Modifier__
#define __java_lang_reflect_Modifier__

#pragma interface

#include <java/lang/Object.h>

class java::lang::reflect::Modifier : public ::java::lang::Object
{
public:
  Modifier ();
  static jboolean isAbstract (jint);
  static jboolean isFinal (jint);
  static jboolean isInterface (jint);
  static jboolean isNative (jint);
  static jboolean isPrivate (jint);
  static jboolean isProtected (jint);
  static jboolean isPublic (jint);
  static jboolean isStatic (jint);
  static jboolean isStrict (jint);
  static jboolean isSynchronized (jint);
  static jboolean isTransient (jint);
  static jboolean isVolatile (jint);
  static ::java::lang::String *toString (jint);
public: // actually package-private
  static ::java::lang::StringBuilder *toString (jint, ::java::lang::StringBuilder *);
  static ::java::lang::StringBuffer *toString (jint, ::java::lang::StringBuffer *);
public:
  static const jint PUBLIC = 1L;
  static const jint PRIVATE = 2L;
  static const jint PROTECTED = 4L;
  static const jint STATIC = 8L;
  static const jint FINAL = 16L;
  static const jint SYNCHRONIZED = 32L;
  static const jint VOLATILE = 64L;
  static const jint TRANSIENT = 128L;
  static const jint NATIVE = 256L;
  static const jint INTERFACE = 512L;
  static const jint ABSTRACT = 1024L;
  static const jint STRICT = 2048L;
public: // actually package-private
  static const jint SUPER = 32L;
  static const jint ALL_FLAGS = 4095L;
  static const jint BRIDGE = 64L;
  static const jint VARARGS = 128L;
  static const jint SYNTHETIC = 4096L;
  static const jint ENUM = 16384L;
  static const jint INVISIBLE = 32768L;
  static const jint INTERPRETED = 4096L;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_reflect_Modifier__ */
