// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicHTML__
#define __javax_swing_plaf_basic_BasicHTML__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class BasicHTML;
        }
      }
      namespace text
      {
        class View;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::basic::BasicHTML : public ::java::lang::Object
{
public:
  BasicHTML ();
  static ::javax::swing::text::View *createHTMLView (::javax::swing::JComponent *, ::java::lang::String *);
  static jboolean isHTMLString (::java::lang::String *);
  static void updateRenderer (::javax::swing::JComponent *, ::java::lang::String *);
  static ::java::lang::String *propertyKey;
  static ::java::lang::String *documentBaseKey;

  friend class javax_swing_plaf_basic_BasicHTML$HTMLRootView;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicHTML__ */
