// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_pad_WrongPaddingException__
#define __gnu_javax_crypto_pad_WrongPaddingException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace pad
        {
          class WrongPaddingException;
        }
      }
    }
  }
}

class gnu::javax::crypto::pad::WrongPaddingException : public ::java::lang::Exception
{
public:
  WrongPaddingException ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_pad_WrongPaddingException__ */
