// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_datatransfer_FlavorEvent__
#define __java_awt_datatransfer_FlavorEvent__

#pragma interface

#include <java/util/EventObject.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace datatransfer
      {
        class FlavorEvent;
        class Clipboard;
      }
    }
  }
}

class java::awt::datatransfer::FlavorEvent : public ::java::util::EventObject
{
public:
  FlavorEvent (::java::awt::datatransfer::Clipboard *);

  static ::java::lang::Class class$;
};

#endif /* __java_awt_datatransfer_FlavorEvent__ */
