// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_datatransfer_UnsupportedFlavorException__
#define __java_awt_datatransfer_UnsupportedFlavorException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace datatransfer
      {
        class UnsupportedFlavorException;
        class DataFlavor;
      }
    }
  }
}

class java::awt::datatransfer::UnsupportedFlavorException : public ::java::lang::Exception
{
public:
  UnsupportedFlavorException (::java::awt::datatransfer::DataFlavor *);
private:
  static const jlong serialVersionUID = 5383814944251665601LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_datatransfer_UnsupportedFlavorException__ */
