// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_png_PNGFilter__
#define __gnu_javax_imageio_png_PNGFilter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace png
        {
          class PNGFilter;
          class PNGHeader;
        }
      }
    }
  }
}

class gnu::javax::imageio::png::PNGFilter : public ::java::lang::Object
{
public:
  static jboolean useFilter (::gnu::javax::imageio::png::PNGHeader *);
  static jbyte chooseFilter (jbyteArray, jbyteArray, jint);
  static jbyteArray filterScanline (jbyte, jbyteArray, jbyteArray, jint);
  static jbyteArray unFilterScanline (jint, jbyteArray, jbyteArray, jint);
  PNGFilter ();
  static const jint FILTER_NONE = 0L;
  static const jint FILTER_SUB = 1L;
  static const jint FILTER_UP = 2L;
  static const jint FILTER_AVERAGE = 3L;
  static const jint FILTER_PAETH = 4L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_png_PNGFilter__ */
