// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_FormatterClosedException__
#define __java_util_FormatterClosedException__

#pragma interface

#include <java/lang/IllegalStateException.h>

class java::util::FormatterClosedException : public ::java::lang::IllegalStateException
{
public:
  FormatterClosedException ();
private:
  static const jlong serialVersionUID = 18111216LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_FormatterClosedException__ */
