// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_FlavorException__
#define __javax_print_FlavorException__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class FlavorException;
      class DocFlavor;
    }
  }
}

class javax::print::FlavorException : public ::java::lang::Object
{
public:
  virtual JArray< ::javax::print::DocFlavor *> *getUnsupportedFlavors () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_print_FlavorException__ */
