// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalScrollBarUI__
#define __javax_swing_plaf_metal_MetalScrollBarUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicScrollBarUI.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JButton;
      class JComponent;
      namespace plaf
      {
        class ComponentUI;
        namespace metal
        {
          class MetalScrollBarUI;
          class MetalScrollButton;
        }
      }
    }
  }
  namespace java
  {
    namespace beans
    {
      class PropertyChangeListener;
    }
    namespace awt
    {
      class Rectangle;
      class Graphics;
      class Color;
      class Dimension;
    }
  }
}

class javax::swing::plaf::metal::MetalScrollBarUI : public ::javax::swing::plaf::basic::BasicScrollBarUI
{
public:
  MetalScrollBarUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual void installDefaults ();
  virtual ::java::beans::PropertyChangeListener *createPropertyChangeListener ();
  virtual ::javax::swing::JButton *createDecreaseButton (jint);
  virtual ::javax::swing::JButton *createIncreaseButton (jint);
  virtual void paintTrack (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *);
private:
  void paintTrackHorizontal (::java::awt::Graphics *, ::javax::swing::JComponent *, jint, jint, jint, jint);
  void paintTrackVertical (::java::awt::Graphics *, ::javax::swing::JComponent *, jint, jint, jint, jint);
public:  // actually protected
  virtual void paintThumb (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *);
private:
  void paintThumbHorizontal (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *);
  void paintThumbVertical (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *);
public:  // actually protected
  virtual ::java::awt::Dimension *getMinimumThumbSize ();
public:
  virtual ::java::awt::Dimension *getPreferredSize (::javax::swing::JComponent *);
  static ::java::lang::String *FREE_STANDING_PROP;
private:
  static ::java::awt::Dimension *MIN_THUMB_SIZE;
  static ::java::awt::Dimension *MIN_THUMB_SIZE_FREE_STANDING;
public:  // actually protected
  ::javax::swing::plaf::metal::MetalScrollButton * __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicScrollBarUI )))) increaseButton;
  ::javax::swing::plaf::metal::MetalScrollButton *decreaseButton;
  jint scrollBarWidth;
  jboolean isFreeStanding;
public: // actually package-private
  ::java::awt::Color *scrollBarShadowColor;

  friend class javax_swing_plaf_metal_MetalScrollBarUI$MetalScrollBarPropertyChangeHandler;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalScrollBarUI__ */
