// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_png_PNGImageReader__
#define __gnu_javax_imageio_png_PNGImageReader__

#pragma interface

#include <javax/imageio/ImageReader.h>

extern "Java"
{
  namespace javax
  {
    namespace imageio
    {
      namespace metadata
      {
        class IIOMetadata;
      }
      class ImageReadParam;
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class BufferedImage;
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace png
        {
          class PNGImageReader;
          class PNGImageReaderSpi;
          class PNGFile;
        }
      }
    }
  }
}

class gnu::javax::imageio::png::PNGImageReader : public ::javax::imageio::ImageReader
{
public:
  PNGImageReader (::gnu::javax::imageio::png::PNGImageReaderSpi *);
  virtual jint getHeight (jint);
  virtual jint getWidth (jint);
  virtual ::java::util::Iterator *getImageTypes (jint);
  virtual jint getNumImages (jboolean);
  virtual ::java::awt::image::BufferedImage *read (jint, ::javax::imageio::ImageReadParam *);
  virtual void setInput (::java::lang::Object *, jboolean, jboolean);
  virtual ::javax::imageio::metadata::IIOMetadata *getImageMetadata (jint);
  virtual ::javax::imageio::metadata::IIOMetadata *getStreamMetadata () { return 0; }
private:
  void checkIndex (jint);
  void readImage ();
  ::gnu::javax::imageio::png::PNGFile * __attribute__((aligned(__alignof__( ::javax::imageio::ImageReader )))) pngFile;
  ::java::awt::image::BufferedImage *image;
  ::java::util::ArrayList *imageTypes;
  static jboolean $assertionsDisabled;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_png_PNGImageReader__ */
