// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_VMFrame__
#define __gnu_classpath_jdwp_VMFrame__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        class VMFrame;
        namespace util
        {
          class Location;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::VMFrame : public ::java::lang::Object
{
public:
  virtual ::gnu::classpath::jdwp::util::Location *getLocation () { return loc; }
  virtual ::java::lang::Object *getValue (jint);
  virtual void setValue (jint, ::java::lang::Object *);
  virtual ::java::lang::Object *getObject () { return obj; }
  virtual jlong getId () { return id; }
  VMFrame ();
  static const jint SIZE = 8L;
private:
  ::java::lang::Object * __attribute__((aligned(__alignof__( ::java::lang::Object )))) obj;
  ::gnu::classpath::jdwp::util::Location *loc;
  jlong id;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_VMFrame__ */
