// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_Checksum__
#define __java_util_zip_Checksum__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::util::zip::Checksum : public ::java::lang::Object
{
public:
  virtual jlong getValue () = 0;
  virtual void reset () = 0;
  virtual void update (jint) = 0;
  virtual void update (jbyteArray, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_zip_Checksum__ */
