// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_VMPipe__
#define __gnu_java_nio_VMPipe__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        namespace spi
        {
          class SelectorProvider;
        }
      }
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        class VMPipe;
        class PipeImpl;
      }
    }
  }
}

class gnu::java::nio::VMPipe : public ::java::lang::Object
{
public: // actually package-private
  static void init (::gnu::java::nio::PipeImpl *, ::java::nio::channels::spi::SelectorProvider *);
  VMPipe ();
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_VMPipe__ */
