// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_TreeSelectionEvent__
#define __javax_swing_event_TreeSelectionEvent__

#pragma interface

#include <java/util/EventObject.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class TreeSelectionEvent;
      }
      namespace tree
      {
        class TreePath;
      }
    }
  }
}

class javax::swing::event::TreeSelectionEvent : public ::java::util::EventObject
{
public:
  TreeSelectionEvent (::java::lang::Object *, JArray< ::javax::swing::tree::TreePath *> *, jbooleanArray, ::javax::swing::tree::TreePath *, ::javax::swing::tree::TreePath *);
  TreeSelectionEvent (::java::lang::Object *, ::javax::swing::tree::TreePath *, jboolean, ::javax::swing::tree::TreePath *, ::javax::swing::tree::TreePath *);
  virtual ::javax::swing::tree::TreePath *getPath ();
  virtual JArray< ::javax::swing::tree::TreePath *> *getPaths ();
  virtual jboolean isAddedPath ();
  virtual jboolean isAddedPath (::javax::swing::tree::TreePath *);
  virtual jboolean isAddedPath (jint);
  virtual ::javax::swing::tree::TreePath *getOldLeadSelectionPath () { return oldLeadSelectionPath; }
  virtual ::javax::swing::tree::TreePath *getNewLeadSelectionPath () { return newLeadSelectionPath; }
  virtual ::java::lang::Object *cloneWithSource (::java::lang::Object *);
public:  // actually protected
  JArray< ::javax::swing::tree::TreePath *> * __attribute__((aligned(__alignof__( ::java::util::EventObject )))) paths;
  jbooleanArray areNew;
  ::javax::swing::tree::TreePath *oldLeadSelectionPath;
  ::javax::swing::tree::TreePath *newLeadSelectionPath;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_TreeSelectionEvent__ */
