// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_SocketOptions__
#define __java_net_SocketOptions__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class SocketOptions;
    }
  }
}

class java::net::SocketOptions : public ::java::lang::Object
{
public:
  virtual void setOption (jint, ::java::lang::Object *) = 0;
  virtual ::java::lang::Object *getOption (jint) = 0;
  static const jint SO_KEEPALIVE = 8L;
  static const jint SO_LINGER = 128L;
  static const jint SO_TIMEOUT = 4102L;
  static const jint SO_BINDADDR = 15L;
  static const jint SO_SNDBUF = 4097L;
  static const jint SO_RCVBUF = 4098L;
  static const jint SO_REUSEADDR = 4L;
  static const jint SO_BROADCAST = 32L;
  static const jint SO_OOBINLINE = 4099L;
  static const jint TCP_NODELAY = 1L;
  static const jint IP_MULTICAST_IF = 16L;
  static const jint IP_MULTICAST_IF2 = 31L;
  static const jint IP_MULTICAST_LOOP = 18L;
  static const jint IP_TOS = 3L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_net_SocketOptions__ */
