// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_reflect_ReflectPermission__
#define __java_lang_reflect_ReflectPermission__

#pragma interface

#include <java/security/BasicPermission.h>

class java::lang::reflect::ReflectPermission : public ::java::security::BasicPermission
{
public:
  ReflectPermission (::java::lang::String *);
  ReflectPermission (::java::lang::String *, ::java::lang::String *);
private:
  static const jlong serialVersionUID = 7412737110241507485LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_reflect_ReflectPermission__ */
