// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_TabSet__
#define __javax_swing_text_TabSet__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class TabSet;
        class TabStop;
      }
    }
  }
}

class javax::swing::text::TabSet : public ::java::lang::Object
{
public:
  TabSet (JArray< ::javax::swing::text::TabStop *> *);
  virtual ::javax::swing::text::TabStop *getTab (jint);
  virtual ::javax::swing::text::TabStop *getTabAfter (jfloat);
  virtual jint getTabCount ();
  virtual jint getTabIndex (::javax::swing::text::TabStop *);
  virtual jint getTabIndexAfter (jfloat);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = 2367703481999080593LL;
public: // actually package-private
  JArray< ::javax::swing::text::TabStop *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) tabs;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_TabSet__ */
