// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_TextSyntax__
#define __javax_print_attribute_TextSyntax__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class TextSyntax;
      }
    }
  }
}

class javax::print::attribute::TextSyntax : public ::java::lang::Object
{
public:  // actually protected
  TextSyntax (::java::lang::String *, ::java::util::Locale *);
public:
  virtual ::java::lang::String *getValue () { return value; }
  virtual ::java::util::Locale *getLocale () { return locale; }
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = -8130648736378144102LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) value;
  ::java::util::Locale *locale;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_TextSyntax__ */
