// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_CertificateRequest__
#define __gnu_javax_net_ssl_provider_CertificateRequest__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class Principal;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class CertificateRequest;
            class CertificateRequest$ClientType;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::CertificateRequest : public ::java::lang::Object
{
public: // actually package-private
  CertificateRequest (JArray< ::gnu::javax::net::ssl::provider::CertificateRequest$ClientType *> *, JArray< ::java::security::Principal *> *);
  static ::gnu::javax::net::ssl::provider::CertificateRequest *read (::java::io::InputStream *);
public:
  virtual void write (::java::io::OutputStream *);
public: // actually package-private
  virtual JArray< ::gnu::javax::net::ssl::provider::CertificateRequest$ClientType *> *getTypes () { return types; }
  virtual JArray< ::java::lang::String *> *getTypeStrings ();
  virtual JArray< ::java::security::Principal *> *getAuthorities () { return authorities; }
public:
  virtual ::java::lang::String *toString ();
private:
  JArray< ::gnu::javax::net::ssl::provider::CertificateRequest$ClientType *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) types;
  JArray< ::java::security::Principal *> *authorities;

  friend class gnu_javax_net_ssl_provider_CertificateRequest$ClientType;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_CertificateRequest__ */
