// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_hash_Whirlpool__
#define __gnu_java_security_hash_Whirlpool__

#pragma interface

#include <gnu/java/security/hash/BaseHash.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace hash
        {
          class Whirlpool;
        }
      }
    }
  }
}

class gnu::java::security::hash::Whirlpool : public ::gnu::java::security::hash::BaseHash
{
public:
  Whirlpool ();
private:
  Whirlpool (::gnu::java::security::hash::Whirlpool *);
public:
  virtual ::java::lang::Object *clone ();
public:  // actually protected
  virtual void transform (jbyteArray, jint);
  virtual jbyteArray padBuffer ();
  virtual jbyteArray getResult ();
  virtual void resetContext ();
public:
  virtual jboolean selfTest ();
private:
  static ::java::util::logging::Logger *log;
  static const jint BLOCK_SIZE = 64L;
  static ::java::lang::String *DIGEST0;
  static const jint R = 10L;
  static ::java::lang::String *S_box;
  static jlongArray T0;
  static jlongArray T1;
  static jlongArray T2;
  static jlongArray T3;
  static jlongArray T4;
  static jlongArray T5;
  static jlongArray T6;
  static jlongArray T7;
  static jlongArray rc;
  static ::java::lang::Boolean *valid;
  jlong __attribute__((aligned(__alignof__( ::gnu::java::security::hash::BaseHash ))))  H0;
  jlong H1;
  jlong H2;
  jlong H3;
  jlong H4;
  jlong H5;
  jlong H6;
  jlong H7;
  jlong k00;
  jlong k01;
  jlong k02;
  jlong k03;
  jlong k04;
  jlong k05;
  jlong k06;
  jlong k07;
  jlong Kr0;
  jlong Kr1;
  jlong Kr2;
  jlong Kr3;
  jlong Kr4;
  jlong Kr5;
  jlong Kr6;
  jlong Kr7;
  jlong n0;
  jlong n1;
  jlong n2;
  jlong n3;
  jlong n4;
  jlong n5;
  jlong n6;
  jlong n7;
  jlong nn0;
  jlong nn1;
  jlong nn2;
  jlong nn3;
  jlong nn4;
  jlong nn5;
  jlong nn6;
  jlong nn7;
  jlong w0;
  jlong w1;
  jlong w2;
  jlong w3;
  jlong w4;
  jlong w5;
  jlong w6;
  jlong w7;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_hash_Whirlpool__ */
