// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_parser_Entity__
#define __javax_swing_text_html_parser_Entity__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          namespace parser
          {
            class Entity;
          }
        }
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                class gnuStringIntMapper;
              }
            }
          }
        }
      }
    }
  }
}

class javax::swing::text::html::parser::Entity : public ::java::lang::Object
{
public:
  Entity (::java::lang::String *, jint, jcharArray);
  static jint name2type (::java::lang::String *);
  virtual jcharArray getData () { return data; }
  virtual jboolean isGeneral ();
  virtual ::java::lang::String *getName () { return name; }
  virtual jboolean isParameter ();
  virtual ::java::lang::String *getString ();
  virtual jint getType () { return type; }
public: // actually package-private
  static ::gnu::javax::swing::text::html::parser::support::gnuStringIntMapper *mapper;
public:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  jcharArray data;
  jint type;
private:
  ::java::lang::String *sdata;

  friend class javax_swing_text_html_parser_Entity$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_parser_Entity__ */
