// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicButtonListener__
#define __javax_swing_plaf_basic_BasicButtonListener__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class MouseEvent;
        class FocusEvent;
      }
    }
    namespace beans
    {
      class PropertyChangeEvent;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class BasicButtonListener;
        }
      }
      namespace event
      {
        class ChangeEvent;
      }
      class JComponent;
      class AbstractButton;
    }
  }
}

class javax::swing::plaf::basic::BasicButtonListener : public ::java::lang::Object
{
public:
  BasicButtonListener (::javax::swing::AbstractButton *);
  virtual void propertyChange (::java::beans::PropertyChangeEvent *);
public:  // actually protected
  virtual void checkOpacity (::javax::swing::AbstractButton *) { }
public:
  virtual void focusGained (::java::awt::event::FocusEvent *);
  virtual void focusLost (::java::awt::event::FocusEvent *);
  virtual void installKeyboardActions (::javax::swing::JComponent *);
  virtual void uninstallKeyboardActions (::javax::swing::JComponent *);
  virtual void stateChanged (::javax::swing::event::ChangeEvent *) { }
  virtual void mouseMoved (::java::awt::event::MouseEvent *) { }
  virtual void mouseDragged (::java::awt::event::MouseEvent *) { }
  virtual void mouseClicked (::java::awt::event::MouseEvent *) { }
  virtual void mousePressed (::java::awt::event::MouseEvent *);
  virtual void mouseReleased (::java::awt::event::MouseEvent *);
  virtual void mouseEntered (::java::awt::event::MouseEvent *);
  virtual void mouseExited (::java::awt::event::MouseEvent *);

  friend class javax_swing_plaf_basic_BasicButtonListener$2;
  friend class javax_swing_plaf_basic_BasicButtonListener$1;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicButtonListener__ */
