// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_ImageViewIconFactory__
#define __gnu_javax_swing_text_html_ImageViewIconFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            class ImageViewIconFactory;
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace swing
    {
      class Icon;
    }
  }
}

class gnu::javax::swing::text::html::ImageViewIconFactory : public ::java::lang::Object
{
public:
  static ::javax::swing::Icon *getNoImageIcon ();
  static ::javax::swing::Icon *getLoadingImageIcon ();
  ImageViewIconFactory ();
private:
  static ::javax::swing::Icon *noImageIcon;
  static ::javax::swing::Icon *loadingImageIcon;

  friend class gnu_javax_swing_text_html_ImageViewIconFactory$LoadingImageIcon;
  friend class gnu_javax_swing_text_html_ImageViewIconFactory$NoImageIcon;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_ImageViewIconFactory__ */
