// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_PointerInfo__
#define __java_awt_PointerInfo__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class PointerInfo;
      class Point;
      class GraphicsDevice;
    }
  }
}

class java::awt::PointerInfo : public ::java::lang::Object
{
public: // actually package-private
  PointerInfo (::java::awt::GraphicsDevice *, ::java::awt::Point *);
public:
  virtual ::java::awt::GraphicsDevice *getDevice () { return gd; }
  virtual ::java::awt::Point *getLocation () { return p; }
private:
  ::java::awt::GraphicsDevice * __attribute__((aligned(__alignof__( ::java::lang::Object )))) gd;
  ::java::awt::Point *p;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_PointerInfo__ */
