// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_StringContent__
#define __javax_swing_text_StringContent__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace undo
      {
        class UndoableEdit;
      }
      namespace text
      {
        class StringContent;
        class Segment;
        class Position;
      }
    }
  }
}

class javax::swing::text::StringContent : public ::java::lang::Object
{
public:
  StringContent ();
  StringContent (jint);
public:  // actually protected
  virtual ::java::util::Vector *getPositionsInRange (::java::util::Vector *, jint, jint);
public:
  virtual ::javax::swing::text::Position *createPosition (jint);
  virtual jint length () { return count; }
  virtual ::javax::swing::undo::UndoableEdit *insertString (jint, ::java::lang::String *);
  virtual ::javax::swing::undo::UndoableEdit *remove (jint, jint);
  virtual ::java::lang::String *getString (jint, jint);
  virtual void getChars (jint, jint, ::javax::swing::text::Segment *);
public:  // actually protected
  virtual void updateUndoPositions (::java::util::Vector *) { }
public: // actually package-private
  virtual void checkLocation (jint, jint);
private:
  static const jlong serialVersionUID = 4755994433709540381LL;
public: // actually package-private
  jcharArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  content;
private:
  jint count;
  ::java::util::Vector *positions;

  friend class javax_swing_text_StringContent$StickyPosition;
  friend class javax_swing_text_StringContent$RemoveUndo;
  friend class javax_swing_text_StringContent$InsertUndo;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_StringContent__ */
