// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_RawData__
#define __gnu_gcj_RawData__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      class RawData;
    }
  }
}

class gnu::gcj::RawData : public ::java::lang::Object
{
private:
  RawData ();
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_RawData__ */
