// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_directory_InitialDirContext__
#define __javax_naming_directory_InitialDirContext__

#pragma interface

#include <javax/naming/InitialContext.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class NamingEnumeration;
      namespace directory
      {
        class InitialDirContext;
        class SearchControls;
        class ModificationItem;
        class Attributes;
        class DirContext;
      }
      class Name;
    }
  }
}

class javax::naming::directory::InitialDirContext : public ::javax::naming::InitialContext
{
public:
  InitialDirContext ();
public:  // actually protected
  InitialDirContext (jboolean);
public:
  InitialDirContext (::java::util::Hashtable *);
private:
  ::javax::naming::directory::DirContext *getURLOrDefaultInitDirCtx (::javax::naming::Name *);
  ::javax::naming::directory::DirContext *getURLOrDefaultInitDirCtx (::java::lang::String *);
public:
  virtual ::javax::naming::directory::Attributes *getAttributes (::java::lang::String *);
  virtual ::javax::naming::directory::Attributes *getAttributes (::java::lang::String *, JArray< ::java::lang::String *> *);
  virtual ::javax::naming::directory::Attributes *getAttributes (::javax::naming::Name *);
  virtual ::javax::naming::directory::Attributes *getAttributes (::javax::naming::Name *, JArray< ::java::lang::String *> *);
  virtual void modifyAttributes (::javax::naming::Name *, jint, ::javax::naming::directory::Attributes *);
  virtual void modifyAttributes (::java::lang::String *, jint, ::javax::naming::directory::Attributes *);
  virtual void modifyAttributes (::javax::naming::Name *, JArray< ::javax::naming::directory::ModificationItem *> *);
  virtual void modifyAttributes (::java::lang::String *, JArray< ::javax::naming::directory::ModificationItem *> *);
  virtual void bind (::javax::naming::Name *, ::java::lang::Object *, ::javax::naming::directory::Attributes *);
  virtual void bind (::java::lang::String *, ::java::lang::Object *, ::javax::naming::directory::Attributes *);
  virtual void rebind (::javax::naming::Name *, ::java::lang::Object *, ::javax::naming::directory::Attributes *);
  virtual void rebind (::java::lang::String *, ::java::lang::Object *, ::javax::naming::directory::Attributes *);
  virtual ::javax::naming::directory::DirContext *createSubcontext (::javax::naming::Name *, ::javax::naming::directory::Attributes *);
  virtual ::javax::naming::directory::DirContext *createSubcontext (::java::lang::String *, ::javax::naming::directory::Attributes *);
  virtual ::javax::naming::directory::DirContext *getSchema (::javax::naming::Name *);
  virtual ::javax::naming::directory::DirContext *getSchema (::java::lang::String *);
  virtual ::javax::naming::directory::DirContext *getSchemaClassDefinition (::javax::naming::Name *);
  virtual ::javax::naming::directory::DirContext *getSchemaClassDefinition (::java::lang::String *);
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::javax::naming::directory::Attributes *, JArray< ::java::lang::String *> *);
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::javax::naming::directory::Attributes *, JArray< ::java::lang::String *> *);
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::javax::naming::directory::Attributes *);
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::javax::naming::directory::Attributes *);
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::java::lang::String *, ::javax::naming::directory::SearchControls *);
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::java::lang::String *, ::javax::naming::directory::SearchControls *);
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::java::lang::String *, JArray< ::java::lang::Object *> *, ::javax::naming::directory::SearchControls *);
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::java::lang::String *, JArray< ::java::lang::Object *> *, ::javax::naming::directory::SearchControls *);

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_directory_InitialDirContext__ */
