// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_CellRendererPane__
#define __javax_swing_CellRendererPane__

#pragma interface

#include <java/awt/Container.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      class Container;
      class Component;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class CellRendererPane;
    }
    namespace accessibility
    {
      class AccessibleContext;
    }
  }
}

class javax::swing::CellRendererPane : public ::java::awt::Container
{
public:
  CellRendererPane ();
  virtual void update (::java::awt::Graphics *) { }
  virtual void invalidate () { }
  virtual void paint (::java::awt::Graphics *) { }
public:  // actually protected
  virtual void addImpl (::java::awt::Component *, ::java::lang::Object *, jint);
public:
  virtual void paintComponent (::java::awt::Graphics *, ::java::awt::Component *, ::java::awt::Container *, jint, jint, jint, jint, jboolean);
  virtual void paintComponent (::java::awt::Graphics *, ::java::awt::Component *, ::java::awt::Container *, jint, jint, jint, jint);
  virtual void paintComponent (::java::awt::Graphics *, ::java::awt::Component *, ::java::awt::Container *, ::java::awt::Rectangle *);
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = -7642183829532984273LL;
public:  // actually protected
  ::javax::accessibility::AccessibleContext * __attribute__((aligned(__alignof__( ::java::awt::Container )))) accessibleContext;

  friend class javax_swing_CellRendererPane$AccessibleCellRendererPane;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_CellRendererPane__ */
