// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_SRPTrustManager__
#define __gnu_javax_net_ssl_SRPTrustManager__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          class SRPTrustManager;
        }
      }
      namespace crypto
      {
        namespace sasl
        {
          namespace srp
          {
            class PasswordFile;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
    namespace security
    {
      class KeyPair;
    }
  }
}

class gnu::javax::net::ssl::SRPTrustManager : public ::java::lang::Object
{
public:
  virtual jboolean contains (::java::lang::String *) = 0;
  virtual ::java::security::KeyPair *getKeyPair (::java::lang::String *) = 0;
  virtual jbyteArray getSalt (::java::lang::String *) = 0;
  virtual ::java::math::BigInteger *getVerifier (::java::lang::String *) = 0;
  virtual ::gnu::javax::crypto::sasl::srp::PasswordFile *getPasswordFile () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_net_ssl_SRPTrustManager__ */
