// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_openmbean_CompositeDataSupport__
#define __javax_management_openmbean_CompositeDataSupport__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      namespace openmbean
      {
        class CompositeDataSupport;
        class CompositeType;
      }
    }
  }
}

class javax::management::openmbean::CompositeDataSupport : public ::java::lang::Object
{
public:
  CompositeDataSupport (::javax::management::openmbean::CompositeType *, ::java::util::Map *);
  CompositeDataSupport (::javax::management::openmbean::CompositeType *, JArray< ::java::lang::String *> *, JArray< ::java::lang::Object *> *);
  virtual jboolean containsKey (::java::lang::String *);
  virtual jboolean containsValue (::java::lang::Object *);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::Object *get (::java::lang::String *);
  virtual JArray< ::java::lang::Object *> *getAll (JArray< ::java::lang::String *> *);
  virtual ::javax::management::openmbean::CompositeType *getCompositeType () { return compositeType; }
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
  virtual ::java::util::Collection *values ();
private:
  static const jlong serialVersionUID = 8003518976613702244LL;
  ::java::util::SortedMap * __attribute__((aligned(__alignof__( ::java::lang::Object )))) contents;
  ::javax::management::openmbean::CompositeType *compositeType;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_openmbean_CompositeDataSupport__ */
