// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_CharacterAttributeTranslator__
#define __gnu_javax_swing_text_html_CharacterAttributeTranslator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            class CharacterAttributeTranslator;
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class HTML$Tag;
        }
        class MutableAttributeSet;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Color;
    }
  }
}

class gnu::javax::swing::text::html::CharacterAttributeTranslator : public ::java::lang::Object
{
public:
  static ::java::awt::Color *getColor (::java::lang::String *);
  static jboolean translateTag (::javax::swing::text::MutableAttributeSet *, ::javax::swing::text::html::HTML$Tag *, ::javax::swing::text::MutableAttributeSet *);
  CharacterAttributeTranslator ();
private:
  static ::java::util::HashMap *colorMap;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_CharacterAttributeTranslator__ */
