// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_sasl_SaslException__
#define __javax_security_sasl_SaslException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace sasl
      {
        class SaslException;
      }
    }
  }
}

class javax::security::sasl::SaslException : public ::java::io::IOException
{
public:
  SaslException ();
  SaslException (::java::lang::String *);
  SaslException (::java::lang::String *, ::java::lang::Throwable *);
  virtual ::java::lang::Throwable *getCause () { return _exception; }
  virtual void printStackTrace ();
  virtual void printStackTrace (::java::io::PrintStream *);
  virtual void printStackTrace (::java::io::PrintWriter *);
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = 4579784287983423626LL;
  ::java::lang::Throwable * __attribute__((aligned(__alignof__( ::java::io::IOException )))) _exception;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_sasl_SaslException__ */
