// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_prefs_EventDispatcher__
#define __gnu_java_util_prefs_EventDispatcher__

#pragma interface

#include <java/lang/Thread.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace prefs
        {
          class EventDispatcher;
        }
      }
    }
  }
}

class gnu::java::util::prefs::EventDispatcher : public ::java::lang::Thread
{
private:
  EventDispatcher ();
public:
  virtual void run ();
  static void dispatch (::java::lang::Runnable *);
private:
  static ::java::lang::Thread *dispatchThread;
  static ::java::util::ArrayList *queue;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_prefs_EventDispatcher__ */
