// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_kwa_KeyUnwrappingException__
#define __gnu_javax_crypto_kwa_KeyUnwrappingException__

#pragma interface

#include <java/security/GeneralSecurityException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace kwa
        {
          class KeyUnwrappingException;
        }
      }
    }
  }
}

class gnu::javax::crypto::kwa::KeyUnwrappingException : public ::java::security::GeneralSecurityException
{
public:
  KeyUnwrappingException ();
  KeyUnwrappingException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_kwa_KeyUnwrappingException__ */
