// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_SessionContext__
#define __gnu_javax_net_ssl_provider_SessionContext__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class SessionContext;
            class Session;
            class Session$ID;
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class SSLSession;
      }
    }
  }
}

class gnu::javax::net::ssl::provider::SessionContext : public ::java::lang::Object
{
public: // actually package-private
  SessionContext ();
public:
  virtual ::java::util::Enumeration *getIds ();
  virtual ::javax::net::ssl::SSLSession *getSession (jbyteArray);
  virtual jint getSessionCacheSize () { return cacheSize; }
  virtual void setSessionCacheSize (jint);
  virtual jint getSessionTimeout () { return timeout; }
  virtual void setSessionTimeout (jint);
  virtual ::java::lang::String *toString ();
public: // actually package-private
  virtual jboolean addSession (::gnu::javax::net::ssl::provider::Session$ID *, ::gnu::javax::net::ssl::provider::Session *);
  virtual jboolean containsSessionID (::gnu::javax::net::ssl::provider::Session$ID *);
  virtual jboolean removeSession (::gnu::javax::net::ssl::provider::Session$ID *);
  virtual void notifyAccess (::gnu::javax::net::ssl::provider::Session *) { }
public:  // actually protected
  ::java::util::HashMap * __attribute__((aligned(__alignof__( ::java::lang::Object )))) sessions;
  jint cacheSize;
  jint timeout;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_SessionContext__ */
