// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_colorchooser_DefaultSwatchChooserPanel__
#define __javax_swing_colorchooser_DefaultSwatchChooserPanel__

#pragma interface

#include <javax/swing/colorchooser/AbstractColorChooserPanel.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
      namespace event
      {
        class MouseEvent;
        class MouseListener;
      }
    }
  }
  namespace javax
  {
    namespace swing
    {
      class Icon;
      class JColorChooser;
      namespace colorchooser
      {
        class DefaultSwatchChooserPanel;
        class DefaultSwatchChooserPanel$RecentSwatchPanel;
        class DefaultSwatchChooserPanel$MainSwatchPanel;
      }
    }
  }
}

class javax::swing::colorchooser::DefaultSwatchChooserPanel : public ::javax::swing::colorchooser::AbstractColorChooserPanel
{
public: // actually package-private
  DefaultSwatchChooserPanel ();
public:
  virtual void updateChooser () { }
public:  // actually protected
  virtual void buildChooser ();
public:
  virtual void uninstallChooserPanel (::javax::swing::JColorChooser *);
  virtual ::java::lang::String *getDisplayName ();
  virtual ::javax::swing::Icon *getSmallDisplayIcon () { return 0; }
  virtual ::javax::swing::Icon *getLargeDisplayIcon () { return 0; }
  virtual void paint (::java::awt::Graphics *);
  virtual ::java::lang::String *getToolTipText (::java::awt::event::MouseEvent *) { return 0; }
public: // actually package-private
  ::javax::swing::colorchooser::DefaultSwatchChooserPanel$MainSwatchPanel * __attribute__((aligned(__alignof__( ::javax::swing::colorchooser::AbstractColorChooserPanel )))) mainPalette;
  ::javax::swing::colorchooser::DefaultSwatchChooserPanel$RecentSwatchPanel *recentPalette;
  ::java::awt::event::MouseListener *mouseHandler;

  friend class javax_swing_colorchooser_DefaultSwatchChooserPanel$RecentPanelLayout;
  friend class javax_swing_colorchooser_DefaultSwatchChooserPanel$MainPanelLayout;
  friend class javax_swing_colorchooser_DefaultSwatchChooserPanel$MouseHandler;
  friend class javax_swing_colorchooser_DefaultSwatchChooserPanel$RecentSwatchPanel;
  friend class javax_swing_colorchooser_DefaultSwatchChooserPanel$MainSwatchPanel;
  friend class javax_swing_colorchooser_DefaultSwatchChooserPanel$SwatchPanel;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_colorchooser_DefaultSwatchChooserPanel__ */
