// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_BindException__
#define __java_net_BindException__

#pragma interface

#include <java/net/SocketException.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class BindException;
    }
  }
}

class java::net::BindException : public ::java::net::SocketException
{
public:
  BindException ();
  BindException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -5945005768251722951LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_BindException__ */
