// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_SpinnerListModel__
#define __javax_swing_SpinnerListModel__

#pragma interface

#include <javax/swing/AbstractSpinnerModel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class SpinnerListModel;
    }
  }
}

class javax::swing::SpinnerListModel : public ::javax::swing::AbstractSpinnerModel
{
public:
  SpinnerListModel ();
  SpinnerListModel (::java::util::List *);
  SpinnerListModel (JArray< ::java::lang::Object *> *);
  virtual ::java::util::List *getList () { return list; }
  virtual ::java::lang::Object *getNextValue ();
  virtual ::java::lang::Object *getPreviousValue ();
  virtual ::java::lang::Object *getValue ();
  virtual void setList (::java::util::List *);
  virtual void setValue (::java::lang::Object *);
private:
  static const jlong serialVersionUID = 3358804052191994516LL;
  ::java::util::List * __attribute__((aligned(__alignof__( ::javax::swing::AbstractSpinnerModel )))) list;
  jint index;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_SpinnerListModel__ */
