// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_x509_PolicyNodeImpl__
#define __gnu_java_security_x509_PolicyNodeImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class PolicyQualifierInfo;
        class PolicyNode;
      }
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace x509
        {
          class PolicyNodeImpl;
        }
      }
    }
  }
}

class gnu::java::security::x509::PolicyNodeImpl : public ::java::lang::Object
{
public:
  PolicyNodeImpl ();
  virtual void addChild (::gnu::java::security::x509::PolicyNodeImpl *);
  virtual ::java::util::Iterator *getChildren ();
  virtual jint getDepth () { return depth; }
  virtual void setDepth (jint);
  virtual void addAllExpectedPolicies (::java::util::Set *);
  virtual void addExpectedPolicy (::java::lang::String *);
  virtual ::java::util::Set *getExpectedPolicies ();
  virtual ::java::security::cert::PolicyNode *getParent () { return reinterpret_cast< ::java::security::cert::PolicyNode *> (parent); }
  virtual void addAllPolicyQualifiers (::java::util::Collection *);
  virtual void addPolicyQualifier (::java::security::cert::PolicyQualifierInfo *);
  virtual ::java::util::Set *getPolicyQualifiers ();
  virtual ::java::lang::String *getValidPolicy () { return policy; }
  virtual void setValidPolicy (::java::lang::String *);
  virtual jboolean isCritical () { return critical; }
  virtual void setCritical (jboolean);
  virtual void setReadOnly ();
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) policy;
  ::java::util::Set *expectedPolicies;
  ::java::util::Set *qualifiers;
  ::java::util::Set *children;
  ::gnu::java::security::x509::PolicyNodeImpl *parent;
  jint depth;
  jboolean critical;
  jboolean readOnly;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_x509_PolicyNodeImpl__ */
