// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_activation_ActivateFailedException__
#define __java_rmi_activation_ActivateFailedException__

#pragma interface

#include <java/rmi/RemoteException.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      namespace activation
      {
        class ActivateFailedException;
      }
    }
  }
}

class java::rmi::activation::ActivateFailedException : public ::java::rmi::RemoteException
{
public:
  ActivateFailedException (::java::lang::String *);
  ActivateFailedException (::java::lang::String *, ::java::lang::Exception *);
private:
  static const jlong serialVersionUID = 4863550261346652506LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_activation_ActivateFailedException__ */
