// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_ObjectView__
#define __javax_swing_text_html_ObjectView__

#pragma interface

#include <javax/swing/text/ComponentView.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Component;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class ObjectView;
        }
        class Element;
      }
    }
  }
}

class javax::swing::text::html::ObjectView : public ::javax::swing::text::ComponentView
{
public:
  ObjectView (::javax::swing::text::Element *);
public:  // actually protected
  virtual ::java::awt::Component *createComponent ();
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_ObjectView__ */
