// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_srp_SRPServer__
#define __gnu_javax_crypto_sasl_srp_SRPServer__

#pragma interface

#include <gnu/javax/crypto/sasl/ServerMechanism.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class PRNG;
        }
      }
    }
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          class IKeyAgreementParty;
        }
        namespace sasl
        {
          namespace srp
          {
            class SRPServer;
            class CALG;
            class IALG;
            class SRP;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::sasl::srp::SRPServer : public ::gnu::javax::crypto::sasl::ServerMechanism
{
public:
  SRPServer ();
public:  // actually protected
  virtual void initMechanism ();
  virtual void resetMechanism ();
public:
  virtual jbyteArray evaluateResponse (jbyteArray);
public:  // actually protected
  virtual jbyteArray engineUnwrap (jbyteArray, jint, jint);
  virtual jbyteArray engineWrap (jbyteArray, jint, jint);
  virtual ::java::lang::String *getNegotiatedQOP ();
  virtual ::java::lang::String *getNegotiatedStrength ();
  virtual ::java::lang::String *getNegotiatedRawSendSize ();
  virtual ::java::lang::String *getReuse ();
private:
  jbyteArray sendProtocolElements (jbyteArray);
  jbyteArray sendEvidence (jbyteArray);
  ::java::lang::String *createL ();
  void parseO (::java::lang::String *);
  void setupSecurityServices (jboolean);
  ::gnu::java::security::util::PRNG *getDefaultPRNG ();
  static ::java::util::logging::Logger *log;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::sasl::ServerMechanism )))) U;
  ::java::math::BigInteger *N;
  ::java::math::BigInteger *g;
  ::java::math::BigInteger *A;
  ::java::math::BigInteger *B;
  jbyteArray s;
  jbyteArray cIV;
  jbyteArray sIV;
  jbyteArray cn;
  jbyteArray sn;
  ::gnu::javax::crypto::sasl::srp::SRP *srp;
  jbyteArray sid;
  jint ttl;
  jbyteArray cCB;
  ::java::lang::String *mandatory;
  ::java::lang::String *L;
  ::java::lang::String *o;
  ::java::lang::String *chosenIntegrityAlgorithm;
  ::java::lang::String *chosenConfidentialityAlgorithm;
  jint rawSendSize;
  jbyteArray K;
  jboolean replayDetection;
  jint inCounter;
  jint outCounter;
  ::gnu::javax::crypto::sasl::srp::IALG *inMac;
  ::gnu::javax::crypto::sasl::srp::IALG *outMac;
  ::gnu::javax::crypto::sasl::srp::CALG *inCipher;
  ::gnu::javax::crypto::sasl::srp::CALG *outCipher;
  ::gnu::javax::crypto::key::IKeyAgreementParty *serverHandler;
  ::gnu::java::security::util::PRNG *prng;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_srp_SRPServer__ */
