// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_print_SpooledDocument__
#define __gnu_java_awt_print_SpooledDocument__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace print
        {
          class SpooledDocument;
        }
      }
    }
  }
  namespace javax
  {
    namespace print
    {
      class DocFlavor;
      namespace attribute
      {
        class DocAttributeSet;
      }
    }
  }
}

class gnu::java::awt::print::SpooledDocument : public ::java::lang::Object
{
public:
  SpooledDocument (::java::io::File *);
  virtual ::javax::print::attribute::DocAttributeSet *getAttributes () { return 0; }
  virtual ::javax::print::DocFlavor *getDocFlavor ();
  virtual ::java::lang::Object *getPrintData () { return reinterpret_cast< ::java::lang::Object *> (fis); }
  virtual ::java::io::Reader *getReaderForText ();
  virtual ::java::io::InputStream *getStreamForBytes () { return reinterpret_cast< ::java::io::InputStream *> (fis); }
private:
  ::java::io::FileInputStream * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fis;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_print_SpooledDocument__ */
