// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_ByteOrder__
#define __java_nio_ByteOrder__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class ByteOrder;
    }
  }
}

class java::nio::ByteOrder : public ::java::lang::Object
{
public:
  static ::java::nio::ByteOrder *nativeOrder ();
  virtual ::java::lang::String *toString ();
private:
  ByteOrder ();
public:
  static ::java::nio::ByteOrder *BIG_ENDIAN;
  static ::java::nio::ByteOrder *LITTLE_ENDIAN;

  static ::java::lang::Class class$;
};

#endif /* __java_nio_ByteOrder__ */
