// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_rmi_server_RMIHashes__
#define __gnu_java_rmi_server_RMIHashes__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace rmi
      {
        namespace server
        {
          class RMIHashes;
        }
      }
    }
  }
}

class gnu::java::rmi::server::RMIHashes : public ::java::lang::Object
{
public:
  static jlong getMethodHash (::java::lang::reflect::Method *);
  static jlong getInterfaceHash (::java::lang::Class *);
  RMIHashes ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_rmi_server_RMIHashes__ */
