// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_der_DEREncodingException__
#define __gnu_java_security_der_DEREncodingException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace der
        {
          class DEREncodingException;
        }
      }
    }
  }
}

class gnu::java::security::der::DEREncodingException : public ::java::io::IOException
{
public:
  DEREncodingException ();
  DEREncodingException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_der_DEREncodingException__ */
