// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_mac_TMMH16__
#define __gnu_javax_crypto_mac_TMMH16__

#pragma interface

#include <gnu/javax/crypto/mac/BaseMac.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace mac
        {
          class TMMH16;
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace prng
        {
          class IRandom;
        }
      }
    }
  }
}

class gnu::javax::crypto::mac::TMMH16 : public ::gnu::javax::crypto::mac::BaseMac
{
public:
  TMMH16 ();
  virtual jint macSize ();
  virtual void init (::java::util::Map *);
  virtual void update (jbyte);
  virtual void update (jbyteArray, jint, jint);
  virtual jbyteArray digest ();
  virtual void reset ();
  virtual jboolean selfTest ();
  virtual ::java::lang::Object *clone ();
  virtual void update (jbyte, ::gnu::java::security::prng::IRandom *);
  virtual void update (jbyteArray, jint, jint, ::gnu::java::security::prng::IRandom *);
  virtual jbyteArray digest (::gnu::java::security::prng::IRandom *);
private:
  jint getNextKeyWord (::gnu::java::security::prng::IRandom *);
  void doFinalRound (::gnu::java::security::prng::IRandom *);
public:
  static ::java::lang::String *TAG_LENGTH;
  static ::java::lang::String *KEYSTREAM;
  static ::java::lang::String *PREFIX;
private:
  static const jint P = 65537L;
  static ::java::lang::Boolean *valid;
  jint __attribute__((aligned(__alignof__( ::gnu::javax::crypto::mac::BaseMac ))))  tagWords;
  ::gnu::java::security::prng::IRandom *keystream;
  jbyteArray prefix;
  jlong keyWords;
  jlong msgLength;
  jlong msgWords;
  jintArray context;
  jintArray K0;
  jintArray Ki;
  jint Mi;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_mac_TMMH16__ */
