// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_TreeUI__
#define __javax_swing_plaf_TreeUI__

#pragma interface

#include <javax/swing/plaf/ComponentUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class TreeUI;
      }
      namespace tree
      {
        class TreePath;
      }
      class JTree;
    }
  }
}

class javax::swing::plaf::TreeUI : public ::javax::swing::plaf::ComponentUI
{
public:
  TreeUI ();
  virtual ::java::awt::Rectangle *getPathBounds (::javax::swing::JTree *, ::javax::swing::tree::TreePath *) = 0;
  virtual ::javax::swing::tree::TreePath *getPathForRow (::javax::swing::JTree *, jint) = 0;
  virtual jint getRowForPath (::javax::swing::JTree *, ::javax::swing::tree::TreePath *) = 0;
  virtual jint getRowCount (::javax::swing::JTree *) = 0;
  virtual ::javax::swing::tree::TreePath *getClosestPathForLocation (::javax::swing::JTree *, jint, jint) = 0;
  virtual jboolean isEditing (::javax::swing::JTree *) = 0;
  virtual jboolean stopEditing (::javax::swing::JTree *) = 0;
  virtual void cancelEditing (::javax::swing::JTree *) = 0;
  virtual void startEditingAtPath (::javax::swing::JTree *, ::javax::swing::tree::TreePath *) = 0;
  virtual ::javax::swing::tree::TreePath *getEditingPath (::javax::swing::JTree *) = 0;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_TreeUI__ */
