// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_AncestorEvent__
#define __javax_swing_event_AncestorEvent__

#pragma interface

#include <java/awt/AWTEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Container;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class AncestorEvent;
      }
      class JComponent;
    }
  }
}

class javax::swing::event::AncestorEvent : public ::java::awt::AWTEvent
{
public:
  AncestorEvent (::javax::swing::JComponent *, jint, ::java::awt::Container *, ::java::awt::Container *);
  virtual ::java::awt::Container *getAncestor () { return ancestor; }
  virtual ::java::awt::Container *getAncestorParent () { return ancestorParent; }
  virtual ::javax::swing::JComponent *getComponent () { return sourceComponent; }
private:
  static const jlong serialVersionUID = -8079801679695605002LL;
public:
  static const jint ANCESTOR_ADDED = 1L;
  static const jint ANCESTOR_REMOVED = 2L;
  static const jint ANCESTOR_MOVED = 3L;
private:
  ::javax::swing::JComponent * __attribute__((aligned(__alignof__( ::java::awt::AWTEvent )))) sourceComponent;
  ::java::awt::Container *ancestor;
  ::java::awt::Container *ancestorParent;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_AncestorEvent__ */
