// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_NetworkInterface__
#define __java_net_NetworkInterface__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class NetworkInterface;
      class InetAddress;
    }
  }
}

class java::net::NetworkInterface : public ::java::lang::Object
{
public: // actually package-private
  NetworkInterface (::java::lang::String *, ::java::net::InetAddress *);
  NetworkInterface (::java::lang::String *, JArray< ::java::net::InetAddress *> *);
public:
  virtual ::java::lang::String *getName () { return name; }
  virtual ::java::util::Enumeration *getInetAddresses ();
  virtual ::java::lang::String *getDisplayName () { return name; }
  static ::java::net::NetworkInterface *getByName (::java::lang::String *);
  static ::java::net::NetworkInterface *getByInetAddress (::java::net::InetAddress *);
private:
  static ::java::util::Collection *condense (::java::util::Collection *);
public:
  static ::java::util::Enumeration *getNetworkInterfaces ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  ::java::util::Vector *inetAddresses;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_NetworkInterface__ */
