// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_srp_IALG__
#define __gnu_javax_crypto_sasl_srp_IALG__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace srp
          {
            class KDF;
            class IALG;
          }
        }
        namespace mac
        {
          class IMac;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::srp::IALG : public ::java::lang::Object
{
private:
  IALG (::gnu::javax::crypto::mac::IMac *);
public: // actually package-private
  static ::gnu::javax::crypto::sasl::srp::IALG *getInstance (::java::lang::String *);
public:
  virtual ::java::lang::Object *clone ();
  virtual void init (::gnu::javax::crypto::sasl::srp::KDF *);
  virtual void update (jbyteArray);
  virtual void update (jbyteArray, jint, jint);
  virtual jbyteArray doFinal ();
  virtual jint length ();
private:
  ::gnu::javax::crypto::mac::IMac * __attribute__((aligned(__alignof__( ::java::lang::Object )))) hmac;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_srp_IALG__ */
