// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_LayoutFocusTraversalPolicy__
#define __javax_swing_LayoutFocusTraversalPolicy__

#pragma interface

#include <javax/swing/SortingFocusTraversalPolicy.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class LayoutFocusTraversalPolicy;
    }
  }
}

class javax::swing::LayoutFocusTraversalPolicy : public ::javax::swing::SortingFocusTraversalPolicy
{
public:
  LayoutFocusTraversalPolicy ();
private:
  static const jlong serialVersionUID = 4312146927238881442LL;

  friend class javax_swing_LayoutFocusTraversalPolicy$LayoutComparator;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_LayoutFocusTraversalPolicy__ */
