// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_NullPointerException__
#define __java_lang_NullPointerException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::NullPointerException : public ::java::lang::RuntimeException
{
public:
  NullPointerException ();
  NullPointerException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 5162710183389028792LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_NullPointerException__ */
