// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_InputVerifier__
#define __javax_swing_InputVerifier__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class InputVerifier;
      class JComponent;
    }
  }
}

class javax::swing::InputVerifier : public ::java::lang::Object
{
public:
  InputVerifier ();
  virtual jboolean verify (::javax::swing::JComponent *) = 0;
  virtual jboolean shouldYieldFocus (::javax::swing::JComponent *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_InputVerifier__ */
