// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_security_auth_login_ConfigFileTokenizer__
#define __gnu_javax_security_auth_login_ConfigFileTokenizer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace security
      {
        namespace auth
        {
          namespace login
          {
            class ConfigFileTokenizer;
          }
        }
      }
    }
  }
}

class gnu::javax::security::auth::login::ConfigFileTokenizer : public ::java::lang::Object
{
public: // actually package-private
  ConfigFileTokenizer (::java::io::Reader *);
public:
  virtual jint nextToken ();
  virtual void pushBack ();
private:
  void init ();
  void skipWhitespace ();
  void abort (::java::lang::String *);
  static ::java::util::logging::Logger *log;
public:
  static const jint TT_EOF = -1L;
  static const jint TT_WORD = -3L;
private:
  static const jint TT_NONE = -4L;
public:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) sval;
  jint ttype;
private:
  ::java::io::BufferedReader *br;
public: // actually package-private
  jboolean initialised;
private:
  ::java::lang::StringBuffer *sb;
  jint sbNdx;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_security_auth_login_ConfigFileTokenizer__ */
