// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_TLSRandom__
#define __gnu_javax_net_ssl_provider_TLSRandom__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class TLSRandom;
          }
        }
      }
      namespace crypto
      {
        namespace mac
        {
          class IMac;
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::TLSRandom : public ::java::lang::Object
{
public: // actually package-private
  TLSRandom ();
public:
  virtual ::java::lang::Object *clone ();
  virtual void init (::java::util::Map *);
  virtual ::java::lang::String *name ();
  virtual jbyte nextByte ();
  virtual void nextBytes (jbyteArray, jint, jint);
  virtual void addRandomByte (jbyte) { }
  virtual void addRandomBytes (jbyteArray);
  virtual void addRandomBytes (jbyteArray, jint, jint) { }
private:
  void fillBuffer ();
public: // actually package-private
  static ::java::lang::String *SECRET;
  static ::java::lang::String *SEED;
private:
  ::gnu::javax::crypto::mac::IMac * __attribute__((aligned(__alignof__( ::java::lang::Object )))) hmac_sha;
  ::gnu::javax::crypto::mac::IMac *hmac_md5;
  jbyteArray sha_a;
  jbyteArray md5_a;
  jbyteArray seed;
  jbyteArray buffer;
  jint idx;
  jboolean init__;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_TLSRandom__ */
