// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_logging_LoggingMXBean__
#define __java_util_logging_LoggingMXBean__

#pragma interface

#include <java/lang/Object.h>

class java::util::logging::LoggingMXBean : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getLoggerLevel (::java::lang::String *) = 0;
  virtual ::java::util::List *getLoggerNames () = 0;
  virtual ::java::lang::String *getParentLoggerName (::java::lang::String *) = 0;
  virtual void setLoggerLevel (::java::lang::String *, ::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_logging_LoggingMXBean__ */
