// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_border_Border__
#define __javax_swing_border_Border__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace border
      {
        class Border;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Insets;
      class Graphics;
      class Component;
    }
  }
}

class javax::swing::border::Border : public ::java::lang::Object
{
public:
  virtual void paintBorder (::java::awt::Component *, ::java::awt::Graphics *, jint, jint, jint, jint) = 0;
  virtual ::java::awt::Insets *getBorderInsets (::java::awt::Component *) = 0;
  virtual jboolean isBorderOpaque () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_border_Border__ */
