( cd usr/bin ; rm -rf c++ )
( cd usr/bin ; ln -sf g++ c++ )
( cd usr/bin ; rm -rf g++ )
( cd usr/bin ; ln -sf g++-gcc-4.2.3 g++ )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-c++ )
( cd usr/bin ; ln -sf g++-gcc-4.2.3 x86_64-slamd64-linux-c++ )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-g++ )
( cd usr/bin ; ln -sf g++-gcc-4.2.3 x86_64-slamd64-linux-g++ )
( cd usr/man/man1 ; rm -rf c++.1.gz )
( cd usr/man/man1 ; ln -sf g++.1.gz c++.1.gz )
( cd usr/lib64 ; rm -rf libstdc++.so )
( cd usr/lib64 ; ln -sf libstdc++.so.6.0.9 libstdc++.so )
( cd usr/lib64 ; rm -rf libstdc++.so.6 )
( cd usr/lib64 ; ln -sf libstdc++.so.6.0.9 libstdc++.so.6 )
