// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_Reader__
#define __java_io_Reader__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::io::Reader : public ::java::lang::Object
{
public:  // actually protected
  Reader ();
  Reader (::java::lang::Object *);
public:
  virtual jint read (jcharArray, jint, jint) = 0;
  virtual jint read (jcharArray);
  virtual jint read ();
  virtual void close () = 0;
  virtual jboolean markSupported ();
  virtual void mark (jint);
  virtual void reset ();
  virtual jboolean ready ();
  virtual jlong skip (jlong);
public:  // actually protected
  ::java::lang::Object * __attribute__((aligned(__alignof__( ::java::lang::Object )))) lock;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_Reader__ */
