// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_HTMLDocument__
#define __javax_swing_text_html_HTMLDocument__

#pragma interface

#include <javax/swing/text/DefaultStyledDocument.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class AttributeSet;
        class Element;
        class AbstractDocument$AbstractElement;
        class AbstractDocument$Content;
        namespace html
        {
          class HTMLDocument;
          class HTMLEditorKit$ParserCallback;
          class HTMLDocument$Iterator;
          class HTML$Tag;
          class HTMLFrameHyperlinkEvent;
          class StyleSheet;
          class HTMLEditorKit$Parser;
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URL;
    }
  }
}

class javax::swing::text::html::HTMLDocument : public ::javax::swing::text::DefaultStyledDocument
{
public:
  HTMLDocument ();
  HTMLDocument (::javax::swing::text::html::StyleSheet *);
  HTMLDocument (::javax::swing::text::AbstractDocument$Content *, ::javax::swing::text::html::StyleSheet *);
  virtual ::javax::swing::text::html::StyleSheet *getStyleSheet () { return styleSheet; }
public:  // actually protected
  virtual ::javax::swing::text::AbstractDocument$AbstractElement *createDefaultRoot ();
  virtual ::javax::swing::text::Element *createLeafElement (::javax::swing::text::Element *, ::javax::swing::text::AttributeSet *, jint, jint);
  virtual ::javax::swing::text::Element *createBranchElement (::javax::swing::text::Element *, ::javax::swing::text::AttributeSet *);
public:
  virtual ::javax::swing::text::html::HTMLEditorKit$Parser *getParser () { return parser; }
  virtual void setParser (::javax::swing::text::html::HTMLEditorKit$Parser *);
  virtual void setTokenThreshold (jint);
  virtual jint getTokenThreshold () { return tokenThreshold; }
  virtual ::java::net::URL *getBase () { return baseURL; }
  virtual void setBase (::java::net::URL *);
  virtual jboolean getPreservesUnknownTags () { return preservesUnknownTags; }
  virtual void setPreservesUnknownTags (jboolean);
  virtual void processHTMLFrameHyperlinkEvent (::javax::swing::text::html::HTMLFrameHyperlinkEvent *) { }
  virtual ::javax::swing::text::html::HTMLDocument$Iterator *getIterator (::javax::swing::text::html::HTML$Tag *);
  virtual ::javax::swing::text::html::HTMLEditorKit$ParserCallback *getReader (jint);
  virtual ::javax::swing::text::html::HTMLEditorKit$ParserCallback *getReader (jint, jint, jint, ::javax::swing::text::html::HTML$Tag *);
  virtual ::javax::swing::text::html::HTMLEditorKit$ParserCallback *getInsertingReader (jint, jint, jint, ::javax::swing::text::html::HTML$Tag *, ::javax::swing::text::Element *);
  virtual ::javax::swing::text::Element *getElement (::javax::swing::text::Element *, ::java::lang::Object *, ::java::lang::Object *);
  virtual ::javax::swing::text::Element *getElement (::java::lang::String *);
  virtual void setInnerHTML (::javax::swing::text::Element *, ::java::lang::String *);
  virtual void setOuterHTML (::javax::swing::text::Element *, ::java::lang::String *);
  virtual void insertBeforeStart (::javax::swing::text::Element *, ::java::lang::String *);
  virtual void insertBeforeEnd (::javax::swing::text::Element *, ::java::lang::String *);
  virtual void insertAfterEnd (::javax::swing::text::Element *, ::java::lang::String *);
  virtual void insertAfterStart (::javax::swing::text::Element *, ::java::lang::String *);
  static ::java::lang::String *AdditionalComments;
public: // actually package-private
  ::java::net::URL * __attribute__((aligned(__alignof__( ::javax::swing::text::DefaultStyledDocument )))) baseURL;
  jboolean preservesUnknownTags;
  jint tokenThreshold;
  ::javax::swing::text::html::HTMLEditorKit$Parser *parser;
  ::javax::swing::text::html::StyleSheet *styleSheet;
  ::javax::swing::text::AbstractDocument$Content *content;

  friend class javax_swing_text_html_HTMLDocument$1;
  friend class javax_swing_text_html_HTMLDocument$HTMLReader;
  friend class javax_swing_text_html_HTMLDocument$RunElement;
  friend class javax_swing_text_html_HTMLDocument$BlockElement;
  friend class javax_swing_text_html_HTMLDocument$Iterator;
  friend class javax_swing_text_html_HTMLDocument$LeafIterator;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_HTMLDocument__ */
