// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_Icon__
#define __javax_swing_Icon__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class Icon;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Component;
    }
  }
}

class javax::swing::Icon : public ::java::lang::Object
{
public:
  virtual jint getIconHeight () = 0;
  virtual jint getIconWidth () = 0;
  virtual void paintIcon (::java::awt::Component *, ::java::awt::Graphics *, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_Icon__ */
