// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_CSS__
#define __javax_swing_text_html_CSS__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class CSS;
          class CSS$Attribute;
        }
      }
    }
  }
}

class javax::swing::text::html::CSS : public ::java::lang::Object
{
public:
  static JArray< ::javax::swing::text::html::CSS$Attribute *> *getAllAttributeKeys ();
  static ::javax::swing::text::html::CSS$Attribute *getAttribute (::java::lang::String *);
  CSS ();

  friend class javax_swing_text_html_CSS$Attribute;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_CSS__ */
