// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_prng_ICMGenerator__
#define __gnu_javax_crypto_prng_ICMGenerator__

#pragma interface

#include <gnu/java/security/prng/BasePRNG.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace prng
        {
          class ICMGenerator;
        }
        namespace cipher
        {
          class IBlockCipher;
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::prng::ICMGenerator : public ::gnu::java::security::prng::BasePRNG
{
public:
  ICMGenerator ();
  virtual void setup (::java::util::Map *);
  virtual void fillBlock ();
  static ::java::lang::String *CIPHER;
  static ::java::lang::String *BLOCK_INDEX_LENGTH;
  static ::java::lang::String *SEGMENT_INDEX_LENGTH;
  static ::java::lang::String *OFFSET;
  static ::java::lang::String *SEGMENT_INDEX;
private:
  static ::java::math::BigInteger *TWO_FIFTY_SIX;
  ::gnu::javax::crypto::cipher::IBlockCipher * __attribute__((aligned(__alignof__( ::gnu::java::security::prng::BasePRNG )))) cipher;
  jint blockNdxLength;
  jint segmentNdxLength;
  ::java::math::BigInteger *blockNdx;
  ::java::math::BigInteger *segmentNdx;
  ::java::math::BigInteger *C0;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_prng_ICMGenerator__ */
