// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_font_opentype_truetype_ZonePathIterator__
#define __gnu_java_awt_font_opentype_truetype_ZonePathIterator__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace font
        {
          namespace opentype
          {
            namespace truetype
            {
              class ZonePathIterator;
              class Zone;
            }
          }
        }
      }
    }
  }
}

class gnu::java::awt::font::opentype::truetype::ZonePathIterator : public ::java::lang::Object
{
public: // actually package-private
  ZonePathIterator (::gnu::java::awt::font::opentype::truetype::Zone *);
public:
  virtual jint getWindingRule ();
  virtual jboolean isDone ();
  virtual void next ();
private:
  jint getSuccessor (jint);
public:
  virtual jint currentSegment (jfloatArray);
  virtual jint currentSegment (jdoubleArray);
private:
  jint getSegment (jint, jfloatArray);
  jint getStartSegment (jint, jfloatArray);
  static const jint EMIT_SEGMENT = 0L;
  static const jint EMIT_CLOSE = 1L;
  static const jint EMIT_MOVETO = 2L;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  state;
  ::gnu::java::awt::font::opentype::truetype::Zone *zone;
  jint numPoints;
  jint curPoint;
  jint contourStart;
public: // actually package-private
  jfloatArray floats;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_font_opentype_truetype_ZonePathIterator__ */
