// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_RETokenRepeated__
#define __gnu_java_util_regex_RETokenRepeated__

#pragma interface

#include <gnu/java/util/regex/REToken.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class RETokenRepeated;
          class BacktrackStack;
          class REMatch;
          class CharIndexed;
          class REToken;
        }
      }
    }
  }
}

class gnu::java::util::regex::RETokenRepeated : public ::gnu::java::util::regex::REToken
{
public: // actually package-private
  RETokenRepeated (jint, ::gnu::java::util::regex::REToken *, jint, jint);
  virtual void makeStingy ();
  virtual jboolean isStingy () { return stingy; }
  virtual void makePossessive ();
  virtual jboolean isPossessive () { return possessive; }
  virtual jint getMinimumLength ();
  virtual jint getMaximumLength ();
  virtual ::gnu::java::util::regex::REMatch *findMatch (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
  virtual ::gnu::java::util::regex::REMatch *backtrack (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, ::java::lang::Object *);
private:
  ::gnu::java::util::regex::REMatch *findMatch (::gnu::java::util::regex::BacktrackStack *);
public: // actually package-private
  virtual jboolean match (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
private:
  static jintArray initVisited ();
  static jboolean visitedContains (jint, jintArray);
  static jintArray addVisited (jint, jintArray);
  ::gnu::java::util::regex::REMatch *matchRest (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
  ::gnu::java::util::regex::REMatch *findMatchFixedLength (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
  ::gnu::java::util::regex::REMatch *backtrackFixedLength (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, ::java::lang::Object *);
  ::gnu::java::util::regex::REMatch *findMatchFixedLength (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, jint, jint);
public: // actually package-private
  virtual void dump (::java::lang::StringBuffer *);
private:
  ::gnu::java::util::regex::REToken * __attribute__((aligned(__alignof__( ::gnu::java::util::regex::REToken )))) token;
  jint min;
  jint max;
  jboolean stingy;
  jboolean possessive;
  jint tokenFixedLength;

  friend class gnu_java_util_regex_RETokenRepeated$StackedInfo;
  friend class gnu_java_util_regex_RETokenRepeated$DoablesFinder;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_RETokenRepeated__ */
