// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_bmp_BMPImageWriter__
#define __gnu_javax_imageio_bmp_BMPImageWriter__

#pragma interface

#include <javax/imageio/ImageWriter.h>

extern "Java"
{
  namespace javax
  {
    namespace imageio
    {
      class IIOImage;
      class ImageWriteParam;
      class ImageTypeSpecifier;
      namespace metadata
      {
        class IIOMetadata;
      }
      namespace spi
      {
        class ImageWriterSpi;
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace bmp
        {
          class BMPImageWriter;
          class BMPInfoHeader;
          class BMPFileHeader;
          class BMPEncoder;
        }
      }
    }
  }
}

class gnu::javax::imageio::bmp::BMPImageWriter : public ::javax::imageio::ImageWriter
{
public:  // actually protected
  BMPImageWriter (::javax::imageio::spi::ImageWriterSpi *);
public:
  virtual ::javax::imageio::metadata::IIOMetadata *convertImageMetadata (::javax::imageio::metadata::IIOMetadata *, ::javax::imageio::ImageTypeSpecifier *, ::javax::imageio::ImageWriteParam *);
  virtual ::javax::imageio::metadata::IIOMetadata *convertStreamMetadata (::javax::imageio::metadata::IIOMetadata *, ::javax::imageio::ImageWriteParam *);
  virtual ::javax::imageio::metadata::IIOMetadata *getDefaultImageMetadata (::javax::imageio::ImageTypeSpecifier *, ::javax::imageio::ImageWriteParam *) { return 0; }
  virtual ::javax::imageio::metadata::IIOMetadata *getDefaultStreamMetadata (::javax::imageio::ImageWriteParam *) { return 0; }
  virtual void write (::javax::imageio::metadata::IIOMetadata *, ::javax::imageio::IIOImage *, ::javax::imageio::ImageWriteParam *);
private:
  void checkStream ();
public:  // actually protected
  ::gnu::javax::imageio::bmp::BMPEncoder * __attribute__((aligned(__alignof__( ::javax::imageio::ImageWriter )))) encoder;
  ::gnu::javax::imageio::bmp::BMPFileHeader *fileHeader;
  ::gnu::javax::imageio::bmp::BMPInfoHeader *infoHeader;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_bmp_BMPImageWriter__ */
