// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_jpeg_ZigZag__
#define __gnu_javax_imageio_jpeg_ZigZag__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace jpeg
        {
          class ZigZag;
        }
      }
    }
  }
}

class gnu::javax::imageio::jpeg::ZigZag : public ::java::lang::Object
{
public:
  static jbyteArray encode (JArray<jbyteArray> *);
  static jdoubleArray encode (JArray<jdoubleArray> *);
  static jfloatArray encode (JArray<jfloatArray> *);
  static jshortArray encode (JArray<jshortArray> *);
  static JArray<jdoubleArray> * decode (jdoubleArray);
  static JArray<jbyteArray> * decode (jbyteArray);
  static JArray<jintArray> * decode (jintArray);
  static JArray<jbyteArray> * decode (jbyteArray, jint, jint);
  static JArray<jdoubleArray> * decode (jdoubleArray, jint, jint);
  static JArray<jfloatArray> * decode (jfloatArray, jint, jint);
  static JArray<jintArray> * decode (jintArray, jint, jint);
  static JArray<jdoubleArray> * decode8x8_map (jdoubleArray);
  ZigZag ();
  static const jint ZIGZAG_FORWARD = 1L;
  static const jint ZIGZAG_BACKWARD = 0L;
  static jintArray ZIGZAG_8X8_MAP;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_jpeg_ZigZag__ */
