// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_crammd5_CramMD5Util__
#define __gnu_javax_crypto_sasl_crammd5_CramMD5Util__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace crammd5
          {
            class CramMD5Util;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::crammd5::CramMD5Util : public ::java::lang::Object
{
private:
  CramMD5Util ();
public: // actually package-private
  static jbyteArray createMsgID ();
  static jbyteArray createHMac (jcharArray, jbyteArray);
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_crammd5_CramMD5Util__ */
