// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_IllegalFormatCodePointException__
#define __java_util_IllegalFormatCodePointException__

#pragma interface

#include <java/util/IllegalFormatException.h>

class java::util::IllegalFormatCodePointException : public ::java::util::IllegalFormatException
{
public:
  IllegalFormatCodePointException (jint);
  virtual jint getCodePoint () { return c; }
private:
  static const jlong serialVersionUID = 19080630LL;
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::util::IllegalFormatException ))))  c;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_IllegalFormatCodePointException__ */
