// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_Deflater__
#define __java_util_zip_Deflater__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      class RawData;
    }
  }
}

class java::util::zip::Deflater : public ::java::lang::Object
{
public:
  Deflater ();
  Deflater (jint);
  Deflater (jint, jboolean);
private:
  void init (jint, jboolean);
  void update ();
public:
  virtual void reset ();
  virtual void end ();
  virtual jint getAdler ();
  virtual jint getTotalIn ();
  virtual jint getTotalOut ();
public:  // actually protected
  virtual void finalize ();
public:
  virtual void finish ();
  virtual jboolean finished ();
  virtual jboolean needsInput ();
  virtual void setInput (jbyteArray);
  virtual void setInput (jbyteArray, jint, jint);
  virtual void setLevel (jint);
  virtual void setStrategy (jint);
  virtual jint deflate (jbyteArray);
  virtual jint deflate (jbyteArray, jint, jint);
  virtual void setDictionary (jbyteArray);
  virtual void setDictionary (jbyteArray, jint, jint);
public: // actually package-private
  virtual void flush () { }
public:
  static const jint BEST_COMPRESSION = 9L;
  static const jint BEST_SPEED = 1L;
  static const jint DEFAULT_COMPRESSION = -1L;
  static const jint NO_COMPRESSION = 0L;
  static const jint DEFAULT_STRATEGY = 0L;
  static const jint FILTERED = 1L;
  static const jint HUFFMAN_ONLY = 2L;
  static const jint DEFLATED = 8L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  level;
  jint strategy;
  ::gnu::gcj::RawData *zstream;
  jboolean is_finished;
  jint flush_flag;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_Deflater__ */
