// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_jpeg_JPEGMarker__
#define __gnu_javax_imageio_jpeg_JPEGMarker__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace jpeg
        {
          class JPEGMarker;
        }
      }
    }
  }
}

class gnu::javax::imageio::jpeg::JPEGMarker : public ::java::lang::Object
{
public:
  JPEGMarker ();
  static const jint JFIF_J = 74L;
  static const jint JFIF_F = 70L;
  static const jint JFIF_I = 73L;
  static const jint JFIF_X = 70L;
  static const jint JFXX_JPEG = 16L;
  static const jint JFXX_ONE_BPP = 17L;
  static const jint JFXX_THREE_BPP = 19L;
  static const jint XFF = -1L;
  static const jint X00 = 0L;
  static const jint APP0 = -32L;
  static const jint APP1 = -31L;
  static const jint APP2 = -30L;
  static const jint APP3 = -29L;
  static const jint APP4 = -28L;
  static const jint APP5 = -27L;
  static const jint APP6 = -26L;
  static const jint APP7 = -25L;
  static const jint APP8 = -24L;
  static const jint APP9 = -23L;
  static const jint APP10 = -22L;
  static const jint APP11 = -21L;
  static const jint APP12 = -20L;
  static const jint APP13 = -19L;
  static const jint APP14 = -18L;
  static const jint APP15 = -17L;
  static const jint RST0 = -48L;
  static const jint RST1 = -47L;
  static const jint RST2 = -46L;
  static const jint RST3 = -45L;
  static const jint RST4 = -44L;
  static const jint RST5 = -43L;
  static const jint RST6 = -42L;
  static const jint RST7 = -41L;
  static const jint SOF0 = -64L;
  static const jint SOF1 = -63L;
  static const jint SOF2 = -62L;
  static const jint SOF3 = -61L;
  static const jint SOF5 = -59L;
  static const jint SOF6 = -58L;
  static const jint SOF7 = -57L;
  static const jint SOF9 = -55L;
  static const jint SOF10 = -54L;
  static const jint SOF11 = -53L;
  static const jint SOF13 = -51L;
  static const jint SOF14 = -50L;
  static const jint SOF15 = -49L;
  static const jint DHT = -60L;
  static const jint DQT = -37L;
  static const jint SOS = -38L;
  static const jint DRI = -35L;
  static const jint COM = -2L;
  static const jint SOI = -40L;
  static const jint EOI = -39L;
  static const jint DNL = -36L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_jpeg_JPEGMarker__ */
