// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_annotation_AnnotationFormatError__
#define __java_lang_annotation_AnnotationFormatError__

#pragma interface

#include <java/lang/Error.h>

class java::lang::annotation::AnnotationFormatError : public ::java::lang::Error
{
public:
  AnnotationFormatError (::java::lang::String *);
  AnnotationFormatError (::java::lang::String *, ::java::lang::Throwable *);
  AnnotationFormatError (::java::lang::Throwable *);
private:
  static const jlong serialVersionUID = -4256701562333669892LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_annotation_AnnotationFormatError__ */
