// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_RETokenIndependent__
#define __gnu_java_util_regex_RETokenIndependent__

#pragma interface

#include <gnu/java/util/regex/REToken.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class RETokenIndependent;
          class REMatch;
          class CharIndexed;
          class REToken;
        }
      }
    }
  }
}

class gnu::java::util::regex::RETokenIndependent : public ::gnu::java::util::regex::REToken
{
public: // actually package-private
  RETokenIndependent (::gnu::java::util::regex::REToken *);
  virtual jint getMinimumLength ();
  virtual jint getMaximumLength ();
  virtual ::gnu::java::util::regex::REMatch *matchThis (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
  virtual void dump (::java::lang::StringBuffer *);
  ::gnu::java::util::regex::REToken * __attribute__((aligned(__alignof__( ::gnu::java::util::regex::REToken )))) re;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_RETokenIndependent__ */
