// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicFormattedTextFieldUI__
#define __javax_swing_plaf_basic_BasicFormattedTextFieldUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicTextFieldUI.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class BasicFormattedTextFieldUI;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::basic::BasicFormattedTextFieldUI : public ::javax::swing::plaf::basic::BasicTextFieldUI
{
public:
  BasicFormattedTextFieldUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual ::java::lang::String *getPropertyPrefix ();
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicFormattedTextFieldUI__ */
