// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_key_AnubisKeyGeneratorImpl__
#define __gnu_javax_crypto_jce_key_AnubisKeyGeneratorImpl__

#pragma interface

#include <gnu/javax/crypto/jce/key/SecretKeyGeneratorImpl.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace key
          {
            class AnubisKeyGeneratorImpl;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::key::AnubisKeyGeneratorImpl : public ::gnu::javax::crypto::jce::key::SecretKeyGeneratorImpl
{
public:
  AnubisKeyGeneratorImpl ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_key_AnubisKeyGeneratorImpl__ */
