// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_support_textPreProcessor__
#define __gnu_javax_swing_text_html_parser_support_textPreProcessor__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                class textPreProcessor;
              }
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::support::textPreProcessor : public ::java::lang::Object
{
public:
  virtual jcharArray preprocess (::java::lang::StringBuffer *);
  virtual jcharArray preprocessPreformatted (::java::lang::StringBuffer *);
private:
  static jcharArray toCharArray (::java::lang::StringBuffer *);
public:
  textPreProcessor ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_support_textPreProcessor__ */
