// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicIconFactory__
#define __javax_swing_plaf_basic_BasicIconFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class Icon;
      namespace plaf
      {
        namespace basic
        {
          class BasicIconFactory;
          class BasicIconFactory$RadioButtonIcon;
          class BasicIconFactory$CheckBoxIcon;
        }
      }
    }
  }
}

class javax::swing::plaf::basic::BasicIconFactory : public ::java::lang::Object
{
public:
  static ::javax::swing::Icon *getMenuItemCheckIcon ();
  static ::javax::swing::Icon *getMenuItemArrowIcon ();
  static ::javax::swing::Icon *getMenuArrowIcon ();
  static ::javax::swing::Icon *getCheckBoxIcon ();
  static ::javax::swing::Icon *getRadioButtonIcon ();
  static ::javax::swing::Icon *getCheckBoxMenuItemIcon ();
  static ::javax::swing::Icon *getRadioButtonMenuItemIcon ();
  static ::javax::swing::Icon *createEmptyFrameIcon ();
  BasicIconFactory ();
public: // actually package-private
  static const jlong serialVersionUID = 5605588811185324383LL;
private:
  static ::javax::swing::plaf::basic::BasicIconFactory$CheckBoxIcon *checkBoxIcon;
  static ::javax::swing::plaf::basic::BasicIconFactory$RadioButtonIcon *radioButtonIcon;

  friend class javax_swing_plaf_basic_BasicIconFactory$2;
  friend class javax_swing_plaf_basic_BasicIconFactory$1;
  friend class javax_swing_plaf_basic_BasicIconFactory$RadioButtonIcon;
  friend class javax_swing_plaf_basic_BasicIconFactory$CheckBoxMenuItemIcon;
  friend class javax_swing_plaf_basic_BasicIconFactory$CheckBoxIcon;
  friend class javax_swing_plaf_basic_BasicIconFactory$DummyIcon;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicIconFactory__ */
