// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_HierarchyEvent__
#define __java_awt_event_HierarchyEvent__

#pragma interface

#include <java/awt/AWTEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class HierarchyEvent;
      }
      class Container;
      class Component;
    }
  }
}

class java::awt::event::HierarchyEvent : public ::java::awt::AWTEvent
{
public:
  HierarchyEvent (::java::awt::Component *, jint, ::java::awt::Component *, ::java::awt::Container *);
  HierarchyEvent (::java::awt::Component *, jint, ::java::awt::Component *, ::java::awt::Container *, jlong);
  virtual ::java::awt::Component *getComponent ();
  virtual ::java::awt::Component *getChanged () { return changed; }
  virtual ::java::awt::Container *getChangedParent () { return changedParent; }
  virtual jlong getChangeFlags () { return changeFlags; }
  virtual ::java::lang::String *paramString ();
private:
  static const jlong serialVersionUID = -5337576970038043990LL;
public:
  static const jint HIERARCHY_FIRST = 1400L;
  static const jint HIERARCHY_CHANGED = 1400L;
  static const jint ANCESTOR_MOVED = 1401L;
  static const jint ANCESTOR_RESIZED = 1402L;
  static const jint HIERARCHY_LAST = 1402L;
  static const jint PARENT_CHANGED = 1L;
  static const jint DISPLAYABILITY_CHANGED = 2L;
  static const jint SHOWING_CHANGED = 4L;
private:
  ::java::awt::Component * __attribute__((aligned(__alignof__( ::java::awt::AWTEvent )))) changed;
  ::java::awt::Container *changedParent;
  jlong changeFlags;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_HierarchyEvent__ */
