// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_CannotProceedException__
#define __javax_naming_CannotProceedException__

#pragma interface

#include <javax/naming/NamingException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class CannotProceedException;
      class Context;
      class Name;
    }
  }
}

class javax::naming::CannotProceedException : public ::javax::naming::NamingException
{
public:
  CannotProceedException ();
  CannotProceedException (::java::lang::String *);
  virtual ::java::util::Hashtable *getEnvironment () { return environment; }
  virtual void setEnvironment (::java::util::Hashtable *);
  virtual ::javax::naming::Name *getRemainingNewName () { return remainingNewName; }
  virtual void setRemainingNewName (::javax::naming::Name *);
  virtual ::javax::naming::Name *getAltName () { return altName; }
  virtual void setAltName (::javax::naming::Name *);
  virtual ::javax::naming::Context *getAltNameCtx () { return altNameCtx; }
  virtual void setAltNameCtx (::javax::naming::Context *);
private:
  static const jlong serialVersionUID = 1219724816191576813LL;
public:  // actually protected
  ::javax::naming::Name * __attribute__((aligned(__alignof__( ::javax::naming::NamingException )))) remainingNewName;
  ::java::util::Hashtable *environment;
  ::javax::naming::Name *altName;
  ::javax::naming::Context *altNameCtx;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_CannotProceedException__ */
