// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_LinkageError__
#define __java_lang_LinkageError__

#pragma interface

#include <java/lang/Error.h>

class java::lang::LinkageError : public ::java::lang::Error
{
public:
  LinkageError ();
  LinkageError (::java::lang::String *);
private:
  static const jlong serialVersionUID = 3579600108157160122LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_LinkageError__ */
