// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_cert_CertificateException__
#define __javax_security_cert_CertificateException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace cert
      {
        class CertificateException;
      }
    }
  }
}

class javax::security::cert::CertificateException : public ::java::lang::Exception
{
public:
  CertificateException ();
  CertificateException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_security_cert_CertificateException__ */
