// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_UnresolvedAddressException__
#define __java_nio_channels_UnresolvedAddressException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class UnresolvedAddressException;
      }
    }
  }
}

class java::nio::channels::UnresolvedAddressException : public ::java::lang::IllegalArgumentException
{
public:
  UnresolvedAddressException ();
private:
  static const jlong serialVersionUID = 6136959093620794148LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_channels_UnresolvedAddressException__ */
