// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_synth_SynthPainter__
#define __javax_swing_plaf_synth_SynthPainter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace synth
        {
          class SynthPainter;
          class SynthContext;
        }
      }
    }
  }
}

class javax::swing::plaf::synth::SynthPainter : public ::java::lang::Object
{
public:
  SynthPainter ();
  virtual void paintArrowButtonForeground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintProgressBarForeground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintSeparatorForeground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintSplitPaneDividerForeground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintSplitPaneDragDivider (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintTreeCellFocus (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintArrowButtonBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintArrowButtonBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintButtonBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintButtonBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintCheckBoxBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintCheckBoxBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintCheckBoxMenuItemBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintCheckBoxMenuItemBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintColorChooserBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintColorChooserBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintComboBoxBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintComboBoxBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintDesktopIconBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintDesktopIconBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintDesktopPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintDesktopPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintEditorPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintEditorPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintFileChooserBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintFileChooserBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintFormattedTextFieldBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintFormattedTextFieldBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintInternalFrameBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintInternalFrameBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintInternalFrameTitlePaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintInternalFrameTitlePaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintLabelBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintLabelBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintListBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintListBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintMenuBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintMenuBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintMenuBarBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintMenuBarBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintMenuItemBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintMenuItemBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintOptionPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintOptionPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintPanelBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintPanelBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintPasswordFieldBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintPasswordFieldBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintPopupMenuBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintPopupMenuBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintProgressBarBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintProgressBarBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintRadioButtonBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintRadioButtonBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintRadioButtonMenuItemBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintRadioButtonMenuItemBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintRootPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintRootPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintScrollBarBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintScrollBarBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintScrollBarThumbBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintScrollBarThumbBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintScrollBarTrackBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintScrollBarTrackBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintScrollPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintScrollPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSeparatorBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSeparatorBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSliderBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSliderBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSliderThumbBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintSliderThumbBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintSliderTrackBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSliderTrackBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSpinnerBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSpinnerBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSplitPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSplitPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintSplitPaneDividerBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneContentBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneContentBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneTabAreaBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneTabAreaBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneTabBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintTabbedPaneTabBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint, jint) { }
  virtual void paintTableBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTableBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTableHeaderBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTableHeaderBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTextAreaBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTextAreaBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTextFieldBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTextFieldBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTextPaneBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTextPaneBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToggleButtonBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToggleButtonBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolBarBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolBarBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolBarContentBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolBarContentBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolBarDragWindowBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolBarDragWindowBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolTipBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintToolTipBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTreeBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTreeBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTreeCellBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintTreeCellBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintViewportBackground (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }
  virtual void paintViewportBorder (::javax::swing::plaf::synth::SynthContext *, ::java::awt::Graphics *, jint, jint, jint, jint) { }

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_synth_SynthPainter__ */
