// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_IllegalFormatConversionException__
#define __java_util_IllegalFormatConversionException__

#pragma interface

#include <java/util/IllegalFormatException.h>

class java::util::IllegalFormatConversionException : public ::java::util::IllegalFormatException
{
public:
  IllegalFormatConversionException (jchar, ::java::lang::Class *);
  virtual jchar getConversion () { return c; }
  virtual ::java::lang::Class *getArgumentClass () { return arg; }
private:
  static const jlong serialVersionUID = 17000126LL;
public: // actually package-private
  jchar __attribute__((aligned(__alignof__( ::java::util::IllegalFormatException ))))  c;
  ::java::lang::Class *arg;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_IllegalFormatConversionException__ */
