// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_Adler32__
#define __java_util_zip_Adler32__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::util::zip::Adler32 : public ::java::lang::Object
{
public:
  Adler32 ();
  virtual void reset ();
  virtual void update (jint);
  virtual void update (jbyteArray);
  virtual void update (jbyteArray, jint, jint);
  virtual jlong getValue ();
private:
  static const jint BASE = 65521L;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  checksum;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_Adler32__ */
