// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_NoSuchFieldException__
#define __java_lang_NoSuchFieldException__

#pragma interface

#include <java/lang/Exception.h>

class java::lang::NoSuchFieldException : public ::java::lang::Exception
{
public:
  NoSuchFieldException ();
  NoSuchFieldException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -6143714805279938260LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_NoSuchFieldException__ */
