// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_accessibility_AccessibleRelationSet__
#define __javax_accessibility_AccessibleRelationSet__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleRelationSet;
      class AccessibleRelation;
    }
  }
}

class javax::accessibility::AccessibleRelationSet : public ::java::lang::Object
{
public:
  AccessibleRelationSet ();
  AccessibleRelationSet (JArray< ::javax::accessibility::AccessibleRelation *> *);
  virtual jboolean add (::javax::accessibility::AccessibleRelation *);
  virtual void addAll (JArray< ::javax::accessibility::AccessibleRelation *> *);
  virtual jboolean remove (::javax::accessibility::AccessibleRelation *);
  virtual void clear ();
  virtual jint size ();
  virtual jboolean contains (::java::lang::String *);
  virtual ::javax::accessibility::AccessibleRelation *get (::java::lang::String *);
  virtual JArray< ::javax::accessibility::AccessibleRelation *> *toArray ();
  virtual ::java::lang::String *toString ();
public:  // actually protected
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::java::lang::Object )))) relations;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_accessibility_AccessibleRelationSet__ */
