// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_params_DERWriter__
#define __gnu_javax_crypto_jce_params_DERWriter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace params
          {
            class DERWriter;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::jce::params::DERWriter : public ::java::lang::Object
{
public:
  DERWriter ();
  virtual jbyteArray writeBigInteger (::java::math::BigInteger *);
private:
  jbyteArray writePrimitive (jint, jint, jint, jbyteArray);
public:
  virtual jbyteArray joinarrays (jbyteArray, jbyteArray);
  virtual jbyteArray joinarrays (jbyteArray, jbyteArray, jbyteArray);
private:
  jbyteArray generateIdentifier (jint, jint);
  jbyte translateLeadIdentifierByte (jint);
  jbyteArray generateLength (jint);
public: // actually package-private
  static const jint UNIVERSAL = 1L;
  static const jint APPLICATION = 2L;
  static const jint CONTEXT_SPECIFIC = 3L;
  static const jint PRIVATE = 4L;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_params_DERWriter__ */
