// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalScrollPaneUI__
#define __javax_swing_plaf_metal_MetalScrollPaneUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicScrollPaneUI.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class PropertyChangeListener;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class JScrollPane;
      namespace plaf
      {
        namespace metal
        {
          class MetalScrollPaneUI;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::metal::MetalScrollPaneUI : public ::javax::swing::plaf::basic::BasicScrollPaneUI
{
public:
  MetalScrollPaneUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual void installUI (::javax::swing::JComponent *);
  virtual void uninstallUI (::javax::swing::JComponent *);
  virtual void installListeners (::javax::swing::JScrollPane *);
  virtual void uninstallListeners (::javax::swing::JScrollPane *);
public:  // actually protected
  virtual ::java::beans::PropertyChangeListener *createScrollBarSwapListener ();
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalScrollPaneUI__ */
