// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_locale_LocaleInformation__
#define __gnu_java_locale_LocaleInformation__

#pragma interface

#include <gnu/java/locale/LocaleInformation_en.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace locale
      {
        class LocaleInformation;
      }
    }
  }
}

class gnu::java::locale::LocaleInformation : public ::gnu::java::locale::LocaleInformation_en
{
public:
  LocaleInformation ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_locale_LocaleInformation__ */
