// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalRootPaneUI__
#define __javax_swing_plaf_metal_MetalRootPaneUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicRootPaneUI.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class PropertyChangeEvent;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class JRootPane;
      class JComponent;
      namespace plaf
      {
        class ComponentUI;
        namespace metal
        {
          class MetalRootPaneUI;
        }
      }
    }
  }
}

class javax::swing::plaf::metal::MetalRootPaneUI : public ::javax::swing::plaf::basic::BasicRootPaneUI
{
public:
  MetalRootPaneUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual void installUI (::javax::swing::JComponent *);
  virtual void uninstallUI (::javax::swing::JComponent *);
  virtual void propertyChange (::java::beans::PropertyChangeEvent *);
private:
  void installWindowDecorations (::javax::swing::JRootPane *);
  void uninstallWindowDecorations (::javax::swing::JRootPane *);
  static ::javax::swing::plaf::metal::MetalRootPaneUI *instance;
  static jboolean $assertionsDisabled;

  friend class javax_swing_plaf_metal_MetalRootPaneUI$MetalRootLayout;
  friend class javax_swing_plaf_metal_MetalRootPaneUI$MetalTitlePane;
  friend class javax_swing_plaf_metal_MetalRootPaneUI$MetalFrameBorder;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalRootPaneUI__ */
