// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sql_RowSetEvent__
#define __javax_sql_RowSetEvent__

#pragma interface

#include <java/util/EventObject.h>

extern "Java"
{
  namespace javax
  {
    namespace sql
    {
      class RowSetEvent;
      class RowSet;
    }
  }
}

class javax::sql::RowSetEvent : public ::java::util::EventObject
{
public:
  RowSetEvent (::javax::sql::RowSet *);

  static ::java::lang::Class class$;
};

#endif /* __javax_sql_RowSetEvent__ */
