// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_Properties__
#define __gnu_javax_crypto_keyring_Properties__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class Properties;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::Properties : public ::java::lang::Object
{
public:
  Properties ();
  virtual void clear ();
  virtual ::java::lang::Object *clone ();
  virtual jboolean containsKey (::java::lang::String *);
  virtual jboolean containsValue (::java::lang::String *);
  virtual ::java::lang::String *put (::java::lang::String *, ::java::lang::String *);
  virtual ::java::lang::String *get (::java::lang::String *);
  virtual ::java::lang::String *remove (::java::lang::String *);
  virtual void decode (::java::io::DataInputStream *);
  virtual void encode (::java::io::DataOutputStream *);
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String *canonicalize (::java::lang::String *);
  ::java::util::HashMap * __attribute__((aligned(__alignof__( ::java::lang::Object )))) props;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_Properties__ */
