// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_SSLSocketInputStream__
#define __gnu_javax_net_ssl_provider_SSLSocketInputStream__

#pragma interface

#include <java/io/FilterInputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class SSLSocketInputStream;
            class SSLSocket;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::SSLSocketInputStream : public ::java::io::FilterInputStream
{
public: // actually package-private
  SSLSocketInputStream (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::SSLSocket *);
  SSLSocketInputStream (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::SSLSocket *, jboolean);
public:
  virtual jint available ();
  virtual jint read ();
  virtual jint read (jbyteArray);
  virtual jint read (jbyteArray, jint, jint);
private:
  jboolean checkAlert ();
  ::gnu::javax::net::ssl::provider::SSLSocket * __attribute__((aligned(__alignof__( ::java::io::FilterInputStream )))) socket;
  jboolean checkHandshake;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_SSLSocketInputStream__ */
