// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_attribute_RequestedAttributes__
#define __gnu_javax_print_ipp_attribute_RequestedAttributes__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          namespace attribute
          {
            class RequestedAttributes;
          }
        }
      }
    }
  }
}

class gnu::javax::print::ipp::attribute::RequestedAttributes : public ::java::lang::Object
{
public:
  RequestedAttributes (::java::lang::String *);
  virtual void addValue (::java::lang::String *);
  virtual ::java::util::List *getValues () { return reinterpret_cast< ::java::util::List *> (attributes); }
  virtual ::java::lang::Class *getCategory ();
  virtual ::java::lang::String *getName ();
  virtual ::java::lang::String *toString ();
private:
  ::java::util::ArrayList * __attribute__((aligned(__alignof__( ::java::lang::Object )))) attributes;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_attribute_RequestedAttributes__ */
