// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_assembly_Transformer__
#define __gnu_javax_crypto_assembly_Transformer__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace pad
        {
          class IPad;
        }
        namespace assembly
        {
          class Cascade;
          class Transformer;
          class Operation;
          class Direction;
        }
      }
    }
  }
}

class gnu::javax::crypto::assembly::Transformer : public ::java::lang::Object
{
public:  // actually protected
  Transformer ();
public:
  static ::gnu::javax::crypto::assembly::Transformer *getCascadeTransformer (::gnu::javax::crypto::assembly::Cascade *);
  static ::gnu::javax::crypto::assembly::Transformer *getPaddingTransformer (::gnu::javax::crypto::pad::IPad *);
  static ::gnu::javax::crypto::assembly::Transformer *getDeflateTransformer ();
  virtual void setMode (::gnu::javax::crypto::assembly::Operation *);
  virtual jboolean isPreProcessing ();
  virtual jboolean isPostProcessing ();
  virtual void init (::java::util::Map *);
  virtual jint currentBlockSize ();
  virtual void reset ();
  virtual jbyteArray update (jbyte);
  virtual jbyteArray update (jbyteArray);
  virtual jbyteArray update (jbyteArray, jint, jint);
  virtual jbyteArray lastUpdate ();
  virtual jbyteArray lastUpdate (jbyte);
  virtual jbyteArray lastUpdate (jbyteArray);
  virtual jbyteArray lastUpdate (jbyteArray, jint, jint);
private:
  jbyteArray forwardUpdate (jbyteArray, jint, jint);
  jbyteArray inverseUpdate (jbyteArray, jint, jint);
  jbyteArray preTransform (jbyteArray, jint, jint);
  jbyteArray postTransform (jbyteArray, jint, jint);
  jbyteArray lastForwardUpdate ();
  jbyteArray lastInverseUpdate ();
  jbyteArray preLastTransform ();
  jbyteArray postLastTransform ();
public: // actually package-private
  virtual void initDelegate (::java::util::Map *) = 0;
  virtual jint delegateBlockSize () = 0;
  virtual void resetDelegate () = 0;
  virtual jbyteArray updateDelegate (jbyteArray, jint, jint) = 0;
  virtual jbyteArray lastUpdateDelegate () = 0;
public:
  static ::java::lang::String *DIRECTION;
public:  // actually protected
  ::gnu::javax::crypto::assembly::Direction * __attribute__((aligned(__alignof__( ::java::lang::Object )))) wired;
  ::gnu::javax::crypto::assembly::Operation *mode;
  ::gnu::javax::crypto::assembly::Transformer *tail;
  ::java::io::ByteArrayOutputStream *inBuffer;
  ::java::io::ByteArrayOutputStream *outBuffer;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_assembly_Transformer__ */
