// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_event_PrintJobAttributeEvent__
#define __javax_print_event_PrintJobAttributeEvent__

#pragma interface

#include <javax/print/event/PrintEvent.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace event
      {
        class PrintJobAttributeEvent;
      }
      class DocPrintJob;
      namespace attribute
      {
        class PrintJobAttributeSet;
      }
    }
  }
}

class javax::print::event::PrintJobAttributeEvent : public ::javax::print::event::PrintEvent
{
public:
  PrintJobAttributeEvent (::javax::print::DocPrintJob *, ::javax::print::attribute::PrintJobAttributeSet *);
  virtual ::javax::print::DocPrintJob *getPrintJob ();
  virtual ::javax::print::attribute::PrintJobAttributeSet *getAttributes () { return attributes; }
private:
  static const jlong serialVersionUID = -6534469883874742101LL;
  ::javax::print::attribute::PrintJobAttributeSet * __attribute__((aligned(__alignof__( ::javax::print::event::PrintEvent )))) attributes;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_event_PrintJobAttributeEvent__ */
