// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_management_VMMemoryPoolMXBeanImpl__
#define __gnu_java_lang_management_VMMemoryPoolMXBeanImpl__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        namespace management
        {
          class VMMemoryPoolMXBeanImpl;
        }
      }
    }
  }
}

class gnu::java::lang::management::VMMemoryPoolMXBeanImpl : public ::java::lang::Object
{
public: // actually package-private
  static ::java::lang::management::MemoryUsage *getCollectionUsage (::java::lang::String *) { return 0; }
  static jlong getCollectionUsageThreshold (::java::lang::String *);
  static jlong getCollectionUsageThresholdCount (::java::lang::String *);
  static JArray< ::java::lang::String *> *getMemoryManagerNames (::java::lang::String *);
  static ::java::lang::management::MemoryUsage *getPeakUsage (::java::lang::String *) { return 0; }
  static ::java::lang::String *getType (::java::lang::String *);
  static ::java::lang::management::MemoryUsage *getUsage (::java::lang::String *) { return 0; }
  static jlong getUsageThreshold (::java::lang::String *);
  static jlong getUsageThresholdCount (::java::lang::String *);
  static jboolean isValid (::java::lang::String *);
  static void resetPeakUsage (::java::lang::String *) { }
  static void setCollectionUsageThreshold (::java::lang::String *, jlong) { }
  static void setUsageThreshold (::java::lang::String *, jlong) { }
  VMMemoryPoolMXBeanImpl ();
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_lang_management_VMMemoryPoolMXBeanImpl__ */
