// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_rmi_activation_BidiTable__
#define __gnu_java_rmi_activation_BidiTable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace rmi
      {
        namespace activation
        {
          class BidiTable;
        }
      }
    }
  }
}

class gnu::java::rmi::activation::BidiTable : public ::java::lang::Object
{
public:
  BidiTable ();
public:  // actually protected
  BidiTable (jint);
public:
  virtual ::java::lang::Object *getKey (::java::lang::Object *);
  virtual void put (::java::lang::Object *, ::java::lang::Object *);
  virtual ::java::lang::Object *get (::java::lang::Object *);
  virtual void removeKey (::java::lang::Object *);
  virtual jboolean containsKey (::java::lang::Object *);
  virtual void shutdown ();
  virtual jint size ();
  virtual JArray< ::java::lang::Object *> *keys ();
private:
  static const jlong serialVersionUID = 1LL;
public:  // actually protected
  ::java::util::Map * __attribute__((aligned(__alignof__( ::java::lang::Object )))) k2v;
  ::java::util::Map *v2k;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_rmi_activation_BidiTable__ */
