// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_support_parameterDefaulter__
#define __gnu_javax_swing_text_html_parser_support_parameterDefaulter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                class parameterDefaulter;
              }
              class htmlAttributeSet;
            }
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          namespace parser
          {
            class DTD;
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::support::parameterDefaulter : public ::java::lang::Object
{
public:
  parameterDefaulter (::javax::swing::text::html::parser::DTD *);
  virtual ::gnu::javax::swing::text::html::parser::htmlAttributeSet *getDefaultParameters (::java::lang::String *);
  ::javax::swing::text::html::parser::DTD * __attribute__((aligned(__alignof__( ::java::lang::Object )))) dtd;
public: // actually package-private
  ::java::util::Hashtable *sets;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_support_parameterDefaulter__ */
