// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_Clip__
#define __javax_sound_sampled_Clip__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class Clip;
        class AudioInputStream;
        class AudioFormat;
      }
    }
  }
}

class javax::sound::sampled::Clip : public ::java::lang::Object
{
public:
  virtual jint getFrameLength () = 0;
  virtual jlong getMicrosecondLength () = 0;
  virtual void loop (jint) = 0;
  virtual void open (::javax::sound::sampled::AudioFormat *, jbyteArray, jint, jint) = 0;
  virtual void open (::javax::sound::sampled::AudioInputStream *) = 0;
  virtual void setFramePosition (jint) = 0;
  virtual void setLoopPoints (jint, jint) = 0;
  virtual void setMicrosecondPosition (jlong) = 0;
  static const jint LOOP_CONTINUOUSLY = -1L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sound_sampled_Clip__ */
