// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_parser_DTD__
#define __javax_swing_text_html_parser_DTD__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          namespace parser
          {
            class ContentModel;
            class AttributeList;
            class Entity;
            class DTD;
            class Element;
          }
        }
      }
    }
  }
}

class javax::swing::text::html::parser::DTD : public ::java::lang::Object
{
public:  // actually protected
  DTD (::java::lang::String *);
public:
  static ::javax::swing::text::html::parser::DTD *getDTD (::java::lang::String *);
  virtual ::javax::swing::text::html::parser::Element *getElement (::java::lang::String *);
  virtual ::javax::swing::text::html::parser::Element *getElement (jint);
  virtual ::javax::swing::text::html::parser::Entity *getEntity (jint);
  virtual ::javax::swing::text::html::parser::Entity *getEntity (::java::lang::String *);
  virtual ::java::lang::String *getName () { return name; }
  virtual ::javax::swing::text::html::parser::Entity *defEntity (::java::lang::String *, jint, jint);
  virtual void defineAttributes (::java::lang::String *, ::javax::swing::text::html::parser::AttributeList *);
  virtual ::javax::swing::text::html::parser::Element *defineElement (::java::lang::String *, jint, jboolean, jboolean, ::javax::swing::text::html::parser::ContentModel *, ::java::util::BitSet *, ::java::util::BitSet *, ::javax::swing::text::html::parser::AttributeList *);
  virtual ::javax::swing::text::html::parser::Entity *defineEntity (::java::lang::String *, jint, jcharArray);
  static void putDTDHash (::java::lang::String *, ::javax::swing::text::html::parser::DTD *);
  virtual void read (::java::io::DataInputStream *);
  virtual ::java::lang::String *toString () { return name; }
public:  // actually protected
  virtual ::javax::swing::text::html::parser::AttributeList *defAttributeList (::java::lang::String *, jint, jint, ::java::lang::String *, ::java::lang::String *, ::javax::swing::text::html::parser::AttributeList *);
  virtual ::javax::swing::text::html::parser::ContentModel *defContentModel (jint, ::java::lang::Object *, ::javax::swing::text::html::parser::ContentModel *);
  virtual ::javax::swing::text::html::parser::Element *defElement (::java::lang::String *, jint, jboolean, jboolean, ::javax::swing::text::html::parser::ContentModel *, JArray< ::java::lang::String *> *, JArray< ::java::lang::String *> *, ::javax::swing::text::html::parser::AttributeList *);
  virtual ::javax::swing::text::html::parser::Entity *defEntity (::java::lang::String *, jint, ::java::lang::String *);
private:
  void assignField (::javax::swing::text::html::parser::Element *);
  ::java::util::BitSet *bitSet (JArray< ::java::lang::String *> *);
  ::javax::swing::text::html::parser::Element *newElement (::java::lang::String *);
  ::javax::swing::text::html::parser::Entity *newEntity (::java::lang::String *, jint);
  void unexpected (::java::lang::Exception *);
public:
  static const jint FILE_VERSION = 1L;
public: // actually package-private
  static ::java::util::Hashtable *dtdHash;
public:
  ::javax::swing::text::html::parser::Element * __attribute__((aligned(__alignof__( ::java::lang::Object )))) applet;
  ::javax::swing::text::html::parser::Element *base;
  ::javax::swing::text::html::parser::Element *body;
  ::javax::swing::text::html::parser::Element *head;
  ::javax::swing::text::html::parser::Element *html;
  ::javax::swing::text::html::parser::Element *isindex;
  ::javax::swing::text::html::parser::Element *meta;
  ::javax::swing::text::html::parser::Element *p;
  ::javax::swing::text::html::parser::Element *param;
  ::javax::swing::text::html::parser::Element *pcdata;
  ::javax::swing::text::html::parser::Element *title;
  ::java::util::Hashtable *elementHash;
  ::java::util::Hashtable *entityHash;
  ::java::lang::String *name;
  ::java::util::Vector *elements;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_parser_DTD__ */
