// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalTextFieldUI__
#define __javax_swing_plaf_metal_MetalTextFieldUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicTextFieldUI.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class PropertyChangeEvent;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalTextFieldUI;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::metal::MetalTextFieldUI : public ::javax::swing::plaf::basic::BasicTextFieldUI
{
public:
  MetalTextFieldUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual void propertyChange (::java::beans::PropertyChangeEvent *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalTextFieldUI__ */
