// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_TextEvent__
#define __java_awt_event_TextEvent__

#pragma interface

#include <java/awt/AWTEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class TextEvent;
      }
    }
  }
}

class java::awt::event::TextEvent : public ::java::awt::AWTEvent
{
public:
  TextEvent (::java::lang::Object *, jint);
  virtual ::java::lang::String *paramString ();
private:
  static const jlong serialVersionUID = 6269902291250941179LL;
public:
  static const jint TEXT_FIRST = 900L;
  static const jint TEXT_LAST = 900L;
  static const jint TEXT_VALUE_CHANGED = 900L;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_TextEvent__ */
