// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_spi_MixerProvider__
#define __javax_sound_sampled_spi_MixerProvider__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        namespace spi
        {
          class MixerProvider;
        }
        class Mixer;
        class Mixer$Info;
      }
    }
  }
}

class javax::sound::sampled::spi::MixerProvider : public ::java::lang::Object
{
public:
  MixerProvider ();
  virtual ::javax::sound::sampled::Mixer *getMixer (::javax::sound::sampled::Mixer$Info *) = 0;
  virtual JArray< ::javax::sound::sampled::Mixer$Info *> *getMixerInfo () = 0;
  virtual jboolean isMixerSupported (::javax::sound::sampled::Mixer$Info *);

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_sampled_spi_MixerProvider__ */
