// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_Destroyable__
#define __javax_security_auth_Destroyable__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        class Destroyable;
      }
    }
  }
}

class javax::security::auth::Destroyable : public ::java::lang::Object
{
public:
  virtual void destroy () = 0;
  virtual jboolean isDestroyed () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_security_auth_Destroyable__ */
