// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_reflect_MalformedParameterizedTypeException__
#define __java_lang_reflect_MalformedParameterizedTypeException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::reflect::MalformedParameterizedTypeException : public ::java::lang::RuntimeException
{
public:
  MalformedParameterizedTypeException ();
private:
  static const jlong serialVersionUID = -5696557788586220964LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_reflect_MalformedParameterizedTypeException__ */
