// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_AreaAveragingScaleFilter__
#define __java_awt_image_AreaAveragingScaleFilter__

#pragma interface

#include <java/awt/image/ReplicateScaleFilter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class AreaAveragingScaleFilter;
        class ColorModel;
      }
    }
  }
}

class java::awt::image::AreaAveragingScaleFilter : public ::java::awt::image::ReplicateScaleFilter
{
public:
  AreaAveragingScaleFilter (jint, jint);
  virtual void setHints (jint);
  virtual void setPixels (jint, jint, jint, jint, ::java::awt::image::ColorModel *, jbyteArray, jint, jint);
  virtual void setPixels (jint, jint, jint, jint, ::java::awt::image::ColorModel *, jintArray, jint, jint);
private:
  jbyteArray averagePixels (jint, jint, jint, jint, ::java::awt::image::ColorModel *, jbyteArray, jint, jint, jdouble, jdouble, jint);
  jintArray averagePixels (jint, jint, jint, jint, ::java::awt::image::ColorModel *, jintArray, jint, jint, jdouble, jdouble, jint);
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_AreaAveragingScaleFilter__ */
