// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_prng_IPBE__
#define __gnu_javax_crypto_prng_IPBE__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace prng
        {
          class IPBE;
        }
      }
    }
  }
}

class gnu::javax::crypto::prng::IPBE : public ::java::lang::Object
{
public:
  static ::java::lang::String *ITERATION_COUNT;
  static ::java::lang::String *PASSWORD;
  static ::java::lang::String *PASSWORD_ENCODING;
  static ::java::lang::String *SALT;
  static ::java::lang::String *DEFAULT_PASSWORD_ENCODING;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_prng_IPBE__ */
