// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_ObjectStreamConstants__
#define __java_io_ObjectStreamConstants__

#pragma interface

#include <java/lang/Object.h>

class java::io::ObjectStreamConstants : public ::java::lang::Object
{
public:
  static const jint PROTOCOL_VERSION_1 = 1L;
  static const jint PROTOCOL_VERSION_2 = 2L;
  static const jint STREAM_MAGIC = -21267L;
  static const jint STREAM_VERSION = 5L;
  static const jint TC_NULL = 112L;
  static const jint TC_REFERENCE = 113L;
  static const jint TC_CLASSDESC = 114L;
  static const jint TC_OBJECT = 115L;
  static const jint TC_STRING = 116L;
  static const jint TC_ARRAY = 117L;
  static const jint TC_CLASS = 118L;
  static const jint TC_BLOCKDATA = 119L;
  static const jint TC_ENDBLOCKDATA = 120L;
  static const jint TC_RESET = 121L;
  static const jint TC_BLOCKDATALONG = 122L;
  static const jint TC_EXCEPTION = 123L;
  static const jint TC_LONGSTRING = 124L;
  static const jint TC_PROXYCLASSDESC = 125L;
  static const jint TC_ENUM = 126L;
  static const jint TC_BASE = 112L;
  static const jint TC_MAX = 126L;
  static const jint baseWireHandle = 8257536L;
  static const jint SC_WRITE_METHOD = 1L;
  static const jint SC_SERIALIZABLE = 2L;
  static const jint SC_EXTERNALIZABLE = 4L;
  static const jint SC_BLOCK_DATA = 8L;
  static const jint SC_ENUM = 16L;
  static ::java::io::SerializablePermission *SUBSTITUTION_PERMISSION;
  static ::java::io::SerializablePermission *SUBCLASS_IMPLEMENTATION_PERMISSION;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_io_ObjectStreamConstants__ */
