// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_srp_CALG__
#define __gnu_javax_crypto_sasl_srp_CALG__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace srp
          {
            class KDF;
            class CALG;
          }
        }
        namespace assembly
        {
          class Direction;
          class Assembly;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::srp::CALG : public ::java::lang::Object
{
private:
  CALG (jint, jint, ::java::lang::Object *, ::gnu::javax::crypto::assembly::Assembly *);
public: // actually package-private
  static ::gnu::javax::crypto::sasl::srp::CALG *getInstance (::java::lang::String *);
public:
  virtual void init (::gnu::javax::crypto::sasl::srp::KDF *, jbyteArray, ::gnu::javax::crypto::assembly::Direction *);
  virtual jbyteArray doFinal (jbyteArray);
  virtual jbyteArray doFinal (jbyteArray, jint, jint);
private:
  ::gnu::javax::crypto::assembly::Assembly * __attribute__((aligned(__alignof__( ::java::lang::Object )))) assembly;
  ::java::lang::Object *modeNdx;
  jint blockSize;
  jint keySize;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_srp_CALG__ */
