// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_color_ProfileHeader__
#define __gnu_java_awt_color_ProfileHeader__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace color
        {
          class ProfileHeader;
        }
      }
    }
  }
}

class gnu::java::awt::color::ProfileHeader : public ::java::lang::Object
{
public:
  ProfileHeader ();
  ProfileHeader (jbyteArray);
  virtual void verifyHeader (jint);
  virtual jbyteArray getData (jint);
  virtual jint getSize () { return size; }
  virtual void setSize (jint);
  virtual jint getMajorVersion () { return majorVersion; }
  virtual jint getMinorVersion () { return minorVersion; }
  virtual jint getProfileClass () { return profileClass; }
  virtual void setProfileClass (jint);
  virtual jint getColorSpace () { return colorSpace; }
  virtual jint getProfileColorSpace () { return profileColorSpace; }
  virtual void setColorSpace (jint);
  virtual void setProfileColorSpace (jint);
private:
  static const jint icMagicNumber = 1633907568L;
  static jintArray csTypeMap;
public:
  static const jint HEADERSIZE = 128L;
private:
  static jintArray classMap;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  size;
  jint cmmId;
  jint majorVersion;
  jint minorVersion;
  jint profileClass;
  jint colorSpace;
  jint profileColorSpace;
  jbyteArray timestamp;
  jint platform;
  jint flags;
  jint magic;
  jint manufacturerSig;
  jint modelSig;
  jbyteArray attributes;
  jint intent;
  jbyteArray illuminant;
  jint creatorSig;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_color_ProfileHeader__ */
