// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalToolBarUI__
#define __javax_swing_plaf_metal_MetalToolBarUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicToolBarUI.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class MouseInputListener;
      }
      namespace border
      {
        class Border;
      }
      namespace plaf
      {
        namespace metal
        {
          class MetalToolBarUI;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
  namespace java
  {
    namespace beans
    {
      class PropertyChangeListener;
    }
    namespace awt
    {
      class Graphics;
      class Point;
      namespace event
      {
        class ContainerListener;
      }
    }
  }
}

class javax::swing::plaf::metal::MetalToolBarUI : public ::javax::swing::plaf::basic::BasicToolBarUI
{
public:
  MetalToolBarUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual ::java::beans::PropertyChangeListener *createRolloverListener () { return 0; }
  virtual ::java::awt::event::ContainerListener *createContainerListener () { return 0; }
  virtual ::javax::swing::border::Border *createNonRolloverBorder ();
  virtual void setDragOffset (::java::awt::Point *);
  virtual ::javax::swing::event::MouseInputListener *createDockingListener ();
public:
  virtual void installUI (::javax::swing::JComponent *);
  virtual void uninstallUI (::javax::swing::JComponent *);
  virtual void update (::java::awt::Graphics *, ::javax::swing::JComponent *);
public:  // actually protected
  ::java::awt::event::ContainerListener * __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicToolBarUI )))) contListener;
  ::java::beans::PropertyChangeListener *rolloverListener;

  friend class javax_swing_plaf_metal_MetalToolBarUI$MetalDockingListener;
  friend class javax_swing_plaf_metal_MetalToolBarUI$MetalRolloverListener;
  friend class javax_swing_plaf_metal_MetalToolBarUI$MetalContainerListener;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalToolBarUI__ */
