// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_InvalidParameterException__
#define __java_security_InvalidParameterException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class InvalidParameterException;
    }
  }
}

class java::security::InvalidParameterException : public ::java::lang::IllegalArgumentException
{
public:
  InvalidParameterException ();
  InvalidParameterException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -857968536935667808LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_InvalidParameterException__ */
