// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_JMRuntimeException__
#define __javax_management_JMRuntimeException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      class JMRuntimeException;
    }
  }
}

class javax::management::JMRuntimeException : public ::java::lang::RuntimeException
{
public:
  JMRuntimeException ();
  JMRuntimeException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_management_JMRuntimeException__ */
