// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_midi_Patch__
#define __javax_sound_midi_Patch__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace midi
      {
        class Patch;
      }
    }
  }
}

class javax::sound::midi::Patch : public ::java::lang::Object
{
public:
  Patch (jint, jint);
  virtual jint getBank () { return bank; }
  virtual jint getProgram () { return program; }
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  bank;
  jint program;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_midi_Patch__ */
