// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_LimitExceededException__
#define __javax_naming_LimitExceededException__

#pragma interface

#include <javax/naming/NamingException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class LimitExceededException;
    }
  }
}

class javax::naming::LimitExceededException : public ::javax::naming::NamingException
{
public:
  LimitExceededException ();
  LimitExceededException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -776898738660207856LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_LimitExceededException__ */
