// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_management_VMMemoryManagerMXBeanImpl__
#define __gnu_java_lang_management_VMMemoryManagerMXBeanImpl__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        namespace management
        {
          class VMMemoryManagerMXBeanImpl;
        }
      }
    }
  }
}

class gnu::java::lang::management::VMMemoryManagerMXBeanImpl : public ::java::lang::Object
{
public: // actually package-private
  static JArray< ::java::lang::String *> *getMemoryPoolNames (::java::lang::String *);
  static jboolean isValid (::java::lang::String *);
  VMMemoryManagerMXBeanImpl ();
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_lang_management_VMMemoryManagerMXBeanImpl__ */
