// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_font_ShapeGraphicAttribute__
#define __java_awt_font_ShapeGraphicAttribute__

#pragma interface

#include <java/awt/font/GraphicAttribute.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace font
      {
        class ShapeGraphicAttribute;
      }
      class Graphics2D;
      namespace geom
      {
        class Rectangle2D;
      }
      class Shape;
    }
  }
}

class java::awt::font::ShapeGraphicAttribute : public ::java::awt::font::GraphicAttribute
{
public:
  ShapeGraphicAttribute (::java::awt::Shape *, jint, jboolean);
  virtual void draw (::java::awt::Graphics2D *, jfloat, jfloat);
  virtual jboolean equals (::java::lang::Object *);
  virtual jboolean equals (::java::awt::font::ShapeGraphicAttribute *);
  virtual jfloat getAdvance ();
  virtual jfloat getAscent ();
  virtual jfloat getDescent ();
  virtual ::java::awt::geom::Rectangle2D *getBounds ();
  virtual jint hashCode ();
  static const jint FILL = 0L;
  static const jint STROKE = 1L;
private:
  ::java::awt::Shape * __attribute__((aligned(__alignof__( ::java::awt::font::GraphicAttribute )))) shape;
  jboolean stroke;
  ::java::awt::geom::Rectangle2D *bounds;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_font_ShapeGraphicAttribute__ */
