// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_RESyntax__
#define __gnu_java_util_regex_RESyntax__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class RESyntax;
        }
      }
    }
  }
}

class gnu::java::util::regex::RESyntax : public ::java::lang::Object
{
public:
  RESyntax ();
  virtual ::gnu::java::util::regex::RESyntax *makeFinal ();
  RESyntax (::gnu::java::util::regex::RESyntax *);
  virtual jboolean get (jint);
  virtual ::gnu::java::util::regex::RESyntax *set (jint);
  virtual ::gnu::java::util::regex::RESyntax *clear (jint);
  virtual ::gnu::java::util::regex::RESyntax *setLineSeparator (::java::lang::String *);
  virtual ::java::lang::String *getLineSeparator () { return lineSeparator; }
public: // actually package-private
  static ::java::lang::String *DEFAULT_LINE_SEPARATOR;
private:
  static ::java::lang::String *SYNTAX_IS_FINAL;
  ::java::util::BitSet * __attribute__((aligned(__alignof__( ::java::lang::Object )))) bits;
  jboolean isFinal;
  ::java::lang::String *lineSeparator;
public:
  static const jint RE_BACKSLASH_ESCAPE_IN_LISTS = 0L;
  static const jint RE_BK_PLUS_QM = 1L;
  static const jint RE_CHAR_CLASSES = 2L;
  static const jint RE_CONTEXT_INDEP_ANCHORS = 3L;
  static const jint RE_CONTEXT_INDEP_OPS = 4L;
  static const jint RE_CONTEXT_INVALID_OPS = 5L;
  static const jint RE_DOT_NEWLINE = 6L;
  static const jint RE_DOT_NOT_NULL = 7L;
  static const jint RE_INTERVALS = 8L;
  static const jint RE_LIMITED_OPS = 9L;
  static const jint RE_NEWLINE_ALT = 10L;
  static const jint RE_NO_BK_BRACES = 11L;
  static const jint RE_NO_BK_PARENS = 12L;
  static const jint RE_NO_BK_REFS = 13L;
  static const jint RE_NO_BK_VBAR = 14L;
  static const jint RE_NO_EMPTY_RANGES = 15L;
  static const jint RE_UNMATCHED_RIGHT_PAREN_ORD = 16L;
  static const jint RE_HAT_LISTS_NOT_NEWLINE = 17L;
  static const jint RE_STINGY_OPS = 18L;
  static const jint RE_CHAR_CLASS_ESCAPES = 19L;
  static const jint RE_PURE_GROUPING = 20L;
  static const jint RE_LOOKAHEAD = 21L;
  static const jint RE_STRING_ANCHORS = 22L;
  static const jint RE_COMMENTS = 23L;
  static const jint RE_CHAR_CLASS_ESC_IN_LISTS = 24L;
  static const jint RE_POSSESSIVE_OPS = 25L;
  static const jint RE_EMBEDDED_FLAGS = 26L;
  static const jint RE_OCTAL_CHAR = 27L;
  static const jint RE_HEX_CHAR = 28L;
  static const jint RE_UNICODE_CHAR = 29L;
  static const jint RE_NAMED_PROPERTY = 30L;
  static const jint RE_NESTED_CHARCLASS = 31L;
private:
  static const jint BIT_TOTAL = 32L;
public:
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_AWK;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_ED;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_EGREP;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_EMACS;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_GREP;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_POSIX_AWK;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_POSIX_BASIC;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_POSIX_EGREP;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_POSIX_EXTENDED;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_POSIX_MINIMAL_BASIC;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_POSIX_MINIMAL_EXTENDED;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_SED;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_PERL4;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_PERL4_S;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_PERL5;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_PERL5_S;
  static ::gnu::java::util::regex::RESyntax *RE_SYNTAX_JAVA_1_4;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_RESyntax__ */
