// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_DatagramChannelSelectionKey__
#define __gnu_java_nio_DatagramChannelSelectionKey__

#pragma interface

#include <gnu/java/nio/SelectionKeyImpl.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        class DatagramChannelSelectionKey;
        class SelectorImpl;
      }
    }
  }
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        namespace spi
        {
          class AbstractSelectableChannel;
        }
      }
    }
  }
}

class gnu::java::nio::DatagramChannelSelectionKey : public ::gnu::java::nio::SelectionKeyImpl
{
public:
  DatagramChannelSelectionKey (::java::nio::channels::spi::AbstractSelectableChannel *, ::gnu::java::nio::SelectorImpl *);
  virtual jint getNativeFD ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_DatagramChannelSelectionKey__ */
