// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_sig_DHParametersGenerator__
#define __gnu_javax_crypto_jce_sig_DHParametersGenerator__

#pragma interface

#include <java/security/AlgorithmParameterGeneratorSpi.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace sig
          {
            class DHParametersGenerator;
          }
        }
        namespace key
        {
          namespace dh
          {
            class RFC2631;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      class AlgorithmParameters;
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class SecureRandom;
      class Provider;
    }
  }
}

class gnu::javax::crypto::jce::sig::DHParametersGenerator : public ::java::security::AlgorithmParameterGeneratorSpi
{
public:  // actually protected
  virtual void engineInit (jint, ::java::security::SecureRandom *);
  virtual void engineInit (::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *);
  virtual ::java::security::AlgorithmParameters *engineGenerateParameters ();
public:
  DHParametersGenerator ();
private:
  static ::java::security::Provider *GNU_CRYPTO;
  jint __attribute__((aligned(__alignof__( ::java::security::AlgorithmParameterGeneratorSpi ))))  modulusSize;
  jint exponentSize;
  ::java::security::SecureRandom *rnd;
  ::gnu::javax::crypto::key::dh::RFC2631 *rfc2631;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_sig_DHParametersGenerator__ */
