// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_server_RMIClassLoaderSpi__
#define __java_rmi_server_RMIClassLoaderSpi__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      namespace server
      {
        class RMIClassLoaderSpi;
      }
    }
  }
}

class java::rmi::server::RMIClassLoaderSpi : public ::java::lang::Object
{
public:
  RMIClassLoaderSpi ();
  virtual ::java::lang::Class *loadClass (::java::lang::String *, ::java::lang::String *, ::java::lang::ClassLoader *) = 0;
  virtual ::java::lang::Class *loadProxyClass (::java::lang::String *, JArray< ::java::lang::String *> *, ::java::lang::ClassLoader *) = 0;
  virtual ::java::lang::ClassLoader *getClassLoader (::java::lang::String *) = 0;
  virtual ::java::lang::String *getClassAnnotation (::java::lang::Class *) = 0;

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_server_RMIClassLoaderSpi__ */
