// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_RuntimePermission__
#define __java_lang_RuntimePermission__

#pragma interface

#include <java/security/BasicPermission.h>

class java::lang::RuntimePermission : public ::java::security::BasicPermission
{
public:
  RuntimePermission (::java::lang::String *);
  RuntimePermission (::java::lang::String *, ::java::lang::String *);
private:
  static const jlong serialVersionUID = 7399184964622342223LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_RuntimePermission__ */
