// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_ber_BEREncodingException__
#define __gnu_java_security_ber_BEREncodingException__

#pragma interface

#include <gnu/java/security/der/DEREncodingException.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace ber
        {
          class BEREncodingException;
        }
      }
    }
  }
}

class gnu::java::security::ber::BEREncodingException : public ::gnu::java::security::der::DEREncodingException
{
public:
  BEREncodingException ();
  BEREncodingException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_ber_BEREncodingException__ */
