// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_GnuCrypto__
#define __gnu_javax_crypto_jce_GnuCrypto__

#pragma interface

#include <java/security/Provider.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          class GnuCrypto;
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::GnuCrypto : public ::java::security::Provider
{
public:
  GnuCrypto ();
  static ::java::util::Set *getCipherNames ();
  static ::java::util::Set *getMacNames ();

  friend class gnu_javax_crypto_jce_GnuCrypto$1;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_GnuCrypto__ */
