// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_sig_rsa_RSAPSSSignatureRawCodec__
#define __gnu_java_security_sig_rsa_RSAPSSSignatureRawCodec__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace sig
        {
          namespace rsa
          {
            class RSAPSSSignatureRawCodec;
          }
        }
      }
    }
  }
}

class gnu::java::security::sig::rsa::RSAPSSSignatureRawCodec : public ::java::lang::Object
{
public:
  virtual jint getFormatID ();
  virtual jbyteArray encodeSignature (::java::lang::Object *);
  virtual ::java::lang::Object *decodeSignature (jbyteArray);
  RSAPSSSignatureRawCodec ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_sig_rsa_RSAPSSSignatureRawCodec__ */
