// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_DefaultMenuLayout__
#define __javax_swing_plaf_basic_DefaultMenuLayout__

#pragma interface

#include <javax/swing/BoxLayout.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class DefaultMenuLayout;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Dimension;
      class Container;
    }
  }
}

class javax::swing::plaf::basic::DefaultMenuLayout : public ::javax::swing::BoxLayout
{
public:
  DefaultMenuLayout (::java::awt::Container *, jint);
  virtual ::java::awt::Dimension *preferredLayoutSize (::java::awt::Container *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_DefaultMenuLayout__ */
