// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_font_opentype_MacResourceFork__
#define __gnu_java_awt_font_opentype_MacResourceFork__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class ByteBuffer;
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace font
        {
          namespace opentype
          {
            class MacResourceFork;
            class MacResourceFork$Resource;
          }
        }
      }
    }
  }
}

class gnu::java::awt::font::opentype::MacResourceFork : public ::java::lang::Object
{
public:
  MacResourceFork (::java::nio::ByteBuffer *);
  virtual JArray< ::gnu::java::awt::font::opentype::MacResourceFork$Resource *> *getResources (jint);
  virtual ::gnu::java::awt::font::opentype::MacResourceFork$Resource *getResource (jint, jshort);
public: // actually package-private
  jintArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  types;
  JArray<JArray< ::gnu::java::awt::font::opentype::MacResourceFork$Resource *> *> *resources;
  ::java::nio::ByteBuffer *buf;

  friend class gnu_java_awt_font_opentype_MacResourceFork$Resource;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_font_opentype_MacResourceFork__ */
