// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_synth_SynthConstants__
#define __javax_swing_plaf_synth_SynthConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace synth
        {
          class SynthConstants;
        }
      }
    }
  }
}

class javax::swing::plaf::synth::SynthConstants : public ::java::lang::Object
{
public:
  static const jint ENABLED = 1L;
  static const jint DISABLED = 8L;
  static const jint MOUSE_OVER = 2L;
  static const jint PRESSED = 4L;
  static const jint FOCUSED = 256L;
  static const jint SELECTED = 512L;
  static const jint DEFAULT = 1024L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_plaf_synth_SynthConstants__ */
