// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_REMatchEnumeration__
#define __gnu_java_util_regex_REMatchEnumeration__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class REMatchEnumeration;
          class CharIndexed;
          class RE;
          class REMatch;
        }
      }
    }
  }
}

class gnu::java::util::regex::REMatchEnumeration : public ::java::lang::Object
{
public: // actually package-private
  REMatchEnumeration (::gnu::java::util::regex::RE *, ::gnu::java::util::regex::CharIndexed *, jint, jint);
public:
  virtual jboolean hasMoreElements ();
  virtual jboolean hasMoreMatches ();
  virtual jboolean hasMoreMatches (::java::lang::StringBuffer *);
  virtual ::java::lang::Object *nextElement ();
  virtual ::gnu::java::util::regex::REMatch *nextMatch ();
private:
  static const jint YES = 1L;
  static const jint MAYBE = 0L;
  static const jint NO = -1L;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  more;
  ::gnu::java::util::regex::REMatch *match;
  ::gnu::java::util::regex::RE *expr;
  ::gnu::java::util::regex::CharIndexed *input;
  jint eflags;
  jint index;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_REMatchEnumeration__ */
