// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_ServiceUIFactory__
#define __javax_print_ServiceUIFactory__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class ServiceUIFactory;
    }
  }
}

class javax::print::ServiceUIFactory : public ::java::lang::Object
{
public:
  ServiceUIFactory ();
  virtual ::java::lang::Object *getUI (jint, ::java::lang::String *) = 0;
  virtual JArray< ::java::lang::String *> *getUIClassNamesForRole (jint) = 0;
  static const jint ABOUT_UIROLE = 1L;
  static const jint ADMIN_UIROLE = 2L;
  static const jint MAIN_UIROLE = 3L;
  static const jint RESERVED_UIROLE = 99L;
  static ::java::lang::String *DIALOG_UI;
  static ::java::lang::String *JCOMPONENT_UI;
  static ::java::lang::String *JDIALOG_UI;
  static ::java::lang::String *PANEL_UI;

  static ::java::lang::Class class$;
};

#endif /* __javax_print_ServiceUIFactory__ */
