// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_logging_SocketHandler__
#define __java_util_logging_SocketHandler__

#pragma interface

#include <java/util/logging/StreamHandler.h>

class java::util::logging::SocketHandler : public ::java::util::logging::StreamHandler
{
public:
  SocketHandler ();
  SocketHandler (::java::lang::String *, jint);
private:
  static jint getPortNumber ();
  static ::java::io::OutputStream *createSocket (::java::lang::String *, jint);
public:
  virtual void publish (::java::util::logging::LogRecord *);

  static ::java::lang::Class class$;
};

#endif /* __java_util_logging_SocketHandler__ */
