// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_color_CMMException__
#define __java_awt_color_CMMException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class CMMException;
      }
    }
  }
}

class java::awt::color::CMMException : public ::java::lang::RuntimeException
{
public:
  CMMException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 5775558044142994965LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_color_CMMException__ */
