// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_Utilities__
#define __javax_swing_text_Utilities__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class FontMetrics;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class Utilities;
        class Element;
        class JTextComponent;
        class TabExpander;
        class Segment;
      }
    }
  }
}

class javax::swing::text::Utilities : public ::java::lang::Object
{
public:
  Utilities ();
  static jint drawTabbedText (::javax::swing::text::Segment *, jint, jint, ::java::awt::Graphics *, ::javax::swing::text::TabExpander *, jint);
  static jint getTabbedTextWidth (::javax::swing::text::Segment *, ::java::awt::FontMetrics *, jint, ::javax::swing::text::TabExpander *, jint);
  static jint getTabbedTextOffset (::javax::swing::text::Segment *, ::java::awt::FontMetrics *, jint, jint, ::javax::swing::text::TabExpander *, jint, jboolean);
  static jint getTabbedTextOffset (::javax::swing::text::Segment *, ::java::awt::FontMetrics *, jint, jint, ::javax::swing::text::TabExpander *, jint);
  static jint getNextWord (::javax::swing::text::JTextComponent *, jint);
  static jint getPreviousWord (::javax::swing::text::JTextComponent *, jint);
  static jint getWordStart (::javax::swing::text::JTextComponent *, jint);
  static jint getWordEnd (::javax::swing::text::JTextComponent *, jint);
  static jint getRowEnd (::javax::swing::text::JTextComponent *, jint);
  static jint getRowStart (::javax::swing::text::JTextComponent *, jint);
  static jint getBreakLocation (::javax::swing::text::Segment *, ::java::awt::FontMetrics *, jint, jint, ::javax::swing::text::TabExpander *, jint);
  static ::javax::swing::text::Element *getParagraphElement (::javax::swing::text::JTextComponent *, jint);
  static jint getPositionAbove (::javax::swing::text::JTextComponent *, jint, jint);
  static jint getPositionBelow (::javax::swing::text::JTextComponent *, jint, jint);
public: // actually package-private
  static jint getNextVisualPositionFrom (::javax::swing::text::JTextComponent *, jint, jint);
private:
  static const jint BUF_LENGTH = 64L;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_Utilities__ */
