// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_RuntimeException__
#define __java_lang_RuntimeException__

#pragma interface

#include <java/lang/Exception.h>

class java::lang::RuntimeException : public ::java::lang::Exception
{
public:
  RuntimeException ();
  RuntimeException (::java::lang::String *);
  RuntimeException (::java::lang::String *, ::java::lang::Throwable *);
  RuntimeException (::java::lang::Throwable *);
private:
  static const jlong serialVersionUID = -7034897190745766939LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_RuntimeException__ */
