// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_jce_prng_SecureRandomAdapter__
#define __gnu_java_security_jce_prng_SecureRandomAdapter__

#pragma interface

#include <java/security/SecureRandomSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace jce
        {
          namespace prng
          {
            class SecureRandomAdapter;
          }
        }
        namespace prng
        {
          class MDGenerator;
        }
      }
    }
  }
}

class gnu::java::security::jce::prng::SecureRandomAdapter : public ::java::security::SecureRandomSpi
{
public:  // actually protected
  SecureRandomAdapter (::java::lang::String *);
public:
  virtual jbyteArray engineGenerateSeed (jint);
  virtual void engineNextBytes (jbyteArray);
  virtual void engineSetSeed (jbyteArray);
private:
  ::gnu::java::security::prng::MDGenerator * __attribute__((aligned(__alignof__( ::java::security::SecureRandomSpi )))) adaptee;
  ::java::lang::String *mdName;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_jce_prng_SecureRandomAdapter__ */
