// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_SourceDataLine__
#define __javax_sound_sampled_SourceDataLine__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class SourceDataLine;
        class AudioFormat;
      }
    }
  }
}

class javax::sound::sampled::SourceDataLine : public ::java::lang::Object
{
public:
  virtual void open (::javax::sound::sampled::AudioFormat *) = 0;
  virtual void open (::javax::sound::sampled::AudioFormat *, jint) = 0;
  virtual jint write (jbyteArray, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sound_sampled_SourceDataLine__ */
