// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_IllegalThreadStateException__
#define __java_lang_IllegalThreadStateException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

class java::lang::IllegalThreadStateException : public ::java::lang::IllegalArgumentException
{
public:
  IllegalThreadStateException ();
  IllegalThreadStateException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -7626246362397460174LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_IllegalThreadStateException__ */
