// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_CompositeName__
#define __javax_naming_CompositeName__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class CompositeName;
      class Name;
    }
  }
}

class javax::naming::CompositeName : public ::java::lang::Object
{
public:
  CompositeName ();
public:  // actually protected
  CompositeName (::java::util::Enumeration *);
public:
  CompositeName (::java::lang::String *);
  virtual ::javax::naming::Name *add (jint, ::java::lang::String *);
  virtual ::javax::naming::Name *add (::java::lang::String *);
  virtual ::javax::naming::Name *addAll (jint, ::javax::naming::Name *);
  virtual ::javax::naming::Name *addAll (::javax::naming::Name *);
  virtual ::java::lang::Object *clone ();
  virtual jint compareTo (::java::lang::Object *);
  virtual jboolean endsWith (::javax::naming::Name *);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *get (jint);
  virtual ::java::util::Enumeration *getAll ();
  virtual ::javax::naming::Name *getPrefix (jint);
  virtual ::javax::naming::Name *getSuffix (jint);
  virtual jint hashCode ();
  virtual jboolean isEmpty ();
  virtual ::java::lang::Object *remove (jint);
  virtual jint size ();
  virtual jboolean startsWith (::javax::naming::Name *);
  virtual ::java::lang::String *toString ();
private:
  void readObject (::java::io::ObjectInputStream *);
  void writeObject (::java::io::ObjectOutputStream *);
  static const jlong serialVersionUID = 1667768148915813118LL;
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::java::lang::Object )))) elts;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_CompositeName__ */
