// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_login_Configuration__
#define __javax_security_auth_login_Configuration__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace login
        {
          class AppConfigurationEntry;
          class Configuration;
        }
      }
    }
  }
}

class javax::security::auth::login::Configuration : public ::java::lang::Object
{
public:  // actually protected
  Configuration ();
public:
  static ::javax::security::auth::login::Configuration *getConfiguration ();
  static void setConfiguration (::javax::security::auth::login::Configuration *);
  virtual JArray< ::javax::security::auth::login::AppConfigurationEntry *> *getAppConfigurationEntry (::java::lang::String *) = 0;
  virtual void refresh () = 0;
public: // actually package-private
  static ::javax::security::auth::login::Configuration *getConfig ();
private:
  static ::javax::security::auth::login::Configuration *config;

  friend class javax_security_auth_login_Configuration$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_login_Configuration__ */
