// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_jar_Manifest__
#define __java_util_jar_Manifest__

#pragma interface

#include <java/lang/Object.h>

class java::util::jar::Manifest : public ::java::lang::Object
{
public:
  Manifest ();
  Manifest (::java::io::InputStream *);
  Manifest (::java::util::jar::Manifest *);
  virtual ::java::util::jar::Attributes *getMainAttributes () { return mainAttr; }
  virtual ::java::util::Map *getEntries () { return entries; }
  virtual ::java::util::jar::Attributes *getAttributes (::java::lang::String *);
  virtual void clear ();
  virtual void read (::java::io::InputStream *);
  virtual void write (::java::io::OutputStream *);
  virtual ::java::lang::Object *clone ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  ::java::util::jar::Attributes * __attribute__((aligned(__alignof__( ::java::lang::Object )))) mainAttr;
  ::java::util::Map *entries;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_jar_Manifest__ */
