// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_Kernel__
#define __java_awt_image_Kernel__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class Kernel;
      }
    }
  }
}

class java::awt::image::Kernel : public ::java::lang::Object
{
public:
  Kernel (jint, jint, jfloatArray);
  virtual jint getXOrigin ();
  virtual jint getYOrigin ();
  virtual jint getWidth () { return width; }
  virtual jint getHeight () { return height; }
  virtual jfloatArray getKernelData (jfloatArray);
  virtual ::java::lang::Object *clone ();
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  width;
  jint height;
  jfloatArray data;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_Kernel__ */
