// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_key_rsa_GnuRSAPublicKey__
#define __gnu_java_security_key_rsa_GnuRSAPublicKey__

#pragma interface

#include <gnu/java/security/key/rsa/GnuRSAKey.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace key
        {
          namespace rsa
          {
            class GnuRSAPublicKey;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::java::security::key::rsa::GnuRSAPublicKey : public ::gnu::java::security::key::rsa::GnuRSAKey
{
public:
  GnuRSAPublicKey (::java::math::BigInteger *, ::java::math::BigInteger *);
  GnuRSAPublicKey (jint, ::java::math::BigInteger *, ::java::math::BigInteger *);
  static ::gnu::java::security::key::rsa::GnuRSAPublicKey *valueOf (jbyteArray);
  virtual jbyteArray getEncoded (jint);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::gnu::java::security::key::rsa::GnuRSAKey )))) str;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_key_rsa_GnuRSAPublicKey__ */
