// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_DoubleViewBufferImpl__
#define __java_nio_DoubleViewBufferImpl__

#pragma interface

#include <java/nio/DoubleBuffer.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class DoubleViewBufferImpl;
      class DoubleBuffer;
      class ByteOrder;
      class ByteBuffer;
    }
  }
}

class java::nio::DoubleViewBufferImpl : public ::java::nio::DoubleBuffer
{
public: // actually package-private
  DoubleViewBufferImpl (::java::nio::ByteBuffer *, jint);
public:
  DoubleViewBufferImpl (::java::nio::ByteBuffer *, jint, jint, jint, jint, jint, jboolean, ::java::nio::ByteOrder *);
  virtual jdouble get ();
  virtual jdouble get (jint);
  virtual ::java::nio::DoubleBuffer *put (jdouble);
  virtual ::java::nio::DoubleBuffer *put (jint, jdouble);
  virtual ::java::nio::DoubleBuffer *compact ();
  virtual ::java::nio::DoubleBuffer *slice ();
public: // actually package-private
  virtual ::java::nio::DoubleBuffer *duplicate (jboolean);
public:
  virtual ::java::nio::DoubleBuffer *duplicate ();
  virtual ::java::nio::DoubleBuffer *asReadOnlyBuffer ();
  virtual jboolean isReadOnly () { return readOnly; }
  virtual jboolean isDirect ();
  virtual ::java::nio::ByteOrder *order () { return endian; }
private:
  jint __attribute__((aligned(__alignof__( ::java::nio::DoubleBuffer ))))  offset;
  ::java::nio::ByteBuffer *bb;
  jboolean readOnly;
  ::java::nio::ByteOrder *endian;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_DoubleViewBufferImpl__ */
