// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_kerberos_KerberosPrincipal__
#define __javax_security_auth_kerberos_KerberosPrincipal__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace kerberos
        {
          class KerberosPrincipal;
        }
      }
    }
  }
}

class javax::security::auth::kerberos::KerberosPrincipal : public ::java::lang::Object
{
public:
  KerberosPrincipal (::java::lang::String *);
  KerberosPrincipal (::java::lang::String *, jint);
private:
  ::java::lang::String *parseRealm ();
public:
  virtual ::java::lang::String *getName () { return name; }
  virtual ::java::lang::String *getRealm () { return realm; }
  virtual jint getNameType () { return type; }
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
  static const jint KRB_NT_PRINCIPAL = 1L;
  static const jint KRB_NT_SRV_HST = 3L;
  static const jint KRB_NT_SRV_INST = 2L;
  static const jint KRB_NT_SRV_XHST = 4L;
  static const jint KRB_NT_UID = 5L;
  static const jint KRB_NT_UNKNOWN = 0L;
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  jint type;
  ::java::lang::String *realm;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_kerberos_KerberosPrincipal__ */
