// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_locale_Calendar_de__
#define __gnu_java_locale_Calendar_de__

#pragma interface

#include <java/util/ListResourceBundle.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace locale
      {
        class Calendar_de;
      }
    }
  }
}

class gnu::java::locale::Calendar_de : public ::java::util::ListResourceBundle
{
public:
  virtual JArray<JArray< ::java::lang::Object *> *> *getContents ();
  Calendar_de ();
private:
  static JArray<JArray< ::java::lang::Object *> *> *contents;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_locale_Calendar_de__ */
