// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_IndexOutOfBoundsException__
#define __java_lang_IndexOutOfBoundsException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::IndexOutOfBoundsException : public ::java::lang::RuntimeException
{
public:
  IndexOutOfBoundsException ();
  IndexOutOfBoundsException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 234122996006267687LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_IndexOutOfBoundsException__ */
