// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_rmi_rmic_TabbedWriter__
#define __gnu_java_rmi_rmic_TabbedWriter__

#pragma interface

#include <java/io/FilterWriter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace rmi
      {
        namespace rmic
        {
          class TabbedWriter;
        }
      }
    }
  }
}

class gnu::java::rmi::rmic::TabbedWriter : public ::java::io::FilterWriter
{
public:
  TabbedWriter (::java::io::Writer *);
  TabbedWriter (::java::io::Writer *, ::java::lang::String *);
  virtual void write (jint);
  virtual void write (jcharArray, jint, jint);
  virtual void write (::java::lang::String *, jint, jint);
  virtual void unindent ();
  virtual void unindent (jint);
  virtual void indent ();
  virtual void indent (jint);
private:
  static ::java::lang::String *defaultTabstring;
  jcharArray __attribute__((aligned(__alignof__( ::java::io::FilterWriter ))))  tabstring;
  jint tabs;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_rmi_rmic_TabbedWriter__ */
