// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_protocol_http_ResponseHeaderHandler__
#define __gnu_java_net_protocol_http_ResponseHeaderHandler__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        namespace protocol
        {
          namespace http
          {
            class ResponseHeaderHandler;
          }
        }
      }
    }
  }
}

class gnu::java::net::protocol::http::ResponseHeaderHandler : public ::java::lang::Object
{
public:
  virtual void setValue (::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_java_net_protocol_http_ResponseHeaderHandler__ */
