// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_debug_SystemLogger__
#define __gnu_classpath_debug_SystemLogger__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace debug
      {
        class SystemLogger;
      }
    }
  }
}

class gnu::classpath::debug::SystemLogger : public ::java::lang::Object
{
public:
  SystemLogger ();
  static ::java::util::logging::Logger *SYSTEM;

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_debug_SystemLogger__ */
