// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_assembly_PaddingTransformer__
#define __gnu_javax_crypto_assembly_PaddingTransformer__

#pragma interface

#include <gnu/javax/crypto/assembly/Transformer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace assembly
        {
          class PaddingTransformer;
        }
        namespace pad
        {
          class IPad;
        }
      }
    }
  }
}

class gnu::javax::crypto::assembly::PaddingTransformer : public ::gnu::javax::crypto::assembly::Transformer
{
public: // actually package-private
  PaddingTransformer (::gnu::javax::crypto::pad::IPad *);
  virtual void initDelegate (::java::util::Map *);
  virtual jint delegateBlockSize () { return outputBlockSize; }
  virtual void resetDelegate ();
  virtual jbyteArray updateDelegate (jbyteArray, jint, jint);
  virtual jbyteArray lastUpdateDelegate ();
private:
  ::gnu::javax::crypto::pad::IPad * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::assembly::Transformer )))) delegate;
  jint outputBlockSize;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_assembly_PaddingTransformer__ */
