// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Frame__
#define __java_awt_Frame__

#pragma interface

#include <java/awt/Window.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Frame;
      class MenuComponent;
      class GraphicsConfiguration;
      class Rectangle;
      class MenuBar;
      class Image;
    }
  }
}

class java::awt::Frame : public ::java::awt::Window
{
public:
  Frame ();
  Frame (::java::lang::String *);
  Frame (::java::awt::GraphicsConfiguration *);
  Frame (::java::lang::String *, ::java::awt::GraphicsConfiguration *);
  virtual ::java::lang::String *getTitle () { return title; }
  virtual void setTitle (::java::lang::String *);
  virtual ::java::awt::Image *getIconImage () { return icon; }
  virtual void setIconImage (::java::awt::Image *);
  virtual ::java::awt::MenuBar *getMenuBar () { return menuBar; }
  virtual void setMenuBar (::java::awt::MenuBar *);
  virtual jboolean isResizable () { return resizable; }
  virtual void setResizable (jboolean);
  virtual jint getCursorType ();
  virtual void setCursor (jint);
  virtual void remove (::java::awt::MenuComponent *);
  virtual void addNotify ();
  virtual void removeNotify ();
public:  // actually protected
  virtual ::java::lang::String *paramString ();
private:
  static void noteFrame (::java::awt::Frame *);
public:
  static JArray< ::java::awt::Frame *> *getFrames ();
  virtual void setState (jint);
  virtual jint getState ();
  virtual void setExtendedState (jint);
  virtual jint getExtendedState () { return state; }
  virtual void setMaximizedBounds (::java::awt::Rectangle *);
  virtual ::java::awt::Rectangle *getMaximizedBounds () { return maximizedBounds; }
  virtual jboolean isUndecorated () { return undecorated; }
  virtual void setUndecorated (jboolean);
public: // actually package-private
  virtual ::java::lang::String *generateName ();
private:
  static jlong getUniqueLong ();
public:
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
  static const jint DEFAULT_CURSOR = 0L;
  static const jint CROSSHAIR_CURSOR = 1L;
  static const jint TEXT_CURSOR = 2L;
  static const jint WAIT_CURSOR = 3L;
  static const jint SW_RESIZE_CURSOR = 4L;
  static const jint SE_RESIZE_CURSOR = 5L;
  static const jint NW_RESIZE_CURSOR = 6L;
  static const jint NE_RESIZE_CURSOR = 7L;
  static const jint N_RESIZE_CURSOR = 8L;
  static const jint S_RESIZE_CURSOR = 9L;
  static const jint E_RESIZE_CURSOR = 11L;
  static const jint W_RESIZE_CURSOR = 10L;
  static const jint HAND_CURSOR = 12L;
  static const jint MOVE_CURSOR = 13L;
  static const jint ICONIFIED = 1L;
  static const jint MAXIMIZED_BOTH = 6L;
  static const jint MAXIMIZED_HORIZ = 2L;
  static const jint MAXIMIZED_VERT = 4L;
  static const jint NORMAL = 0L;
private:
  static const jlong serialVersionUID = 2673458971256075116LL;
  jint __attribute__((aligned(__alignof__( ::java::awt::Window ))))  frameSerializedDataVersion;
  ::java::awt::Image *icon;
  jboolean mbManagement;
  ::java::awt::MenuBar *menuBar;
public: // actually package-private
  ::java::util::Vector *ownedWindows;
private:
  jboolean resizable;
public: // actually package-private
  jint state;
private:
  ::java::lang::String *title;
  ::java::awt::Rectangle *maximizedBounds;
  jboolean undecorated;
  static jlong next_frame_number;
  static ::java::util::ArrayList *weakFrames;

  friend class java_awt_Frame$AccessibleAWTFrame;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Frame__ */
