// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_jce_sig_SHA512withRSA__
#define __gnu_java_security_jce_sig_SHA512withRSA__

#pragma interface

#include <gnu/java/security/jce/sig/SignatureAdapter.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace jce
        {
          namespace sig
          {
            class SHA512withRSA;
          }
        }
      }
    }
  }
}

class gnu::java::security::jce::sig::SHA512withRSA : public ::gnu::java::security::jce::sig::SignatureAdapter
{
public:
  SHA512withRSA ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_jce_sig_SHA512withRSA__ */
