// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_login_CredentialException__
#define __javax_security_auth_login_CredentialException__

#pragma interface

#include <javax/security/auth/login/LoginException.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace login
        {
          class CredentialException;
        }
      }
    }
  }
}

class javax::security::auth::login::CredentialException : public ::javax::security::auth::login::LoginException
{
public:
  CredentialException ();
  CredentialException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -4772893876810601859LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_login_CredentialException__ */
