// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_FileDialog__
#define __java_awt_FileDialog__

#pragma interface

#include <java/awt/Dialog.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class FileDialog;
      class Frame;
      class Dialog;
    }
  }
}

class java::awt::FileDialog : public ::java::awt::Dialog
{
public:
  FileDialog (::java::awt::Dialog *);
  FileDialog (::java::awt::Dialog *, ::java::lang::String *);
  FileDialog (::java::awt::Dialog *, ::java::lang::String *, jint);
  FileDialog (::java::awt::Frame *);
  FileDialog (::java::awt::Frame *, ::java::lang::String *);
  FileDialog (::java::awt::Frame *, ::java::lang::String *, jint);
  virtual jint getMode () { return mode; }
  virtual void setMode (jint);
  virtual ::java::lang::String *getDirectory () { return dir; }
  virtual void setDirectory (::java::lang::String *);
  virtual ::java::lang::String *getFile () { return file; }
  virtual void setFile (::java::lang::String *);
  virtual ::java::io::FilenameFilter *getFilenameFilter () { return filter; }
  virtual void setFilenameFilter (::java::io::FilenameFilter *);
  virtual void addNotify ();
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  static const jint LOAD = 0L;
  static const jint SAVE = 1L;
private:
  static const jlong serialVersionUID = 5035145889651310422LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::awt::Dialog )))) dir;
  ::java::lang::String *file;
  ::java::io::FilenameFilter *filter;
  jint mode;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_FileDialog__ */
