// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_support_low_Queue__
#define __gnu_javax_swing_text_html_parser_support_low_Queue__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                namespace low
                {
                  class Queue;
                  class Token;
                }
              }
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::support::low::Queue : public ::java::lang::Object
{
public:
  virtual jboolean isEmpty ();
  virtual void add (::gnu::javax::swing::text::html::parser::support::low::Token *);
  virtual void clear ();
  virtual ::gnu::javax::swing::text::html::parser::support::low::Token *get (jint);
  virtual ::gnu::javax::swing::text::html::parser::support::low::Token *next ();
  virtual jint size ();
  Queue ();
public: // actually package-private
  JArray< ::gnu::javax::swing::text::html::parser::support::low::Token *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) m;
  jint a;
  jint b;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_support_low_Queue__ */
