// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_IPrivateKeyring__
#define __gnu_javax_crypto_keyring_IPrivateKeyring__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class IPrivateKeyring;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class Certificate;
      }
      class PublicKey;
      class Key;
    }
  }
}

class gnu::javax::crypto::keyring::IPrivateKeyring : public ::java::lang::Object
{
public:
  virtual jboolean containsPrivateKey (::java::lang::String *) = 0;
  virtual ::java::security::Key *getPrivateKey (::java::lang::String *, jcharArray) = 0;
  virtual void putPrivateKey (::java::lang::String *, ::java::security::Key *, jcharArray) = 0;
  virtual jboolean containsPublicKey (::java::lang::String *) = 0;
  virtual ::java::security::PublicKey *getPublicKey (::java::lang::String *) = 0;
  virtual void putPublicKey (::java::lang::String *, ::java::security::PublicKey *) = 0;
  virtual jboolean containsCertPath (::java::lang::String *) = 0;
  virtual JArray< ::java::security::cert::Certificate *> *getCertPath (::java::lang::String *) = 0;
  virtual void putCertPath (::java::lang::String *, JArray< ::java::security::cert::Certificate *> *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_keyring_IPrivateKeyring__ */
