// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Error__
#define __java_lang_Error__

#pragma interface

#include <java/lang/Throwable.h>

class java::lang::Error : public ::java::lang::Throwable
{
public:
  Error ();
  Error (::java::lang::String *);
  Error (::java::lang::String *, ::java::lang::Throwable *);
  Error (::java::lang::Throwable *);
private:
  static const jlong serialVersionUID = 4980196508277280342LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Error__ */
