// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_RecordOutputStream__
#define __gnu_javax_net_ssl_provider_RecordOutputStream__

#pragma interface

#include <java/io/FilterOutputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class RecordOutputStream;
            class SecurityParameters;
            class ContentType;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::RecordOutputStream : public ::java::io::FilterOutputStream
{
public: // actually package-private
  RecordOutputStream (::java::io::OutputStream *, ::gnu::javax::net::ssl::provider::ContentType *, ::gnu::javax::net::ssl::provider::SecurityParameters *);
public:
  virtual void write (jint);
  virtual void write (jbyteArray);
  virtual void write (jbyteArray, jint, jint);
private:
  static const jint DEBUG_RECORD_LAYER = 1L;
  static ::java::util::logging::Logger *logger;
  ::gnu::javax::net::ssl::provider::ContentType * __attribute__((aligned(__alignof__( ::java::io::FilterOutputStream )))) type;
  ::gnu::javax::net::ssl::provider::SecurityParameters *params;
  jboolean emitEmpty;
  static jbyteArray ZERO;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_RecordOutputStream__ */
