// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_mode_IAuthenticatedMode__
#define __gnu_javax_crypto_mode_IAuthenticatedMode__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace mode
        {
          class IAuthenticatedMode;
        }
      }
    }
  }
}

class gnu::javax::crypto::mode::IAuthenticatedMode : public ::java::lang::Object
{
public:

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_mode_IAuthenticatedMode__ */
