// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_key_DESedeSecretKeyFactoryImpl__
#define __gnu_javax_crypto_jce_key_DESedeSecretKeyFactoryImpl__

#pragma interface

#include <gnu/javax/crypto/jce/key/SecretKeyFactoryImpl.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace key
          {
            class DESedeSecretKeyFactoryImpl;
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace crypto
    {
      class SecretKey;
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class KeySpec;
      }
    }
  }
}

class gnu::javax::crypto::jce::key::DESedeSecretKeyFactoryImpl : public ::gnu::javax::crypto::jce::key::SecretKeyFactoryImpl
{
public:
  DESedeSecretKeyFactoryImpl ();
public:  // actually protected
  virtual ::javax::crypto::SecretKey *engineGenerateSecret (::java::security::spec::KeySpec *);
  virtual ::java::security::spec::KeySpec *engineGetKeySpec (::javax::crypto::SecretKey *, ::java::lang::Class *);
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_key_DESedeSecretKeyFactoryImpl__ */
