// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_attribute_CharsetSyntax__
#define __gnu_javax_print_ipp_attribute_CharsetSyntax__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          namespace attribute
          {
            class CharsetSyntax;
          }
        }
      }
    }
  }
}

class gnu::javax::print::ipp::attribute::CharsetSyntax : public ::java::lang::Object
{
public:  // actually protected
  CharsetSyntax (::java::lang::String *);
public:
  virtual ::java::lang::String *getValue () { return value; }
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) value;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_attribute_CharsetSyntax__ */
