// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Insets__
#define __java_awt_Insets__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Insets;
    }
  }
}

class java::awt::Insets : public ::java::lang::Object
{
public:
  Insets (jint, jint, jint, jint);
  virtual void set (jint, jint, jint, jint);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
  virtual ::java::lang::Object *clone ();
private:
  static const jlong serialVersionUID = -2272572637695466749LL;
public:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  top;
  jint left;
  jint bottom;
  jint right;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Insets__ */
