// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_plaf_metal_CustomizableTheme__
#define __gnu_javax_swing_plaf_metal_CustomizableTheme__

#pragma interface

#include <javax/swing/plaf/metal/DefaultMetalTheme.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace plaf
        {
          namespace metal
          {
            class CustomizableTheme;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Color;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class ColorUIResource;
      }
    }
  }
}

class gnu::javax::swing::plaf::metal::CustomizableTheme : public ::javax::swing::plaf::metal::DefaultMetalTheme
{
public:
  virtual void setPrimary1 (::java::awt::Color *);
  virtual ::javax::swing::plaf::ColorUIResource *getPrimary1 ();
  virtual void setPrimary2 (::java::awt::Color *);
  virtual ::javax::swing::plaf::ColorUIResource *getPrimary2 ();
  virtual void setPrimary3 (::java::awt::Color *);
  virtual ::javax::swing::plaf::ColorUIResource *getPrimary3 ();
  virtual void setSecondary1 (::java::awt::Color *);
  virtual ::javax::swing::plaf::ColorUIResource *getSecondary1 ();
  virtual void setSecondary2 (::java::awt::Color *);
  virtual ::javax::swing::plaf::ColorUIResource *getSecondary2 ();
  virtual void setSecondary3 (::java::awt::Color *);
  virtual ::javax::swing::plaf::ColorUIResource *getSecondary3 ();
  virtual ::java::lang::Object *clone ();
  CustomizableTheme ();
private:
  ::javax::swing::plaf::ColorUIResource * __attribute__((aligned(__alignof__( ::javax::swing::plaf::metal::DefaultMetalTheme )))) primary1;
  ::javax::swing::plaf::ColorUIResource *primary2;
  ::javax::swing::plaf::ColorUIResource *primary3;
  ::javax::swing::plaf::ColorUIResource *secondary1;
  ::javax::swing::plaf::ColorUIResource *secondary2;
  ::javax::swing::plaf::ColorUIResource *secondary3;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_plaf_metal_CustomizableTheme__ */
