// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_filechooser_FileView__
#define __javax_swing_filechooser_FileView__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace filechooser
      {
        class FileView;
      }
      class Icon;
    }
  }
}

class javax::swing::filechooser::FileView : public ::java::lang::Object
{
public:
  FileView ();
  virtual ::java::lang::String *getName (::java::io::File *) { return 0; }
  virtual ::java::lang::String *getDescription (::java::io::File *) { return 0; }
  virtual ::java::lang::String *getTypeDescription (::java::io::File *) { return 0; }
  virtual ::javax::swing::Icon *getIcon (::java::io::File *) { return 0; }
  virtual ::java::lang::Boolean *isTraversable (::java::io::File *) { return 0; }

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_filechooser_FileView__ */
