// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_MacException__
#define __gnu_javax_net_ssl_provider_MacException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class MacException;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::MacException : public ::java::io::IOException
{
public: // actually package-private
  MacException ();
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_MacException__ */
