// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_MouseEvent__
#define __java_awt_event_MouseEvent__

#pragma interface

#include <java/awt/event/InputEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class MouseEvent;
      }
      class Point;
      class Component;
    }
  }
}

class java::awt::event::MouseEvent : public ::java::awt::event::InputEvent
{
public:
  MouseEvent (::java::awt::Component *, jint, jlong, jint, jint, jint, jint, jboolean, jint);
  MouseEvent (::java::awt::Component *, jint, jlong, jint, jint, jint, jint, jboolean);
  virtual jint getX () { return x; }
  virtual jint getY () { return y; }
  virtual ::java::awt::Point *getPoint ();
  virtual void translatePoint (jint, jint);
  virtual jint getClickCount () { return clickCount; }
  virtual jint getButton () { return button; }
  virtual jboolean isPopupTrigger () { return popupTrigger; }
  static ::java::lang::String *getMouseModifiersText (jint);
  virtual ::java::lang::String *paramString ();
private:
  void readObject (::java::io::ObjectInputStream *);
  static const jlong serialVersionUID = -991214153494842848LL;
public:
  static const jint MOUSE_FIRST = 500L;
  static const jint MOUSE_LAST = 507L;
  static const jint MOUSE_CLICKED = 500L;
  static const jint MOUSE_PRESSED = 501L;
  static const jint MOUSE_RELEASED = 502L;
  static const jint MOUSE_MOVED = 503L;
  static const jint MOUSE_ENTERED = 504L;
  static const jint MOUSE_EXITED = 505L;
  static const jint NOBUTTON = 0L;
  static const jint BUTTON1 = 1L;
  static const jint BUTTON2 = 2L;
  static const jint BUTTON3 = 3L;
  static const jint MOUSE_DRAGGED = 506L;
  static const jint MOUSE_WHEEL = 507L;
private:
  jint __attribute__((aligned(__alignof__( ::java::awt::event::InputEvent ))))  x;
  jint y;
  jint clickCount;
  jint button;
  jboolean popupTrigger;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_MouseEvent__ */
