// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_Permission__
#define __java_security_Permission__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class PermissionCollection;
      class Permission;
    }
  }
}

class java::security::Permission : public ::java::lang::Object
{
public:
  Permission (::java::lang::String *);
  virtual void checkGuard (::java::lang::Object *);
  virtual jboolean implies (::java::security::Permission *) = 0;
  virtual jboolean equals (::java::lang::Object *) = 0;
  virtual jint hashCode () = 0;
  virtual ::java::lang::String *getName () { return name; }
  virtual ::java::lang::String *getActions () = 0;
  virtual ::java::security::PermissionCollection *newPermissionCollection () { return 0; }
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = -5636570222231596674LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_Permission__ */
