// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_colorchooser_AbstractColorChooserPanel__
#define __javax_swing_colorchooser_AbstractColorChooserPanel__

#pragma interface

#include <javax/swing/JPanel.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Color;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace colorchooser
      {
        class AbstractColorChooserPanel;
        class ColorSelectionModel;
      }
      class Icon;
      class JColorChooser;
    }
  }
}

class javax::swing::colorchooser::AbstractColorChooserPanel : public ::javax::swing::JPanel
{
public:
  AbstractColorChooserPanel ();
  virtual ::java::lang::String *getDisplayName () = 0;
  virtual jint getMnemonic ();
  virtual jint getDisplayedMnemonicIndex ();
  virtual void updateChooser () = 0;
public:  // actually protected
  virtual void buildChooser () = 0;
public:
  virtual ::javax::swing::Icon *getSmallDisplayIcon () = 0;
  virtual ::javax::swing::Icon *getLargeDisplayIcon () = 0;
  virtual void installChooserPanel (::javax::swing::JColorChooser *);
  virtual void uninstallChooserPanel (::javax::swing::JColorChooser *);
  virtual ::javax::swing::colorchooser::ColorSelectionModel *getColorSelectionModel ();
public:  // actually protected
  virtual ::java::awt::Color *getColorFromModel ();
public:
  virtual void paint (::java::awt::Graphics *);
private:
  static const jlong serialVersionUID = -977469671210173863LL;
  ::javax::swing::JColorChooser * __attribute__((aligned(__alignof__( ::javax::swing::JPanel )))) chooser;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_colorchooser_AbstractColorChooserPanel__ */
