// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_StreamCorruptedException__
#define __java_io_StreamCorruptedException__

#pragma interface

#include <java/io/ObjectStreamException.h>

class java::io::StreamCorruptedException : public ::java::io::ObjectStreamException
{
public:
  StreamCorruptedException ();
  StreamCorruptedException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 8983558202217591746LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_StreamCorruptedException__ */
