// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_FloatBufferImpl__
#define __java_nio_FloatBufferImpl__

#pragma interface

#include <java/nio/FloatBuffer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class FloatBufferImpl;
      class ByteOrder;
      class FloatBuffer;
    }
  }
}

class java::nio::FloatBufferImpl : public ::java::nio::FloatBuffer
{
public: // actually package-private
  FloatBufferImpl (jint);
  FloatBufferImpl (jfloatArray, jint, jint, jint, jint, jint, jboolean);
public:
  virtual jboolean isReadOnly () { return readOnly; }
  virtual ::java::nio::FloatBuffer *slice ();
  virtual ::java::nio::FloatBuffer *duplicate ();
  virtual ::java::nio::FloatBuffer *asReadOnlyBuffer ();
  virtual ::java::nio::FloatBuffer *compact ();
  virtual jboolean isDirect ();
  virtual jfloat get ();
  virtual ::java::nio::FloatBuffer *put (jfloat);
  virtual jfloat get (jint);
  virtual ::java::nio::FloatBuffer *put (jint, jfloat);
  virtual ::java::nio::ByteOrder *order ();
private:
  jboolean __attribute__((aligned(__alignof__( ::java::nio::FloatBuffer ))))  readOnly;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_FloatBufferImpl__ */
