// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_ImageObserver__
#define __java_awt_image_ImageObserver__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class ImageObserver;
      }
      class Image;
    }
  }
}

class java::awt::image::ImageObserver : public ::java::lang::Object
{
public:
  virtual jboolean imageUpdate (::java::awt::Image *, jint, jint, jint, jint, jint) = 0;
  static const jint WIDTH = 1L;
  static const jint HEIGHT = 2L;
  static const jint PROPERTIES = 4L;
  static const jint SOMEBITS = 8L;
  static const jint FRAMEBITS = 16L;
  static const jint ALLBITS = 32L;
  static const jint ERROR = 64L;
  static const jint ABORT = 128L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_image_ImageObserver__ */
