// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_PrimitiveEntry__
#define __gnu_javax_crypto_keyring_PrimitiveEntry__

#pragma interface

#include <gnu/javax/crypto/keyring/Entry.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class PrimitiveEntry;
          class Properties;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::PrimitiveEntry : public ::gnu::javax::crypto::keyring::Entry
{
public:  // actually protected
  PrimitiveEntry (jint, ::java::util::Date *, ::gnu::javax::crypto::keyring::Properties *);
  PrimitiveEntry (jint);
public:
  virtual ::java::lang::String *getAlias ();
  virtual ::java::util::Date *getCreationDate ();
  virtual jboolean equals (::java::lang::Object *);
public:  // actually protected
  virtual void makeCreationDate ();
  ::java::util::Date * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::keyring::Entry )))) creationDate;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_PrimitiveEntry__ */
