// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_jpeg_JPEGDecoder__
#define __gnu_javax_imageio_jpeg_JPEGDecoder__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace imageio
    {
      namespace stream
      {
        class ImageInputStream;
      }
      namespace plugins
      {
        namespace jpeg
        {
          class JPEGQTable;
          class JPEGHuffmanTable;
        }
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace jpeg
        {
          class JPEGDecoder;
          class JPEGImageInputStream;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class BufferedImage;
      }
    }
  }
}

class gnu::javax::imageio::jpeg::JPEGDecoder : public ::java::lang::Object
{
public:
  virtual jint getHeight () { return height; }
  virtual jint getWidth () { return width; }
  JPEGDecoder (::javax::imageio::stream::ImageInputStream *);
  virtual void decode ();
private:
  void decodeJFIFExtension ();
public:
  virtual ::java::awt::image::BufferedImage *getImage () { return image; }
public: // actually package-private
  jbyte __attribute__((aligned(__alignof__( ::java::lang::Object ))))  majorVersion;
  jbyte minorVersion;
  jbyte units;
  jshort Xdensity;
  jshort Ydensity;
  jbyte Xthumbnail;
  jbyte Ythumbnail;
  jbyteArray thumbnail;
  ::java::awt::image::BufferedImage *image;
  jint width;
  jint height;
  jbyte marker;
public:
  static const jint MAJOR_VERSION = 1L;
  static const jint MINOR_VERSION = 2L;
  static const jint JFIF_FIXED_LENGTH = 16L;
  static const jint JFXX_FIXED_LENGTH = 8L;
private:
  ::gnu::javax::imageio::jpeg::JPEGImageInputStream *jpegStream;
public: // actually package-private
  ::java::util::ArrayList *jpegFrames;
  JArray< ::javax::imageio::plugins::jpeg::JPEGHuffmanTable *> *dcTables;
  JArray< ::javax::imageio::plugins::jpeg::JPEGHuffmanTable *> *acTables;
  JArray< ::javax::imageio::plugins::jpeg::JPEGQTable *> *qTables;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_jpeg_JPEGDecoder__ */
