// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_callback_UnsupportedCallbackException__
#define __javax_security_auth_callback_UnsupportedCallbackException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace callback
        {
          class UnsupportedCallbackException;
          class Callback;
        }
      }
    }
  }
}

class javax::security::auth::callback::UnsupportedCallbackException : public ::java::lang::Exception
{
public:
  UnsupportedCallbackException (::javax::security::auth::callback::Callback *);
  UnsupportedCallbackException (::javax::security::auth::callback::Callback *, ::java::lang::String *);
  virtual ::javax::security::auth::callback::Callback *getCallback () { return callback; }
private:
  ::javax::security::auth::callback::Callback * __attribute__((aligned(__alignof__( ::java::lang::Exception )))) callback;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_callback_UnsupportedCallbackException__ */
