// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_color_ToneReproductionCurve__
#define __gnu_java_awt_color_ToneReproductionCurve__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace color
        {
          class ToneReproductionCurve;
        }
      }
    }
  }
}

class gnu::java::awt::color::ToneReproductionCurve : public ::java::lang::Object
{
public:
  ToneReproductionCurve (jfloat);
  ToneReproductionCurve (jfloatArray);
  ToneReproductionCurve (jshortArray);
  virtual jfloat lookup (jfloat);
  virtual jfloat reverseLookup (jfloat);
  virtual void setupReverseTrc ();
private:
  jfloatArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  trc;
  jfloat gamma;
  jfloatArray reverseTrc;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_color_ToneReproductionCurve__ */
