// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_Base64__
#define __gnu_javax_net_ssl_Base64__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          class Base64;
        }
      }
    }
  }
}

class gnu::javax::net::ssl::Base64 : public ::java::lang::Object
{
private:
  Base64 ();
public:
  static ::java::lang::String *encode (jbyteArray, jint);
  static jbyteArray decode (::java::lang::String *);
private:
  static ::java::lang::String *BASE_64;
  static const jint BASE_64_PAD = 61L;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_Base64__ */
