// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_cipher_Rijndael__
#define __gnu_javax_crypto_cipher_Rijndael__

#pragma interface

#include <gnu/javax/crypto/cipher/BaseCipher.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace cipher
        {
          class Rijndael;
        }
      }
    }
  }
}

class gnu::javax::crypto::cipher::Rijndael : public ::gnu::javax::crypto::cipher::BaseCipher
{
public:
  Rijndael ();
  static jint getRounds (jint, jint);
private:
  static void rijndaelEncrypt (jbyteArray, jint, jbyteArray, jint, ::java::lang::Object *, jint);
  static void rijndaelDecrypt (jbyteArray, jint, jbyteArray, jint, ::java::lang::Object *, jint);
  static void aesEncrypt (jbyteArray, jint, jbyteArray, jint, ::java::lang::Object *);
  static void aesDecrypt (jbyteArray, jint, jbyteArray, jint, ::java::lang::Object *);
public:
  virtual ::java::lang::Object *clone ();
  virtual ::java::util::Iterator *blockSizes ();
  virtual ::java::util::Iterator *keySizes ();
  virtual ::java::lang::Object *makeKey (jbyteArray, jint);
  virtual void encrypt (jbyteArray, jint, jbyteArray, jint, ::java::lang::Object *, jint);
  virtual void decrypt (jbyteArray, jint, jbyteArray, jint, ::java::lang::Object *, jint);
  virtual jboolean selfTest ();
private:
  static ::java::util::logging::Logger *log;
  static const jint DEFAULT_BLOCK_SIZE = 16L;
  static const jint DEFAULT_KEY_SIZE = 16L;
  static ::java::lang::String *SS;
  static jbyteArray S;
  static jbyteArray Si;
  static jintArray T1;
  static jintArray T2;
  static jintArray T3;
  static jintArray T4;
  static jintArray T5;
  static jintArray T6;
  static jintArray T7;
  static jintArray T8;
  static jintArray U1;
  static jintArray U2;
  static jintArray U3;
  static jintArray U4;
  static jbyteArray rcon;
  static JArray<JArray<jintArray> *> * shifts;
  static jbyteArray KAT_KEY;
  static jbyteArray KAT_CT;
  static ::java::lang::Boolean *valid;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_cipher_Rijndael__ */
