// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JEditorPane__
#define __javax_swing_JEditorPane__

#pragma interface

#include <javax/swing/text/JTextComponent.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JEditorPane;
      namespace event
      {
        class HyperlinkListener;
        class HyperlinkEvent;
      }
      namespace text
      {
        class EditorKit;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Dimension;
    }
    namespace net
    {
      class URL;
    }
  }
}

class javax::swing::JEditorPane : public ::javax::swing::text::JTextComponent
{
public:
  JEditorPane ();
  JEditorPane (::java::lang::String *);
  JEditorPane (::java::lang::String *, ::java::lang::String *);
  JEditorPane (::java::net::URL *);
public: // actually package-private
  virtual void init ();
public:  // actually protected
  virtual ::javax::swing::text::EditorKit *createDefaultEditorKit ();
public:
  static ::javax::swing::text::EditorKit *createEditorKitForContentType (::java::lang::String *);
  virtual void fireHyperlinkUpdate (::javax::swing::event::HyperlinkEvent *);
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
  virtual ::java::lang::String *getContentType ();
  virtual ::javax::swing::text::EditorKit *getEditorKit ();
  static ::java::lang::String *getEditorKitClassNameForContentType (::java::lang::String *);
  virtual ::javax::swing::text::EditorKit *getEditorKitForContentType (::java::lang::String *);
  virtual ::java::awt::Dimension *getPreferredSize ();
  virtual jboolean getScrollableTracksViewportHeight ();
  virtual jboolean getScrollableTracksViewportWidth ();
  virtual ::java::net::URL *getPage () { return page; }
public:  // actually protected
  virtual ::java::io::InputStream *getStream (::java::net::URL *);
public:
  virtual ::java::lang::String *getText ();
  virtual ::java::lang::String *getUIClassID ();
  virtual jboolean isFocusCycleRoot () { return focus_root; }
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  virtual void read (::java::io::InputStream *, ::java::lang::Object *);
  static void registerEditorKitForContentType (::java::lang::String *, ::java::lang::String *);
  static void registerEditorKitForContentType (::java::lang::String *, ::java::lang::String *, ::java::lang::ClassLoader *) { }
  virtual void replaceSelection (::java::lang::String *);
  virtual void scrollToReference (::java::lang::String *) { }
  virtual void setContentType (::java::lang::String *);
  virtual void setEditorKit (::javax::swing::text::EditorKit *);
  virtual void setEditorKitForContentType (::java::lang::String *, ::javax::swing::text::EditorKit *);
  virtual void setPage (::java::lang::String *);
  virtual void setPage (::java::net::URL *);
  virtual void setText (::java::lang::String *);
  virtual void addHyperlinkListener (::javax::swing::event::HyperlinkListener *);
  virtual void removeHyperlinkListener (::javax::swing::event::HyperlinkListener *);
  virtual JArray< ::javax::swing::event::HyperlinkListener *> *getHyperlinkListeners ();
private:
  static const jlong serialVersionUID = 3140472492599046285LL;
  ::java::net::URL * __attribute__((aligned(__alignof__( ::javax::swing::text::JTextComponent )))) page;
  ::javax::swing::text::EditorKit *editorKit;
public: // actually package-private
  jboolean focus_root;
  static ::java::util::HashMap *registerMap;
  ::java::util::HashMap *editorMap;
private:
  static jboolean $assertionsDisabled;

  friend class javax_swing_JEditorPane$PlainEditorKit;
  friend class javax_swing_JEditorPane$JEditorPaneAccessibleHypertextSupport;
  friend class javax_swing_JEditorPane$AccessibleJEditorPaneHTML;
  friend class javax_swing_JEditorPane$AccessibleJEditorPane;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JEditorPane__ */
