// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_x509_ext_GeneralNames__
#define __gnu_java_security_x509_ext_GeneralNames__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace x509
        {
          namespace ext
          {
            class GeneralNames;
          }
        }
      }
    }
  }
}

class gnu::java::security::x509::ext::GeneralNames : public ::java::lang::Object
{
public:
  GeneralNames (jbyteArray);
  virtual ::java::util::List *getNames ();
  virtual ::java::lang::String *toString ();
  static const jint OTHER_NAME = 0L;
  static const jint RFC822_NAME = 1L;
  static const jint DNS_NAME = 2L;
  static const jint X400_ADDRESS = 3L;
  static const jint DIRECTORY_NAME = 4L;
  static const jint EDI_PARTY_NAME = 5L;
  static const jint URI = 6L;
  static const jint IP_ADDRESS = 7L;
  static const jint REGISTERED_ID = 8L;
private:
  ::java::util::List * __attribute__((aligned(__alignof__( ::java::lang::Object )))) names;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_x509_ext_GeneralNames__ */
