// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_REMatch__
#define __gnu_java_util_regex_REMatch__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class REMatch;
          class BacktrackStack;
          class CharIndexed;
        }
      }
    }
  }
}

class gnu::java::util::regex::REMatch : public ::java::lang::Object
{
public:
  virtual ::java::lang::Object *clone ();
public: // actually package-private
  virtual void assignFrom (::gnu::java::util::regex::REMatch *);
  REMatch (jint, jint, jint);
  virtual void finish (::gnu::java::util::regex::CharIndexed *);
  virtual void clear (jint);
public:
  virtual ::java::lang::String *toString () { return matchedText; }
  virtual jint getStartIndex ();
  virtual jint getEndIndex ();
  virtual ::java::lang::String *toString (jint);
  virtual jint getSubStartIndex (jint);
  virtual jint getStartIndex (jint);
  virtual jint getSubEndIndex (jint);
  virtual jint getEndIndex (jint);
  virtual ::java::lang::String *substituteInto (::java::lang::String *);
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) matchedText;
  ::gnu::java::util::regex::CharIndexed *matchedCharIndexed;
public: // actually package-private
  jint eflags;
  jint offset;
  jint anchor;
  jint index;
  jintArray start;
  jintArray start1;
  jintArray end;
  jboolean empty;
  ::gnu::java::util::regex::BacktrackStack *backtrackStack;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_REMatch__ */
