// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_CharArrayWriter__
#define __java_io_CharArrayWriter__

#pragma interface

#include <java/io/Writer.h>
#include <gcj/array.h>

class java::io::CharArrayWriter : public ::java::io::Writer
{
public:
  CharArrayWriter ();
  CharArrayWriter (jint);
  virtual void close () { }
  virtual void flush () { }
  virtual void reset ();
  virtual jint size () { return count; }
  virtual jcharArray toCharArray ();
  virtual ::java::lang::String *toString ();
  virtual void write (jint);
  virtual void write (jcharArray, jint, jint);
  virtual void write (::java::lang::String *, jint, jint);
  virtual void writeTo (::java::io::Writer *);
  virtual ::java::io::CharArrayWriter *append (jchar);
  virtual ::java::io::CharArrayWriter *append (::java::lang::CharSequence *);
  virtual ::java::io::CharArrayWriter *append (::java::lang::CharSequence *, jint, jint);
private:
  void resize (jint);
  static const jint DEFAULT_INITIAL_BUFFER_SIZE = 32L;
public:  // actually protected
  jcharArray __attribute__((aligned(__alignof__( ::java::io::Writer ))))  buf;
  jint count;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_CharArrayWriter__ */
