// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Random__
#define __gnu_javax_net_ssl_provider_Random__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class Random;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Random : public ::java::lang::Object
{
public: // actually package-private
  Random (jint, jbyteArray);
  static ::gnu::javax::net::ssl::provider::Random *read (::java::io::InputStream *);
public:
  virtual void write (::java::io::OutputStream *);
public: // actually package-private
  virtual jbyteArray getEncoded ();
  virtual jint getTime () { return gmtUnixTime; }
  virtual jbyteArray getRandomBytes () { return randomBytes; }
public:
  virtual ::java::lang::String *toString ();
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  gmtUnixTime;
  jbyteArray randomBytes;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Random__ */
