// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_filechooser_FileFilter__
#define __javax_swing_filechooser_FileFilter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace filechooser
      {
        class FileFilter;
      }
    }
  }
}

class javax::swing::filechooser::FileFilter : public ::java::lang::Object
{
public:
  FileFilter ();
  virtual jboolean accept (::java::io::File *) = 0;
  virtual ::java::lang::String *getDescription () = 0;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_filechooser_FileFilter__ */
