// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_GridBagConstraints__
#define __java_awt_GridBagConstraints__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class GridBagConstraints;
      class Insets;
    }
  }
}

class java::awt::GridBagConstraints : public ::java::lang::Object
{
public:
  virtual ::java::lang::Object *clone ();
  GridBagConstraints ();
  GridBagConstraints (jint, jint, jint, jint, jdouble, jdouble, jint, jint, ::java::awt::Insets *, jint, jint);
public: // actually package-private
  static const jlong serialVersionUID = -1000070633030801713LL;
public:
  static const jint NONE = 0L;
  static const jint BOTH = 1L;
  static const jint HORIZONTAL = 2L;
  static const jint VERTICAL = 3L;
  static const jint CENTER = 10L;
  static const jint NORTH = 11L;
  static const jint NORTHEAST = 12L;
  static const jint EAST = 13L;
  static const jint SOUTHEAST = 14L;
  static const jint SOUTH = 15L;
  static const jint SOUTHWEST = 16L;
  static const jint WEST = 17L;
  static const jint NORTHWEST = 18L;
  static const jint RELATIVE = -1L;
  static const jint REMAINDER = 0L;
  static const jint PAGE_START = 19L;
  static const jint PAGE_END = 20L;
  static const jint LINE_START = 21L;
  static const jint LINE_END = 22L;
  static const jint FIRST_LINE_START = 23L;
  static const jint FIRST_LINE_END = 24L;
  static const jint LAST_LINE_START = 25L;
  static const jint LAST_LINE_END = 26L;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  anchor;
  jint fill;
  jint gridheight;
  jint gridwidth;
  jint gridx;
  jint gridy;
  ::java::awt::Insets *insets;
  jint ipadx;
  jint ipady;
  jdouble weightx;
  jdouble weighty;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_GridBagConstraints__ */
