// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_directory_DirContext__
#define __javax_naming_directory_DirContext__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class NamingEnumeration;
      class Name;
      namespace directory
      {
        class SearchControls;
        class DirContext;
        class ModificationItem;
        class Attributes;
      }
    }
  }
}

class javax::naming::directory::DirContext : public ::java::lang::Object
{
public:
  virtual ::javax::naming::directory::Attributes *getAttributes (::java::lang::String *) = 0;
  virtual ::javax::naming::directory::Attributes *getAttributes (::java::lang::String *, JArray< ::java::lang::String *> *) = 0;
  virtual ::javax::naming::directory::Attributes *getAttributes (::javax::naming::Name *) = 0;
  virtual ::javax::naming::directory::Attributes *getAttributes (::javax::naming::Name *, JArray< ::java::lang::String *> *) = 0;
  virtual void modifyAttributes (::javax::naming::Name *, jint, ::javax::naming::directory::Attributes *) = 0;
  virtual void modifyAttributes (::java::lang::String *, jint, ::javax::naming::directory::Attributes *) = 0;
  virtual void modifyAttributes (::javax::naming::Name *, JArray< ::javax::naming::directory::ModificationItem *> *) = 0;
  virtual void modifyAttributes (::java::lang::String *, JArray< ::javax::naming::directory::ModificationItem *> *) = 0;
  virtual void bind (::javax::naming::Name *, ::java::lang::Object *, ::javax::naming::directory::Attributes *) = 0;
  virtual void bind (::java::lang::String *, ::java::lang::Object *, ::javax::naming::directory::Attributes *) = 0;
  virtual void rebind (::javax::naming::Name *, ::java::lang::Object *, ::javax::naming::directory::Attributes *) = 0;
  virtual void rebind (::java::lang::String *, ::java::lang::Object *, ::javax::naming::directory::Attributes *) = 0;
  virtual ::javax::naming::directory::DirContext *createSubcontext (::javax::naming::Name *, ::javax::naming::directory::Attributes *) = 0;
  virtual ::javax::naming::directory::DirContext *createSubcontext (::java::lang::String *, ::javax::naming::directory::Attributes *) = 0;
  virtual ::javax::naming::directory::DirContext *getSchema (::javax::naming::Name *) = 0;
  virtual ::javax::naming::directory::DirContext *getSchema (::java::lang::String *) = 0;
  virtual ::javax::naming::directory::DirContext *getSchemaClassDefinition (::javax::naming::Name *) = 0;
  virtual ::javax::naming::directory::DirContext *getSchemaClassDefinition (::java::lang::String *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::javax::naming::directory::Attributes *, JArray< ::java::lang::String *> *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::javax::naming::directory::Attributes *, JArray< ::java::lang::String *> *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::javax::naming::directory::Attributes *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::javax::naming::directory::Attributes *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::java::lang::String *, ::javax::naming::directory::SearchControls *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::java::lang::String *, ::javax::naming::directory::SearchControls *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::javax::naming::Name *, ::java::lang::String *, JArray< ::java::lang::Object *> *, ::javax::naming::directory::SearchControls *) = 0;
  virtual ::javax::naming::NamingEnumeration *search (::java::lang::String *, ::java::lang::String *, JArray< ::java::lang::Object *> *, ::javax::naming::directory::SearchControls *) = 0;
  static const jint ADD_ATTRIBUTE = 1L;
  static const jint REPLACE_ATTRIBUTE = 2L;
  static const jint REMOVE_ATTRIBUTE = 3L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_naming_directory_DirContext__ */
