// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_transaction_InvalidTransactionException__
#define __javax_transaction_InvalidTransactionException__

#pragma interface

#include <java/rmi/RemoteException.h>

extern "Java"
{
  namespace javax
  {
    namespace transaction
    {
      class InvalidTransactionException;
    }
  }
}

class javax::transaction::InvalidTransactionException : public ::java::rmi::RemoteException
{
public:
  InvalidTransactionException ();
  InvalidTransactionException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_transaction_InvalidTransactionException__ */
