// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_WrappedPlainView__
#define __javax_swing_text_WrappedPlainView__

#pragma interface

#include <javax/swing/text/BoxView.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class DocumentEvent;
      }
      namespace text
      {
        class WrappedPlainView;
        class Element;
        class Segment;
        class ViewFactory;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Shape;
      class Graphics;
      class FontMetrics;
      class Color;
    }
  }
}

class javax::swing::text::WrappedPlainView : public ::javax::swing::text::BoxView
{
public:
  WrappedPlainView (::javax::swing::text::Element *);
  WrappedPlainView (::javax::swing::text::Element *, jboolean);
public:  // actually protected
  virtual ::javax::swing::text::Segment *getLineBuffer ();
public:
  virtual jfloat nextTabStop (jfloat, jint);
public:  // actually protected
  virtual jint getTabSize ();
  virtual void drawLine (jint, jint, ::java::awt::Graphics *, jint, jint);
  virtual jint drawSelectedText (::java::awt::Graphics *, jint, jint, jint, jint);
  virtual jint drawUnselectedText (::java::awt::Graphics *, jint, jint, jint, jint);
  virtual void loadChildren (::javax::swing::text::ViewFactory *);
  virtual jint calculateBreakPosition (jint, jint);
public: // actually package-private
  virtual void updateMetrics ();
public:
  virtual jfloat getPreferredSpan (jint);
  virtual jfloat getMinimumSpan (jint);
  virtual jfloat getMaximumSpan (jint);
  virtual void insertUpdate (::javax::swing::event::DocumentEvent *, ::java::awt::Shape *, ::javax::swing::text::ViewFactory *);
  virtual void removeUpdate (::javax::swing::event::DocumentEvent *, ::java::awt::Shape *, ::javax::swing::text::ViewFactory *);
  virtual void changedUpdate (::javax::swing::event::DocumentEvent *, ::java::awt::Shape *, ::javax::swing::text::ViewFactory *);
  virtual void paint (::java::awt::Graphics *, ::java::awt::Shape *);
  virtual void setSize (jfloat, jfloat);
public: // actually package-private
  ::java::awt::Color * __attribute__((aligned(__alignof__( ::javax::swing::text::BoxView )))) selectedColor;
  ::java::awt::Color *unselectedColor;
  ::java::awt::Color *disabledColor;
  ::java::awt::FontMetrics *metrics;
  jboolean wordWrap;
  ::javax::swing::text::ViewFactory *viewFactory;
  jint selectionStart;
  jint selectionEnd;
  jint lineHeight;
private:
  ::javax::swing::text::Segment *lineBuffer;

  friend class javax_swing_text_WrappedPlainView$WrappedLine;
  friend class javax_swing_text_WrappedPlainView$WrappedLineCreator;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_WrappedPlainView__ */
