// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_CRL__
#define __java_security_cert_CRL__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class CRL;
        class Certificate;
      }
    }
  }
}

class java::security::cert::CRL : public ::java::lang::Object
{
public:  // actually protected
  CRL (::java::lang::String *);
public:
  virtual ::java::lang::String *getType () { return type; }
  virtual ::java::lang::String *toString () = 0;
  virtual jboolean isRevoked (::java::security::cert::Certificate *) = 0;
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) type;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_cert_CRL__ */
