// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_ItemEvent__
#define __java_awt_event_ItemEvent__

#pragma interface

#include <java/awt/AWTEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class ItemEvent;
      }
      class ItemSelectable;
    }
  }
}

class java::awt::event::ItemEvent : public ::java::awt::AWTEvent
{
public:
  ItemEvent (::java::awt::ItemSelectable *, jint, ::java::lang::Object *, jint);
  virtual ::java::awt::ItemSelectable *getItemSelectable ();
  virtual ::java::lang::Object *getItem () { return item; }
  virtual jint getStateChange () { return stateChange; }
  virtual ::java::lang::String *paramString ();
private:
  static const jlong serialVersionUID = -608708132447206933LL;
public:
  static const jint ITEM_FIRST = 701L;
  static const jint ITEM_LAST = 701L;
  static const jint ITEM_STATE_CHANGED = 701L;
  static const jint SELECTED = 1L;
  static const jint DESELECTED = 2L;
private:
  ::java::lang::Object * __attribute__((aligned(__alignof__( ::java::awt::AWTEvent )))) item;
  jint stateChange;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_ItemEvent__ */
