// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_ReadOnlyBufferException__
#define __java_nio_ReadOnlyBufferException__

#pragma interface

#include <java/lang/UnsupportedOperationException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class ReadOnlyBufferException;
    }
  }
}

class java::nio::ReadOnlyBufferException : public ::java::lang::UnsupportedOperationException
{
public:
  ReadOnlyBufferException ();
private:
  static const jlong serialVersionUID = -1210063976496234090LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_ReadOnlyBufferException__ */
