// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_ServerError__
#define __java_rmi_ServerError__

#pragma interface

#include <java/rmi/RemoteException.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      class ServerError;
    }
  }
}

class java::rmi::ServerError : public ::java::rmi::RemoteException
{
public:
  ServerError (::java::lang::String *, ::java::lang::Error *);
private:
  static const jlong serialVersionUID = 8455284893909696482LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_ServerError__ */
