// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_accessibility_AccessibleResourceBundle__
#define __javax_accessibility_AccessibleResourceBundle__

#pragma interface

#include <java/util/ListResourceBundle.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleResourceBundle;
    }
  }
}

class javax::accessibility::AccessibleResourceBundle : public ::java::util::ListResourceBundle
{
public:
  AccessibleResourceBundle ();
  virtual JArray<JArray< ::java::lang::Object *> *> *getContents () { return 0; }

  static ::java::lang::Class class$;
};

#endif /* __javax_accessibility_AccessibleResourceBundle__ */
