// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_mac_HMac__
#define __gnu_javax_crypto_mac_HMac__

#pragma interface

#include <gnu/javax/crypto/mac/BaseMac.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace mac
        {
          class HMac;
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace hash
        {
          class IMessageDigest;
        }
      }
    }
  }
}

class gnu::javax::crypto::mac::HMac : public ::gnu::javax::crypto::mac::BaseMac
{
public:  // actually protected
  HMac (::gnu::java::security::hash::IMessageDigest *);
public:
  virtual ::java::lang::Object *clone ();
  virtual void init (::java::util::Map *);
  virtual void reset ();
  virtual jbyteArray digest ();
  virtual jboolean selfTest ();
  static ::java::lang::String *USE_WITH_PKCS5_V2;
private:
  static const jint IPAD_BYTE = 54L;
  static const jint OPAD_BYTE = 92L;
  static ::java::lang::Boolean *valid;
public:  // actually protected
  jint __attribute__((aligned(__alignof__( ::gnu::javax::crypto::mac::BaseMac ))))  macSize;
  jint blockSize;
  ::gnu::java::security::hash::IMessageDigest *ipadHash;
  ::gnu::java::security::hash::IMessageDigest *opadHash;
  jbyteArray ipad;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_mac_HMac__ */
