// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_mac_MacAdapter__
#define __gnu_javax_crypto_jce_mac_MacAdapter__

#pragma interface

#include <javax/crypto/MacSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class Key;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace mac
          {
            class MacAdapter;
          }
        }
        namespace mac
        {
          class IMac;
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::mac::MacAdapter : public ::javax::crypto::MacSpi
{
public:  // actually protected
  MacAdapter (::java::lang::String *);
private:
  MacAdapter (::gnu::javax::crypto::mac::IMac *, ::java::util::Map *);
public:
  virtual ::java::lang::Object *clone ();
public:  // actually protected
  virtual jbyteArray engineDoFinal ();
  virtual jint engineGetMacLength ();
  virtual void engineInit (::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *);
  virtual void engineReset ();
  virtual void engineUpdate (jbyte);
  virtual void engineUpdate (jbyteArray, jint, jint);
  ::gnu::javax::crypto::mac::IMac * __attribute__((aligned(__alignof__( ::javax::crypto::MacSpi )))) mac;
  ::java::util::Map *attributes;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_mac_MacAdapter__ */
