// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_X509CRLSelector__
#define __java_security_cert_X509CRLSelector__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class X509CRLSelector;
        class CRL;
        class X509Certificate;
      }
    }
    namespace math
    {
      class BigInteger;
    }
  }
}

class java::security::cert::X509CRLSelector : public ::java::lang::Object
{
public:
  X509CRLSelector ();
  virtual void addIssuerName (jbyteArray);
  virtual void addIssuerName (::java::lang::String *);
  virtual void setIssuerNames (::java::util::Collection *);
  virtual ::java::util::Collection *getIssuerNames ();
  virtual ::java::math::BigInteger *getMaxCRL () { return maxCrlNumber; }
  virtual ::java::math::BigInteger *getMinCRL () { return minCrlNumber; }
  virtual void setMaxCRLNumber (::java::math::BigInteger *);
  virtual void setMinCRLNumber (::java::math::BigInteger *);
  virtual ::java::util::Date *getDateAndTime ();
  virtual void setDateAndTime (::java::util::Date *);
  virtual ::java::security::cert::X509Certificate *getCertificateChecking () { return cert; }
  virtual void setCertificateChecking (::java::security::cert::X509Certificate *);
  virtual ::java::lang::String *toString ();
  virtual jboolean match (::java::security::cert::CRL *);
  virtual ::java::lang::Object *clone ();
private:
  static ::java::lang::String *CRL_NUMBER_ID;
  ::java::util::List * __attribute__((aligned(__alignof__( ::java::lang::Object )))) issuerNames;
  ::java::math::BigInteger *maxCrlNumber;
  ::java::math::BigInteger *minCrlNumber;
  ::java::util::Date *date;
  ::java::security::cert::X509Certificate *cert;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_cert_X509CRLSelector__ */
