// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_server_RMIClassLoader__
#define __java_rmi_server_RMIClassLoader__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      namespace server
      {
        class RMIClassLoader;
        class RMIClassLoaderSpi;
      }
    }
    namespace net
    {
      class URL;
    }
  }
}

class java::rmi::server::RMIClassLoader : public ::java::lang::Object
{
private:
  RMIClassLoader ();
public:
  static ::java::lang::Class *loadClass (::java::lang::String *);
  static ::java::lang::Class *loadClass (::java::lang::String *, ::java::lang::String *);
  static ::java::lang::Class *loadClass (::java::lang::String *, ::java::lang::String *, ::java::lang::ClassLoader *);
  static ::java::lang::Class *loadProxyClass (::java::lang::String *, JArray< ::java::lang::String *> *, ::java::lang::ClassLoader *);
  static ::java::lang::Class *loadClass (::java::net::URL *, ::java::lang::String *);
  static ::java::lang::ClassLoader *getClassLoader (::java::lang::String *);
  static ::java::lang::String *getClassAnnotation (::java::lang::Class *);
  static ::java::lang::Object *getSecurityContext (::java::lang::ClassLoader *);
  static ::java::rmi::server::RMIClassLoaderSpi *getDefaultProviderInstance ();
private:
  static ::java::rmi::server::RMIClassLoaderSpi *getProviderInstance ();
public:

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_server_RMIClassLoader__ */
