// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_font_TextMeasurer__
#define __java_awt_font_TextMeasurer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace font
      {
        class TextMeasurer;
        class TextLayout;
        class FontRenderContext;
      }
    }
    namespace text
    {
      class AttributedCharacterIterator;
    }
  }
}

class java::awt::font::TextMeasurer : public ::java::lang::Object
{
public:
  TextMeasurer (::java::text::AttributedCharacterIterator *, ::java::awt::font::FontRenderContext *);
public:  // actually protected
  virtual ::java::lang::Object *clone ();
public:
  virtual void deleteChar (::java::text::AttributedCharacterIterator *, jint);
  virtual void insertChar (::java::text::AttributedCharacterIterator *, jint);
  virtual jfloat getAdvanceBetween (jint, jint);
  virtual ::java::awt::font::TextLayout *getLayout (jint, jint);
  virtual jint getLineBreakIndex (jint, jfloat);
private:
  ::java::text::AttributedCharacterIterator * __attribute__((aligned(__alignof__( ::java::lang::Object )))) text;
  ::java::awt::font::FontRenderContext *frc;
  ::java::awt::font::TextLayout *totalLayout;
  jint numChars;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_font_TextMeasurer__ */
