// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_CupsIppOperation__
#define __gnu_javax_print_CupsIppOperation__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        class CupsIppOperation;
      }
    }
  }
}

class gnu::javax::print::CupsIppOperation : public ::java::lang::Object
{
private:
  CupsIppOperation ();
public:
  static const jint CUPS_GET_DEFAULT = 16385L;
  static const jint CUPS_GET_PRINTERS = 16386L;
  static const jint CUPS_ADD_MODIFY_PRINTER = 16387L;
  static const jint CUPS_DELETE_PRINTER = 16388L;
  static const jint CUPS_GET_CLASSES = 16389L;
  static const jint CUPS_ADD_MODIFY_CLASS = 16390L;
  static const jint CUPS_DELETE_CLASS = 16391L;
  static const jint CUPS_ACCEPT_JOBS = 16392L;
  static const jint CUPS_REJECT_JOBS = 16393L;
  static const jint CUPS_SET_DEFAULT = 16394L;
  static const jint CUPS_GET_DEVICES = 16395L;
  static const jint CUPS_GET_PPDS = 16396L;
  static const jint CUPS_MOVE_JOB = 16397L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_CupsIppOperation__ */
