// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_IAuthInfoProvider__
#define __gnu_javax_crypto_sasl_IAuthInfoProvider__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          class IAuthInfoProvider;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::IAuthInfoProvider : public ::java::lang::Object
{
public:
  virtual void activate (::java::util::Map *) = 0;
  virtual void passivate () = 0;
  virtual jboolean contains (::java::lang::String *) = 0;
  virtual ::java::util::Map *lookup (::java::util::Map *) = 0;
  virtual void update (::java::util::Map *) = 0;
  virtual ::java::util::Map *getConfiguration (::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_sasl_IAuthInfoProvider__ */
