// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_sql_Driver__
#define __java_sql_Driver__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace sql
    {
      class Driver;
      class DriverPropertyInfo;
      class Connection;
    }
  }
}

class java::sql::Driver : public ::java::lang::Object
{
public:
  virtual ::java::sql::Connection *connect (::java::lang::String *, ::java::util::Properties *) = 0;
  virtual jboolean acceptsURL (::java::lang::String *) = 0;
  virtual JArray< ::java::sql::DriverPropertyInfo *> *getPropertyInfo (::java::lang::String *, ::java::util::Properties *) = 0;
  virtual jint getMajorVersion () = 0;
  virtual jint getMinorVersion () = 0;
  virtual jboolean jdbcCompliant () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_sql_Driver__ */
