// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_Attribute__
#define __javax_management_Attribute__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      class Attribute;
    }
  }
}

class javax::management::Attribute : public ::java::lang::Object
{
public:
  Attribute (::java::lang::String *, ::java::lang::Object *);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *getName () { return m_name; }
  virtual ::java::lang::Object *getValue () { return m_value; }
  virtual jint hashCode ();
private:
  static const jlong serialVersionUID = 2484220110589082382LL;
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) m_name;
  ::java::lang::Object *m_value;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_Attribute__ */
