// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_net_ssl_SSLPeerUnverifiedException__
#define __javax_net_ssl_SSLPeerUnverifiedException__

#pragma interface

#include <javax/net/ssl/SSLException.h>

extern "Java"
{
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class SSLPeerUnverifiedException;
      }
    }
  }
}

class javax::net::ssl::SSLPeerUnverifiedException : public ::javax::net::ssl::SSLException
{
public:
  SSLPeerUnverifiedException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_net_ssl_SSLPeerUnverifiedException__ */
