// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_mode_IMode__
#define __gnu_javax_crypto_mode_IMode__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace mode
        {
          class IMode;
        }
      }
    }
  }
}

class gnu::javax::crypto::mode::IMode : public ::java::lang::Object
{
public:
  virtual void update (jbyteArray, jint, jbyteArray, jint) = 0;
  static ::java::lang::String *STATE;
  static ::java::lang::String *MODE_BLOCK_SIZE;
  static ::java::lang::String *IV;
  static const jint ENCRYPTION = 1L;
  static const jint DECRYPTION = 2L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_mode_IMode__ */
