// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_InsetsUIResource__
#define __javax_swing_plaf_InsetsUIResource__

#pragma interface

#include <java/awt/Insets.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class InsetsUIResource;
      }
    }
  }
}

class javax::swing::plaf::InsetsUIResource : public ::java::awt::Insets
{
public:
  InsetsUIResource (jint, jint, jint, jint);
public: // actually package-private
  static const jlong serialVersionUID = 5622110143266315421LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_InsetsUIResource__ */
