// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_midi_Receiver__
#define __javax_sound_midi_Receiver__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace midi
      {
        class Receiver;
        class MidiMessage;
      }
    }
  }
}

class javax::sound::midi::Receiver : public ::java::lang::Object
{
public:
  virtual void send (::javax::sound::midi::MidiMessage *, jlong) = 0;
  virtual void close () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sound_midi_Receiver__ */
