// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_EventModifier__
#define __gnu_java_awt_EventModifier__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        class EventModifier;
      }
    }
  }
}

class gnu::java::awt::EventModifier : public ::java::lang::Object
{
private:
  EventModifier ();
public:
  static jint extend (jint);
  static jint revert (jint);
  static const jint OLD_MASK = 63L;
  static const jint NEW_MASK = 16320L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_EventModifier__ */
