// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_standard_PrinterStateReason__
#define __javax_print_attribute_standard_PrinterStateReason__

#pragma interface

#include <javax/print/attribute/EnumSyntax.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class EnumSyntax;
        namespace standard
        {
          class PrinterStateReason;
        }
      }
    }
  }
}

class javax::print::attribute::standard::PrinterStateReason : public ::javax::print::attribute::EnumSyntax
{
public:  // actually protected
  PrinterStateReason (jint);
public:
  virtual ::java::lang::Class *getCategory ();
  virtual ::java::lang::String *getName ();
public:  // actually protected
  virtual JArray< ::java::lang::String *> *getStringTable ();
  virtual JArray< ::javax::print::attribute::EnumSyntax *> *getEnumValueTable ();
private:
  static const jlong serialVersionUID = -1623720656201472593LL;
public:
  static ::javax::print::attribute::standard::PrinterStateReason *OTHER;
  static ::javax::print::attribute::standard::PrinterStateReason *MEDIA_NEEDED;
  static ::javax::print::attribute::standard::PrinterStateReason *MEDIA_JAM;
  static ::javax::print::attribute::standard::PrinterStateReason *MOVING_TO_PAUSED;
  static ::javax::print::attribute::standard::PrinterStateReason *PAUSED;
  static ::javax::print::attribute::standard::PrinterStateReason *SHUTDOWN;
  static ::javax::print::attribute::standard::PrinterStateReason *CONNECTING_TO_DEVICE;
  static ::javax::print::attribute::standard::PrinterStateReason *TIMED_OUT;
  static ::javax::print::attribute::standard::PrinterStateReason *STOPPING;
  static ::javax::print::attribute::standard::PrinterStateReason *STOPPED_PARTLY;
  static ::javax::print::attribute::standard::PrinterStateReason *TONER_LOW;
  static ::javax::print::attribute::standard::PrinterStateReason *TONER_EMPTY;
  static ::javax::print::attribute::standard::PrinterStateReason *SPOOL_AREA_FULL;
  static ::javax::print::attribute::standard::PrinterStateReason *COVER_OPEN;
  static ::javax::print::attribute::standard::PrinterStateReason *INTERLOCK_OPEN;
  static ::javax::print::attribute::standard::PrinterStateReason *DOOR_OPEN;
  static ::javax::print::attribute::standard::PrinterStateReason *INPUT_TRAY_MISSING;
  static ::javax::print::attribute::standard::PrinterStateReason *MEDIA_LOW;
  static ::javax::print::attribute::standard::PrinterStateReason *MEDIA_EMPTY;
  static ::javax::print::attribute::standard::PrinterStateReason *OUTPUT_TRAY_MISSING;
  static ::javax::print::attribute::standard::PrinterStateReason *OUTPUT_AREA_ALMOST_FULL;
  static ::javax::print::attribute::standard::PrinterStateReason *OUTPUT_AREA_FULL;
  static ::javax::print::attribute::standard::PrinterStateReason *MARKER_SUPPLY_LOW;
  static ::javax::print::attribute::standard::PrinterStateReason *MARKER_SUPPLY_EMPTY;
  static ::javax::print::attribute::standard::PrinterStateReason *MARKER_WASTE_ALMOST_FULL;
  static ::javax::print::attribute::standard::PrinterStateReason *MARKER_WASTE_FULL;
  static ::javax::print::attribute::standard::PrinterStateReason *FUSER_OVER_TEMP;
  static ::javax::print::attribute::standard::PrinterStateReason *FUSER_UNDER_TEMP;
  static ::javax::print::attribute::standard::PrinterStateReason *OPC_NEAR_EOL;
  static ::javax::print::attribute::standard::PrinterStateReason *OPC_LIFE_OVER;
  static ::javax::print::attribute::standard::PrinterStateReason *DEVELOPER_LOW;
  static ::javax::print::attribute::standard::PrinterStateReason *DEVELOPER_EMPTY;
  static ::javax::print::attribute::standard::PrinterStateReason *INTERPRETER_RESOURCE_UNAVAILABLE;
private:
  static JArray< ::java::lang::String *> *stringTable;
  static JArray< ::javax::print::attribute::standard::PrinterStateReason *> *enumValueTable;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_standard_PrinterStateReason__ */
