// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_transaction_Status__
#define __javax_transaction_Status__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace transaction
    {
      class Status;
    }
  }
}

class javax::transaction::Status : public ::java::lang::Object
{
public:
  static const jint STATUS_ACTIVE = 0L;
  static const jint STATUS_MARKED_ROLLBACK = 1L;
  static const jint STATUS_PREPARED = 2L;
  static const jint STATUS_COMMITTED = 3L;
  static const jint STATUS_ROLLEDBACK = 4L;
  static const jint STATUS_UNKNOWN = 5L;
  static const jint STATUS_NO_TRANSACTION = 6L;
  static const jint STATUS_PREPARING = 7L;
  static const jint STATUS_COMMITTING = 8L;
  static const jint STATUS_ROLLING_BACK = 9L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_transaction_Status__ */
