// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicRadioButtonUI__
#define __javax_swing_plaf_basic_BasicRadioButtonUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicToggleButtonUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      class Dimension;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class AbstractButton;
      namespace plaf
      {
        namespace basic
        {
          class BasicRadioButtonUI;
        }
        class ComponentUI;
      }
      class JComponent;
      class Icon;
    }
  }
}

class javax::swing::plaf::basic::BasicRadioButtonUI : public ::javax::swing::plaf::basic::BasicToggleButtonUI
{
public:
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  BasicRadioButtonUI ();
public:  // actually protected
  virtual void installDefaults (::javax::swing::AbstractButton *);
  virtual ::java::lang::String *getPropertyPrefix ();
public:
  virtual ::javax::swing::Icon *getDefaultIcon ();
  virtual void paint (::java::awt::Graphics *, ::javax::swing::JComponent *);
  virtual ::java::awt::Dimension *getPreferredSize (::javax::swing::JComponent *);
public:  // actually protected
  virtual void paintFocus (::java::awt::Graphics *, ::java::awt::Rectangle *, ::java::awt::Dimension *);
  ::javax::swing::Icon * __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicToggleButtonUI )))) icon;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicRadioButtonUI__ */
