// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_locale_LocaleData__
#define __gnu_java_locale_LocaleData__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace locale
      {
        class LocaleData;
      }
    }
  }
}

class gnu::java::locale::LocaleData : public ::java::lang::Object
{
public: // actually package-private
  LocaleData ();
public:
  static JArray< ::java::lang::String *> *localeNames;
  static JArray< ::java::lang::String *> *collatorLocaleNames;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_locale_LocaleData__ */
