// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_tree_GnuPath__
#define __gnu_javax_swing_tree_GnuPath__

#pragma interface

#include <javax/swing/tree/TreePath.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace tree
        {
          class GnuPath;
        }
      }
    }
  }
}

class gnu::javax::swing::tree::GnuPath : public ::javax::swing::tree::TreePath
{
public:
  GnuPath (JArray< ::java::lang::Object *> *, jboolean);
  jboolean __attribute__((aligned(__alignof__( ::javax::swing::tree::TreePath ))))  isLastChild;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_tree_GnuPath__ */
