// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicButtonUI__
#define __javax_swing_plaf_basic_BasicButtonUI__

#pragma interface

#include <javax/swing/plaf/ButtonUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      class Graphics;
      class Dimension;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class Icon;
      class AbstractButton;
      class JComponent;
      namespace plaf
      {
        class ComponentUI;
        namespace basic
        {
          class BasicButtonUI;
          class BasicButtonListener;
        }
      }
    }
  }
}

class javax::swing::plaf::basic::BasicButtonUI : public ::javax::swing::plaf::ButtonUI
{
public:
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual jint getDefaultTextIconGap (::javax::swing::AbstractButton *) { return defaultTextIconGap; }
public:  // actually protected
  virtual void clearTextShiftOffset ();
  virtual jint getTextShiftOffset () { return textShiftOffset; }
  virtual void setTextShiftOffset ();
  virtual ::java::lang::String *getPropertyPrefix ();
  virtual void installDefaults (::javax::swing::AbstractButton *);
  virtual void uninstallDefaults (::javax::swing::AbstractButton *);
  virtual ::javax::swing::plaf::basic::BasicButtonListener *createButtonListener (::javax::swing::AbstractButton *);
  virtual void installListeners (::javax::swing::AbstractButton *);
  virtual void uninstallListeners (::javax::swing::AbstractButton *);
  virtual void installKeyboardActions (::javax::swing::AbstractButton *);
  virtual void uninstallKeyboardActions (::javax::swing::AbstractButton *);
public:
  virtual void installUI (::javax::swing::JComponent *);
  virtual ::java::awt::Dimension *getPreferredSize (::javax::swing::JComponent *);
public: // actually package-private
  static ::javax::swing::Icon *currentIcon (::javax::swing::AbstractButton *);
public:
  virtual void paint (::java::awt::Graphics *, ::javax::swing::JComponent *);
public:  // actually protected
  virtual void paintFocus (::java::awt::Graphics *, ::javax::swing::AbstractButton *, ::java::awt::Rectangle *, ::java::awt::Rectangle *, ::java::awt::Rectangle *) { }
  virtual void paintIcon (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *);
  virtual void paintButtonPressed (::java::awt::Graphics *, ::javax::swing::AbstractButton *);
  virtual void paintText (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *, ::java::lang::String *);
  virtual void paintText (::java::awt::Graphics *, ::javax::swing::AbstractButton *, ::java::awt::Rectangle *, ::java::lang::String *);
public:
  BasicButtonUI ();
public:  // actually protected
  jint __attribute__((aligned(__alignof__( ::javax::swing::plaf::ButtonUI ))))  defaultTextIconGap;
  jint defaultTextShiftOffset;
private:
  jint textShiftOffset;
public:  // actually protected
  ::javax::swing::plaf::basic::BasicButtonListener *listener;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicButtonUI__ */
