// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_FilterOutputStream__
#define __java_io_FilterOutputStream__

#pragma interface

#include <java/io/OutputStream.h>
#include <gcj/array.h>

class java::io::FilterOutputStream : public ::java::io::OutputStream
{
public:
  FilterOutputStream (::java::io::OutputStream *);
  virtual void close ();
  virtual void flush ();
  virtual void write (jint);
  virtual void write (jbyteArray);
  virtual void write (jbyteArray, jint, jint);
public:  // actually protected
  ::java::io::OutputStream * __attribute__((aligned(__alignof__( ::java::io::OutputStream )))) out;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_FilterOutputStream__ */
