// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_JobAttributes__
#define __java_awt_JobAttributes__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class JobAttributes;
      class JobAttributes$SidesType;
      class JobAttributes$MultipleDocumentHandlingType;
      class JobAttributes$DialogType;
      class JobAttributes$DestinationType;
      class JobAttributes$DefaultSelectionType;
    }
  }
}

class java::awt::JobAttributes : public ::java::lang::Object
{
public:
  JobAttributes ();
  JobAttributes (::java::awt::JobAttributes *);
  JobAttributes (jint, ::java::awt::JobAttributes$DefaultSelectionType *, ::java::awt::JobAttributes$DestinationType *, ::java::awt::JobAttributes$DialogType *, ::java::lang::String *, jint, jint, ::java::awt::JobAttributes$MultipleDocumentHandlingType *, JArray<jintArray> *, ::java::lang::String *, ::java::awt::JobAttributes$SidesType *);
  virtual ::java::lang::Object *clone ();
  virtual void set (::java::awt::JobAttributes *);
  virtual jint getCopies () { return copies; }
  virtual void setCopies (jint);
  virtual void setCopiesToDefault ();
  virtual ::java::awt::JobAttributes$DefaultSelectionType *getDefaultSelection () { return selection; }
  virtual void setDefaultSelection (::java::awt::JobAttributes$DefaultSelectionType *);
  virtual ::java::awt::JobAttributes$DestinationType *getDestination () { return destination; }
  virtual void setDestination (::java::awt::JobAttributes$DestinationType *);
  virtual ::java::awt::JobAttributes$DialogType *getDialog () { return dialog; }
  virtual void setDialog (::java::awt::JobAttributes$DialogType *);
  virtual ::java::lang::String *getFileName () { return filename; }
  virtual void setFileName (::java::lang::String *);
  virtual jint getFromPage ();
  virtual void setFromPage (jint);
  virtual jint getMaxPage () { return maxPage; }
  virtual void setMaxPage (jint);
  virtual jint getMinPage () { return minPage; }
  virtual void setMinPage (jint);
  virtual ::java::awt::JobAttributes$MultipleDocumentHandlingType *getMultipleDocumentHandling () { return multiple; }
  virtual void setMultipleDocumentHandling (::java::awt::JobAttributes$MultipleDocumentHandlingType *);
  virtual void setMultipleDocumentHandlingToDefault ();
  virtual JArray<jintArray> * getPageRanges ();
  virtual void setPageRanges (JArray<jintArray> *);
  virtual ::java::lang::String *getPrinter () { return printer; }
  virtual void setPrinter (::java::lang::String *);
  virtual ::java::awt::JobAttributes$SidesType *getSides () { return sides; }
  virtual void setSides (::java::awt::JobAttributes$SidesType *);
  virtual void setSidesToDefault ();
  virtual jint getToPage ();
  virtual void setToPage (jint);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  copies;
  ::java::awt::JobAttributes$DefaultSelectionType *selection;
  ::java::awt::JobAttributes$DestinationType *destination;
  ::java::awt::JobAttributes$DialogType *dialog;
  ::java::lang::String *filename;
  jint maxPage;
  jint minPage;
  ::java::awt::JobAttributes$MultipleDocumentHandlingType *multiple;
  JArray<jintArray> * pageRanges;
  jint fromPage;
  jint toPage;
  ::java::lang::String *printer;
  ::java::awt::JobAttributes$SidesType *sides;

  friend class java_awt_JobAttributes$SidesType;
  friend class java_awt_JobAttributes$MultipleDocumentHandlingType;
  friend class java_awt_JobAttributes$DialogType;
  friend class java_awt_JobAttributes$DestinationType;
  friend class java_awt_JobAttributes$DefaultSelectionType;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_JobAttributes__ */
