// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_AttributeSet__
#define __javax_swing_text_AttributeSet__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class AttributeSet;
      }
    }
  }
}

class javax::swing::text::AttributeSet : public ::java::lang::Object
{
public:
  virtual jboolean containsAttribute (::java::lang::Object *, ::java::lang::Object *) = 0;
  virtual jboolean containsAttributes (::javax::swing::text::AttributeSet *) = 0;
  virtual ::javax::swing::text::AttributeSet *copyAttributes () = 0;
  virtual ::java::lang::Object *getAttribute (::java::lang::Object *) = 0;
  virtual jint getAttributeCount () = 0;
  virtual ::java::util::Enumeration *getAttributeNames () = 0;
  virtual ::javax::swing::text::AttributeSet *getResolveParent () = 0;
  virtual jboolean isDefined (::java::lang::Object *) = 0;
  virtual jboolean isEqual (::javax::swing::text::AttributeSet *) = 0;
  static ::java::lang::Object *NameAttribute;
  static ::java::lang::Object *ResolveAttribute;

  friend class javax_swing_text_AttributeSet$ParagraphAttribute;
  friend class javax_swing_text_AttributeSet$FontAttribute;
  friend class javax_swing_text_AttributeSet$ColorAttribute;
  friend class javax_swing_text_AttributeSet$CharacterAttribute;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_text_AttributeSet__ */
