// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_TooManyListenersException__
#define __java_util_TooManyListenersException__

#pragma interface

#include <java/lang/Exception.h>

class java::util::TooManyListenersException : public ::java::lang::Exception
{
public:
  TooManyListenersException ();
  TooManyListenersException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 5074640544770687831LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_TooManyListenersException__ */
