// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_NIODatagramSocket__
#define __gnu_java_nio_NIODatagramSocket__

#pragma interface

#include <java/net/DatagramSocket.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class DatagramChannel;
      }
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        class NIODatagramSocket;
        class DatagramChannelImpl;
      }
      namespace net
      {
        class PlainDatagramSocketImpl;
      }
    }
  }
}

class gnu::java::nio::NIODatagramSocket : public ::java::net::DatagramSocket
{
public:
  NIODatagramSocket (::gnu::java::net::PlainDatagramSocketImpl *, ::gnu::java::nio::DatagramChannelImpl *);
  virtual ::gnu::java::net::PlainDatagramSocketImpl *getPlainDatagramSocketImpl () { return impl; }
  virtual ::java::nio::channels::DatagramChannel *getChannel () { return reinterpret_cast< ::java::nio::channels::DatagramChannel *> (channel); }
private:
  ::gnu::java::net::PlainDatagramSocketImpl * __attribute__((aligned(__alignof__( ::java::net::DatagramSocket )))) impl;
  ::gnu::java::nio::DatagramChannelImpl *channel;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_NIODatagramSocket__ */
