// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_geom_Dimension2D__
#define __java_awt_geom_Dimension2D__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace geom
      {
        class Dimension2D;
      }
    }
  }
}

class java::awt::geom::Dimension2D : public ::java::lang::Object
{
public:  // actually protected
  Dimension2D ();
public:
  virtual jdouble getWidth () = 0;
  virtual jdouble getHeight () = 0;
  virtual void setSize (jdouble, jdouble) = 0;
  virtual void setSize (::java::awt::geom::Dimension2D *);
  virtual ::java::lang::Object *clone ();

  static ::java::lang::Class class$;
};

#endif /* __java_awt_geom_Dimension2D__ */
