// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_DefaultHighlighter__
#define __javax_swing_text_DefaultHighlighter__

#pragma interface

#include <javax/swing/text/LayeredHighlighter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Shape;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class DefaultHighlighter;
        class View;
        class Highlighter$Highlight;
        class Highlighter$HighlightPainter;
        class JTextComponent;
        class LayeredHighlighter$LayerPainter;
      }
    }
  }
}

class javax::swing::text::DefaultHighlighter : public ::javax::swing::text::LayeredHighlighter
{
public:
  DefaultHighlighter ();
  virtual jboolean getDrawsLayeredHighlights () { return drawsLayeredHighlights; }
  virtual void setDrawsLayeredHighlights (jboolean);
private:
  void checkPositions (jint, jint);
public:
  virtual void install (::javax::swing::text::JTextComponent *);
  virtual void deinstall (::javax::swing::text::JTextComponent *);
  virtual ::java::lang::Object *addHighlight (jint, jint, ::javax::swing::text::Highlighter$HighlightPainter *);
  virtual void removeHighlight (::java::lang::Object *);
  virtual void removeAllHighlights ();
  virtual JArray< ::javax::swing::text::Highlighter$Highlight *> *getHighlights ();
  virtual void changeHighlight (::java::lang::Object *, jint, jint);
  virtual void paintLayeredHighlights (::java::awt::Graphics *, jint, jint, ::java::awt::Shape *, ::javax::swing::text::JTextComponent *, ::javax::swing::text::View *) { }
  virtual void paint (::java::awt::Graphics *);
  static ::javax::swing::text::LayeredHighlighter$LayerPainter *DefaultPainter;
private:
  ::javax::swing::text::JTextComponent * __attribute__((aligned(__alignof__( ::javax::swing::text::LayeredHighlighter )))) textComponent;
  ::java::util::ArrayList *highlights;
  jboolean drawsLayeredHighlights;

  friend class javax_swing_text_DefaultHighlighter$HighlightEntry;
  friend class javax_swing_text_DefaultHighlighter$DefaultHighlightPainter;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_DefaultHighlighter__ */
