// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_callback_LanguageCallback__
#define __javax_security_auth_callback_LanguageCallback__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace callback
        {
          class LanguageCallback;
        }
      }
    }
  }
}

class javax::security::auth::callback::LanguageCallback : public ::java::lang::Object
{
public:
  LanguageCallback ();
  virtual void setLocale (::java::util::Locale *);
  virtual ::java::util::Locale *getLocale () { return locale; }
private:
  ::java::util::Locale * __attribute__((aligned(__alignof__( ::java::lang::Object )))) locale;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_callback_LanguageCallback__ */
