// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sql_RowSetInternal__
#define __javax_sql_RowSetInternal__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace sql
    {
      class RowSetInternal;
      class RowSetMetaData;
    }
  }
  namespace java
  {
    namespace sql
    {
      class ResultSet;
      class Connection;
    }
  }
}

class javax::sql::RowSetInternal : public ::java::lang::Object
{
public:
  virtual JArray< ::java::lang::Object *> *getParams () = 0;
  virtual ::java::sql::Connection *getConnection () = 0;
  virtual void setMetaData (::javax::sql::RowSetMetaData *) = 0;
  virtual ::java::sql::ResultSet *getOriginal () = 0;
  virtual ::java::sql::ResultSet *getOriginalRow () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sql_RowSetInternal__ */
