// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_cert_CertificateEncodingException__
#define __javax_security_cert_CertificateEncodingException__

#pragma interface

#include <javax/security/cert/CertificateException.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace cert
      {
        class CertificateEncodingException;
      }
    }
  }
}

class javax::security::cert::CertificateEncodingException : public ::javax::security::cert::CertificateException
{
public:
  CertificateEncodingException ();
  CertificateEncodingException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_security_cert_CertificateEncodingException__ */
