// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_Core__
#define __gnu_gcj_Core__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      class Core;
      class RawData;
    }
  }
}

class gnu::gcj::Core : public ::java::lang::Object
{
public:
  static ::gnu::gcj::Core *create (::java::lang::String *);
  static ::gnu::gcj::Core *find (::java::lang::String *);
public: // actually package-private
  Core ();
public:
  ::gnu::gcj::RawData * __attribute__((aligned(__alignof__( ::java::lang::Object )))) ptr;
  jint length;

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_Core__ */
