// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_NegativeArraySizeException__
#define __java_lang_NegativeArraySizeException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::NegativeArraySizeException : public ::java::lang::RuntimeException
{
public:
  NegativeArraySizeException ();
  NegativeArraySizeException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -8960118058596991861LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_NegativeArraySizeException__ */
