// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_spi_ObjectFactoryBuilder__
#define __javax_naming_spi_ObjectFactoryBuilder__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace spi
      {
        class ObjectFactoryBuilder;
        class ObjectFactory;
      }
    }
  }
}

class javax::naming::spi::ObjectFactoryBuilder : public ::java::lang::Object
{
public:
  virtual ::javax::naming::spi::ObjectFactory *createObjectFactory (::java::lang::Object *, ::java::util::Hashtable *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_naming_spi_ObjectFactoryBuilder__ */
