// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_KeyAgreementFactory__
#define __gnu_javax_crypto_key_KeyAgreementFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          class KeyAgreementFactory;
          class IKeyAgreementParty;
        }
      }
    }
  }
}

class gnu::javax::crypto::key::KeyAgreementFactory : public ::java::lang::Object
{
private:
  KeyAgreementFactory ();
public:
  static ::gnu::javax::crypto::key::IKeyAgreementParty *getPartyAInstance (::java::lang::String *);
  static ::gnu::javax::crypto::key::IKeyAgreementParty *getPartyBInstance (::java::lang::String *);
  static ::java::util::Set *getNames ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_key_KeyAgreementFactory__ */
