// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_BufferedImageFilter__
#define __java_awt_image_BufferedImageFilter__

#pragma interface

#include <java/awt/image/ImageFilter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class BufferedImageFilter;
        class ColorModel;
        class BufferedImageOp;
      }
    }
  }
}

class java::awt::image::BufferedImageFilter : public ::java::awt::image::ImageFilter
{
public:
  BufferedImageFilter (::java::awt::image::BufferedImageOp *);
  virtual ::java::awt::image::BufferedImageOp *getBufferedImageOp () { return op; }
  virtual void setPixels (jint, jint, jint, jint, ::java::awt::image::ColorModel *, jbyteArray, jint, jint);
  virtual void setPixels (jint, jint, jint, jint, ::java::awt::image::ColorModel *, jintArray, jint, jint);
private:
  ::java::awt::image::BufferedImageOp * __attribute__((aligned(__alignof__( ::java::awt::image::ImageFilter )))) op;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_BufferedImageFilter__ */
