// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_NullCipherImpl__
#define __javax_crypto_NullCipherImpl__

#pragma interface

#include <javax/crypto/CipherSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      class NullCipherImpl;
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class SecureRandom;
      class Key;
      class AlgorithmParameters;
    }
  }
}

class javax::crypto::NullCipherImpl : public ::javax::crypto::CipherSpi
{
public: // actually package-private
  NullCipherImpl ();
public:  // actually protected
  virtual void engineSetMode (::java::lang::String *) { }
  virtual void engineSetPadding (::java::lang::String *) { }
  virtual jint engineGetBlockSize ();
  virtual jint engineGetOutputSize (jint);
  virtual jbyteArray engineGetIV () { return 0; }
  virtual ::java::security::AlgorithmParameters *engineGetParameters () { return 0; }
  virtual void engineInit (jint, ::java::security::Key *, ::java::security::SecureRandom *) { }
  virtual void engineInit (jint, ::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *) { }
  virtual void engineInit (jint, ::java::security::Key *, ::java::security::AlgorithmParameters *, ::java::security::SecureRandom *) { }
  virtual jbyteArray engineUpdate (jbyteArray, jint, jint);
  virtual jint engineUpdate (jbyteArray, jint, jint, jbyteArray, jint);
  virtual jbyteArray engineDoFinal (jbyteArray, jint, jint);
  virtual jint engineDoFinal (jbyteArray, jint, jint, jbyteArray, jint);
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_NullCipherImpl__ */
