// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_JNIWeakRef__
#define __gnu_gcj_runtime_JNIWeakRef__

#pragma interface

#include <java/lang/ref/WeakReference.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class JNIWeakRef;
      }
    }
  }
}

class gnu::gcj::runtime::JNIWeakRef : public ::java::lang::ref::WeakReference
{
public:
  JNIWeakRef (::java::lang::Object *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_JNIWeakRef__ */
