// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_SocketAddress__
#define __java_net_SocketAddress__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class SocketAddress;
    }
  }
}

class java::net::SocketAddress : public ::java::lang::Object
{
public:
  SocketAddress ();
public: // actually package-private
  static const jlong serialVersionUID = 5215720748342549866LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_SocketAddress__ */
