// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_protocol_ftp_FTPURLConnection__
#define __gnu_java_net_protocol_ftp_FTPURLConnection__

#pragma interface

#include <java/net/URLConnection.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class URL;
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        namespace protocol
        {
          namespace ftp
          {
            class FTPURLConnection;
            class FTPConnection;
          }
        }
      }
    }
  }
}

class gnu::java::net::protocol::ftp::FTPURLConnection : public ::java::net::URLConnection
{
public:
  FTPURLConnection (::java::net::URL *);
  virtual void connect ();
  virtual void setDoInput (jboolean);
  virtual void setDoOutput (jboolean);
  virtual ::java::io::InputStream *getInputStream ();
  virtual ::java::io::OutputStream *getOutputStream ();
  virtual ::java::lang::String *getRequestProperty (::java::lang::String *);
  virtual ::java::util::Map *getRequestProperties ();
private:
  void addRequestPropertyValue (::java::util::Map *, ::java::lang::String *);
public:
  virtual void setRequestProperty (::java::lang::String *, ::java::lang::String *);
  virtual void addRequestProperty (::java::lang::String *, ::java::lang::String *);
public:  // actually protected
  ::gnu::java::net::protocol::ftp::FTPConnection * __attribute__((aligned(__alignof__( ::java::net::URLConnection )))) connection;
  jboolean passive;
  jint representationType;
  jint fileStructure;
  jint transferMode;

  friend class gnu_java_net_protocol_ftp_FTPURLConnection$ClosingOutputStream;
  friend class gnu_java_net_protocol_ftp_FTPURLConnection$ClosingInputStream;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_protocol_ftp_FTPURLConnection__ */
