// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_models_list__
#define __gnu_javax_swing_text_html_parser_models_list__

#pragma interface

#include <gnu/javax/swing/text/html/parser/models/node.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace models
              {
                class list;
                class node;
              }
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::models::list : public ::gnu::javax::swing::text::html::parser::models::node
{
public:
  list (jchar, jchar, JArray< ::gnu::javax::swing::text::html::parser::models::node *> *);
  list (JArray< ::gnu::javax::swing::text::html::parser::models::node *> *);
  virtual jboolean isClosed ();
  virtual ::java::lang::Object *findFreeNode ();
  virtual jboolean matches (JArray< ::java::lang::Object *> *);
  virtual jboolean mustClose ();
  virtual jboolean performMatch (::java::lang::Object *);
  virtual void reset ();
  virtual ::java::lang::Object *show (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
  virtual jboolean valid ();
  virtual jboolean validPreliminary ();
public:  // actually protected
  virtual void close ();
  virtual jboolean compare (::java::lang::Object *);
private:
  static const jlong serialVersionUID = 1LL;
public:
  static jboolean CLEAR;
  JArray< ::gnu::javax::swing::text::html::parser::models::node *> * __attribute__((aligned(__alignof__( ::gnu::javax::swing::text::html::parser::models::node )))) nodes;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_models_list__ */
