// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_Configuration__
#define __gnu_java_security_Configuration__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        class Configuration;
      }
    }
  }
}

class gnu::java::security::Configuration : public ::java::lang::Object
{
public:
  static const jint DEBUG = 0L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_java_security_Configuration__ */
