// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_MenuBarUI__
#define __javax_swing_plaf_MenuBarUI__

#pragma interface

#include <javax/swing/plaf/ComponentUI.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class MenuBarUI;
      }
    }
  }
}

class javax::swing::plaf::MenuBarUI : public ::javax::swing::plaf::ComponentUI
{
public:
  MenuBarUI ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_MenuBarUI__ */
