// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_print_Book__
#define __java_awt_print_Book__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace print
      {
        class Book;
        class Printable;
        class PageFormat;
      }
    }
  }
}

class java::awt::print::Book : public ::java::lang::Object
{
public:
  Book ();
  virtual jint getNumberOfPages ();
  virtual ::java::awt::print::PageFormat *getPageFormat (jint);
  virtual ::java::awt::print::Printable *getPrintable (jint);
  virtual void append (::java::awt::print::Printable *, ::java::awt::print::PageFormat *);
  virtual void append (::java::awt::print::Printable *, ::java::awt::print::PageFormat *, jint);
  virtual void setPage (jint, ::java::awt::print::Printable *, ::java::awt::print::PageFormat *);
public: // actually package-private
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::java::lang::Object )))) printables;
  ::java::util::Vector *page_formats;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_print_Book__ */
