// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_SSLHMac__
#define __gnu_javax_net_ssl_provider_SSLHMac__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class SSLHMac;
          }
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace hash
        {
          class IMessageDigest;
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::SSLHMac : public ::java::lang::Object
{
public: // actually package-private
  SSLHMac (::java::lang::String *);
public:
  virtual ::java::lang::Object *clone ();
  virtual ::java::lang::String *name ();
  virtual jint macSize ();
  virtual void init (::java::util::Map *);
  virtual void reset ();
  virtual jbyteArray digest ();
  virtual void update (jbyte);
  virtual void update (jbyteArray, jint, jint);
  virtual jboolean selfTest ();
public: // actually package-private
  static const jint PAD1 = 54L;
  static const jint PAD2 = 92L;
public:  // actually protected
  ::gnu::java::security::hash::IMessageDigest * __attribute__((aligned(__alignof__( ::java::lang::Object )))) md;
  jbyteArray key;
  jbyteArray pad1;
  jbyteArray pad2;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_SSLHMac__ */
