// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_openmbean_InvalidKeyException__
#define __javax_management_openmbean_InvalidKeyException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      namespace openmbean
      {
        class InvalidKeyException;
      }
    }
  }
}

class javax::management::openmbean::InvalidKeyException : public ::java::lang::IllegalArgumentException
{
public:
  InvalidKeyException ();
  InvalidKeyException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 4224269443946322062LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_openmbean_InvalidKeyException__ */
