// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_Stack__
#define __java_util_Stack__

#pragma interface

#include <java/util/Vector.h>

class java::util::Stack : public ::java::util::Vector
{
public:
  Stack ();
  virtual ::java::lang::Object *push (::java::lang::Object *);
  virtual ::java::lang::Object *pop ();
  virtual ::java::lang::Object *peek ();
  virtual jboolean empty ();
  virtual jint search (::java::lang::Object *);
private:
  static const jlong serialVersionUID = 1224463164541339165LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_Stack__ */
