// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Enum__
#define __java_lang_Enum__

#pragma interface

#include <java/lang/Object.h>

class java::lang::Enum : public ::java::lang::Object
{
public:  // actually protected
  Enum (::java::lang::String *, jint);
public:
  static ::java::lang::Enum *valueOf (::java::lang::Class *, ::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode () { return ordinal__; }
  virtual ::java::lang::String *toString () { return name__; }
  virtual jint compareTo (::java::lang::Enum *);
  virtual jint compareTo (::java::lang::Object *);
public:  // actually protected
  virtual ::java::lang::Object *clone ();
public:
  virtual ::java::lang::String *name () { return name__; }
  virtual jint ordinal () { return ordinal__; }
  virtual ::java::lang::Class *getDeclaringClass ();
private:
  static const jlong serialVersionUID = -4300926546619394005LL;
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name__;
  jint ordinal__;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Enum__ */
