// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_SwingConstants__
#define __javax_swing_SwingConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class SwingConstants;
    }
  }
}

class javax::swing::SwingConstants : public ::java::lang::Object
{
public:
  static const jint CENTER = 0L;
  static const jint TOP = 1L;
  static const jint LEFT = 2L;
  static const jint BOTTOM = 3L;
  static const jint RIGHT = 4L;
  static const jint NORTH = 1L;
  static const jint NORTH_EAST = 2L;
  static const jint EAST = 3L;
  static const jint SOUTH_EAST = 4L;
  static const jint SOUTH = 5L;
  static const jint SOUTH_WEST = 6L;
  static const jint WEST = 7L;
  static const jint NORTH_WEST = 8L;
  static const jint HORIZONTAL = 0L;
  static const jint VERTICAL = 1L;
  static const jint LEADING = 10L;
  static const jint TRAILING = 11L;
  static const jint NEXT = 12L;
  static const jint PREVIOUS = 13L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_SwingConstants__ */
