// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_jpeg_YCbCr_ColorSpace__
#define __gnu_javax_imageio_jpeg_YCbCr_ColorSpace__

#pragma interface

#include <java/awt/color/ColorSpace.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace jpeg
        {
          class YCbCr_ColorSpace;
        }
      }
    }
  }
}

class gnu::javax::imageio::jpeg::YCbCr_ColorSpace : public ::java::awt::color::ColorSpace
{
public:
  YCbCr_ColorSpace ();
  virtual jfloatArray fromCIEXYZ (jfloatArray);
  virtual jfloatArray toCIEXYZ (jfloatArray);
  virtual jfloatArray fromRGB (jfloatArray);
  virtual jfloatArray toRGB (jfloatArray);
  static jfloatArray toYCbCr (jfloatArray);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_jpeg_YCbCr_ColorSpace__ */
