// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_TableView__
#define __javax_swing_text_html_TableView__

#pragma interface

#include <javax/swing/text/TableView.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class ViewFactory;
        class TableView$TableRow;
        namespace html
        {
          class TableView;
          class StyleSheet;
        }
        class Element;
      }
    }
  }
}

class javax::swing::text::html::TableView : public ::javax::swing::text::TableView
{
public:
  TableView (::javax::swing::text::Element *);
public:  // actually protected
  virtual ::javax::swing::text::html::StyleSheet *getStyleSheet ();
  virtual ::javax::swing::text::TableView$TableRow *createTableRow (::javax::swing::text::Element *);
  virtual void loadChildren (::javax::swing::text::ViewFactory *);

  friend class javax_swing_text_html_TableView$RowView;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_TableView__ */
