// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Extensions__
#define __gnu_javax_net_ssl_provider_Extensions__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class Extensions;
            class CertificateType;
            class Extension;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Extensions : public ::java::lang::Object
{
private:
  Extensions ();
public: // actually package-private
  static ::java::util::List *getServerName (::gnu::javax::net::ssl::provider::Extension *);
  static ::java::util::List *getClientCertTypes (::gnu::javax::net::ssl::provider::Extension *);
  static ::gnu::javax::net::ssl::provider::CertificateType *getServerCertType (::gnu::javax::net::ssl::provider::Extension *);
  static ::java::lang::Integer *getMaxFragmentLength (::gnu::javax::net::ssl::provider::Extension *);
  static JArray< ::java::lang::Object *> *getTrustedCA (::gnu::javax::net::ssl::provider::Extension *);
  static ::java::lang::String *getSRPUsername (::gnu::javax::net::ssl::provider::Extension *);
private:
  static ::java::lang::Integer *_512;
  static ::java::lang::Integer *_1024;
  static ::java::lang::Integer *_2048;
  static ::java::lang::Integer *_4096;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Extensions__ */
