// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_accessibility_AccessibleAttributeSequence__
#define __javax_accessibility_AccessibleAttributeSequence__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleAttributeSequence;
    }
    namespace swing
    {
      namespace text
      {
        class AttributeSet;
      }
    }
  }
}

class javax::accessibility::AccessibleAttributeSequence : public ::java::lang::Object
{
public:
  AccessibleAttributeSequence ();
  ::javax::swing::text::AttributeSet * __attribute__((aligned(__alignof__( ::java::lang::Object )))) attributes;
  jint startIndex;
  jint endIndex;

  static ::java::lang::Class class$;
};

#endif /* __javax_accessibility_AccessibleAttributeSequence__ */
