// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_srp_ClientStore__
#define __gnu_javax_crypto_sasl_srp_ClientStore__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace srp
          {
            class SecurityContext;
            class ClientStore;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::srp::ClientStore : public ::java::lang::Object
{
private:
  ClientStore ();
public: // actually package-private
  static ::gnu::javax::crypto::sasl::srp::ClientStore *instance ();
  virtual jboolean isAlive (::java::lang::String *);
  virtual void cacheSession (::java::lang::String *, jint, ::gnu::javax::crypto::sasl::srp::SecurityContext *);
  virtual void invalidateSession (::java::lang::String *);
  virtual ::gnu::javax::crypto::sasl::srp::SecurityContext *restoreSession (::java::lang::String *);
private:
  static ::gnu::javax::crypto::sasl::srp::ClientStore *singleton;
  static ::java::util::HashMap *uid2ssc;
  static ::java::util::HashMap *uid2ttl;
  static ::java::lang::Object *lock;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_srp_ClientStore__ */
