// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalInternalFrameTitlePane__
#define __javax_swing_plaf_metal_MetalInternalFrameTitlePane__

#pragma interface

#include <javax/swing/plaf/basic/BasicInternalFrameTitlePane.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class PropertyChangeListener;
    }
    namespace awt
    {
      class Graphics;
      class LayoutManager;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalInternalFrameTitlePane;
        }
      }
      class JMenu;
      class JInternalFrame;
      class JLabel;
      class Icon;
    }
  }
}

class javax::swing::plaf::metal::MetalInternalFrameTitlePane : public ::javax::swing::plaf::basic::BasicInternalFrameTitlePane
{
public:
  MetalInternalFrameTitlePane (::javax::swing::JInternalFrame *);
public:  // actually protected
  virtual void installDefaults ();
  virtual void uninstallDefaults ();
  virtual void createButtons ();
  virtual void addSystemMenuItems (::javax::swing::JMenu *) { }
  virtual void showSystemMenu () { }
  virtual void addSubComponents ();
  virtual ::java::awt::LayoutManager *createLayout ();
public:
  virtual void paintPalette (::java::awt::Graphics *);
  virtual void paintComponent (::java::awt::Graphics *);
  virtual void setPalette (jboolean);
public:  // actually protected
  virtual ::java::beans::PropertyChangeListener *createPropertyChangeListener ();
  jboolean __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicInternalFrameTitlePane ))))  isPalette;
  ::javax::swing::Icon *paletteCloseIcon;
  jint paletteTitleHeight;
public: // actually package-private
  ::javax::swing::JLabel *title;

  friend class javax_swing_plaf_metal_MetalInternalFrameTitlePane$MetalTitlePaneLayout;
  friend class javax_swing_plaf_metal_MetalInternalFrameTitlePane$MetalInternalFrameTitlePanePropertyChangeHandler;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalInternalFrameTitlePane__ */
