// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Void__
#define __java_lang_Void__

#pragma interface

#include <java/lang/Object.h>

class java::lang::Void : public ::java::lang::Object
{
private:
  Void ();
public:
  static ::java::lang::Class *TYPE;

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Void__ */
