// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_pad_BasePad__
#define __gnu_javax_crypto_pad_BasePad__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace pad
        {
          class BasePad;
        }
      }
    }
  }
}

class gnu::javax::crypto::pad::BasePad : public ::java::lang::Object
{
public:  // actually protected
  BasePad (::java::lang::String *);
public:
  virtual ::java::lang::String *name ();
  virtual void init (jint);
  virtual void init (::java::util::Map *);
  virtual void reset ();
  virtual jboolean selfTest ();
public:  // actually protected
  virtual jboolean test1BlockSize (jint, jbyteArray);
public:
  virtual void setup () = 0;
  virtual jbyteArray pad (jbyteArray, jint, jint) = 0;
  virtual jint unpad (jbyteArray, jint, jint) = 0;
private:
  static ::java::util::logging::Logger *log;
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name__;
  jint blockSize;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_pad_BasePad__ */
