// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_LineUnavailableException__
#define __javax_sound_sampled_LineUnavailableException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class LineUnavailableException;
      }
    }
  }
}

class javax::sound::sampled::LineUnavailableException : public ::java::lang::Exception
{
public:
  LineUnavailableException ();
  LineUnavailableException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -2046718279487432130LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_sampled_LineUnavailableException__ */
