// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Finished__
#define __gnu_javax_net_ssl_provider_Finished__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class Finished;
            class CipherSuite;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Finished : public ::java::lang::Object
{
public: // actually package-private
  Finished (jbyteArray);
  Finished (jbyteArray, jbyteArray);
  static ::gnu::javax::net::ssl::provider::Finished *read (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::CipherSuite *);
public:
  virtual void write (::java::io::OutputStream *);
public: // actually package-private
  virtual jbyteArray getVerifyData () { return verifyData; }
  virtual jbyteArray getMD5Hash () { return md5; }
  virtual jbyteArray getSHAHash () { return sha; }
public:
  virtual ::java::lang::String *toString ();
private:
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  verifyData;
  jbyteArray md5;
  jbyteArray sha;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Finished__ */
