// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ThreadDeath__
#define __java_lang_ThreadDeath__

#pragma interface

#include <java/lang/Error.h>

class java::lang::ThreadDeath : public ::java::lang::Error
{
public:
  ThreadDeath ();
private:
  static const jlong serialVersionUID = -4417128565033088268LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ThreadDeath__ */
