// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_HttpURLConnection__
#define __java_net_HttpURLConnection__

#pragma interface

#include <java/net/URLConnection.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class Permission;
    }
    namespace net
    {
      class HttpURLConnection;
      class URL;
    }
  }
}

class java::net::HttpURLConnection : public ::java::net::URLConnection
{
public:  // actually protected
  HttpURLConnection (::java::net::URL *);
public:
  virtual void disconnect () = 0;
  virtual jboolean usingProxy () = 0;
  static void setFollowRedirects (jboolean);
  static jboolean getFollowRedirects ();
  virtual jboolean getInstanceFollowRedirects () { return instanceFollowRedirects; }
  virtual void setInstanceFollowRedirects (jboolean);
  virtual void setRequestMethod (::java::lang::String *);
  virtual ::java::lang::String *getRequestMethod () { return method; }
  virtual jint getResponseCode ();
  virtual ::java::lang::String *getResponseMessage ();
private:
  void getResponseVals ();
public:
  virtual ::java::security::Permission *getPermission ();
  virtual ::java::io::InputStream *getErrorStream ();
  virtual jlong getHeaderFieldDate (::java::lang::String *, jlong);
public: // actually package-private
  static const jint HTTP_CONTINUE = 100L;
public:
  static const jint HTTP_OK = 200L;
  static const jint HTTP_CREATED = 201L;
  static const jint HTTP_ACCEPTED = 202L;
  static const jint HTTP_NOT_AUTHORITATIVE = 203L;
  static const jint HTTP_NO_CONTENT = 204L;
  static const jint HTTP_RESET = 205L;
  static const jint HTTP_PARTIAL = 206L;
  static const jint HTTP_MULT_CHOICE = 300L;
  static const jint HTTP_MOVED_PERM = 301L;
  static const jint HTTP_MOVED_TEMP = 302L;
  static const jint HTTP_SEE_OTHER = 303L;
  static const jint HTTP_NOT_MODIFIED = 304L;
  static const jint HTTP_USE_PROXY = 305L;
  static const jint HTTP_BAD_REQUEST = 400L;
  static const jint HTTP_UNAUTHORIZED = 401L;
  static const jint HTTP_PAYMENT_REQUIRED = 402L;
  static const jint HTTP_FORBIDDEN = 403L;
  static const jint HTTP_NOT_FOUND = 404L;
  static const jint HTTP_BAD_METHOD = 405L;
  static const jint HTTP_NOT_ACCEPTABLE = 406L;
  static const jint HTTP_PROXY_AUTH = 407L;
  static const jint HTTP_CLIENT_TIMEOUT = 408L;
  static const jint HTTP_CONFLICT = 409L;
  static const jint HTTP_GONE = 410L;
  static const jint HTTP_LENGTH_REQUIRED = 411L;
  static const jint HTTP_PRECON_FAILED = 412L;
  static const jint HTTP_ENTITY_TOO_LARGE = 413L;
  static const jint HTTP_REQ_TOO_LONG = 414L;
  static const jint HTTP_UNSUPPORTED_TYPE = 415L;
  static const jint HTTP_SERVER_ERROR = 500L;
  static const jint HTTP_INTERNAL_ERROR = 500L;
  static const jint HTTP_NOT_IMPLEMENTED = 501L;
  static const jint HTTP_BAD_GATEWAY = 502L;
  static const jint HTTP_UNAVAILABLE = 503L;
  static const jint HTTP_GATEWAY_TIMEOUT = 504L;
  static const jint HTTP_VERSION = 505L;
private:
  static jboolean followRedirects;
  static ::java::lang::String *valid_methods;
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::net::URLConnection )))) method;
  jint responseCode;
  ::java::lang::String *responseMessage;
  jboolean instanceFollowRedirects;
private:
  jboolean gotResponseVals;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_HttpURLConnection__ */
