// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_text_DateFormatSymbols__
#define __java_text_DateFormatSymbols__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace text
    {
      class DateFormatSymbols;
    }
  }
}

class java::text::DateFormatSymbols : public ::java::lang::Object
{
private:
  JArray< ::java::lang::String *> *formatsForKey (::java::util::ResourceBundle *, ::java::lang::String *);
public:
  DateFormatSymbols (::java::util::Locale *);
  DateFormatSymbols ();
  virtual JArray< ::java::lang::String *> *getAmPmStrings () { return ampms; }
  virtual JArray< ::java::lang::String *> *getEras () { return eras; }
  virtual ::java::lang::String *getLocalPatternChars () { return localPatternChars; }
  virtual JArray< ::java::lang::String *> *getMonths () { return months; }
  virtual JArray< ::java::lang::String *> *getShortMonths () { return shortMonths; }
  virtual JArray< ::java::lang::String *> *getShortWeekdays () { return shortWeekdays; }
  virtual JArray< ::java::lang::String *> *getWeekdays () { return weekdays; }
  virtual JArray<JArray< ::java::lang::String *> *> *getZoneStrings () { return zoneStrings; }
  virtual void setAmPmStrings (JArray< ::java::lang::String *> *);
  virtual void setEras (JArray< ::java::lang::String *> *);
  virtual void setLocalPatternChars (::java::lang::String *);
  virtual void setMonths (JArray< ::java::lang::String *> *);
  virtual void setShortMonths (JArray< ::java::lang::String *> *);
  virtual void setShortWeekdays (JArray< ::java::lang::String *> *);
  virtual void setWeekdays (JArray< ::java::lang::String *> *);
  virtual void setZoneStrings (JArray<JArray< ::java::lang::String *> *> *);
private:
  static jboolean equals (::java::lang::Object *, ::java::lang::Object *);
  static jint hashCode (::java::lang::Object *);
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::Object *clone ();
  virtual jint hashCode ();
public: // actually package-private
  JArray< ::java::lang::String *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) ampms;
  JArray< ::java::lang::String *> *eras;
private:
  ::java::lang::String *localPatternChars;
public: // actually package-private
  JArray< ::java::lang::String *> *months;
  JArray< ::java::lang::String *> *shortMonths;
  JArray< ::java::lang::String *> *shortWeekdays;
  JArray< ::java::lang::String *> *weekdays;
private:
  JArray<JArray< ::java::lang::String *> *> *zoneStrings;
  static const jlong serialVersionUID = -5987973545549424702LL;
  static JArray< ::java::lang::String *> *formatPrefixes;
public: // actually package-private
  JArray< ::java::lang::String *> *dateFormats;
  JArray< ::java::lang::String *> *timeFormats;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_text_DateFormatSymbols__ */
