// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_NoSuchFieldError__
#define __java_lang_NoSuchFieldError__

#pragma interface

#include <java/lang/IncompatibleClassChangeError.h>

class java::lang::NoSuchFieldError : public ::java::lang::IncompatibleClassChangeError
{
public:
  NoSuchFieldError ();
  NoSuchFieldError (::java::lang::String *);
private:
  static const jlong serialVersionUID = -3456430195886129035LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_NoSuchFieldError__ */
