// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_KeyEvent__
#define __java_awt_event_KeyEvent__

#pragma interface

#include <java/awt/event/InputEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class KeyEvent;
      }
      class Component;
    }
  }
}

class java::awt::event::KeyEvent : public ::java::awt::event::InputEvent
{
public:
  KeyEvent (::java::awt::Component *, jint, jlong, jint, jint, jchar, jint);
  KeyEvent (::java::awt::Component *, jint, jlong, jint, jint, jchar);
  KeyEvent (::java::awt::Component *, jint, jlong, jint, jint);
  virtual jint getKeyCode () { return keyCode; }
  virtual void setKeyCode (jint);
  virtual jchar getKeyChar () { return keyChar; }
  virtual void setKeyChar (jchar);
  virtual void setModifiers (jint);
  virtual jint getKeyLocation () { return keyLocation; }
  static ::java::lang::String *getKeyText (jint);
  static ::java::lang::String *getKeyModifiersText (jint);
  virtual jboolean isActionKey ();
  virtual ::java::lang::String *paramString ();
private:
  void readObject (::java::io::ObjectInputStream *);
  static const jlong serialVersionUID = -2352130953028126954LL;
public:
  static const jint KEY_FIRST = 400L;
  static const jint KEY_LAST = 402L;
  static const jint KEY_TYPED = 400L;
  static const jint KEY_PRESSED = 401L;
  static const jint KEY_RELEASED = 402L;
  static const jint VK_ENTER = 10L;
  static const jint VK_BACK_SPACE = 8L;
  static const jint VK_TAB = 9L;
  static const jint VK_CANCEL = 3L;
  static const jint VK_CLEAR = 12L;
  static const jint VK_SHIFT = 16L;
  static const jint VK_CONTROL = 17L;
  static const jint VK_ALT = 18L;
  static const jint VK_PAUSE = 19L;
  static const jint VK_CAPS_LOCK = 20L;
  static const jint VK_ESCAPE = 27L;
  static const jint VK_SPACE = 32L;
  static const jint VK_PAGE_UP = 33L;
  static const jint VK_PAGE_DOWN = 34L;
  static const jint VK_END = 35L;
  static const jint VK_HOME = 36L;
  static const jint VK_LEFT = 37L;
  static const jint VK_UP = 38L;
  static const jint VK_RIGHT = 39L;
  static const jint VK_DOWN = 40L;
  static const jint VK_COMMA = 44L;
  static const jint VK_MINUS = 45L;
  static const jint VK_PERIOD = 46L;
  static const jint VK_SLASH = 47L;
  static const jint VK_0 = 48L;
  static const jint VK_1 = 49L;
  static const jint VK_2 = 50L;
  static const jint VK_3 = 51L;
  static const jint VK_4 = 52L;
  static const jint VK_5 = 53L;
  static const jint VK_6 = 54L;
  static const jint VK_7 = 55L;
  static const jint VK_8 = 56L;
  static const jint VK_9 = 57L;
  static const jint VK_SEMICOLON = 59L;
  static const jint VK_EQUALS = 61L;
  static const jint VK_A = 65L;
  static const jint VK_B = 66L;
  static const jint VK_C = 67L;
  static const jint VK_D = 68L;
  static const jint VK_E = 69L;
  static const jint VK_F = 70L;
  static const jint VK_G = 71L;
  static const jint VK_H = 72L;
  static const jint VK_I = 73L;
  static const jint VK_J = 74L;
  static const jint VK_K = 75L;
  static const jint VK_L = 76L;
  static const jint VK_M = 77L;
  static const jint VK_N = 78L;
  static const jint VK_O = 79L;
  static const jint VK_P = 80L;
  static const jint VK_Q = 81L;
  static const jint VK_R = 82L;
  static const jint VK_S = 83L;
  static const jint VK_T = 84L;
  static const jint VK_U = 85L;
  static const jint VK_V = 86L;
  static const jint VK_W = 87L;
  static const jint VK_X = 88L;
  static const jint VK_Y = 89L;
  static const jint VK_Z = 90L;
  static const jint VK_OPEN_BRACKET = 91L;
  static const jint VK_BACK_SLASH = 92L;
  static const jint VK_CLOSE_BRACKET = 93L;
  static const jint VK_NUMPAD0 = 96L;
  static const jint VK_NUMPAD1 = 97L;
  static const jint VK_NUMPAD2 = 98L;
  static const jint VK_NUMPAD3 = 99L;
  static const jint VK_NUMPAD4 = 100L;
  static const jint VK_NUMPAD5 = 101L;
  static const jint VK_NUMPAD6 = 102L;
  static const jint VK_NUMPAD7 = 103L;
  static const jint VK_NUMPAD8 = 104L;
  static const jint VK_NUMPAD9 = 105L;
  static const jint VK_MULTIPLY = 106L;
  static const jint VK_ADD = 107L;
  static const jint VK_SEPARATER = 108L;
  static const jint VK_SEPARATOR = 108L;
  static const jint VK_SUBTRACT = 109L;
  static const jint VK_DECIMAL = 110L;
  static const jint VK_DIVIDE = 111L;
  static const jint VK_DELETE = 127L;
  static const jint VK_NUM_LOCK = 144L;
  static const jint VK_SCROLL_LOCK = 145L;
  static const jint VK_F1 = 112L;
  static const jint VK_F2 = 113L;
  static const jint VK_F3 = 114L;
  static const jint VK_F4 = 115L;
  static const jint VK_F5 = 116L;
  static const jint VK_F6 = 117L;
  static const jint VK_F7 = 118L;
  static const jint VK_F8 = 119L;
  static const jint VK_F9 = 120L;
  static const jint VK_F10 = 121L;
  static const jint VK_F11 = 122L;
  static const jint VK_F12 = 123L;
  static const jint VK_F13 = 61440L;
  static const jint VK_F14 = 61441L;
  static const jint VK_F15 = 61442L;
  static const jint VK_F16 = 61443L;
  static const jint VK_F17 = 61444L;
  static const jint VK_F18 = 61445L;
  static const jint VK_F19 = 61446L;
  static const jint VK_F20 = 61447L;
  static const jint VK_F21 = 61448L;
  static const jint VK_F22 = 61449L;
  static const jint VK_F23 = 61450L;
  static const jint VK_F24 = 61451L;
  static const jint VK_PRINTSCREEN = 154L;
  static const jint VK_INSERT = 155L;
  static const jint VK_HELP = 156L;
  static const jint VK_META = 157L;
  static const jint VK_BACK_QUOTE = 192L;
  static const jint VK_QUOTE = 222L;
  static const jint VK_KP_UP = 224L;
  static const jint VK_KP_DOWN = 225L;
  static const jint VK_KP_LEFT = 226L;
  static const jint VK_KP_RIGHT = 227L;
  static const jint VK_DEAD_GRAVE = 128L;
  static const jint VK_DEAD_ACUTE = 129L;
  static const jint VK_DEAD_CIRCUMFLEX = 130L;
  static const jint VK_DEAD_TILDE = 131L;
  static const jint VK_DEAD_MACRON = 132L;
  static const jint VK_DEAD_BREVE = 133L;
  static const jint VK_DEAD_ABOVEDOT = 134L;
  static const jint VK_DEAD_DIAERESIS = 135L;
  static const jint VK_DEAD_ABOVERING = 136L;
  static const jint VK_DEAD_DOUBLEACUTE = 137L;
  static const jint VK_DEAD_CARON = 138L;
  static const jint VK_DEAD_CEDILLA = 139L;
  static const jint VK_DEAD_OGONEK = 140L;
  static const jint VK_DEAD_IOTA = 141L;
  static const jint VK_DEAD_VOICED_SOUND = 142L;
  static const jint VK_DEAD_SEMIVOICED_SOUND = 143L;
  static const jint VK_AMPERSAND = 150L;
  static const jint VK_ASTERISK = 151L;
  static const jint VK_QUOTEDBL = 152L;
  static const jint VK_LESS = 153L;
  static const jint VK_GREATER = 160L;
  static const jint VK_BRACELEFT = 161L;
  static const jint VK_BRACERIGHT = 162L;
  static const jint VK_AT = 512L;
  static const jint VK_COLON = 513L;
  static const jint VK_CIRCUMFLEX = 514L;
  static const jint VK_DOLLAR = 515L;
  static const jint VK_EURO_SIGN = 516L;
  static const jint VK_EXCLAMATION_MARK = 517L;
  static const jint VK_INVERTED_EXCLAMATION_MARK = 518L;
  static const jint VK_LEFT_PARENTHESIS = 519L;
  static const jint VK_NUMBER_SIGN = 520L;
  static const jint VK_PLUS = 521L;
  static const jint VK_RIGHT_PARENTHESIS = 522L;
  static const jint VK_UNDERSCORE = 523L;
  static const jint VK_FINAL = 24L;
  static const jint VK_CONVERT = 28L;
  static const jint VK_NONCONVERT = 29L;
  static const jint VK_ACCEPT = 30L;
  static const jint VK_MODECHANGE = 31L;
  static const jint VK_KANA = 21L;
  static const jint VK_KANJI = 25L;
  static const jint VK_ALPHANUMERIC = 240L;
  static const jint VK_KATAKANA = 241L;
  static const jint VK_HIRAGANA = 242L;
  static const jint VK_FULL_WIDTH = 243L;
  static const jint VK_HALF_WIDTH = 244L;
  static const jint VK_ROMAN_CHARACTERS = 245L;
  static const jint VK_ALL_CANDIDATES = 256L;
  static const jint VK_PREVIOUS_CANDIDATE = 257L;
  static const jint VK_CODE_INPUT = 258L;
  static const jint VK_JAPANESE_KATAKANA = 259L;
  static const jint VK_JAPANESE_HIRAGANA = 260L;
  static const jint VK_JAPANESE_ROMAN = 261L;
  static const jint VK_KANA_LOCK = 262L;
  static const jint VK_INPUT_METHOD_ON_OFF = 263L;
  static const jint VK_CUT = 65489L;
  static const jint VK_COPY = 65485L;
  static const jint VK_PASTE = 65487L;
  static const jint VK_UNDO = 65483L;
  static const jint VK_AGAIN = 65481L;
  static const jint VK_FIND = 65488L;
  static const jint VK_PROPS = 65482L;
  static const jint VK_STOP = 65480L;
  static const jint VK_COMPOSE = 65312L;
  static const jint VK_ALT_GRAPH = 65406L;
  static const jint VK_BEGIN = 65368L;
  static const jint VK_CONTEXT_MENU = 525L;
  static const jint VK_WINDOWS = 524L;
  static const jint VK_UNDEFINED = 0L;
  static const jint CHAR_UNDEFINED = 65535L;
  static const jint KEY_LOCATION_UNKNOWN = 0L;
  static const jint KEY_LOCATION_STANDARD = 1L;
  static const jint KEY_LOCATION_LEFT = 2L;
  static const jint KEY_LOCATION_RIGHT = 3L;
  static const jint KEY_LOCATION_NUMPAD = 4L;
private:
  jint __attribute__((aligned(__alignof__( ::java::awt::event::InputEvent ))))  keyCode;
  jchar keyChar;
  jint keyLocation;
  jboolean isProxyActive;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_KeyEvent__ */
