// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_attribute_DefaultValueAttribute__
#define __gnu_javax_print_ipp_attribute_DefaultValueAttribute__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          namespace attribute
          {
            class DefaultValueAttribute;
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class Attribute;
      }
    }
  }
}

class gnu::javax::print::ipp::attribute::DefaultValueAttribute : public ::java::lang::Object
{
public:
  virtual ::javax::print::attribute::Attribute *getAssociatedAttribute () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_print_ipp_attribute_DefaultValueAttribute__ */
