// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_prng_PBKDF2__
#define __gnu_javax_crypto_prng_PBKDF2__

#pragma interface

#include <gnu/java/security/prng/BasePRNG.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace prng
        {
          class PBKDF2;
        }
        namespace mac
        {
          class IMac;
        }
      }
    }
  }
}

class gnu::javax::crypto::prng::PBKDF2 : public ::gnu::java::security::prng::BasePRNG
{
public:
  PBKDF2 (::gnu::javax::crypto::mac::IMac *);
  virtual void setup (::java::util::Map *);
  virtual void fillBlock ();
private:
  jbyteArray __attribute__((aligned(__alignof__( ::gnu::java::security::prng::BasePRNG ))))  in;
  jint iterationCount;
  jbyteArray salt;
  ::gnu::javax::crypto::mac::IMac *mac;
  jlong count;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_prng_PBKDF2__ */
