// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_hash_Sha160__
#define __gnu_java_security_hash_Sha160__

#pragma interface

#include <gnu/java/security/hash/BaseHash.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace hash
        {
          class Sha160;
        }
      }
    }
  }
}

class gnu::java::security::hash::Sha160 : public ::gnu::java::security::hash::BaseHash
{
public:
  Sha160 ();
private:
  Sha160 (::gnu::java::security::hash::Sha160 *);
public:
  static jintArray G (jint, jint, jint, jint, jint, jbyteArray, jint);
  virtual ::java::lang::Object *clone ();
public:  // actually protected
  virtual void transform (jbyteArray, jint);
  virtual jbyteArray padBuffer ();
  virtual jbyteArray getResult ();
  virtual void resetContext ();
public:
  virtual jboolean selfTest ();
private:
  static jintArray sha (jint, jint, jint, jint, jint, jbyteArray, jint);
  static const jint BLOCK_SIZE = 64L;
  static ::java::lang::String *DIGEST0;
  static jintArray w;
  static ::java::lang::Boolean *valid;
  jint __attribute__((aligned(__alignof__( ::gnu::java::security::hash::BaseHash ))))  h0;
  jint h1;
  jint h2;
  jint h3;
  jint h4;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_hash_Sha160__ */
