// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_spec_SecretKeySpec__
#define __javax_crypto_spec_SecretKeySpec__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      namespace spec
      {
        class SecretKeySpec;
      }
    }
  }
}

class javax::crypto::spec::SecretKeySpec : public ::java::lang::Object
{
public:
  SecretKeySpec (jbyteArray, ::java::lang::String *);
  SecretKeySpec (jbyteArray, jint, jint, ::java::lang::String *);
  virtual ::java::lang::String *getAlgorithm () { return algorithm; }
  virtual jbyteArray getEncoded () { return key; }
  virtual ::java::lang::String *getFormat ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  static const jlong serialVersionUID = 6577238317307289933LL;
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  key;
  ::java::lang::String *algorithm;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_spec_SecretKeySpec__ */
