// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_IllegalFormatException__
#define __java_util_IllegalFormatException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

class java::util::IllegalFormatException : public ::java::lang::IllegalArgumentException
{
public: // actually package-private
  IllegalFormatException ();
  IllegalFormatException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 18830826LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_IllegalFormatException__ */
