// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_transaction_xa_Xid__
#define __javax_transaction_xa_Xid__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace transaction
    {
      namespace xa
      {
        class Xid;
      }
    }
  }
}

class javax::transaction::xa::Xid : public ::java::lang::Object
{
public:
  virtual jint getFormatId () = 0;
  virtual jbyteArray getGlobalTransactionId () = 0;
  virtual jbyteArray getBranchQualifier () = 0;
  static const jint MAXGTRIDSIZE = 64L;
  static const jint MAXBQUALSIZE = 64L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_transaction_xa_Xid__ */
