// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_NoSuchAlgorithmException__
#define __java_security_NoSuchAlgorithmException__

#pragma interface

#include <java/security/GeneralSecurityException.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class NoSuchAlgorithmException;
    }
  }
}

class java::security::NoSuchAlgorithmException : public ::java::security::GeneralSecurityException
{
public:
  NoSuchAlgorithmException ();
  NoSuchAlgorithmException (::java::lang::String *);
  NoSuchAlgorithmException (::java::lang::String *, ::java::lang::Throwable *);
  NoSuchAlgorithmException (::java::lang::Throwable *);
private:
  static const jlong serialVersionUID = -7443947487218346562LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_NoSuchAlgorithmException__ */
