// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_color_TagEntry__
#define __gnu_java_awt_color_TagEntry__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace color
        {
          class TagEntry;
        }
      }
    }
  }
}

class gnu::java::awt::color::TagEntry : public ::java::lang::Object
{
public:
  TagEntry (jint, jint, jint, jbyteArray);
  TagEntry (jint, jbyteArray);
  virtual jbyteArray getData ();
  virtual ::java::lang::String *hashKey ();
  virtual ::java::lang::String *toString ();
  virtual jint getSignature () { return signature; }
  virtual jint getSize () { return size; }
  virtual jint getOffset () { return offset; }
  virtual void setOffset (jint);
  static ::java::lang::String *tagHashKey (jint);
  static const jint entrySize = 12L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  signature;
  jint size;
  jint offset;
  jbyteArray data;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_color_TagEntry__ */
