// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_TextUI__
#define __javax_swing_plaf_TextUI__

#pragma interface

#include <javax/swing/plaf/ComponentUI.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Point;
      class Rectangle;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class TextUI;
      }
      namespace text
      {
        class View;
        class EditorKit;
        class Position$Bias;
        class JTextComponent;
      }
    }
  }
}

class javax::swing::plaf::TextUI : public ::javax::swing::plaf::ComponentUI
{
public:
  TextUI ();
  virtual ::java::awt::Rectangle *modelToView (::javax::swing::text::JTextComponent *, jint) = 0;
  virtual ::java::awt::Rectangle *modelToView (::javax::swing::text::JTextComponent *, jint, ::javax::swing::text::Position$Bias *) = 0;
  virtual jint viewToModel (::javax::swing::text::JTextComponent *, ::java::awt::Point *) = 0;
  virtual jint viewToModel (::javax::swing::text::JTextComponent *, ::java::awt::Point *, JArray< ::javax::swing::text::Position$Bias *> *) = 0;
  virtual jint getNextVisualPositionFrom (::javax::swing::text::JTextComponent *, jint, ::javax::swing::text::Position$Bias *, jint, JArray< ::javax::swing::text::Position$Bias *> *) = 0;
  virtual void damageRange (::javax::swing::text::JTextComponent *, jint, jint) = 0;
  virtual void damageRange (::javax::swing::text::JTextComponent *, jint, jint, ::javax::swing::text::Position$Bias *, ::javax::swing::text::Position$Bias *) = 0;
  virtual ::javax::swing::text::EditorKit *getEditorKit (::javax::swing::text::JTextComponent *) = 0;
  virtual ::javax::swing::text::View *getRootView (::javax::swing::text::JTextComponent *) = 0;
  virtual ::java::lang::String *getToolTipText (::javax::swing::text::JTextComponent *, ::java::awt::Point *) { return 0; }

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_TextUI__ */
