// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_Highlighter__
#define __javax_swing_text_Highlighter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class Highlighter;
        class Highlighter$Highlight;
        class Highlighter$HighlightPainter;
        class JTextComponent;
      }
    }
  }
}

class javax::swing::text::Highlighter : public ::java::lang::Object
{
public:
  virtual void install (::javax::swing::text::JTextComponent *) = 0;
  virtual void deinstall (::javax::swing::text::JTextComponent *) = 0;
  virtual ::java::lang::Object *addHighlight (jint, jint, ::javax::swing::text::Highlighter$HighlightPainter *) = 0;
  virtual void removeAllHighlights () = 0;
  virtual void removeHighlight (::java::lang::Object *) = 0;
  virtual void changeHighlight (::java::lang::Object *, jint, jint) = 0;
  virtual JArray< ::javax::swing::text::Highlighter$Highlight *> *getHighlights () = 0;
  virtual void paint (::java::awt::Graphics *) = 0;

  friend class javax_swing_text_Highlighter$HighlightPainter;
  friend class javax_swing_text_Highlighter$Highlight;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_text_Highlighter__ */
