// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_security_auth_Password__
#define __gnu_javax_security_auth_Password__

#pragma interface

#include <gnu/java/security/util/ExpirableObject.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace security
      {
        namespace auth
        {
          class Password;
        }
      }
    }
  }
}

class gnu::javax::security::auth::Password : public ::gnu::java::security::util::ExpirableObject
{
public:
  Password (jcharArray);
  Password (jcharArray, jlong);
  Password (jcharArray, jint, jint);
  Password (jcharArray, jint, jint, jlong);
  Password (jbyteArray);
  Password (jbyteArray, jlong);
  Password (jbyteArray, jint, jint);
  Password (jbyteArray, jint, jint, jlong);
  virtual jcharArray getPassword ();
  virtual jbyteArray getBytes ();
public:  // actually protected
  virtual void doDestroy ();
public:
  virtual jboolean isDestroyed ();
private:
  jcharArray __attribute__((aligned(__alignof__( ::gnu::java::security::util::ExpirableObject ))))  password;
  jbyteArray bPassword;
  jboolean mIsDestroyed;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_security_auth_Password__ */
