// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_net_VanillaSocketFactory__
#define __javax_net_VanillaSocketFactory__

#pragma interface

#include <javax/net/SocketFactory.h>

extern "Java"
{
  namespace javax
  {
    namespace net
    {
      class VanillaSocketFactory;
    }
  }
  namespace java
  {
    namespace net
    {
      class InetAddress;
      class Socket;
    }
  }
}

class javax::net::VanillaSocketFactory : public ::javax::net::SocketFactory
{
public: // actually package-private
  VanillaSocketFactory ();
public:
  virtual ::java::net::Socket *createSocket ();
  virtual ::java::net::Socket *createSocket (::java::lang::String *, jint);
  virtual ::java::net::Socket *createSocket (::java::lang::String *, jint, ::java::net::InetAddress *, jint);
  virtual ::java::net::Socket *createSocket (::java::net::InetAddress *, jint);
  virtual ::java::net::Socket *createSocket (::java::net::InetAddress *, jint, ::java::net::InetAddress *, jint);

  static ::java::lang::Class class$;
};

#endif /* __javax_net_VanillaSocketFactory__ */
