// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_AssertionError__
#define __java_lang_AssertionError__

#pragma interface

#include <java/lang/Error.h>

class java::lang::AssertionError : public ::java::lang::Error
{
public:
  AssertionError ();
  AssertionError (::java::lang::Object *);
  AssertionError (jboolean);
  AssertionError (jchar);
  AssertionError (jint);
  AssertionError (jlong);
  AssertionError (jfloat);
  AssertionError (jdouble);
private:
  static const jlong serialVersionUID = -5013299493970297370LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_AssertionError__ */
