// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_EmptyStackException__
#define __java_util_EmptyStackException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::util::EmptyStackException : public ::java::lang::RuntimeException
{
public:
  EmptyStackException ();
private:
  static const jlong serialVersionUID = 5084686378493302095LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_EmptyStackException__ */
