// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_HashPrintRequestAttributeSet__
#define __javax_print_attribute_HashPrintRequestAttributeSet__

#pragma interface

#include <javax/print/attribute/HashAttributeSet.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class HashPrintRequestAttributeSet;
        class PrintRequestAttributeSet;
        class PrintRequestAttribute;
      }
    }
  }
}

class javax::print::attribute::HashPrintRequestAttributeSet : public ::javax::print::attribute::HashAttributeSet
{
public:
  HashPrintRequestAttributeSet ();
  HashPrintRequestAttributeSet (::javax::print::attribute::PrintRequestAttribute *);
  HashPrintRequestAttributeSet (JArray< ::javax::print::attribute::PrintRequestAttribute *> *);
  HashPrintRequestAttributeSet (::javax::print::attribute::PrintRequestAttributeSet *);
private:
  static const jlong serialVersionUID = 2364756266107751933LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_HashPrintRequestAttributeSet__ */
