// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ClassCastException__
#define __java_lang_ClassCastException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::ClassCastException : public ::java::lang::RuntimeException
{
public:
  ClassCastException ();
  ClassCastException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -9223365651070458532LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ClassCastException__ */
