// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_jce_prng_HavalRandomSpi__
#define __gnu_java_security_jce_prng_HavalRandomSpi__

#pragma interface

#include <gnu/java/security/jce/prng/SecureRandomAdapter.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace jce
        {
          namespace prng
          {
            class HavalRandomSpi;
          }
        }
      }
    }
  }
}

class gnu::java::security::jce::prng::HavalRandomSpi : public ::gnu::java::security::jce::prng::SecureRandomAdapter
{
public:
  HavalRandomSpi ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_jce_prng_HavalRandomSpi__ */
