// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_URISyntax__
#define __javax_print_attribute_URISyntax__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class URISyntax;
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URI;
    }
  }
}

class javax::print::attribute::URISyntax : public ::java::lang::Object
{
public:  // actually protected
  URISyntax (::java::net::URI *);
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::net::URI *getURI () { return uri; }
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = -7842661210486401678LL;
  ::java::net::URI * __attribute__((aligned(__alignof__( ::java::lang::Object )))) uri;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_URISyntax__ */
