// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_reflect_TypeSignature__
#define __gnu_java_lang_reflect_TypeSignature__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        namespace reflect
        {
          class TypeSignature;
        }
      }
    }
  }
}

class gnu::java::lang::reflect::TypeSignature : public ::java::lang::Object
{
public:
  static ::java::lang::String *getEncodingOfClass (::java::lang::String *, jboolean);
  static ::java::lang::String *getEncodingOfClass (::java::lang::Class *, jboolean);
  static ::java::lang::String *getEncodingOfClass (::java::lang::Class *);
  static ::java::lang::Class *getClassForEncoding (::java::lang::String *, jboolean);
  static ::java::lang::Class *getClassForEncoding (::java::lang::String *, jboolean, ::java::lang::ClassLoader *);
  static ::java::lang::Class *getClassForEncoding (::java::lang::String *);
  static ::java::lang::String *getEncodingOfMethod (::java::lang::reflect::Method *);
  static ::java::lang::String *getEncodingOfConstructor (::java::lang::reflect::Constructor *);
  static ::java::lang::String *getEncodingOfMember (::java::lang::reflect::Member *);
  TypeSignature ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_lang_reflect_TypeSignature__ */
