// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_sql_PreparedStatement__
#define __java_sql_PreparedStatement__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class URL;
    }
    namespace math
    {
      class BigDecimal;
    }
    namespace sql
    {
      class PreparedStatement;
      class ParameterMetaData;
      class ResultSetMetaData;
      class Array;
      class Clob;
      class Blob;
      class Ref;
      class Timestamp;
      class Time;
      class Date;
      class ResultSet;
    }
  }
}

class java::sql::PreparedStatement : public ::java::lang::Object
{
public:
  virtual ::java::sql::ResultSet *executeQuery () = 0;
  virtual jint executeUpdate () = 0;
  virtual void setNull (jint, jint) = 0;
  virtual void setBoolean (jint, jboolean) = 0;
  virtual void setByte (jint, jbyte) = 0;
  virtual void setShort (jint, jshort) = 0;
  virtual void setInt (jint, jint) = 0;
  virtual void setLong (jint, jlong) = 0;
  virtual void setFloat (jint, jfloat) = 0;
  virtual void setDouble (jint, jdouble) = 0;
  virtual void setBigDecimal (jint, ::java::math::BigDecimal *) = 0;
  virtual void setString (jint, ::java::lang::String *) = 0;
  virtual void setBytes (jint, jbyteArray) = 0;
  virtual void setDate (jint, ::java::sql::Date *) = 0;
  virtual void setTime (jint, ::java::sql::Time *) = 0;
  virtual void setTimestamp (jint, ::java::sql::Timestamp *) = 0;
  virtual void setAsciiStream (jint, ::java::io::InputStream *, jint) = 0;
  virtual void setUnicodeStream (jint, ::java::io::InputStream *, jint) = 0;
  virtual void setBinaryStream (jint, ::java::io::InputStream *, jint) = 0;
  virtual void clearParameters () = 0;
  virtual void setObject (jint, ::java::lang::Object *, jint, jint) = 0;
  virtual void setObject (jint, ::java::lang::Object *, jint) = 0;
  virtual void setObject (jint, ::java::lang::Object *) = 0;
  virtual jboolean execute () = 0;
  virtual void addBatch () = 0;
  virtual void setCharacterStream (jint, ::java::io::Reader *, jint) = 0;
  virtual void setRef (jint, ::java::sql::Ref *) = 0;
  virtual void setBlob (jint, ::java::sql::Blob *) = 0;
  virtual void setClob (jint, ::java::sql::Clob *) = 0;
  virtual void setArray (jint, ::java::sql::Array *) = 0;
  virtual ::java::sql::ResultSetMetaData *getMetaData () = 0;
  virtual void setDate (jint, ::java::sql::Date *, ::java::util::Calendar *) = 0;
  virtual void setTime (jint, ::java::sql::Time *, ::java::util::Calendar *) = 0;
  virtual void setTimestamp (jint, ::java::sql::Timestamp *, ::java::util::Calendar *) = 0;
  virtual void setNull (jint, jint, ::java::lang::String *) = 0;
  virtual void setURL (jint, ::java::net::URL *) = 0;
  virtual ::java::sql::ParameterMetaData *getParameterMetaData () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_sql_PreparedStatement__ */
