// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_DiffieHellmanImpl__
#define __gnu_javax_crypto_jce_DiffieHellmanImpl__

#pragma interface

#include <javax/crypto/KeyAgreementSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          class DiffieHellmanImpl;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class SecureRandom;
      class Key;
    }
  }
  namespace javax
  {
    namespace crypto
    {
      class SecretKey;
      namespace interfaces
      {
        class DHPrivateKey;
      }
    }
  }
}

class gnu::javax::crypto::jce::DiffieHellmanImpl : public ::javax::crypto::KeyAgreementSpi
{
public:
  DiffieHellmanImpl ();
public:  // actually protected
  virtual ::java::security::Key *engineDoPhase (::java::security::Key *, jboolean);
  virtual jbyteArray engineGenerateSecret ();
  virtual jint engineGenerateSecret (jbyteArray, jint);
  virtual ::javax::crypto::SecretKey *engineGenerateSecret (::java::lang::String *);
  virtual void engineInit (::java::security::Key *, ::java::security::SecureRandom *);
  virtual void engineInit (::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *);
private:
  void reset ();
  void checkState ();
  ::javax::crypto::interfaces::DHPrivateKey * __attribute__((aligned(__alignof__( ::javax::crypto::KeyAgreementSpi )))) key;
  jbyteArray result;
  jboolean last_phase_done;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_DiffieHellmanImpl__ */
