// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_server_ServerRef__
#define __java_rmi_server_ServerRef__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      namespace server
      {
        class ServerRef;
        class RemoteStub;
      }
      class Remote;
    }
  }
}

class java::rmi::server::ServerRef : public ::java::lang::Object
{
public:
  virtual ::java::rmi::server::RemoteStub *exportObject (::java::rmi::Remote *, ::java::lang::Object *) = 0;
  virtual ::java::lang::String *getClientHost () = 0;
  static const jlong serialVersionUID = -4557750989390278438LL;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_rmi_server_ServerRef__ */
