// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_prefs_NodeChangeListener__
#define __java_util_prefs_NodeChangeListener__

#pragma interface

#include <java/lang/Object.h>

class java::util::prefs::NodeChangeListener : public ::java::lang::Object
{
public:
  virtual void childAdded (::java::util::prefs::NodeChangeEvent *) = 0;
  virtual void childRemoved (::java::util::prefs::NodeChangeEvent *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_prefs_NodeChangeListener__ */
