// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_font_opentype_truetype_Fixed__
#define __gnu_java_awt_font_opentype_truetype_Fixed__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace font
        {
          namespace opentype
          {
            namespace truetype
            {
              class Fixed;
            }
          }
        }
      }
    }
  }
}

class gnu::java::awt::font::opentype::truetype::Fixed : public ::java::lang::Object
{
private:
  Fixed ();
public:
  static jint mul (jint, jint);
  static jint div (jint, jint);
  static jint ceil (jint);
  static jint floor (jint);
  static jint vectorLength (jint, jint);
  static jint intValue (jint);
  static jfloat floatValue (jint);
  static jdouble doubleValue (jint);
  static jint valueOf (jfloat);
  static jint valueOf (jdouble);
  static ::java::lang::String *toString (jint);
  static ::java::lang::String *toString (jint, jint);
  static const jint ONE = 64L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_font_opentype_truetype_Fixed__ */
