// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_regex_MatchResult__
#define __java_util_regex_MatchResult__

#pragma interface

#include <java/lang/Object.h>

class java::util::regex::MatchResult : public ::java::lang::Object
{
public:
  virtual jint end () = 0;
  virtual jint end (jint) = 0;
  virtual ::java::lang::String *group () = 0;
  virtual ::java::lang::String *group (jint) = 0;
  virtual jint groupCount () = 0;
  virtual jint start () = 0;
  virtual jint start (jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_regex_MatchResult__ */
