// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_sound_sampled_WAV_WAVReader__
#define __gnu_javax_sound_sampled_WAV_WAVReader__

#pragma interface

#include <javax/sound/sampled/spi/AudioFileReader.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace sound
      {
        namespace sampled
        {
          namespace WAV
          {
            class WAVReader;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URL;
    }
  }
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class AudioInputStream;
        class AudioFileFormat;
      }
    }
  }
}

class gnu::javax::sound::sampled::WAV::WAVReader : public ::javax::sound::sampled::spi::AudioFileReader
{
private:
  static jlong readUnsignedIntLE (::java::io::DataInputStream *);
  static jshort readUnsignedShortLE (::java::io::DataInputStream *);
public:
  virtual ::javax::sound::sampled::AudioFileFormat *getAudioFileFormat (::java::io::File *);
  virtual ::javax::sound::sampled::AudioFileFormat *getAudioFileFormat (::java::io::InputStream *);
  virtual ::javax::sound::sampled::AudioFileFormat *getAudioFileFormat (::java::net::URL *);
  virtual ::javax::sound::sampled::AudioInputStream *getAudioInputStream (::java::io::File *);
  virtual ::javax::sound::sampled::AudioInputStream *getAudioInputStream (::java::io::InputStream *);
  virtual ::javax::sound::sampled::AudioInputStream *getAudioInputStream (::java::net::URL *);
  WAVReader ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_sound_sampled_WAV_WAVReader__ */
