// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_net_SocketFactory__
#define __javax_net_SocketFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class InetAddress;
      class Socket;
    }
  }
  namespace javax
  {
    namespace net
    {
      class SocketFactory;
    }
  }
}

class javax::net::SocketFactory : public ::java::lang::Object
{
public:  // actually protected
  SocketFactory ();
public:
  static ::javax::net::SocketFactory *getDefault ();
  virtual ::java::net::Socket *createSocket ();
  virtual ::java::net::Socket *createSocket (::java::lang::String *, jint) = 0;
  virtual ::java::net::Socket *createSocket (::java::lang::String *, jint, ::java::net::InetAddress *, jint) = 0;
  virtual ::java::net::Socket *createSocket (::java::net::InetAddress *, jint) = 0;
  virtual ::java::net::Socket *createSocket (::java::net::InetAddress *, jint, ::java::net::InetAddress *, jint) = 0;

  static ::java::lang::Class class$;
};

#endif /* __javax_net_SocketFactory__ */
