// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalScrollButton__
#define __javax_swing_plaf_metal_MetalScrollButton__

#pragma interface

#include <javax/swing/plaf/basic/BasicArrowButton.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalScrollButton;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Dimension;
    }
  }
}

class javax::swing::plaf::metal::MetalScrollButton : public ::javax::swing::plaf::basic::BasicArrowButton
{
public:
  MetalScrollButton (jint, jint, jboolean);
  virtual jint getButtonWidth () { return buttonWidth; }
  virtual void setFreeStanding (jboolean);
  virtual void paint (::java::awt::Graphics *);
private:
  void paintArrow (::java::awt::Graphics *, jint, jint);
  void paintNorthBorderFreeStanding (::java::awt::Graphics *, jint, jint);
  void paintSouthBorderFreeStanding (::java::awt::Graphics *, jint, jint);
  void paintEastBorderFreeStanding (::java::awt::Graphics *, jint, jint);
  void paintWestBorderFreeStanding (::java::awt::Graphics *, jint, jint);
  void paintNorthBorder (::java::awt::Graphics *, jint, jint);
  void paintSouthBorder (::java::awt::Graphics *, jint, jint);
  void paintEastBorder (::java::awt::Graphics *, jint, jint);
  void paintWestBorder (::java::awt::Graphics *, jint, jint);
public:
  virtual ::java::awt::Dimension *getPreferredSize ();
  virtual ::java::awt::Dimension *getMinimumSize ();
  virtual ::java::awt::Dimension *getMaximumSize ();
private:
  static ::java::awt::Dimension *maximumSize;
  jint __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicArrowButton ))))  buttonWidth;
  jboolean freeStanding;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalScrollButton__ */
