// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_GraphicsConfigTemplate__
#define __java_awt_GraphicsConfigTemplate__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class GraphicsConfigTemplate;
      class GraphicsConfiguration;
    }
  }
}

class java::awt::GraphicsConfigTemplate : public ::java::lang::Object
{
public:
  GraphicsConfigTemplate ();
  virtual ::java::awt::GraphicsConfiguration *getBestConfiguration (JArray< ::java::awt::GraphicsConfiguration *> *) = 0;
  virtual jboolean isGraphicsConfigSupported (::java::awt::GraphicsConfiguration *) = 0;
private:
  static const jlong serialVersionUID = -8061369279557787079LL;
public:
  static const jint REQUIRED = 1L;
  static const jint PREFERRED = 2L;
  static const jint UNNECESSARY = 3L;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_GraphicsConfigTemplate__ */
