// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_assembly_CascadeStage__
#define __gnu_javax_crypto_assembly_CascadeStage__

#pragma interface

#include <gnu/javax/crypto/assembly/Stage.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace assembly
        {
          class CascadeStage;
          class Direction;
          class Cascade;
        }
      }
    }
  }
}

class gnu::javax::crypto::assembly::CascadeStage : public ::gnu::javax::crypto::assembly::Stage
{
public: // actually package-private
  CascadeStage (::gnu::javax::crypto::assembly::Cascade *, ::gnu::javax::crypto::assembly::Direction *);
public:
  virtual ::java::util::Set *blockSizes ();
public: // actually package-private
  virtual void initDelegate (::java::util::Map *);
public:
  virtual jint currentBlockSize ();
public: // actually package-private
  virtual void resetDelegate ();
  virtual void updateDelegate (jbyteArray, jint, jbyteArray, jint);
public:
  virtual jboolean selfTest ();
private:
  ::gnu::javax::crypto::assembly::Cascade * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::assembly::Stage )))) delegate;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_assembly_CascadeStage__ */
