// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_io_DefaultMimeTypes__
#define __gnu_gcj_io_DefaultMimeTypes__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace io
      {
        class DefaultMimeTypes;
      }
    }
  }
}

class gnu::gcj::io::DefaultMimeTypes : public ::java::lang::Object
{
public:
  DefaultMimeTypes ();
  static JArray< ::java::lang::String *> *types;

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_io_DefaultMimeTypes__ */
