// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_BooleanControl__
#define __javax_sound_sampled_BooleanControl__

#pragma interface

#include <javax/sound/sampled/Control.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class BooleanControl;
        class BooleanControl$Type;
      }
    }
  }
}

class javax::sound::sampled::BooleanControl : public ::javax::sound::sampled::Control
{
public:  // actually protected
  BooleanControl (::javax::sound::sampled::BooleanControl$Type *, jboolean);
  BooleanControl (::javax::sound::sampled::BooleanControl$Type *, jboolean, ::java::lang::String *, ::java::lang::String *);
public:
  virtual ::java::lang::String *getStateLabel (jboolean);
  virtual jboolean getValue () { return value; }
  virtual void setValue (jboolean);
  virtual ::java::lang::String *toString ();
private:
  ::javax::sound::sampled::BooleanControl$Type * __attribute__((aligned(__alignof__( ::javax::sound::sampled::Control )))) type;
  jboolean value;
  ::java::lang::String *trueLabel;
  ::java::lang::String *falseLabel;

  friend class javax_sound_sampled_BooleanControl$Type;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_sampled_BooleanControl__ */
