// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_sasl_AuthorizeCallback__
#define __javax_security_sasl_AuthorizeCallback__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace sasl
      {
        class AuthorizeCallback;
      }
    }
  }
}

class javax::security::sasl::AuthorizeCallback : public ::java::lang::Object
{
public:
  AuthorizeCallback (::java::lang::String *, ::java::lang::String *);
  virtual ::java::lang::String *getAuthenticationID () { return authenticationID; }
  virtual ::java::lang::String *getAuthorizationID () { return authorizationID; }
  virtual jboolean isAuthorized () { return authorized; }
  virtual void setAuthorized (jboolean);
  virtual ::java::lang::String *getAuthorizedID ();
  virtual void setAuthorizedID (::java::lang::String *);
private:
  static const jlong serialVersionUID = -2353344186490470805LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) authenticationID;
  ::java::lang::String *authorizationID;
  ::java::lang::String *authorizedID;
  jboolean authorized;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_sasl_AuthorizeCallback__ */
