// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_kwa_AESKeyWrap__
#define __gnu_javax_crypto_kwa_AESKeyWrap__

#pragma interface

#include <gnu/javax/crypto/kwa/BaseKeyWrappingAlgorithm.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace kwa
        {
          class AESKeyWrap;
        }
        namespace cipher
        {
          class Rijndael;
        }
      }
    }
  }
}

class gnu::javax::crypto::kwa::AESKeyWrap : public ::gnu::javax::crypto::kwa::BaseKeyWrappingAlgorithm
{
public:
  AESKeyWrap ();
public:  // actually protected
  virtual void engineInit (::java::util::Map *);
  virtual jbyteArray engineWrap (jbyteArray, jint, jint);
  virtual jbyteArray engineUnwrap (jbyteArray, jint, jint);
private:
  static jbyteArray DEFAULT_IV;
  ::gnu::javax::crypto::cipher::Rijndael * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::kwa::BaseKeyWrappingAlgorithm )))) aes;
  jbyteArray iv;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_kwa_AESKeyWrap__ */
