// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_png_PNGPalette__
#define __gnu_javax_imageio_png_PNGPalette__

#pragma interface

#include <gnu/javax/imageio/png/PNGChunk.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace png
        {
          class PNGPalette;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class ColorSpace;
      }
      namespace image
      {
        class IndexColorModel;
      }
    }
  }
}

class gnu::javax::imageio::png::PNGPalette : public ::gnu::javax::imageio::png::PNGChunk
{
public:  // actually protected
  PNGPalette (jint, jbyteArray, jint);
public:
  PNGPalette (::java::awt::image::IndexColorModel *);
  virtual ::java::awt::image::IndexColorModel *getPalette (::java::awt::color::ColorSpace *);
  virtual ::java::lang::String *toString ();
private:
  jintArray __attribute__((aligned(__alignof__( ::gnu::javax::imageio::png::PNGChunk ))))  red;
  jintArray green;
  jintArray blue;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_png_PNGPalette__ */
