// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_XMLSessionContext__
#define __gnu_javax_net_ssl_provider_XMLSessionContext__

#pragma interface

#include <gnu/javax/net/ssl/provider/SessionContext.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class SecureRandom;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class XMLSessionContext;
            class Session;
            class Session$ID;
          }
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace prng
        {
          class IRandom;
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::XMLSessionContext : public ::gnu::javax::net::ssl::provider::SessionContext
{
public: // actually package-private
  XMLSessionContext ();
  virtual jboolean addSession (::gnu::javax::net::ssl::provider::Session$ID *, ::gnu::javax::net::ssl::provider::Session *);
  virtual void notifyAccess (::gnu::javax::net::ssl::provider::Session *);
  virtual jboolean removeSession (::gnu::javax::net::ssl::provider::Session$ID *);
private:
  void decode ();
  void encode ();
  ::java::io::File * __attribute__((aligned(__alignof__( ::gnu::javax::net::ssl::provider::SessionContext )))) file;
  ::gnu::java::security::prng::IRandom *pbekdf;
  jboolean compress;
  ::java::security::SecureRandom *random;
  jboolean encoding;

  friend class gnu_javax_net_ssl_provider_XMLSessionContext$SAXHandler;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_XMLSessionContext__ */
