// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_attribute_UnknownAttribute__
#define __gnu_javax_print_ipp_attribute_UnknownAttribute__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          namespace attribute
          {
            class UnknownAttribute;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URI;
    }
  }
}

class gnu::javax::print::ipp::attribute::UnknownAttribute : public ::java::lang::Object
{
public:
  UnknownAttribute (jbyte, ::java::lang::String *, jbyteArray);
  virtual ::java::lang::Class *getCategory ();
  virtual ::java::lang::String *getName () { return name; }
  virtual jbyte getValueTag () { return tag; }
  virtual ::java::lang::String *getAttributeName () { return name; }
  virtual jbyteArray getAttributeValue () { return value; }
  virtual ::java::lang::String *getAttributeValueAsString ();
  virtual jint getAttributeValueAsInt ();
  virtual ::java::net::URI *getAttributeValueAsUri ();
  virtual ::java::lang::String *toString ();
private:
  jbyte __attribute__((aligned(__alignof__( ::java::lang::Object ))))  tag;
  ::java::lang::String *name;
  jbyteArray value;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_attribute_UnknownAttribute__ */
