// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppValueTag__
#define __gnu_javax_print_ipp_IppValueTag__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          class IppValueTag;
        }
      }
    }
  }
}

class gnu::javax::print::ipp::IppValueTag : public ::java::lang::Object
{
private:
  IppValueTag ();
public:
  static jboolean isValueTag (jbyte);
  static const jint UNSUPPORTED = 16L;
  static const jint UNKNOWN = 18L;
  static const jint NO_VALUE = 19L;
  static const jint INTEGER = 33L;
  static const jint BOOLEAN = 34L;
  static const jint ENUM = 35L;
  static const jint OCTECTSTRING_UNSPECIFIED = 48L;
  static const jint DATETIME = 49L;
  static const jint RESOLUTION = 50L;
  static const jint RANGEOFINTEGER = 51L;
  static const jint TEXT_WITH_LANGUAGE = 53L;
  static const jint NAME_WITH_LANGUAGE = 54L;
  static const jint TEXT_WITHOUT_LANGUAGE = 65L;
  static const jint NAME_WITHOUT_LANGUAGE = 66L;
  static const jint KEYWORD = 68L;
  static const jint URI = 69L;
  static const jint URI_SCHEME = 70L;
  static const jint CHARSET = 71L;
  static const jint NATURAL_LANGUAGE = 72L;
  static const jint MIME_MEDIA_TYPE = 73L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_IppValueTag__ */
