// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_UnsupportedClassVersionError__
#define __java_lang_UnsupportedClassVersionError__

#pragma interface

#include <java/lang/ClassFormatError.h>

class java::lang::UnsupportedClassVersionError : public ::java::lang::ClassFormatError
{
public:
  UnsupportedClassVersionError ();
  UnsupportedClassVersionError (::java::lang::String *);
private:
  static const jlong serialVersionUID = -7123279212883497373LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_UnsupportedClassVersionError__ */
