// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_CertificateVerify__
#define __gnu_javax_net_ssl_provider_CertificateVerify__

#pragma interface

#include <gnu/javax/net/ssl/provider/Signature.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class PublicKey;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class CertificateVerify;
            class Signature;
            class CipherSuite;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::CertificateVerify : public ::gnu::javax::net::ssl::provider::Signature
{
public: // actually package-private
  CertificateVerify (::java::lang::Object *, ::java::lang::String *);
  static ::gnu::javax::net::ssl::provider::Signature *read (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::CipherSuite *, ::java::security::PublicKey *);
public:
  virtual ::java::lang::String *toString ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_CertificateVerify__ */
