// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_AlreadyBoundException__
#define __java_rmi_AlreadyBoundException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      class AlreadyBoundException;
    }
  }
}

class java::rmi::AlreadyBoundException : public ::java::lang::Exception
{
public:
  AlreadyBoundException ();
  AlreadyBoundException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 9218657361741657110LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_AlreadyBoundException__ */
