// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_applet_Applet__
#define __java_applet_Applet__

#pragma interface

#include <java/awt/Panel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Image;
      class Dimension;
    }
    namespace net
    {
      class URL;
    }
    namespace applet
    {
      class Applet;
      class AudioClip;
      class AppletContext;
      class AppletStub;
    }
  }
}

class java::applet::Applet : public ::java::awt::Panel
{
public:
  Applet ();
  virtual void setStub (::java::applet::AppletStub *);
  virtual jboolean isActive ();
  virtual ::java::net::URL *getDocumentBase ();
  virtual ::java::net::URL *getCodeBase ();
  virtual ::java::lang::String *getParameter (::java::lang::String *);
  virtual ::java::applet::AppletContext *getAppletContext ();
  virtual void resize (jint, jint);
  virtual void resize (::java::awt::Dimension *);
  virtual void showStatus (::java::lang::String *);
  virtual ::java::awt::Image *getImage (::java::net::URL *);
  virtual ::java::awt::Image *getImage (::java::net::URL *, ::java::lang::String *);
  static ::java::applet::AudioClip *newAudioClip (::java::net::URL *);
  virtual ::java::applet::AudioClip *getAudioClip (::java::net::URL *);
  virtual ::java::applet::AudioClip *getAudioClip (::java::net::URL *, ::java::lang::String *);
  virtual ::java::lang::String *getAppletInfo () { return 0; }
  virtual ::java::util::Locale *getLocale ();
  virtual JArray<JArray< ::java::lang::String *> *> *getParameterInfo () { return 0; }
  virtual void play (::java::net::URL *);
  virtual void play (::java::net::URL *, ::java::lang::String *);
  virtual void init () { }
  virtual void start () { }
  virtual void stop () { }
  virtual void destroy () { }
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  void readObject (::java::io::ObjectInputStream *);
  static const jlong serialVersionUID = -5836846270535785031LL;
  ::java::applet::AppletStub * __attribute__((aligned(__alignof__( ::java::awt::Panel )))) stub;
  jint width;
  jint height;
  ::javax::accessibility::AccessibleContext *accessibleContext;

  friend class java_applet_Applet$URLAudioClip;
  friend class java_applet_Applet$AccessibleApplet;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_applet_Applet__ */
