// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_parser_DTDConstants__
#define __javax_swing_text_html_parser_DTDConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          namespace parser
          {
            class DTDConstants;
          }
        }
      }
    }
  }
}

class javax::swing::text::html::parser::DTDConstants : public ::java::lang::Object
{
public:
  static const jint CDATA = 1L;
  static const jint EMPTY = 17L;
  static const jint ID = 4L;
  static const jint IDREF = 5L;
  static const jint IDREFS = 6L;
  static const jint NAME = 7L;
  static const jint NAMES = 8L;
  static const jint NMTOKEN = 9L;
  static const jint NMTOKENS = 10L;
  static const jint NOTATION = 11L;
  static const jint NUMBER = 12L;
  static const jint NUMBERS = 13L;
  static const jint NUTOKEN = 14L;
  static const jint NUTOKENS = 15L;
  static const jint PUBLIC = 10L;
  static const jint SYSTEM = 17L;
  static const jint PARAMETER = 262144L;
  static const jint GENERAL = 65536L;
  static const jint REQUIRED = 2L;
  static const jint FIXED = 1L;
  static const jint IMPLIED = 5L;
  static const jint CURRENT = 3L;
  static const jint CONREF = 4L;
  static const jint STARTTAG = 13L;
  static const jint ENDTAG = 14L;
  static const jint ANY = 19L;
  static const jint DEFAULT = 131072L;
  static const jint ENTITIES = 3L;
  static const jint ENTITY = 2L;
  static const jint MD = 16L;
  static const jint MODEL = 18L;
  static const jint MS = 15L;
  static const jint PI = 12L;
  static const jint RCDATA = 16L;
  static const jint SDATA = 11L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_text_html_parser_DTDConstants__ */
