// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_DataFormatException__
#define __java_util_zip_DataFormatException__

#pragma interface

#include <java/lang/Exception.h>

class java::util::zip::DataFormatException : public ::java::lang::Exception
{
public:
  DataFormatException ();
  DataFormatException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 2219632870893641452LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_DataFormatException__ */
