// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppResponse__
#define __gnu_javax_print_ipp_IppResponse__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          class IppResponse;
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URI;
    }
  }
}

class gnu::javax::print::ipp::IppResponse : public ::java::lang::Object
{
public:
  IppResponse (::java::net::URI *, jshort);
public:  // actually protected
  virtual void setResponseData (::java::io::InputStream *);
public:
  virtual ::java::net::URI *getURI () { return uri; }
  virtual jint getOperationID () { return operation_id; }
  virtual ::java::util::List *getJobAttributes () { return jobAttributes; }
  virtual ::java::util::List *getOperationAttributes () { return operationAttributes; }
  virtual ::java::util::List *getPrinterAttributes () { return printerAttributes; }
  virtual jint getRequestID () { return request_id; }
  virtual jshort getStatusCode () { return status_code; }
  virtual ::java::util::List *getUnsupportedAttributes () { return unsupportedAttributes; }
  virtual jbyteArray getData () { return data; }
public: // actually package-private
  static ::java::util::logging::Logger *logger;
  ::java::net::URI * __attribute__((aligned(__alignof__( ::java::lang::Object )))) uri;
  jshort operation_id;
  jshort status_code;
  jint request_id;
  ::java::util::List *operationAttributes;
  ::java::util::List *printerAttributes;
  ::java::util::List *jobAttributes;
  ::java::util::List *unsupportedAttributes;
  jbyteArray data;

  friend class gnu_javax_print_ipp_IppResponse$ResponseReader;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_IppResponse__ */
