// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_UnmodifiableSetException__
#define __javax_print_attribute_UnmodifiableSetException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class UnmodifiableSetException;
      }
    }
  }
}

class javax::print::attribute::UnmodifiableSetException : public ::java::lang::RuntimeException
{
public:
  UnmodifiableSetException ();
  UnmodifiableSetException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_UnmodifiableSetException__ */
