// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_support_low_Token__
#define __gnu_javax_swing_text_html_parser_support_low_Token__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                namespace low
                {
                  class Token;
                  class Location;
                }
              }
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::support::low::Token : public ::java::lang::Object
{
public:
  Token ();
  Token (jint, ::gnu::javax::swing::text::html::parser::support::low::Location *);
  Token (jint, jchar, ::gnu::javax::swing::text::html::parser::support::low::Location *);
  Token (jint, ::java::lang::String *, ::gnu::javax::swing::text::html::parser::support::low::Location *);
  Token (jint, jint, ::java::lang::String *, ::gnu::javax::swing::text::html::parser::support::low::Location *);
  Token (::gnu::javax::swing::text::html::parser::support::low::Token *, ::gnu::javax::swing::text::html::parser::support::low::Token *);
  virtual ::java::lang::String *getImage ();
  virtual void appendTo (::java::lang::StringBuffer *);
  virtual ::java::lang::String *toString ();
  ::gnu::javax::swing::text::html::parser::support::low::Location * __attribute__((aligned(__alignof__( ::java::lang::Object )))) where;
  jint category;
  jint kind;
private:
  ::java::lang::String *stringImage;
  jchar charImage;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_support_low_Token__ */
