// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_acl_NotOwnerException__
#define __java_security_acl_NotOwnerException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace acl
      {
        class NotOwnerException;
      }
    }
  }
}

class java::security::acl::NotOwnerException : public ::java::lang::Exception
{
public:
  NotOwnerException ();
private:
  static const jlong serialVersionUID = -5555597911163362399LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_acl_NotOwnerException__ */
