// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_StyleSheet__
#define __javax_swing_text_html_StyleSheet__

#pragma interface

#include <javax/swing/text/StyleContext.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class StyleContext$SmallAttributeSet;
        class MutableAttributeSet;
        class View;
        class AttributeSet;
        class Style;
        class Element;
        namespace html
        {
          class StyleSheet$ListPainter;
          class StyleSheet$BoxPainter;
          class CSS$Attribute;
          class HTML$Tag;
          class StyleSheet;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Color;
      class Font;
    }
    namespace net
    {
      class URL;
    }
  }
}

class javax::swing::text::html::StyleSheet : public ::javax::swing::text::StyleContext
{
public:
  StyleSheet ();
  virtual ::javax::swing::text::Style *getRule (::javax::swing::text::html::HTML$Tag *, ::javax::swing::text::Element *) { return 0; }
  virtual ::javax::swing::text::Style *getRule (::java::lang::String *) { return 0; }
  virtual void addRule (::java::lang::String *);
  virtual ::javax::swing::text::AttributeSet *getDeclaration (::java::lang::String *);
  virtual void loadRules (::java::io::Reader *, ::java::net::URL *);
  virtual ::javax::swing::text::AttributeSet *getViewAttributes (::javax::swing::text::View *) { return 0; }
  virtual void removeStyle (::java::lang::String *);
  virtual void addStyleSheet (::javax::swing::text::html::StyleSheet *);
  virtual void removeStyleSheet (::javax::swing::text::html::StyleSheet *);
  virtual JArray< ::javax::swing::text::html::StyleSheet *> *getStyleSheets () { return styleSheet; }
  virtual void importStyleSheet (::java::net::URL *) { }
  virtual void setBase (::java::net::URL *);
  virtual ::java::net::URL *getBase () { return base; }
  virtual void addCSSAttribute (::javax::swing::text::MutableAttributeSet *, ::javax::swing::text::html::CSS$Attribute *, ::java::lang::String *);
  virtual jboolean addCSSAttributeFromHTML (::javax::swing::text::MutableAttributeSet *, ::javax::swing::text::html::CSS$Attribute *, ::java::lang::String *);
  virtual ::javax::swing::text::AttributeSet *translateHTMLToCSS (::javax::swing::text::AttributeSet *) { return 0; }
  virtual ::javax::swing::text::AttributeSet *addAttribute (::javax::swing::text::AttributeSet *, ::java::lang::Object *, ::java::lang::Object *);
  virtual ::javax::swing::text::AttributeSet *addAttributes (::javax::swing::text::AttributeSet *, ::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::AttributeSet *removeAttribute (::javax::swing::text::AttributeSet *, ::java::lang::Object *);
  virtual ::javax::swing::text::AttributeSet *removeAttributes (::javax::swing::text::AttributeSet *, ::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::AttributeSet *removeAttributes (::javax::swing::text::AttributeSet *, ::java::util::Enumeration *);
public:  // actually protected
  virtual ::javax::swing::text::StyleContext$SmallAttributeSet *createSmallAttributeSet (::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::MutableAttributeSet *createLargeAttributeSet (::javax::swing::text::AttributeSet *);
public:
  virtual ::java::awt::Font *getFont (::javax::swing::text::AttributeSet *);
  virtual ::java::awt::Color *getForeground (::javax::swing::text::AttributeSet *);
  virtual ::java::awt::Color *getBackground (::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::html::StyleSheet$BoxPainter *getBoxPainter (::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::html::StyleSheet$ListPainter *getListPainter (::javax::swing::text::AttributeSet *);
  virtual void setBaseFontSize (jint);
  virtual void setBaseFontSize (::java::lang::String *);
  static jint getIndexOfSize (jfloat);
  virtual jfloat getPointSize (jint);
  virtual jfloat getPointSize (::java::lang::String *);
  virtual ::java::awt::Color *stringToColor (::java::lang::String *);
public: // actually package-private
  ::java::net::URL * __attribute__((aligned(__alignof__( ::javax::swing::text::StyleContext )))) base;
  jint baseFontSize;
  JArray< ::javax::swing::text::html::StyleSheet *> *styleSheet;

  friend class javax_swing_text_html_StyleSheet$CssParser;
  friend class javax_swing_text_html_StyleSheet$ListPainter;
  friend class javax_swing_text_html_StyleSheet$BoxPainter;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_StyleSheet__ */
