// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_font_opentype_NameDecoder__
#define __gnu_java_awt_font_opentype_NameDecoder__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace font
        {
          namespace opentype
          {
            class NameDecoder;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace nio
    {
      class ByteBuffer;
    }
  }
}

class gnu::java::awt::font::opentype::NameDecoder : public ::java::lang::Object
{
public:
  static ::java::lang::String *getName (::java::nio::ByteBuffer *, jint, ::java::util::Locale *);
private:
  static jint getMacLanguageCode (::java::util::Locale *);
  static jint getMicrosoftLanguageCode (::java::util::Locale *);
  static jint findLanguageCode (::java::lang::String *, ::java::lang::String *);
  static ::java::lang::String *decodeName (jint, jint, jint, ::java::nio::ByteBuffer *, jint, jint);
  static ::java::lang::String *decodeName (::java::lang::String *, ::java::nio::ByteBuffer *, jint, jint);
  static ::java::util::Locale *getMacLocale (jint);
  static ::java::util::Locale *getWindowsLocale (jint);
  static ::java::lang::String *getMacCharsetName (jint);
  static ::java::lang::String *getMicrosoftCharsetName (jint);
public:
  static ::java::util::Locale *getLocale (jint, jint, jint);
  static ::java::lang::String *getCharsetName (jint, jint, jint);
  NameDecoder ();
  static const jint NAME_COPYRIGHT = 0L;
  static const jint NAME_FAMILY = 1L;
  static const jint NAME_SUBFAMILY = 2L;
  static const jint NAME_UNIQUE = 3L;
  static const jint NAME_FULL = 4L;
  static const jint NAME_VERSION = 5L;
  static const jint NAME_POSTSCRIPT = 6L;
  static const jint NAME_TRADEMARK = 7L;
  static const jint NAME_MANUFACTURER = 8L;
  static const jint NAME_DESIGNER = 9L;
  static const jint NAME_DESCRIPTION = 10L;
  static const jint NAME_VENDOR_URL = 11L;
  static const jint NAME_DESIGNER_URL = 12L;
  static const jint NAME_LICENSE = 13L;
  static const jint NAME_LICENSE_URL = 14L;
  static const jint NAME_PREFERRED_FAMILY = 16L;
  static const jint NAME_PREFERRED_SUBFAMILY = 17L;
  static const jint NAME_FULL_MACCOMPATIBLE = 18L;
  static const jint NAME_SAMPLE_TEXT = 19L;
  static const jint NAME_POSTSCRIPT_CID = 20L;
private:
  static const jint PLATFORM_MACINTOSH = 1L;
  static const jint PLATFORM_MICROSOFT = 3L;
  static ::java::lang::String *macLanguageCodes;
  static ::java::lang::String *microsoftLanguageCodes;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_font_opentype_NameDecoder__ */
