// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ArrayIndexOutOfBoundsException__
#define __java_lang_ArrayIndexOutOfBoundsException__

#pragma interface

#include <java/lang/IndexOutOfBoundsException.h>

class java::lang::ArrayIndexOutOfBoundsException : public ::java::lang::IndexOutOfBoundsException
{
public:
  ArrayIndexOutOfBoundsException ();
  ArrayIndexOutOfBoundsException (::java::lang::String *);
  ArrayIndexOutOfBoundsException (jint);
private:
  static const jlong serialVersionUID = -5116101128118950844LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ArrayIndexOutOfBoundsException__ */
