// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_color_ICC_ProfileRGB__
#define __java_awt_color_ICC_ProfileRGB__

#pragma interface

#include <java/awt/color/ICC_Profile.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class ICC_ProfileRGB;
      }
    }
  }
}

class java::awt::color::ICC_ProfileRGB : public ::java::awt::color::ICC_Profile
{
public: // actually package-private
  ICC_ProfileRGB (jint);
  ICC_ProfileRGB (jbyteArray);
public:
  virtual jfloatArray getMediaWhitePoint ();
  virtual JArray<jfloatArray> * getMatrix ();
  virtual jfloat getGamma (jint);
  virtual jshortArray getTRC (jint);
private:
  JArray<jfloatArray> * createMatrix ();
  static const jlong serialVersionUID = 8505067385152579334LL;
public:
  static const jint REDCOMPONENT = 0L;
  static const jint GREENCOMPONENT = 1L;
  static const jint BLUECOMPONENT = 2L;
private:
  JArray<jfloatArray> * __attribute__((aligned(__alignof__( ::java::awt::color::ICC_Profile ))))  matrix;
  jfloatArray gamma;
  jfloatArray whitePoint;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_color_ICC_ProfileRGB__ */
