// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_UIManager__
#define __javax_swing_UIManager__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Insets;
      class Font;
      class Dimension;
      class Color;
    }
    namespace beans
    {
      class PropertyChangeListener;
      class PropertyChangeSupport;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class UIManager;
      namespace plaf
      {
        class ComponentUI;
      }
      class JComponent;
      class Icon;
      namespace border
      {
        class Border;
      }
      class UIDefaults;
      class UIManager$MultiplexUIDefaults;
      class LookAndFeel;
      class UIManager$LookAndFeelInfo;
    }
  }
}

class javax::swing::UIManager : public ::java::lang::Object
{
public:
  UIManager ();
  static void addPropertyChangeListener (::java::beans::PropertyChangeListener *);
  static void removePropertyChangeListener (::java::beans::PropertyChangeListener *);
  static JArray< ::java::beans::PropertyChangeListener *> *getPropertyChangeListeners ();
  static void addAuxiliaryLookAndFeel (::javax::swing::LookAndFeel *);
  static jboolean removeAuxiliaryLookAndFeel (::javax::swing::LookAndFeel *);
  static JArray< ::javax::swing::LookAndFeel *> *getAuxiliaryLookAndFeels ();
  static ::java::lang::Object *get (::java::lang::Object *);
  static ::java::lang::Object *get (::java::lang::Object *, ::java::util::Locale *);
  static jboolean getBoolean (::java::lang::Object *);
  static jboolean getBoolean (::java::lang::Object *, ::java::util::Locale *);
  static ::javax::swing::border::Border *getBorder (::java::lang::Object *);
  static ::javax::swing::border::Border *getBorder (::java::lang::Object *, ::java::util::Locale *);
  static ::java::awt::Color *getColor (::java::lang::Object *);
  static ::java::awt::Color *getColor (::java::lang::Object *, ::java::util::Locale *);
  static ::java::lang::String *getCrossPlatformLookAndFeelClassName ();
  static ::javax::swing::UIDefaults *getDefaults ();
  static ::java::awt::Dimension *getDimension (::java::lang::Object *);
  static ::java::awt::Dimension *getDimension (::java::lang::Object *, ::java::util::Locale *);
  static ::java::awt::Font *getFont (::java::lang::Object *);
  static ::java::awt::Font *getFont (::java::lang::Object *, ::java::util::Locale *);
  static ::javax::swing::Icon *getIcon (::java::lang::Object *);
  static ::javax::swing::Icon *getIcon (::java::lang::Object *, ::java::util::Locale *);
  static ::java::awt::Insets *getInsets (::java::lang::Object *);
  static ::java::awt::Insets *getInsets (::java::lang::Object *, ::java::util::Locale *);
  static JArray< ::javax::swing::UIManager$LookAndFeelInfo *> *getInstalledLookAndFeels ();
  static jint getInt (::java::lang::Object *);
  static jint getInt (::java::lang::Object *, ::java::util::Locale *);
  static ::javax::swing::LookAndFeel *getLookAndFeel ();
  static ::javax::swing::UIDefaults *getLookAndFeelDefaults ();
  static ::java::lang::String *getString (::java::lang::Object *);
  static ::java::lang::String *getString (::java::lang::Object *, ::java::util::Locale *);
  static ::java::lang::String *getSystemLookAndFeelClassName ();
  static ::javax::swing::plaf::ComponentUI *getUI (::javax::swing::JComponent *);
  static void installLookAndFeel (::java::lang::String *, ::java::lang::String *);
  static void installLookAndFeel (::javax::swing::UIManager$LookAndFeelInfo *);
  static ::java::lang::Object *put (::java::lang::Object *, ::java::lang::Object *);
  static void setInstalledLookAndFeels (JArray< ::javax::swing::UIManager$LookAndFeelInfo *> *);
  static void setLookAndFeel (::javax::swing::LookAndFeel *);
  static void setLookAndFeel (::java::lang::String *);
private:
  static const jlong serialVersionUID = -5547433830339189365LL;
public: // actually package-private
  static JArray< ::javax::swing::UIManager$LookAndFeelInfo *> *installed;
  static JArray< ::javax::swing::LookAndFeel *> *auxLookAndFeels;
  static ::javax::swing::LookAndFeel *currentLookAndFeel;
  static ::javax::swing::UIManager$MultiplexUIDefaults *currentUIDefaults;
  static ::javax::swing::UIDefaults *lookAndFeelDefaults;
  static ::java::beans::PropertyChangeSupport *listeners;

  friend class javax_swing_UIManager$MultiplexUIDefaults;
  friend class javax_swing_UIManager$LookAndFeelInfo;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_UIManager__ */
