// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_spec_UMac32ParameterSpec__
#define __gnu_javax_crypto_jce_spec_UMac32ParameterSpec__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace spec
          {
            class UMac32ParameterSpec;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::spec::UMac32ParameterSpec : public ::java::lang::Object
{
public:
  UMac32ParameterSpec (jbyteArray);
  virtual jbyteArray getNonce () { return nonce; }
public:  // actually protected
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  nonce;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_spec_UMac32ParameterSpec__ */
