// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_FloatControl__
#define __javax_sound_sampled_FloatControl__

#pragma interface

#include <javax/sound/sampled/Control.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class FloatControl;
        class FloatControl$Type;
      }
    }
  }
}

class javax::sound::sampled::FloatControl : public ::javax::sound::sampled::Control
{
public:  // actually protected
  FloatControl (::javax::sound::sampled::FloatControl$Type *, jfloat, jfloat, jfloat, jint, jfloat, ::java::lang::String *);
  FloatControl (::javax::sound::sampled::FloatControl$Type *, jfloat, jfloat, jfloat, jint, jfloat, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
public:
  virtual jfloat getMaximum () { return maximum; }
  virtual ::java::lang::String *getMaxLabel () { return maxLabel; }
  virtual ::java::lang::String *getMidLabel () { return midLabel; }
  virtual jfloat getMinimum () { return minimum; }
  virtual ::java::lang::String *getMinLabel () { return minLabel; }
  virtual jfloat getPrecision () { return precision; }
  virtual ::java::lang::String *getUnits () { return units; }
  virtual jint getUpdatePeriod () { return updatePeriod; }
  virtual jfloat getValue () { return value; }
  virtual void setValue (jfloat);
  virtual void shift (jfloat, jfloat, jint);
  virtual ::java::lang::String *toString ();
private:
  jfloat __attribute__((aligned(__alignof__( ::javax::sound::sampled::Control ))))  minimum;
  jfloat maximum;
  jfloat precision;
  jint updatePeriod;
  jfloat value;
  ::java::lang::String *units;
  ::java::lang::String *minLabel;
  ::java::lang::String *maxLabel;
  ::java::lang::String *midLabel;

  friend class javax_sound_sampled_FloatControl$Type;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_sampled_FloatControl__ */
