// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_InputStreamReader__
#define __java_io_InputStreamReader__

#pragma interface

#include <java/io/Reader.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace charset
      {
        class CharsetDecoder;
        class Charset;
      }
    }
  }
  namespace gnu
  {
    namespace gcj
    {
      namespace convert
      {
        class BytesToUnicode;
      }
    }
  }
}

class java::io::InputStreamReader : public ::java::io::Reader
{
public:
  InputStreamReader (::java::io::InputStream *);
  InputStreamReader (::java::io::InputStream *, ::java::lang::String *);
  InputStreamReader (::java::io::InputStream *, ::java::nio::charset::Charset *);
  InputStreamReader (::java::io::InputStream *, ::java::nio::charset::CharsetDecoder *);
private:
  InputStreamReader (::java::io::InputStream *, ::gnu::gcj::convert::BytesToUnicode *);
public:
  virtual void close ();
  virtual ::java::lang::String *getEncoding ();
  virtual jboolean ready ();
  virtual jint read (jcharArray, jint, jint);
  virtual jint read ();
private:
  jint refill (jcharArray, jint, jint);
public: // actually package-private
  ::java::io::BufferedInputStream * __attribute__((aligned(__alignof__( ::java::io::Reader )))) in;
  jcharArray work;
  jint wpos;
  jint wcount;
  ::gnu::gcj::convert::BytesToUnicode *converter;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_InputStreamReader__ */
