// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_ImageIcon__
#define __javax_swing_ImageIcon__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class ImageIcon;
    }
    namespace accessibility
    {
      class AccessibleContext;
    }
  }
  namespace java
  {
    namespace net
    {
      class URL;
    }
    namespace awt
    {
      class Graphics;
      namespace image
      {
        class ImageObserver;
      }
      class Image;
      class MediaTracker;
      class Component;
    }
  }
}

class javax::swing::ImageIcon : public ::java::lang::Object
{
public:
  ImageIcon ();
  ImageIcon (::java::lang::String *);
  ImageIcon (::java::lang::String *, ::java::lang::String *);
  ImageIcon (jbyteArray);
  ImageIcon (jbyteArray, ::java::lang::String *);
  ImageIcon (::java::net::URL *);
  ImageIcon (::java::net::URL *, ::java::lang::String *);
  ImageIcon (::java::awt::Image *);
  ImageIcon (::java::awt::Image *, ::java::lang::String *);
  virtual ::java::awt::image::ImageObserver *getImageObserver () { return observer; }
  virtual void setImageObserver (::java::awt::image::ImageObserver *);
  virtual ::java::awt::Image *getImage () { return image; }
  virtual void setImage (::java::awt::Image *);
  virtual ::java::lang::String *getDescription () { return description; }
  virtual void setDescription (::java::lang::String *);
  virtual jint getIconHeight ();
  virtual jint getIconWidth ();
  virtual void paintIcon (::java::awt::Component *, ::java::awt::Graphics *, jint, jint);
public:  // actually protected
  virtual void loadImage (::java::awt::Image *);
public:
  virtual jint getImageLoadStatus () { return loadStatus; }
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = 532615968316031794LL;
public:  // actually protected
  static ::java::awt::Component *component;
  static ::java::awt::MediaTracker *tracker;
private:
  static jint id;
public: // actually package-private
  ::java::awt::Image * __attribute__((aligned(__alignof__( ::java::lang::Object )))) image;
  ::java::lang::String *description;
  ::java::awt::image::ImageObserver *observer;
private:
  jint loadStatus;
  ::javax::accessibility::AccessibleContext *accessibleContext;

  friend class javax_swing_ImageIcon$1;
  friend class javax_swing_ImageIcon$AccessibleImageIcon;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_ImageIcon__ */
