// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_standard_NumberOfInterveningJobs__
#define __javax_print_attribute_standard_NumberOfInterveningJobs__

#pragma interface

#include <javax/print/attribute/IntegerSyntax.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        namespace standard
        {
          class NumberOfInterveningJobs;
        }
      }
    }
  }
}

class javax::print::attribute::standard::NumberOfInterveningJobs : public ::javax::print::attribute::IntegerSyntax
{
public:
  NumberOfInterveningJobs (jint);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::Class *getCategory ();
  virtual ::java::lang::String *getName ();
private:
  static const jlong serialVersionUID = 2568141124844982746LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_standard_NumberOfInterveningJobs__ */
