// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_charset_ISO_8859_4__
#define __gnu_java_nio_charset_ISO_8859_4__

#pragma interface

#include <gnu/java/nio/charset/ByteCharset.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        namespace charset
        {
          class ISO_8859_4;
        }
      }
    }
  }
}

class gnu::java::nio::charset::ISO_8859_4 : public ::gnu::java::nio::charset::ByteCharset
{
public:
  ISO_8859_4 ();
private:
  static jcharArray lookup;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_charset_ISO_8859_4__ */
