// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_srp6_SRP6KeyAgreement__
#define __gnu_javax_crypto_key_srp6_SRP6KeyAgreement__

#pragma interface

#include <gnu/javax/crypto/key/BaseKeyAgreementParty.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          namespace srp6
          {
            class SRP6KeyAgreement;
          }
        }
        namespace sasl
        {
          namespace srp
          {
            class SRP;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::key::srp6::SRP6KeyAgreement : public ::gnu::javax::crypto::key::BaseKeyAgreementParty
{
public:  // actually protected
  SRP6KeyAgreement ();
  virtual jbyteArray engineSharedSecret ();
  virtual void engineReset ();
  virtual ::java::math::BigInteger *uValue (::java::math::BigInteger *, ::java::math::BigInteger *);
public:
  static ::java::lang::String *SOURCE_OF_RANDOMNESS;
  static ::java::lang::String *SHARED_MODULUS;
  static ::java::lang::String *GENERATOR;
  static ::java::lang::String *HASH_FUNCTION;
  static ::java::lang::String *USER_IDENTITY;
  static ::java::lang::String *USER_PASSWORD;
  static ::java::lang::String *HOST_PASSWORD_DB;
public:  // actually protected
  static ::java::math::BigInteger *THREE;
  ::gnu::javax::crypto::sasl::srp::SRP * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::key::BaseKeyAgreementParty )))) srp;
  ::java::math::BigInteger *N;
  ::java::math::BigInteger *g;
  ::java::math::BigInteger *K;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_key_srp6_SRP6KeyAgreement__ */
