// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_util_DerUtil__
#define __gnu_java_security_util_DerUtil__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class DerUtil;
        }
        namespace der
        {
          class DERValue;
        }
      }
    }
  }
}

class gnu::java::security::util::DerUtil : public ::java::lang::Object
{
public:
  static void checkIsConstructed (::gnu::java::security::der::DERValue *, ::java::lang::String *);
  static void checkIsBigInteger (::gnu::java::security::der::DERValue *, ::java::lang::String *);
  DerUtil ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_util_DerUtil__ */
