// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JTextArea__
#define __javax_swing_JTextArea__

#pragma interface

#include <javax/swing/text/JTextComponent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Dimension;
      class Rectangle;
    }
  }
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JTextArea;
      namespace text
      {
        class Document;
      }
    }
  }
}

class javax::swing::JTextArea : public ::javax::swing::text::JTextComponent
{
public:
  JTextArea ();
  JTextArea (::java::lang::String *);
  JTextArea (jint, jint);
  JTextArea (::java::lang::String *, jint, jint);
  JTextArea (::javax::swing::text::Document *);
  JTextArea (::javax::swing::text::Document *, ::java::lang::String *, jint, jint);
  virtual void append (::java::lang::String *);
public:  // actually protected
  virtual ::javax::swing::text::Document *createDefaultModel ();
public:
  virtual jboolean getScrollableTracksViewportWidth ();
  virtual jint getScrollableUnitIncrement (::java::awt::Rectangle *, jint, jint);
  virtual ::java::awt::Dimension *getPreferredScrollableViewportSize ();
  virtual ::java::lang::String *getUIClassID ();
  virtual jint getColumns () { return columns; }
  virtual void setColumns (jint);
  virtual jint getRows () { return rows; }
  virtual void setRows (jint);
  virtual jboolean getLineWrap () { return lineWrap; }
  virtual void setLineWrap (jboolean);
  virtual jboolean getWrapStyleWord () { return wrapStyleWord; }
  virtual void setWrapStyleWord (jboolean);
  virtual jint getTabSize () { return tabSize; }
  virtual void setTabSize (jint);
public:  // actually protected
  virtual jint getColumnWidth ();
public:
  virtual jint getLineCount ();
  virtual jint getLineStartOffset (jint);
  virtual jint getLineEndOffset (jint);
  virtual jint getLineOfOffset (jint);
public:  // actually protected
  virtual jint getRowHeight ();
public:
  virtual void insert (::java::lang::String *, jint);
  virtual void replaceRange (::java::lang::String *, jint, jint);
  virtual ::java::awt::Dimension *getPreferredSize ();
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = -6141680179310439825LL;
  jint __attribute__((aligned(__alignof__( ::javax::swing::text::JTextComponent ))))  rows;
  jint columns;
  jboolean lineWrap;
  jint tabSize;
  jboolean wrapStyleWord;

  friend class javax_swing_JTextArea$AccessibleJTextArea;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JTextArea__ */
