// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_event_PrintEvent__
#define __javax_print_event_PrintEvent__

#pragma interface

#include <java/util/EventObject.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace event
      {
        class PrintEvent;
      }
    }
  }
}

class javax::print::event::PrintEvent : public ::java::util::EventObject
{
public:
  PrintEvent (::java::lang::Object *);
  virtual ::java::lang::String *toString ();

  static ::java::lang::Class class$;
};

#endif /* __javax_print_event_PrintEvent__ */
