// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_plain_PlainRegistry__
#define __gnu_javax_crypto_sasl_plain_PlainRegistry__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace plain
          {
            class PlainRegistry;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::plain::PlainRegistry : public ::java::lang::Object
{
public:
  static ::java::lang::String *PASSWORD_FILE;
  static ::java::lang::String *DEFAULT_PASSWORD_FILE;
  static ::java::lang::String *UID_FIELD;
  static ::java::lang::String *GID_FIELD;
  static ::java::lang::String *GECOS_FIELD;
  static ::java::lang::String *DIR_FIELD;
  static ::java::lang::String *SHELL_FIELD;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_javax_crypto_sasl_plain_PlainRegistry__ */
