// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_parser_TagElement__
#define __javax_swing_text_html_parser_TagElement__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class HTML$Tag;
          namespace parser
          {
            class TagElement;
            class Element;
          }
        }
      }
    }
  }
}

class javax::swing::text::html::parser::TagElement : public ::java::lang::Object
{
public:
  TagElement (::javax::swing::text::html::parser::Element *);
  TagElement (::javax::swing::text::html::parser::Element *, jboolean);
  virtual ::javax::swing::text::html::parser::Element *getElement () { return element; }
  virtual ::javax::swing::text::html::HTML$Tag *getHTMLTag () { return tag; }
  virtual jboolean isPreformatted ();
  virtual jboolean breaksFlow ();
  virtual jboolean fictional () { return fictional__; }
  virtual ::java::lang::String *toString ();
private:
  ::javax::swing::text::html::parser::Element * __attribute__((aligned(__alignof__( ::java::lang::Object )))) element;
  ::javax::swing::text::html::HTML$Tag *tag;
  jboolean fictional__;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_parser_TagElement__ */
