// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicArrowButton__
#define __javax_swing_plaf_basic_BasicArrowButton__

#pragma interface

#include <javax/swing/JButton.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class BasicArrowButton;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Dimension;
      class Graphics;
      class Color;
    }
  }
}

class javax::swing::plaf::basic::BasicArrowButton : public ::javax::swing::JButton
{
public:
  BasicArrowButton (jint);
  BasicArrowButton (jint, ::java::awt::Color *, ::java::awt::Color *, ::java::awt::Color *, ::java::awt::Color *);
  virtual jboolean isFocusTraversable ();
  virtual jint getDirection () { return direction; }
  virtual void setDirection (jint);
  virtual void paint (::java::awt::Graphics *);
  virtual ::java::awt::Dimension *getPreferredSize ();
  virtual ::java::awt::Dimension *getMinimumSize ();
  virtual ::java::awt::Dimension *getMaximumSize ();
  virtual void paintTriangle (::java::awt::Graphics *, jint, jint, jint, jint, jboolean);
private:
  void paintTriangleNorth (::java::awt::Graphics *, jint, jint, jint, jboolean);
  void paintTriangleSouth (::java::awt::Graphics *, jint, jint, jint, jboolean);
  void paintTriangleEast (::java::awt::Graphics *, jint, jint, jint, jboolean);
  void paintTriangleWest (::java::awt::Graphics *, jint, jint, jint, jboolean);
public:  // actually protected
  jint __attribute__((aligned(__alignof__( ::javax::swing::JButton ))))  direction;
public: // actually package-private
  ::java::awt::Color *shadow;
  ::java::awt::Color *darkShadow;
  ::java::awt::Color *highlight;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicArrowButton__ */
