// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_logging_LoggingPermission__
#define __java_util_logging_LoggingPermission__

#pragma interface

#include <java/security/BasicPermission.h>

class java::util::logging::LoggingPermission : public ::java::security::BasicPermission
{
public:
  LoggingPermission (::java::lang::String *, ::java::lang::String *);
private:
  static const jlong serialVersionUID = 63564341580231582LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_logging_LoggingPermission__ */
