// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppException__
#define __gnu_javax_print_ipp_IppException__

#pragma interface

#include <javax/print/PrintException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          class IppException;
        }
      }
    }
  }
}

class gnu::javax::print::ipp::IppException : public ::javax::print::PrintException
{
public:
  IppException ();
  IppException (::java::lang::String *);
  IppException (::java::lang::Exception *);
  IppException (::java::lang::String *, ::java::lang::Exception *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_IppException__ */
