// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_login_LoginContext__
#define __javax_security_auth_login_LoginContext__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace spi
        {
          class LoginModule;
        }
        namespace login
        {
          class LoginContext;
          class Configuration;
          class AppConfigurationEntry;
        }
        class Subject;
        namespace callback
        {
          class CallbackHandler;
        }
      }
    }
  }
}

class javax::security::auth::login::LoginContext : public ::java::lang::Object
{
public:
  LoginContext (::java::lang::String *);
  LoginContext (::java::lang::String *, ::javax::security::auth::callback::CallbackHandler *);
  LoginContext (::java::lang::String *, ::javax::security::auth::Subject *);
  LoginContext (::java::lang::String *, ::javax::security::auth::Subject *, ::javax::security::auth::callback::CallbackHandler *);
  LoginContext (::java::lang::String *, ::javax::security::auth::Subject *, ::javax::security::auth::callback::CallbackHandler *, ::javax::security::auth::login::Configuration *);
  virtual ::javax::security::auth::Subject *getSubject () { return subject; }
  virtual void login ();
  virtual void logout ();
private:
  static ::javax::security::auth::callback::CallbackHandler *defaultHandler ();
  ::javax::security::auth::spi::LoginModule *lookupModule (::javax::security::auth::login::AppConfigurationEntry *, ::javax::security::auth::Subject *, ::java::util::Map *);
  static ::java::lang::String *OTHER;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  ::javax::security::auth::callback::CallbackHandler *cbHandler;
  ::javax::security::auth::Subject *subject;
  JArray< ::javax::security::auth::login::AppConfigurationEntry *> *entries;
  JArray< ::javax::security::auth::spi::LoginModule *> *modules;
  ::java::util::Map *sharedState;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_login_LoginContext__ */
