// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_StringWriter__
#define __java_io_StringWriter__

#pragma interface

#include <java/io/Writer.h>
#include <gcj/array.h>

class java::io::StringWriter : public ::java::io::Writer
{
public:
  virtual void close () { }
  virtual void flush () { }
  virtual ::java::lang::StringBuffer *getBuffer () { return buffer; }
  StringWriter ();
  StringWriter (jint);
  virtual ::java::lang::String *toString ();
  virtual void write (jint);
  virtual void write (jcharArray, jint, jint);
  virtual void write (::java::lang::String *);
  virtual void write (::java::lang::String *, jint, jint);
private:
  static const jint DEFAULT_BUFFER_SIZE = 16L;
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::io::Writer )))) buffer;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_StringWriter__ */
