// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_DataLine__
#define __javax_sound_sampled_DataLine__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class DataLine;
        class AudioFormat;
      }
    }
  }
}

class javax::sound::sampled::DataLine : public ::java::lang::Object
{
public:
  virtual jint available () = 0;
  virtual void drain () = 0;
  virtual void flush () = 0;
  virtual jint getBufferSize () = 0;
  virtual ::javax::sound::sampled::AudioFormat *getFormat () = 0;
  virtual jint getFramePosition () = 0;
  virtual jfloat getLevel () = 0;
  virtual jlong getLongFramePosition () = 0;
  virtual jlong getMicrosecondPosition () = 0;
  virtual jboolean isActive () = 0;
  virtual jboolean isRunning () = 0;
  virtual void start () = 0;
  virtual void stop () = 0;

  friend class javax_sound_sampled_DataLine$Info;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sound_sampled_DataLine__ */
