// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_spec_DHParameterSpec__
#define __javax_crypto_spec_DHParameterSpec__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      namespace spec
      {
        class DHParameterSpec;
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class javax::crypto::spec::DHParameterSpec : public ::java::lang::Object
{
public:
  DHParameterSpec (::java::math::BigInteger *, ::java::math::BigInteger *);
  DHParameterSpec (::java::math::BigInteger *, ::java::math::BigInteger *, jint);
  virtual ::java::math::BigInteger *getG () { return g; }
  virtual jint getL () { return l; }
  virtual ::java::math::BigInteger *getP () { return p; }
private:
  ::java::math::BigInteger * __attribute__((aligned(__alignof__( ::java::lang::Object )))) g;
  ::java::math::BigInteger *p;
  jint l;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_spec_DHParameterSpec__ */
