// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalTheme__
#define __javax_swing_plaf_metal_MetalTheme__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class UIDefaults;
      namespace plaf
      {
        namespace metal
        {
          class MetalTheme;
        }
        class FontUIResource;
        class ColorUIResource;
      }
    }
  }
}

class javax::swing::plaf::metal::MetalTheme : public ::java::lang::Object
{
public:
  MetalTheme ();
  virtual ::java::lang::String *getName () = 0;
  virtual void addCustomEntriesToTable (::javax::swing::UIDefaults *) { }
  virtual ::javax::swing::plaf::ColorUIResource *getAcceleratorForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getAcceleratorSelectedForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getControl ();
  virtual ::javax::swing::plaf::ColorUIResource *getControlDarkShadow ();
  virtual ::javax::swing::plaf::ColorUIResource *getControlDisabled ();
  virtual ::javax::swing::plaf::ColorUIResource *getControlHighlight ();
  virtual ::javax::swing::plaf::ColorUIResource *getControlInfo ();
  virtual ::javax::swing::plaf::ColorUIResource *getControlShadow ();
  virtual ::javax::swing::plaf::ColorUIResource *getControlTextColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getDesktopColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getFocusColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getHighlightedTextColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getInactiveControlTextColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getInactiveSystemTextColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getMenuBackground ();
  virtual ::javax::swing::plaf::ColorUIResource *getMenuDisabledForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getMenuForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getMenuSelectedBackground ();
  virtual ::javax::swing::plaf::ColorUIResource *getMenuSelectedForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getPrimaryControl ();
  virtual ::javax::swing::plaf::ColorUIResource *getPrimaryControlDarkShadow ();
  virtual ::javax::swing::plaf::ColorUIResource *getPrimaryControlHighlight ();
  virtual ::javax::swing::plaf::ColorUIResource *getPrimaryControlInfo ();
  virtual ::javax::swing::plaf::ColorUIResource *getPrimaryControlShadow ();
  virtual ::javax::swing::plaf::ColorUIResource *getSeparatorBackground ();
  virtual ::javax::swing::plaf::ColorUIResource *getSeparatorForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getSystemTextColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getTextHighlightColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getUserTextColor ();
  virtual ::javax::swing::plaf::ColorUIResource *getWindowBackground ();
  virtual ::javax::swing::plaf::ColorUIResource *getWindowTitleBackground ();
  virtual ::javax::swing::plaf::ColorUIResource *getWindowTitleForeground ();
  virtual ::javax::swing::plaf::ColorUIResource *getWindowTitleInactiveBackground ();
  virtual ::javax::swing::plaf::ColorUIResource *getWindowTitleInactiveForeground ();
public:  // actually protected
  virtual ::javax::swing::plaf::ColorUIResource *getBlack () { return BLACK; }
  virtual ::javax::swing::plaf::ColorUIResource *getWhite () { return WHITE; }
  virtual ::javax::swing::plaf::ColorUIResource *getPrimary1 () = 0;
  virtual ::javax::swing::plaf::ColorUIResource *getPrimary2 () = 0;
  virtual ::javax::swing::plaf::ColorUIResource *getPrimary3 () = 0;
  virtual ::javax::swing::plaf::ColorUIResource *getSecondary1 () = 0;
  virtual ::javax::swing::plaf::ColorUIResource *getSecondary2 () = 0;
  virtual ::javax::swing::plaf::ColorUIResource *getSecondary3 () = 0;
public:
  virtual ::javax::swing::plaf::FontUIResource *getControlTextFont () = 0;
  virtual ::javax::swing::plaf::FontUIResource *getMenuTextFont () = 0;
  virtual ::javax::swing::plaf::FontUIResource *getSubTextFont () = 0;
  virtual ::javax::swing::plaf::FontUIResource *getSystemTextFont () = 0;
  virtual ::javax::swing::plaf::FontUIResource *getUserTextFont () = 0;
  virtual ::javax::swing::plaf::FontUIResource *getWindowTitleFont () = 0;
private:
  ::javax::swing::plaf::ColorUIResource * __attribute__((aligned(__alignof__( ::java::lang::Object )))) BLACK;
  ::javax::swing::plaf::ColorUIResource *WHITE;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalTheme__ */
