// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_IntrospectionException__
#define __javax_management_IntrospectionException__

#pragma interface

#include <javax/management/OperationsException.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      class IntrospectionException;
    }
  }
}

class javax::management::IntrospectionException : public ::javax::management::OperationsException
{
public:
  IntrospectionException ();
  IntrospectionException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 1054516935875481725LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_IntrospectionException__ */
