// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_reflect_TypeVariable__
#define __java_lang_reflect_TypeVariable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::lang::reflect::TypeVariable : public ::java::lang::Object
{
public:
  virtual JArray< ::java::lang::reflect::Type *> *getBounds () = 0;
  virtual ::java::lang::reflect::GenericDeclaration *getGenericDeclaration () = 0;
  virtual ::java::lang::String *getName () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_lang_reflect_TypeVariable__ */
