// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_util_Util__
#define __gnu_java_security_util_Util__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class Util;
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::java::security::util::Util : public ::java::lang::Object
{
private:
  Util ();
public:
  static ::java::lang::String *toString (jbyteArray);
  static ::java::lang::String *toString (jbyteArray, jint, jint);
  static ::java::lang::String *toReversedString (jbyteArray);
  static ::java::lang::String *toReversedString (jbyteArray, jint, jint);
  static jbyteArray toBytesFromString (::java::lang::String *);
  static jbyteArray toReversedBytesFromString (::java::lang::String *);
  static jint fromDigit (jchar);
  static ::java::lang::String *toString (jint);
  static ::java::lang::String *toString (jintArray);
  static ::java::lang::String *toString (jlong);
  static ::java::lang::String *toUnicodeString (jbyteArray);
  static ::java::lang::String *toUnicodeString (jbyteArray, jint, jint);
  static ::java::lang::String *toUnicodeString (jintArray);
  static jbyteArray toBytesFromUnicode (::java::lang::String *);
  static ::java::lang::String *dumpString (jbyteArray, jint, jint, ::java::lang::String *);
  static ::java::lang::String *dumpString (jbyteArray);
  static ::java::lang::String *dumpString (jbyteArray, ::java::lang::String *);
  static ::java::lang::String *dumpString (jbyteArray, jint, jint);
  static ::java::lang::String *byteToString (jint);
  static ::java::lang::String *toBase64 (jbyteArray);
  static jbyteArray fromBase64 (::java::lang::String *);
  static jbyteArray trim (::java::math::BigInteger *);
  static ::java::lang::String *dump (::java::math::BigInteger *);
private:
  static jcharArray HEX_DIGITS;
  static ::java::lang::String *BASE64_CHARS;
  static jcharArray BASE64_CHARSET;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_util_Util__ */
