// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ref_PhantomReference__
#define __java_lang_ref_PhantomReference__

#pragma interface

#include <java/lang/ref/Reference.h>

class java::lang::ref::PhantomReference : public ::java::lang::ref::Reference
{
public:
  PhantomReference (::java::lang::Object *, ::java::lang::ref::ReferenceQueue *);
  virtual ::java::lang::Object *get () { return 0; }

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ref_PhantomReference__ */
