// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_PlainSocketImpl$SocketOutputStream__
#define __gnu_java_net_PlainSocketImpl$SocketOutputStream__

#pragma interface

#include <java/io/OutputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        class PlainSocketImpl$SocketOutputStream;
        class PlainSocketImpl;
      }
    }
  }
}

class gnu::java::net::PlainSocketImpl$SocketOutputStream : public ::java::io::OutputStream
{
public:
  virtual void close ();
  virtual void write (jint);
  virtual void write (jbyteArray, jint, jint);
public: // actually package-private
  PlainSocketImpl$SocketOutputStream (::gnu::java::net::PlainSocketImpl *);
private:
  ::gnu::java::net::PlainSocketImpl * __attribute__((aligned(__alignof__( ::java::io::OutputStream )))) this$0;

  friend class gnu_java_net_PlainSocketImpl$SocketOutputStream;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_PlainSocketImpl$SocketOutputStream__ */
