// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_directory_SearchControls__
#define __javax_naming_directory_SearchControls__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace directory
      {
        class SearchControls;
      }
    }
  }
}

class javax::naming::directory::SearchControls : public ::java::lang::Object
{
public:
  SearchControls ();
  SearchControls (jint, jlong, jint, JArray< ::java::lang::String *> *, jboolean, jboolean);
  virtual jint getSearchScope () { return searchScope; }
  virtual jint getTimeLimit () { return timeLimit; }
  virtual jboolean getDerefLinkFlag () { return derefLink; }
  virtual jboolean getReturningObjFlag () { return returnObj; }
  virtual jlong getCountLimit () { return countLimit; }
  virtual JArray< ::java::lang::String *> *getReturningAttributes () { return attributesToReturn; }
  virtual void setSearchScope (jint);
  virtual void setTimeLimit (jint);
  virtual void setDerefLinkFlag (jboolean);
  virtual void setReturningObjFlag (jboolean);
  virtual void setCountLimit (jlong);
  virtual void setReturningAttributes (JArray< ::java::lang::String *> *);
private:
  static const jlong serialVersionUID = -2480540967773454797LL;
public:
  static const jint OBJECT_SCOPE = 0L;
  static const jint ONELEVEL_SCOPE = 1L;
  static const jint SUBTREE_SCOPE = 2L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  searchScope;
  jint timeLimit;
  jboolean derefLink;
  jboolean returnObj;
  jlong countLimit;
  JArray< ::java::lang::String *> *attributesToReturn;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_directory_SearchControls__ */
