// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_InterruptedException__
#define __java_lang_InterruptedException__

#pragma interface

#include <java/lang/Exception.h>

class java::lang::InterruptedException : public ::java::lang::Exception
{
public:
  InterruptedException ();
  InterruptedException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 6700697376100628473LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_InterruptedException__ */
