// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_srp6_SRPKeyPairGenerator__
#define __gnu_javax_crypto_key_srp6_SRPKeyPairGenerator__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          namespace srp6
          {
            class SRPKeyPairGenerator;
          }
        }
      }
    }
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class PRNG;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      class KeyPair;
      class SecureRandom;
    }
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::key::srp6::SRPKeyPairGenerator : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *name ();
  virtual void setup (::java::util::Map *);
  virtual ::java::security::KeyPair *generate ();
private:
  JArray< ::java::math::BigInteger *> *generateParameters ();
  ::java::security::KeyPair *hostKeyPair ();
  ::java::security::KeyPair *userKeyPair ();
  void nextRandomBytes (jbyteArray);
  ::gnu::java::security::util::PRNG *getDefaultPRNG ();
public:
  SRPKeyPairGenerator ();
private:
  static ::java::util::logging::Logger *log;
  static ::java::math::BigInteger *ZERO;
  static ::java::math::BigInteger *ONE;
  static ::java::math::BigInteger *TWO;
  static ::java::math::BigInteger *THREE;
public:
  static ::java::lang::String *MODULUS_LENGTH;
  static ::java::lang::String *USE_DEFAULTS;
  static ::java::lang::String *SHARED_MODULUS;
  static ::java::lang::String *GENERATOR;
  static ::java::lang::String *USER_VERIFIER;
  static ::java::lang::String *SOURCE_OF_RANDOMNESS;
private:
  static const jint DEFAULT_MODULUS_LENGTH = 1024L;
  ::java::security::SecureRandom * __attribute__((aligned(__alignof__( ::java::lang::Object )))) rnd;
  jint l;
  ::java::math::BigInteger *N;
  ::java::math::BigInteger *g;
  ::java::math::BigInteger *v;
  ::gnu::java::security::util::PRNG *prng;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_key_srp6_SRPKeyPairGenerator__ */
