// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_IllegalAccessError__
#define __java_lang_IllegalAccessError__

#pragma interface

#include <java/lang/IncompatibleClassChangeError.h>

class java::lang::IllegalAccessError : public ::java::lang::IncompatibleClassChangeError
{
public:
  IllegalAccessError ();
  IllegalAccessError (::java::lang::String *);
private:
  static const jlong serialVersionUID = -8988904074992417891LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_IllegalAccessError__ */
