// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_URLParseError__
#define __gnu_java_net_URLParseError__

#pragma interface

#include <java/lang/Error.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        class URLParseError;
      }
    }
  }
}

class gnu::java::net::URLParseError : public ::java::lang::Error
{
public:
  URLParseError (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_URLParseError__ */
