// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_color_RgbProfileConverter__
#define __gnu_java_awt_color_RgbProfileConverter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class ICC_ProfileRGB;
      }
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace color
        {
          class RgbProfileConverter;
          class ColorLookUpTable;
          class ToneReproductionCurve;
        }
      }
    }
  }
}

class gnu::java::awt::color::RgbProfileConverter : public ::java::lang::Object
{
public:
  RgbProfileConverter (::java::awt::color::ICC_ProfileRGB *);
  virtual jfloatArray toCIEXYZ (jfloatArray);
  virtual jfloatArray toRGB (jfloatArray);
  virtual jfloatArray fromCIEXYZ (jfloatArray);
  virtual jfloatArray fromRGB (jfloatArray);
private:
  JArray<jfloatArray> * invertMatrix (JArray<jfloatArray> *);
  JArray<jfloatArray> * __attribute__((aligned(__alignof__( ::java::lang::Object ))))  matrix;
  JArray<jfloatArray> * inv_matrix;
  ::gnu::java::awt::color::ToneReproductionCurve *rTRC;
  ::gnu::java::awt::color::ToneReproductionCurve *gTRC;
  ::gnu::java::awt::color::ToneReproductionCurve *bTRC;
  ::gnu::java::awt::color::ColorLookUpTable *toPCS;
  ::gnu::java::awt::color::ColorLookUpTable *fromPCS;
  static jfloatArray D50;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_color_RgbProfileConverter__ */
