// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_RMISecurityException__
#define __java_rmi_RMISecurityException__

#pragma interface

#include <java/lang/SecurityException.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      class RMISecurityException;
    }
  }
}

class java::rmi::RMISecurityException : public ::java::lang::SecurityException
{
public:
  RMISecurityException (::java::lang::String *);
  RMISecurityException (::java::lang::String *, ::java::lang::String *);
private:
  static const jlong serialVersionUID = -8433406075740433514LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_RMISecurityException__ */
