// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_IllegalBlockingModeException__
#define __java_nio_channels_IllegalBlockingModeException__

#pragma interface

#include <java/lang/IllegalStateException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class IllegalBlockingModeException;
      }
    }
  }
}

class java::nio::channels::IllegalBlockingModeException : public ::java::lang::IllegalStateException
{
public:
  IllegalBlockingModeException ();
private:
  static const jlong serialVersionUID = -3335774961855590474LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_channels_IllegalBlockingModeException__ */
