// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_NIOConstants__
#define __gnu_java_nio_NIOConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        class NIOConstants;
      }
    }
  }
}

class gnu::java::nio::NIOConstants : public ::java::lang::Object
{
public:
  NIOConstants ();
  static const jint DEFAULT_TIMEOUT = 50L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_NIOConstants__ */
