// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_PageAttributes__
#define __java_awt_PageAttributes__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class PageAttributes;
      class PageAttributes$PrintQualityType;
      class PageAttributes$OriginType;
      class PageAttributes$OrientationRequestedType;
      class PageAttributes$MediaType;
      class PageAttributes$ColorType;
    }
  }
}

class java::awt::PageAttributes : public ::java::lang::Object
{
public:
  PageAttributes ();
  PageAttributes (::java::awt::PageAttributes *);
  PageAttributes (::java::awt::PageAttributes$ColorType *, ::java::awt::PageAttributes$MediaType *, ::java::awt::PageAttributes$OrientationRequestedType *, ::java::awt::PageAttributes$OriginType *, ::java::awt::PageAttributes$PrintQualityType *, jintArray);
  virtual ::java::lang::Object *clone ();
  virtual void set (::java::awt::PageAttributes *);
  virtual ::java::awt::PageAttributes$ColorType *getColor () { return color; }
  virtual void setColor (::java::awt::PageAttributes$ColorType *);
  virtual ::java::awt::PageAttributes$MediaType *getMedia () { return media; }
  virtual void setMedia (::java::awt::PageAttributes$MediaType *);
  virtual void setMediaToDefault ();
  virtual ::java::awt::PageAttributes$OrientationRequestedType *getOrientationRequested () { return orientation; }
  virtual void setOrientationRequested (::java::awt::PageAttributes$OrientationRequestedType *);
  virtual void setOrientationRequested (jint);
  virtual void setOrientationRequestedToDefault ();
  virtual ::java::awt::PageAttributes$OriginType *getOrigin () { return origin; }
  virtual void setOrigin (::java::awt::PageAttributes$OriginType *);
  virtual ::java::awt::PageAttributes$PrintQualityType *getPrintQuality () { return quality; }
  virtual void setPrintQuality (::java::awt::PageAttributes$PrintQualityType *);
  virtual void setPrintQuality (jint);
  virtual void setPrintQualityToDefault ();
  virtual jintArray getPrinterResolution ();
  virtual void setPrinterResolution (jintArray);
  virtual void setPrinterResolution (jint);
  virtual void setPrinterResolutionToDefault ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  ::java::awt::PageAttributes$ColorType * __attribute__((aligned(__alignof__( ::java::lang::Object )))) color;
  ::java::awt::PageAttributes$MediaType *media;
  ::java::awt::PageAttributes$OrientationRequestedType *orientation;
  ::java::awt::PageAttributes$OriginType *origin;
  ::java::awt::PageAttributes$PrintQualityType *quality;
  jint resolutionX;
  jint resolutionY;
  jint resolutionScale;

  friend class java_awt_PageAttributes$PrintQualityType;
  friend class java_awt_PageAttributes$OriginType;
  friend class java_awt_PageAttributes$OrientationRequestedType;
  friend class java_awt_PageAttributes$MediaType;
  friend class java_awt_PageAttributes$ColorType;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_PageAttributes__ */
