// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_TabbedPaneUI__
#define __javax_swing_plaf_TabbedPaneUI__

#pragma interface

#include <javax/swing/plaf/ComponentUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class TabbedPaneUI;
      }
      class JTabbedPane;
    }
  }
}

class javax::swing::plaf::TabbedPaneUI : public ::javax::swing::plaf::ComponentUI
{
public:
  TabbedPaneUI ();
  virtual jint tabForCoordinate (::javax::swing::JTabbedPane *, jint, jint) = 0;
  virtual ::java::awt::Rectangle *getTabBounds (::javax::swing::JTabbedPane *, jint) = 0;
  virtual jint getTabRunCount (::javax::swing::JTabbedPane *) = 0;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_TabbedPaneUI__ */
