// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_KeyStroke__
#define __javax_swing_KeyStroke__

#pragma interface

#include <java/awt/AWTKeyStroke.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class KeyEvent;
      }
    }
  }
  namespace javax
  {
    namespace swing
    {
      class KeyStroke;
    }
  }
}

class javax::swing::KeyStroke : public ::java::awt::AWTKeyStroke
{
private:
  KeyStroke ();
  KeyStroke (jchar, jint, jint, jboolean);
public:
  static ::javax::swing::KeyStroke *getKeyStroke (jchar);
  static ::javax::swing::KeyStroke *getKeyStroke (jchar, jboolean);
  static ::javax::swing::KeyStroke *getKeyStroke (::java::lang::Character *, jint);
  static ::javax::swing::KeyStroke *getKeyStroke (jint, jint, jboolean);
  static ::javax::swing::KeyStroke *getKeyStroke (jint, jint);
  static ::javax::swing::KeyStroke *getKeyStroke (::java::lang::String *);
  static ::javax::swing::KeyStroke *getKeyStrokeForEvent (::java::awt::event::KeyEvent *);
private:
  static const jlong serialVersionUID = -9060180771037902530LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_KeyStroke__ */
