// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppStatusCode__
#define __gnu_javax_print_ipp_IppStatusCode__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
          class IppStatusCode;
        }
      }
    }
  }
}

class gnu::javax::print::ipp::IppStatusCode : public ::java::lang::Object
{
private:
  IppStatusCode ();
public:
  static const jint SUCCESSFUL_OK = 0L;
  static const jint SUCCESSFUL_OK_IGNORED_OR_SUBSTITUED_ATTRIBUTES = 1L;
  static const jint SUCCESSFUL_OK_CONFLICTING_ATTRIBUTES = 2L;
  static const jint CLIENT_ERROR_BAD_REQUEST = 1024L;
  static const jint CLIENT_ERROR_FORBIDDEN = 1025L;
  static const jint CLIENT_ERROR_NOT_AUTHENTICATED = 1026L;
  static const jint CLIENT_ERROR_NOT_AUTHORIZED = 1027L;
  static const jint CLIENT_ERROR_NOT_POSSIBLE = 1028L;
  static const jint CLIENT_ERROR_TIMEOUT = 1029L;
  static const jint CLIENT_ERROR_NOT_FOUND = 1030L;
  static const jint CLIENT_ERROR_GONE = 1031L;
  static const jint CLIENT_ERROR_REQUEST_ENTITY_TOO_LONG = 1032L;
  static const jint CLIENT_ERROR_REQUEST_VALUE_TOO_LONG = 1033L;
  static const jint CLIENT_ERROR_DOCUMENT_FORMAT_NOT_SUPPORTED = 1034L;
  static const jint CLIENT_ERROR_ATTRIBUTES_OR_VALUES_NOT_SUPPORTED = 1035L;
  static const jint CLIENT_ERROR_URI_SCHEME_NOT_SUPPORTED = 1036L;
  static const jint CLIENT_ERROR_CHARSET_NOT_SUPPORTED = 1037L;
  static const jint CLIENT_ERROR_CONFLICTING_ATTRIBUTES = 1038L;
  static const jint CLIENT_ERROR_COMPRESSION_NOT_SUPPORTED = 1039L;
  static const jint CLIENT_ERROR_COMPRESSION_ERROR = 1040L;
  static const jint CLIENT_ERROR_DOCUMENT_FORMAT_ERROR = 1041L;
  static const jint CLIENT_ERROR_DOCUMENT_ACCESS_ERROR = 1042L;
  static const jint SERVER_ERROR_INTERNAL_ERROR = 1280L;
  static const jint SERVER_ERROR_OPERATION_NOT_SUPPORTED = 1281L;
  static const jint SERVER_ERROR_SERVICE_UNAVAILABLE = 1282L;
  static const jint SERVER_ERROR_VERSION_NOT_SUPPORTED = 1283L;
  static const jint SERVER_ERROR_DEVICE_ERROR = 1284L;
  static const jint SERVER_ERROR_TEMPORARY_ERROR = 1285L;
  static const jint SERVER_ERROR_NOT_ACCEPTING_JOBS = 1286L;
  static const jint SERVER_ERROR_BUSY = 1287L;
  static const jint SERVER_ERROR_JOB_CANCELED = 1288L;
  static const jint SERVER_ERROR_MULTIPLE_DOCUMENT_JOBS_NOT_SUPPORTED = 1289L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_ipp_IppStatusCode__ */
