// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_sig_DHKeyPairGeneratorSpi__
#define __gnu_javax_crypto_jce_sig_DHKeyPairGeneratorSpi__

#pragma interface

#include <gnu/java/security/jce/sig/KeyPairGeneratorAdapter.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace sig
          {
            class DHKeyPairGeneratorSpi;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class SecureRandom;
    }
  }
}

class gnu::javax::crypto::jce::sig::DHKeyPairGeneratorSpi : public ::gnu::java::security::jce::sig::KeyPairGeneratorAdapter
{
public:
  DHKeyPairGeneratorSpi ();
  virtual void initialize (jint, ::java::security::SecureRandom *);
  virtual void initialize (::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_sig_DHKeyPairGeneratorSpi__ */
