// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_FormattableFlags__
#define __java_util_FormattableFlags__

#pragma interface

#include <java/lang/Object.h>

class java::util::FormattableFlags : public ::java::lang::Object
{
private:
  FormattableFlags ();
public:
  static const jint LEFT_JUSTIFY = 1L;
  static const jint UPPERCASE = 2L;
  static const jint ALTERNATE = 4L;
public: // actually package-private
  static const jint PLUS = 8L;
  static const jint SPACE = 16L;
  static const jint ZERO = 32L;
  static const jint COMMA = 64L;
  static const jint PAREN = 128L;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_FormattableFlags__ */
