// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_management_VMGarbageCollectorMXBeanImpl__
#define __gnu_java_lang_management_VMGarbageCollectorMXBeanImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        namespace management
        {
          class VMGarbageCollectorMXBeanImpl;
        }
      }
    }
  }
}

class gnu::java::lang::management::VMGarbageCollectorMXBeanImpl : public ::java::lang::Object
{
public: // actually package-private
  static jlong getCollectionCount (::java::lang::String *);
  static jlong getCollectionTime (::java::lang::String *);
  VMGarbageCollectorMXBeanImpl ();
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_lang_management_VMGarbageCollectorMXBeanImpl__ */
