// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_IOException__
#define __java_io_IOException__

#pragma interface

#include <java/lang/Exception.h>

class java::io::IOException : public ::java::lang::Exception
{
public:
  IOException ();
  IOException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 7818375828146090155LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_IOException__ */
