// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_charset_UTF_16Decoder__
#define __gnu_java_nio_charset_UTF_16Decoder__

#pragma interface

#include <java/nio/charset/CharsetDecoder.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        namespace charset
        {
          class UTF_16Decoder;
        }
      }
    }
  }
  namespace java
  {
    namespace nio
    {
      class CharBuffer;
      class ByteBuffer;
      namespace charset
      {
        class CoderResult;
        class Charset;
      }
    }
  }
}

class gnu::java::nio::charset::UTF_16Decoder : public ::java::nio::charset::CharsetDecoder
{
public: // actually package-private
  UTF_16Decoder (::java::nio::charset::Charset *, jint);
public:  // actually protected
  virtual ::java::nio::charset::CoderResult *decodeLoop (::java::nio::ByteBuffer *, ::java::nio::CharBuffer *);
  virtual void implReset ();
public: // actually package-private
  static const jint BIG_ENDIAN = 0L;
  static const jint LITTLE_ENDIAN = 1L;
  static const jint UNKNOWN_ENDIAN = 2L;
  static const jint MAYBE_BIG_ENDIAN = 3L;
  static const jint MAYBE_LITTLE_ENDIAN = 4L;
private:
  static const jint BYTE_ORDER_MARK = 65279L;
  static const jint REVERSED_BYTE_ORDER_MARK = 65534L;
  jint __attribute__((aligned(__alignof__( ::java::nio::charset::CharsetDecoder ))))  originalByteOrder;
  jint byteOrder;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_charset_UTF_16Decoder__ */
