// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_ColorUIResource__
#define __javax_swing_plaf_ColorUIResource__

#pragma interface

#include <java/awt/Color.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class ColorUIResource;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Color;
    }
  }
}

class javax::swing::plaf::ColorUIResource : public ::java::awt::Color
{
public:
  ColorUIResource (jint, jint, jint);
  ColorUIResource (jint);
  ColorUIResource (jfloat, jfloat, jfloat);
  ColorUIResource (::java::awt::Color *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_ColorUIResource__ */
