// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_protocol_ftp_ActiveModeDTP__
#define __gnu_java_net_protocol_ftp_ActiveModeDTP__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        namespace protocol
        {
          namespace ftp
          {
            class ActiveModeDTP;
            class DTPOutputStream;
            class DTPInputStream;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class InetAddress;
      class Socket;
      class ServerSocket;
    }
  }
}

class gnu::java::net::protocol::ftp::ActiveModeDTP : public ::java::lang::Object
{
public: // actually package-private
  ActiveModeDTP (::java::net::InetAddress *, jint, jint, jint);
public:
  virtual void run ();
  virtual void waitFor ();
  virtual ::java::io::InputStream *getInputStream ();
  virtual ::java::io::OutputStream *getOutputStream ();
  virtual void setTransferMode (jint);
  virtual void complete ();
  virtual jboolean abort ();
  virtual void transferComplete ();
public: // actually package-private
  ::java::net::ServerSocket * __attribute__((aligned(__alignof__( ::java::lang::Object )))) server;
  ::java::net::Socket *socket;
  ::gnu::java::net::protocol::ftp::DTPInputStream *in;
  ::gnu::java::net::protocol::ftp::DTPOutputStream *out;
  jboolean completed;
  jboolean inProgress;
  jint transferMode;
  ::java::io::IOException *exception;
  ::java::lang::Thread *acceptThread;
  jint connectionTimeout;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_protocol_ftp_ActiveModeDTP__ */
