// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_X509CRL__
#define __java_security_cert_X509CRL__

#pragma interface

#include <java/security/cert/CRL.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace x500
        {
          class X500Principal;
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
    namespace security
    {
      namespace cert
      {
        class X509CRL;
        class X509CRLEntry;
      }
      class Principal;
      class PublicKey;
    }
  }
}

class java::security::cert::X509CRL : public ::java::security::cert::CRL
{
public:  // actually protected
  X509CRL ();
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual jbyteArray getEncoded () = 0;
  virtual void verify (::java::security::PublicKey *) = 0;
  virtual void verify (::java::security::PublicKey *, ::java::lang::String *) = 0;
  virtual jint getVersion () = 0;
  virtual ::java::security::Principal *getIssuerDN () = 0;
  virtual ::java::util::Date *getThisUpdate () = 0;
  virtual ::java::util::Date *getNextUpdate () = 0;
  virtual ::java::security::cert::X509CRLEntry *getRevokedCertificate (::java::math::BigInteger *) = 0;
  virtual ::java::util::Set *getRevokedCertificates () = 0;
  virtual jbyteArray getTBSCertList () = 0;
  virtual jbyteArray getSignature () = 0;
  virtual ::java::lang::String *getSigAlgName () = 0;
  virtual ::java::lang::String *getSigAlgOID () = 0;
  virtual jbyteArray getSigAlgParams () = 0;
  virtual ::javax::security::auth::x500::X500Principal *getIssuerX500Principal ();

  static ::java::lang::Class class$;
};

#endif /* __java_security_cert_X509CRL__ */
