// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_GetLocalHostAction__
#define __gnu_java_net_GetLocalHostAction__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        class GetLocalHostAction;
      }
    }
  }
}

class gnu::java::net::GetLocalHostAction : public ::java::lang::Object
{
public:
  virtual ::java::lang::Object *run ();
  GetLocalHostAction ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_GetLocalHostAction__ */
