// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Util__
#define __gnu_javax_net_ssl_provider_Util__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class Util;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::net::ssl::provider::Util : public ::java::lang::Object
{
private:
  Util ();
public: // actually package-private
  static jbyteArray toByteArray (::java::lang::String *);
  static ::java::lang::String *toHexString (jbyteArray, jint, jint);
  static ::java::lang::String *toHexString (jbyteArray);
  static ::java::lang::String *toHexString (jbyteArray, jint, jint, jchar);
  static ::java::lang::String *toHexString (jbyteArray, jchar);
  static ::java::lang::String *hexDump (jbyteArray, jint, jint, ::java::lang::String *);
  static ::java::lang::String *hexDump (jbyteArray, jint, jint);
  static ::java::lang::String *hexDump (jbyteArray, ::java::lang::String *);
  static ::java::lang::String *hexDump (jbyteArray);
  static ::java::lang::String *formatInt (jint, jint, jint);
  static jbyteArray concat (jbyteArray, jbyteArray);
  static jbyteArray trim (jbyteArray, jint);
  static jbyteArray trim (jbyteArray, jint, jint);
  static jbyteArray trim (::java::math::BigInteger *);
  static jint unixTime ();
  static JArray< ::java::lang::Object *> *transform (JArray< ::java::lang::Object *> *, ::java::lang::Class *, ::java::lang::String *, JArray< ::java::lang::Object *> *);
  static ::java::lang::String *getProperty (::java::lang::String *);
  static ::java::lang::String *getSecurityProperty (::java::lang::String *);
  static ::java::lang::String *HEX;

  friend class gnu_javax_net_ssl_provider_Util$2;
  friend class gnu_javax_net_ssl_provider_Util$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Util__ */
