// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Event__
#define __java_awt_Event__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Event;
    }
  }
}

class java::awt::Event : public ::java::lang::Object
{
public:
  Event (::java::lang::Object *, jint, ::java::lang::Object *);
  Event (::java::lang::Object *, jlong, jint, jint, jint, jint, jint);
  Event (::java::lang::Object *, jlong, jint, jint, jint, jint, jint, ::java::lang::Object *);
  virtual jboolean controlDown ();
  virtual jboolean metaDown ();
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  virtual jboolean shiftDown ();
  virtual ::java::lang::String *toString ();
  virtual void translate (jint, jint);
public: // actually package-private
  static const jlong serialVersionUID = 5488922509400504703LL;
public:
  static const jint SHIFT_MASK = 1L;
  static const jint CTRL_MASK = 2L;
  static const jint META_MASK = 4L;
  static const jint ALT_MASK = 8L;
  static const jint ACTION_EVENT = 1001L;
  static const jint BACK_SPACE = 8L;
  static const jint CAPS_LOCK = 1022L;
  static const jint DELETE = 127L;
  static const jint DOWN = 1005L;
  static const jint END = 1001L;
  static const jint ENTER = 10L;
  static const jint ESCAPE = 27L;
  static const jint F1 = 1008L;
  static const jint F10 = 1017L;
  static const jint F11 = 1018L;
  static const jint F12 = 1019L;
  static const jint F2 = 1009L;
  static const jint F3 = 1010L;
  static const jint F4 = 1011L;
  static const jint F5 = 1012L;
  static const jint F6 = 1013L;
  static const jint F7 = 1014L;
  static const jint F8 = 1015L;
  static const jint F9 = 1016L;
  static const jint GOT_FOCUS = 1004L;
  static const jint HOME = 1000L;
  static const jint INSERT = 1025L;
  static const jint KEY_ACTION = 403L;
  static const jint KEY_ACTION_RELEASE = 404L;
  static const jint KEY_PRESS = 401L;
  static const jint KEY_RELEASE = 402L;
  static const jint LEFT = 1006L;
  static const jint LIST_DESELECT = 702L;
  static const jint LIST_SELECT = 701L;
  static const jint LOAD_FILE = 1002L;
  static const jint LOST_FOCUS = 1005L;
  static const jint MOUSE_DOWN = 501L;
  static const jint MOUSE_DRAG = 506L;
  static const jint MOUSE_ENTER = 504L;
  static const jint MOUSE_EXIT = 505L;
  static const jint MOUSE_MOVE = 503L;
  static const jint MOUSE_UP = 502L;
  static const jint NUM_LOCK = 1023L;
  static const jint PAUSE = 1024L;
  static const jint PGDN = 1003L;
  static const jint PGUP = 1002L;
  static const jint PRINT_SCREEN = 1020L;
  static const jint RIGHT = 1007L;
  static const jint SAVE_FILE = 1003L;
  static const jint SCROLL_ABSOLUTE = 605L;
  static const jint SCROLL_BEGIN = 606L;
  static const jint SCROLL_END = 607L;
  static const jint SCROLL_LINE_DOWN = 602L;
  static const jint SCROLL_LINE_UP = 601L;
  static const jint SCROLL_LOCK = 1021L;
  static const jint SCROLL_PAGE_DOWN = 604L;
  static const jint SCROLL_PAGE_UP = 603L;
  static const jint TAB = 9L;
  static const jint UP = 1004L;
  static const jint WINDOW_DEICONIFY = 204L;
  static const jint WINDOW_DESTROY = 201L;
  static const jint WINDOW_EXPOSE = 202L;
  static const jint WINDOW_ICONIFY = 203L;
  static const jint WINDOW_MOVED = 205L;
  ::java::lang::Object * __attribute__((aligned(__alignof__( ::java::lang::Object )))) arg;
  jint clickCount;
public: // actually package-private
  jboolean consumed;
public:
  ::java::awt::Event *evt;
  jint id;
  jint key;
  jint modifiers;
  ::java::lang::Object *target;
  jlong when;
  jint x;
  jint y;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Event__ */
