// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_SSLServerSocketFactory__
#define __gnu_javax_net_ssl_provider_SSLServerSocketFactory__

#pragma interface

#include <javax/net/ssl/SSLServerSocketFactory.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class InetAddress;
      class ServerSocket;
    }
    namespace security
    {
      class SecureRandom;
    }
  }
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class X509TrustManager;
        class X509KeyManager;
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          class SRPTrustManager;
          namespace provider
          {
            class SSLServerSocketFactory;
            class SSLServerSocket;
            class SessionContext;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::SSLServerSocketFactory : public ::javax::net::ssl::SSLServerSocketFactory
{
public: // actually package-private
  SSLServerSocketFactory (::javax::net::ssl::X509TrustManager *, ::gnu::javax::net::ssl::SRPTrustManager *, ::javax::net::ssl::X509KeyManager *, ::java::security::SecureRandom *, ::gnu::javax::net::ssl::provider::SessionContext *);
public:
  virtual JArray< ::java::lang::String *> *getDefaultCipherSuites ();
  virtual JArray< ::java::lang::String *> *getSupportedCipherSuites ();
  virtual ::java::net::ServerSocket *createServerSocket ();
  virtual ::java::net::ServerSocket *createServerSocket (jint);
  virtual ::java::net::ServerSocket *createServerSocket (jint, jint);
  virtual ::java::net::ServerSocket *createServerSocket (jint, jint, ::java::net::InetAddress *);
private:
  void setup (::gnu::javax::net::ssl::provider::SSLServerSocket *);
  ::gnu::javax::net::ssl::provider::SessionContext * __attribute__((aligned(__alignof__( ::javax::net::ssl::SSLServerSocketFactory )))) sessions;
  ::javax::net::ssl::X509KeyManager *keyManager;
  ::javax::net::ssl::X509TrustManager *trustManager;
  ::gnu::javax::net::ssl::SRPTrustManager *srpTrustManager;
  ::java::security::SecureRandom *random;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_SSLServerSocketFactory__ */
