// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_beans_SimpleBeanInfo__
#define __java_beans_SimpleBeanInfo__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Image;
    }
    namespace beans
    {
      class SimpleBeanInfo;
      class BeanInfo;
      class MethodDescriptor;
      class PropertyDescriptor;
      class EventSetDescriptor;
      class BeanDescriptor;
    }
  }
}

class java::beans::SimpleBeanInfo : public ::java::lang::Object
{
public:
  virtual ::java::beans::BeanDescriptor *getBeanDescriptor () { return 0; }
  virtual JArray< ::java::beans::EventSetDescriptor *> *getEventSetDescriptors () { return 0; }
  virtual jint getDefaultEventIndex ();
  virtual JArray< ::java::beans::PropertyDescriptor *> *getPropertyDescriptors () { return 0; }
  virtual jint getDefaultPropertyIndex ();
  virtual JArray< ::java::beans::MethodDescriptor *> *getMethodDescriptors () { return 0; }
  virtual JArray< ::java::beans::BeanInfo *> *getAdditionalBeanInfo () { return 0; }
  virtual ::java::awt::Image *getIcon (jint) { return 0; }
  virtual ::java::awt::Image *loadImage (::java::lang::String *);
  SimpleBeanInfo ();

  static ::java::lang::Class class$;
};

#endif /* __java_beans_SimpleBeanInfo__ */
