// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JRadioButtonMenuItem__
#define __javax_swing_JRadioButtonMenuItem__

#pragma interface

#include <javax/swing/JMenuItem.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JRadioButtonMenuItem;
      class Action;
      class Icon;
    }
  }
}

class javax::swing::JRadioButtonMenuItem : public ::javax::swing::JMenuItem
{
public:
  JRadioButtonMenuItem ();
  JRadioButtonMenuItem (::javax::swing::Icon *);
  JRadioButtonMenuItem (::java::lang::String *);
  JRadioButtonMenuItem (::javax::swing::Action *);
  JRadioButtonMenuItem (::java::lang::String *, ::javax::swing::Icon *);
  JRadioButtonMenuItem (::java::lang::String *, jboolean);
  JRadioButtonMenuItem (::javax::swing::Icon *, jboolean);
  JRadioButtonMenuItem (::java::lang::String *, ::javax::swing::Icon *, jboolean);
  virtual ::java::lang::String *getUIClassID ();
  virtual void requestFocus () { }
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = 8482658191548521743LL;
  static ::java::lang::String *uiClassID;

  friend class javax_swing_JRadioButtonMenuItem$AccessibleJRadioButtonMenuItem;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JRadioButtonMenuItem__ */
