// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JSplitPane__
#define __javax_swing_JSplitPane__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JSplitPane;
      namespace plaf
      {
        class SplitPaneUI;
      }
    }
    namespace accessibility
    {
      class AccessibleContext;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Component;
    }
  }
}

class javax::swing::JSplitPane : public ::javax::swing::JComponent
{
public:
  JSplitPane (jint, jboolean, ::java::awt::Component *, ::java::awt::Component *);
  JSplitPane (jint, ::java::awt::Component *, ::java::awt::Component *);
  JSplitPane (jint, jboolean);
  JSplitPane (jint);
  JSplitPane ();
public:  // actually protected
  virtual void addImpl (::java::awt::Component *, ::java::lang::Object *, jint);
public:
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
  virtual ::java::awt::Component *getBottomComponent () { return rightComponent; }
  virtual jint getDividerLocation ();
  virtual jint getDividerSize () { return dividerSize; }
  virtual jint getLastDividerLocation () { return lastDividerLocation; }
  virtual ::java::awt::Component *getLeftComponent () { return leftComponent; }
  virtual jint getMaximumDividerLocation ();
  virtual jint getMinimumDividerLocation ();
  virtual jint getOrientation () { return orientation; }
  virtual jdouble getResizeWeight () { return resizeWeight; }
  virtual ::java::awt::Component *getRightComponent () { return rightComponent; }
  virtual ::java::awt::Component *getTopComponent () { return leftComponent; }
  virtual ::javax::swing::plaf::SplitPaneUI *getUI ();
  virtual jboolean isContinuousLayout () { return continuousLayout; }
  virtual jboolean isOneTouchExpandable () { return oneTouchExpandable; }
  virtual jboolean isValidateRoot ();
public:  // actually protected
  virtual void paintChildren (::java::awt::Graphics *);
  virtual ::java::lang::String *paramString ();
public:
  virtual void remove (::java::awt::Component *);
  virtual void remove (jint);
  virtual void removeAll ();
  virtual void resetToPreferredSizes ();
  virtual void setBottomComponent (::java::awt::Component *);
  virtual void setContinuousLayout (jboolean);
  virtual void setDividerLocation (jdouble);
  virtual void setDividerLocation (jint);
  virtual void setDividerSize (jint);
  virtual void setLastDividerLocation (jint);
  virtual void setLeftComponent (::java::awt::Component *);
  virtual void setOneTouchExpandable (jboolean);
  virtual void setOrientation (jint);
  virtual void setResizeWeight (jdouble);
  virtual void setRightComponent (::java::awt::Component *);
  virtual void setTopComponent (::java::awt::Component *);
  virtual void setUI (::javax::swing::plaf::SplitPaneUI *);
  virtual void updateUI ();
  virtual ::java::lang::String *getUIClassID ();
public: // actually package-private
  virtual void setUIProperty (::java::lang::String *, ::java::lang::Object *);
private:
  static const jlong serialVersionUID = -5634142046175988380LL;
public:
  static ::java::lang::String *BOTTOM;
  static ::java::lang::String *CONTINUOUS_LAYOUT_PROPERTY;
  static ::java::lang::String *DIVIDER;
  static ::java::lang::String *DIVIDER_LOCATION_PROPERTY;
  static ::java::lang::String *DIVIDER_SIZE_PROPERTY;
  static const jint HORIZONTAL_SPLIT = 1L;
  static ::java::lang::String *LAST_DIVIDER_LOCATION_PROPERTY;
  static ::java::lang::String *LEFT;
  static ::java::lang::String *ONE_TOUCH_EXPANDABLE_PROPERTY;
  static ::java::lang::String *ORIENTATION_PROPERTY;
  static ::java::lang::String *RESIZE_WEIGHT_PROPERTY;
  static ::java::lang::String *RIGHT;
  static ::java::lang::String *TOP;
  static const jint VERTICAL_SPLIT = 0L;
public:  // actually protected
  jboolean __attribute__((aligned(__alignof__( ::javax::swing::JComponent ))))  continuousLayout;
  jboolean oneTouchExpandable;
  jint dividerSize;
  jint lastDividerLocation;
  jint orientation;
  ::java::awt::Component *leftComponent;
  ::java::awt::Component *rightComponent;
private:
  jdouble resizeWeight;
  jboolean clientDividerSizeSet;
  jboolean clientOneTouchExpandableSet;

  friend class javax_swing_JSplitPane$AccessibleJSplitPane;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JSplitPane__ */
