// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_ListView__
#define __javax_swing_text_html_ListView__

#pragma interface

#include <javax/swing/text/html/BlockView.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      class Shape;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class Element;
        namespace html
        {
          class ListView;
          class StyleSheet$ListPainter;
        }
      }
    }
  }
}

class javax::swing::text::html::ListView : public ::javax::swing::text::html::BlockView
{
public:
  ListView (::javax::swing::text::Element *);
  virtual jfloat getAlignment (jint);
  virtual void paint (::java::awt::Graphics *, ::java::awt::Shape *);
public:  // actually protected
  virtual void paintChild (::java::awt::Graphics *, ::java::awt::Rectangle *, jint);
  virtual void setPropertiesFromAttributes ();
private:
  ::javax::swing::text::html::StyleSheet$ListPainter * __attribute__((aligned(__alignof__( ::javax::swing::text::html::BlockView )))) painter;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_ListView__ */
