// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_InvalidMarkException__
#define __java_nio_InvalidMarkException__

#pragma interface

#include <java/lang/IllegalStateException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class InvalidMarkException;
    }
  }
}

class java::nio::InvalidMarkException : public ::java::lang::IllegalStateException
{
public:
  InvalidMarkException ();
private:
  static const jlong serialVersionUID = 1698329710438510774LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_InvalidMarkException__ */
