// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ArithmeticException__
#define __java_lang_ArithmeticException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::ArithmeticException : public ::java::lang::RuntimeException
{
public:
  ArithmeticException ();
  ArithmeticException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 2256477558314496007LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ArithmeticException__ */
