// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_event_filters_IEventFilter__
#define __gnu_classpath_jdwp_event_filters_IEventFilter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        namespace event
        {
          namespace filters
          {
            class IEventFilter;
          }
          class Event;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::event::filters::IEventFilter : public ::java::lang::Object
{
public:
  virtual jboolean matches (::gnu::classpath::jdwp::event::Event *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_classpath_jdwp_event_filters_IEventFilter__ */
