// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_spec_BlockCipherParameterSpec__
#define __gnu_javax_crypto_jce_spec_BlockCipherParameterSpec__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace spec
          {
            class BlockCipherParameterSpec;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::spec::BlockCipherParameterSpec : public ::java::lang::Object
{
public:
  BlockCipherParameterSpec (jbyteArray, jint, jint);
  BlockCipherParameterSpec (jint, jint);
  virtual jbyteArray getIV () { return iv; }
  virtual jint getBlockSize () { return blockSize; }
  virtual jint getKeySize () { return keySize; }
  virtual ::java::lang::String *toString ();
public:  // actually protected
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  iv;
  jint blockSize;
  jint keySize;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_spec_BlockCipherParameterSpec__ */
