// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_PrintUriException__
#define __gnu_javax_print_PrintUriException__

#pragma interface

#include <javax/print/PrintException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        class PrintUriException;
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URI;
    }
  }
}

class gnu::javax::print::PrintUriException : public ::javax::print::PrintException
{
public:
  PrintUriException (jint, ::java::net::URI *);
  PrintUriException (::java::lang::Exception *, jint, ::java::net::URI *);
  PrintUriException (::java::lang::String *, jint, ::java::net::URI *);
  PrintUriException (::java::lang::String *, ::java::lang::Exception *, jint, ::java::net::URI *);
  virtual jint getReason () { return reason; }
  virtual ::java::net::URI *getUnsupportedURI () { return uri; }
private:
  jint __attribute__((aligned(__alignof__( ::javax::print::PrintException ))))  reason;
  ::java::net::URI *uri;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_PrintUriException__ */
