// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_event_PrintServiceAttributeEvent__
#define __javax_print_event_PrintServiceAttributeEvent__

#pragma interface

#include <javax/print/event/PrintEvent.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace event
      {
        class PrintServiceAttributeEvent;
      }
      class PrintService;
      namespace attribute
      {
        class PrintServiceAttributeSet;
      }
    }
  }
}

class javax::print::event::PrintServiceAttributeEvent : public ::javax::print::event::PrintEvent
{
public:
  PrintServiceAttributeEvent (::javax::print::PrintService *, ::javax::print::attribute::PrintServiceAttributeSet *);
  virtual ::javax::print::PrintService *getPrintService ();
  virtual ::javax::print::attribute::PrintServiceAttributeSet *getAttributes () { return attributes; }
private:
  ::javax::print::attribute::PrintServiceAttributeSet * __attribute__((aligned(__alignof__( ::javax::print::event::PrintEvent )))) attributes;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_event_PrintServiceAttributeEvent__ */
