// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_io_ASN1ParsingException__
#define __gnu_java_io_ASN1ParsingException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace io
      {
        class ASN1ParsingException;
      }
    }
  }
}

class gnu::java::io::ASN1ParsingException : public ::java::io::IOException
{
public:
  ASN1ParsingException ();
  ASN1ParsingException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_io_ASN1ParsingException__ */
