// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_CompressionMethod__
#define __gnu_javax_net_ssl_provider_CompressionMethod__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class CompressionMethod;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::CompressionMethod : public ::java::lang::Object
{
private:
  CompressionMethod (jint);
public: // actually package-private
  static ::gnu::javax::net::ssl::provider::CompressionMethod *read (::java::io::InputStream *);
public:
  virtual jbyteArray getEncoded ();
  virtual jint getValue () { return value; }
  virtual ::java::lang::String *toString ();
public: // actually package-private
  static ::gnu::javax::net::ssl::provider::CompressionMethod *NULL;
  static ::gnu::javax::net::ssl::provider::CompressionMethod *ZLIB;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  value;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_CompressionMethod__ */
