// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_MBeanInfo__
#define __javax_management_MBeanInfo__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      class MBeanInfo;
      class MBeanNotificationInfo;
      class MBeanConstructorInfo;
      class MBeanOperationInfo;
      class MBeanAttributeInfo;
    }
  }
}

class javax::management::MBeanInfo : public ::java::lang::Object
{
public:
  MBeanInfo (::java::lang::String *, ::java::lang::String *, JArray< ::javax::management::MBeanAttributeInfo *> *, JArray< ::javax::management::MBeanConstructorInfo *> *, JArray< ::javax::management::MBeanOperationInfo *> *, JArray< ::javax::management::MBeanNotificationInfo *> *);
  virtual ::java::lang::Object *clone ();
  virtual jboolean equals (::java::lang::Object *);
  virtual JArray< ::javax::management::MBeanAttributeInfo *> *getAttributes ();
  virtual ::java::lang::String *getClassName () { return className; }
  virtual JArray< ::javax::management::MBeanConstructorInfo *> *getConstructors ();
  virtual ::java::lang::String *getDescription () { return description; }
  virtual JArray< ::javax::management::MBeanNotificationInfo *> *getNotifications ();
  virtual JArray< ::javax::management::MBeanOperationInfo *> *getOperations ();
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = -6451021435135161911LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) description;
  ::java::lang::String *className;
  JArray< ::javax::management::MBeanAttributeInfo *> *attributes;
  JArray< ::javax::management::MBeanOperationInfo *> *operations;
  JArray< ::javax::management::MBeanConstructorInfo *> *constructors;
  JArray< ::javax::management::MBeanNotificationInfo *> *notifications;
  ::java::lang::String *string;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_MBeanInfo__ */
