// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_ProgressMonitor__
#define __javax_swing_ProgressMonitor__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Component;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class ProgressMonitor;
      class Timer;
      class JDialog;
      class JLabel;
      class JProgressBar;
    }
    namespace accessibility
    {
      class AccessibleContext;
    }
  }
}

class javax::swing::ProgressMonitor : public ::java::lang::Object
{
public:
  ProgressMonitor (::java::awt::Component *, ::java::lang::Object *, ::java::lang::String *, jint, jint);
  virtual void close ();
  virtual void setProgress (jint);
  virtual jint getMinimum () { return min; }
  virtual void setMinimum (jint);
  virtual jint getMaximum () { return max; }
  virtual void setMaximum (jint);
  virtual jboolean isCanceled () { return canceled; }
  virtual jint getMillisToDecideToPopup () { return millisToDecideToPopup; }
  virtual void setMillisToDecideToPopup (jint);
  virtual jint getMillisToPopup () { return millisToPopup; }
  virtual void setMillisToPopup (jint);
  virtual ::java::lang::String *getNote () { return note; }
  virtual void setNote (::java::lang::String *);
public: // actually package-private
  virtual void createDialog ();
public:
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext () { return accessibleContext; }
public:  // actually protected
  ::javax::accessibility::AccessibleContext * __attribute__((aligned(__alignof__( ::java::lang::Object )))) accessibleContext;
public: // actually package-private
  ::java::awt::Component *component;
  ::java::lang::String *note;
  ::java::lang::Object *message;
  jint millisToDecideToPopup;
  jint millisToPopup;
  jint min;
  jint max;
  jint progress;
  ::javax::swing::JProgressBar *progressBar;
  ::javax::swing::JLabel *noteLabel;
  ::javax::swing::JDialog *progressDialog;
  ::javax::swing::Timer *timer;
  jboolean canceled;

  friend class javax_swing_ProgressMonitor$TimerListener;
  friend class javax_swing_ProgressMonitor$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_ProgressMonitor__ */
