// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_transport_TransportException__
#define __gnu_classpath_jdwp_transport_TransportException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        namespace transport
        {
          class TransportException;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::transport::TransportException : public ::java::lang::Exception
{
public:
  TransportException (::java::lang::String *);
  TransportException (::java::lang::Throwable *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_transport_TransportException__ */
