// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_dnd_MouseDragGestureRecognizer__
#define __java_awt_dnd_MouseDragGestureRecognizer__

#pragma interface

#include <java/awt/dnd/DragGestureRecognizer.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class MouseEvent;
      }
      class Component;
      namespace dnd
      {
        class MouseDragGestureRecognizer;
        class DragGestureListener;
        class DragSource;
      }
    }
  }
}

class java::awt::dnd::MouseDragGestureRecognizer : public ::java::awt::dnd::DragGestureRecognizer
{
public:  // actually protected
  MouseDragGestureRecognizer (::java::awt::dnd::DragSource *, ::java::awt::Component *, jint, ::java::awt::dnd::DragGestureListener *);
  MouseDragGestureRecognizer (::java::awt::dnd::DragSource *, ::java::awt::Component *, jint);
  MouseDragGestureRecognizer (::java::awt::dnd::DragSource *, ::java::awt::Component *);
  MouseDragGestureRecognizer (::java::awt::dnd::DragSource *);
  virtual void registerListeners ();
  virtual void unregisterListeners ();
public:
  virtual void mouseClicked (::java::awt::event::MouseEvent *) { }
  virtual void mousePressed (::java::awt::event::MouseEvent *) { }
  virtual void mouseReleased (::java::awt::event::MouseEvent *) { }
  virtual void mouseEntered (::java::awt::event::MouseEvent *) { }
  virtual void mouseExited (::java::awt::event::MouseEvent *) { }
  virtual void mouseDragged (::java::awt::event::MouseEvent *) { }
  virtual void mouseMoved (::java::awt::event::MouseEvent *) { }

  static ::java::lang::Class class$;
};

#endif /* __java_awt_dnd_MouseDragGestureRecognizer__ */
