// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_spi_LoginModule__
#define __javax_security_auth_spi_LoginModule__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace spi
        {
          class LoginModule;
        }
        namespace callback
        {
          class CallbackHandler;
        }
        class Subject;
      }
    }
  }
}

class javax::security::auth::spi::LoginModule : public ::java::lang::Object
{
public:
  virtual jboolean abort () = 0;
  virtual jboolean commit () = 0;
  virtual void initialize (::javax::security::auth::Subject *, ::javax::security::auth::callback::CallbackHandler *, ::java::util::Map *, ::java::util::Map *) = 0;
  virtual jboolean login () = 0;
  virtual jboolean logout () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_security_auth_spi_LoginModule__ */
