// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_AuthenticationNotSupportedException__
#define __javax_naming_AuthenticationNotSupportedException__

#pragma interface

#include <javax/naming/NamingSecurityException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class AuthenticationNotSupportedException;
    }
  }
}

class javax::naming::AuthenticationNotSupportedException : public ::javax::naming::NamingSecurityException
{
public:
  AuthenticationNotSupportedException ();
  AuthenticationNotSupportedException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -7149033933259492300LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_AuthenticationNotSupportedException__ */
