// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_sampled_Port__
#define __javax_sound_sampled_Port__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace sampled
      {
        class Port;
      }
    }
  }
}

class javax::sound::sampled::Port : public ::java::lang::Object
{

  friend class javax_sound_sampled_Port$Info;
  friend class javax_sound_sampled_Port$1;
public:

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sound_sampled_Port__ */
