// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_RepaintManager__
#define __javax_swing_RepaintManager__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JComponent;
      class RepaintManager;
      class RepaintManager$RepaintWorker;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Image;
      class Component;
      class Dimension;
      class Rectangle;
    }
  }
}

class javax::swing::RepaintManager : public ::java::lang::Object
{
public:
  RepaintManager ();
  static ::javax::swing::RepaintManager *currentManager (::java::awt::Component *);
  static ::javax::swing::RepaintManager *currentManager (::javax::swing::JComponent *);
  static void setCurrentManager (::javax::swing::RepaintManager *);
  virtual void addInvalidComponent (::javax::swing::JComponent *);
  virtual void removeInvalidComponent (::javax::swing::JComponent *);
  virtual void addDirtyRegion (::javax::swing::JComponent *, jint, jint, jint, jint);
  virtual ::java::awt::Rectangle *getDirtyRegion (::javax::swing::JComponent *);
  virtual void markCompletelyDirty (::javax::swing::JComponent *);
  virtual void markCompletelyClean (::javax::swing::JComponent *);
  virtual jboolean isCompletelyDirty (::javax::swing::JComponent *);
  virtual void validateInvalidComponents ();
  virtual void paintDirtyRegions ();
private:
  void compileRepaintRoots (::java::util::HashMap *, ::javax::swing::JComponent *, ::java::util::HashSet *);
public:
  virtual ::java::awt::Image *getOffscreenBuffer (::java::awt::Component *, jint, jint);
public: // actually package-private
  virtual void commitBuffer (::java::awt::Component *, ::java::awt::Rectangle *);
private:
  void blitBuffer (::java::awt::Component *, ::java::awt::Rectangle *);
  ::java::awt::Component *getHeavyweightParent (::java::awt::Component *);
  void commitRemainingBuffers ();
public:
  virtual ::java::awt::Image *getVolatileOffscreenBuffer (::java::awt::Component *, jint, jint);
  virtual ::java::awt::Dimension *getDoubleBufferMaximumSize () { return doubleBufferMaximumSize; }
  virtual void setDoubleBufferMaximumSize (::java::awt::Dimension *);
  virtual void setDoubleBufferingEnabled (jboolean);
  virtual jboolean isDoubleBufferingEnabled () { return doubleBufferingEnabled; }
  virtual ::java::lang::String *toString ();
public: // actually package-private
  static ::java::util::WeakHashMap *currentRepaintManagers;
private:
  static ::java::awt::Rectangle *rectCache;
  ::java::util::HashMap * __attribute__((aligned(__alignof__( ::java::lang::Object )))) dirtyComponents;
  ::java::util::HashMap *dirtyComponentsWork;
  ::javax::swing::RepaintManager$RepaintWorker *repaintWorker;
  ::java::util::ArrayList *invalidComponents;
  jboolean doubleBufferingEnabled;
  ::java::util::WeakHashMap *offscreenBuffers;
  jboolean repaintUnderway;
  ::java::util::HashMap *commitRequests;
  ::java::awt::Dimension *doubleBufferMaximumSize;

  friend class javax_swing_RepaintManager$RepaintWorker;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_RepaintManager__ */
