// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_HRuleView__
#define __javax_swing_text_html_HRuleView__

#pragma interface

#include <javax/swing/text/html/InlineView.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Shape;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class HRuleView;
        }
        class Element;
        class View;
      }
    }
  }
}

class javax::swing::text::html::HRuleView : public ::javax::swing::text::html::InlineView
{
public:
  HRuleView (::javax::swing::text::Element *);
  virtual jint getBreakWeight (jint, jfloat, jfloat);
  virtual void paint (::java::awt::Graphics *, ::java::awt::Shape *);
  virtual ::javax::swing::text::View *breakView (jint, jint, jfloat, jfloat);
  virtual jfloat getMaximumSpan (jint);
  virtual jfloat getPreferredSpan (jint);
public: // actually package-private
  ::javax::swing::text::View * __attribute__((aligned(__alignof__( ::javax::swing::text::html::InlineView )))) nullView;
  static jint HEIGHT;

  friend class javax_swing_text_html_HRuleView$Beginning;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_HRuleView__ */
