// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JLabel__
#define __javax_swing_JLabel__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JLabel;
      namespace plaf
      {
        class LabelUI;
      }
      class Icon;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Font;
      class Image;
      class Component;
    }
  }
}

class javax::swing::JLabel : public ::javax::swing::JComponent
{
public:
  JLabel ();
  JLabel (::javax::swing::Icon *);
  JLabel (::javax::swing::Icon *, jint);
  JLabel (::java::lang::String *);
  JLabel (::java::lang::String *, jint);
  JLabel (::java::lang::String *, ::javax::swing::Icon *, jint);
  virtual ::javax::swing::plaf::LabelUI *getUI ();
  virtual void setUI (::javax::swing::plaf::LabelUI *);
  virtual void updateUI ();
  virtual ::java::lang::String *getUIClassID ();
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  virtual ::java::lang::String *getText () { return text; }
  virtual void setText (::java::lang::String *);
  virtual ::javax::swing::Icon *getIcon () { return icon; }
  virtual void setIcon (::javax::swing::Icon *);
  virtual ::javax::swing::Icon *getDisabledIcon ();
  virtual void setDisabledIcon (::javax::swing::Icon *);
  virtual void setDisplayedMnemonic (jint);
  virtual void setDisplayedMnemonic (jchar);
  virtual jint getDisplayedMnemonic () { return displayedMnemonic; }
  virtual void setDisplayedMnemonicIndex (jint);
  virtual jint getDisplayedMnemonicIndex () { return displayedMnemonicIndex; }
public:  // actually protected
  virtual jint checkHorizontalKey (jint, ::java::lang::String *);
  virtual jint checkVerticalKey (jint, ::java::lang::String *);
public:
  virtual jint getIconTextGap () { return iconTextGap; }
  virtual void setIconTextGap (jint);
  virtual jint getVerticalAlignment () { return verticalAlignment; }
  virtual void setVerticalAlignment (jint);
  virtual jint getHorizontalAlignment () { return horizontalAlignment; }
  virtual void setHorizontalAlignment (jint);
  virtual jint getVerticalTextPosition () { return verticalTextPosition; }
  virtual void setVerticalTextPosition (jint);
  virtual jint getHorizontalTextPosition () { return horizontalTextPosition; }
  virtual void setHorizontalTextPosition (jint);
  virtual jboolean imageUpdate (::java::awt::Image *, jint, jint, jint, jint, jint);
  virtual ::java::awt::Component *getLabelFor () { return labelFor; }
  virtual void setLabelFor (::java::awt::Component *);
  virtual void setFont (::java::awt::Font *);
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = 5496508283662221534LL;
public: // actually package-private
  static ::java::lang::String *LABEL_PROPERTY;
public:  // actually protected
  ::java::awt::Component * __attribute__((aligned(__alignof__( ::javax::swing::JComponent )))) labelFor;
public: // actually package-private
  ::java::lang::String *text;
private:
  jint horizontalAlignment;
  jint horizontalTextPosition;
  jint verticalAlignment;
  jint verticalTextPosition;
  ::javax::swing::Icon *icon;
  ::javax::swing::Icon *disabledIcon;
  jint displayedMnemonic;
  jint displayedMnemonicIndex;
  jint iconTextGap;

  friend class javax_swing_JLabel$AccessibleJLabel;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JLabel__ */
