// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_ReferralException__
#define __javax_naming_ReferralException__

#pragma interface

#include <javax/naming/NamingException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class ReferralException;
      class Context;
    }
  }
}

class javax::naming::ReferralException : public ::javax::naming::NamingException
{
public:  // actually protected
  ReferralException ();
  ReferralException (::java::lang::String *);
public:
  virtual ::java::lang::Object *getReferralInfo () = 0;
  virtual ::javax::naming::Context *getReferralContext () = 0;
  virtual ::javax::naming::Context *getReferralContext (::java::util::Hashtable *) = 0;
  virtual jboolean skipReferral () = 0;
  virtual void retryReferral () = 0;
private:
  static const jlong serialVersionUID = -2881363844695698876LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_ReferralException__ */
