// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_SizeSequence__
#define __javax_swing_SizeSequence__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class SizeSequence;
    }
  }
}

class javax::swing::SizeSequence : public ::java::lang::Object
{
public:
  SizeSequence ();
  SizeSequence (jint);
  SizeSequence (jint, jint);
  SizeSequence (jintArray);
  virtual void setSize (jint, jint);
  virtual jint getIndex (jint);
  virtual jint getSize (jint);
  virtual void setSizes (jintArray);
  virtual jintArray getSizes ();
  virtual jint getPosition (jint);
  virtual void insertEntries (jint, jint, jint);
  virtual void removeEntries (jint, jint);
private:
  jintArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  sizes;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_SizeSequence__ */
