// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_IIOInputStream__
#define __gnu_javax_imageio_IIOInputStream__

#pragma interface

#include <java/io/InputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        class IIOInputStream;
      }
    }
  }
  namespace javax
  {
    namespace imageio
    {
      namespace stream
      {
        class ImageInputStream;
      }
    }
  }
}

class gnu::javax::imageio::IIOInputStream : public ::java::io::InputStream
{
public:
  IIOInputStream (::javax::imageio::stream::ImageInputStream *);
  virtual jint available ();
  virtual void close ();
  virtual void mark (jint);
  virtual jboolean markSupported ();
  virtual jint read ();
  virtual jint read (jbyteArray);
  virtual jint read (jbyteArray, jint, jint);
  virtual void reset ();
  virtual jlong skip (jlong);
private:
  ::javax::imageio::stream::ImageInputStream * __attribute__((aligned(__alignof__( ::java::io::InputStream )))) is;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_IIOInputStream__ */
