// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_SubjectDomainCombiner__
#define __javax_security_auth_SubjectDomainCombiner__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class ProtectionDomain;
    }
  }
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        class SubjectDomainCombiner;
        class Subject;
      }
    }
  }
}

class javax::security::auth::SubjectDomainCombiner : public ::java::lang::Object
{
public:
  SubjectDomainCombiner (::javax::security::auth::Subject *);
  virtual JArray< ::java::security::ProtectionDomain *> *combine (JArray< ::java::security::ProtectionDomain *> *, JArray< ::java::security::ProtectionDomain *> *);
  virtual ::javax::security::auth::Subject *getSubject () { return subject; }
private:
  ::javax::security::auth::Subject * __attribute__((aligned(__alignof__( ::java::lang::Object )))) subject;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_SubjectDomainCombiner__ */
