// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_util_Base64__
#define __gnu_java_security_util_Base64__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class Base64;
        }
      }
    }
  }
}

class gnu::java::security::util::Base64 : public ::java::lang::Object
{
private:
  Base64 ();
public:
  static ::java::lang::String *encode (jbyteArray);
  static ::java::lang::String *encode (jbyteArray, jint, jint, jboolean);
  static jbyteArray decode (::java::lang::String *);
  static jbyteArray decode (jbyteArray, jint, jint);
private:
  static jbyteArray encode3to4 (jbyteArray, jint, jint, jbyteArray, jint);
  static jint decode4to3 (jbyteArray, jint, jbyteArray, jint);
  static ::java::util::logging::Logger *log;
  static const jint MAX_LINE_LENGTH = 76L;
  static const jint NEW_LINE = 10L;
  static const jint EQUALS_SIGN = 61L;
  static const jint WHITE_SPACE_ENC = -5L;
  static const jint EQUALS_SIGN_ENC = -1L;
  static jbyteArray ALPHABET;
  static jbyteArray DECODABET;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_util_Base64__ */
