// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_support_low_ParseException__
#define __gnu_javax_swing_text_html_parser_support_low_ParseException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                namespace low
                {
                  class ParseException;
                }
              }
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::support::low::ParseException : public ::java::lang::RuntimeException
{
public:
  ParseException (::java::lang::String *, ::java::lang::Throwable *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_support_low_ParseException__ */
