// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicScrollPaneUI__
#define __javax_swing_plaf_basic_BasicScrollPaneUI__

#pragma interface

#include <javax/swing/plaf/ScrollPaneUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Dimension;
      namespace event
      {
        class ContainerListener;
        class MouseWheelListener;
      }
    }
    namespace beans
    {
      class PropertyChangeEvent;
      class PropertyChangeListener;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class ActionMap;
      class InputMap;
      namespace plaf
      {
        namespace basic
        {
          class BasicScrollPaneUI;
        }
        class ComponentUI;
      }
      class JComponent;
      namespace event
      {
        class ChangeListener;
      }
      class JScrollPane;
    }
  }
}

class javax::swing::plaf::basic::BasicScrollPaneUI : public ::javax::swing::plaf::ScrollPaneUI
{
public:
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual void installDefaults (::javax::swing::JScrollPane *);
  virtual void uninstallDefaults (::javax::swing::JScrollPane *);
public:
  virtual void installUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual void installListeners (::javax::swing::JScrollPane *);
public: // actually package-private
  virtual ::javax::swing::InputMap *getInputMap (jint);
  virtual ::javax::swing::ActionMap *getActionMap ();
  virtual ::javax::swing::ActionMap *createActionMap ();
public:  // actually protected
  virtual void installKeyboardActions (::javax::swing::JScrollPane *);
  virtual void uninstallKeyboardActions (::javax::swing::JScrollPane *);
  virtual ::javax::swing::event::ChangeListener *createHSBChangeListener ();
  virtual ::javax::swing::event::ChangeListener *createVSBChangeListener ();
  virtual ::javax::swing::event::ChangeListener *createViewportChangeListener ();
  virtual ::java::beans::PropertyChangeListener *createPropertyChangeListener ();
  virtual ::java::awt::event::MouseWheelListener *createMouseWheelListener ();
public:
  virtual void uninstallUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual void uninstallListeners (::javax::swing::JComponent *);
public:
  virtual ::java::awt::Dimension *getMinimumSize (::javax::swing::JComponent *);
  virtual void paint (::java::awt::Graphics *, ::javax::swing::JComponent *) { }
public:  // actually protected
  virtual void syncScrollPaneWithViewport ();
  virtual void updateColumnHeader (::java::beans::PropertyChangeEvent *) { }
  virtual void updateRowHeader (::java::beans::PropertyChangeEvent *) { }
  virtual void updateScrollBarDisplayPolicy (::java::beans::PropertyChangeEvent *) { }
  virtual void updateViewport (::java::beans::PropertyChangeEvent *);
public:
  BasicScrollPaneUI ();
public: // actually package-private
  static jint SCROLL_NON_SCROLLABLES;
  static jint ROWS_PER_WHEEL_CLICK;
public:  // actually protected
  ::javax::swing::JScrollPane * __attribute__((aligned(__alignof__( ::javax::swing::plaf::ScrollPaneUI )))) scrollpane;
  ::javax::swing::event::ChangeListener *hsbChangeListener;
  ::javax::swing::event::ChangeListener *vsbChangeListener;
  ::javax::swing::event::ChangeListener *viewportChangeListener;
  ::java::beans::PropertyChangeListener *spPropertyChangeListener;
public: // actually package-private
  ::java::awt::event::MouseWheelListener *mouseWheelListener;
  ::java::awt::event::ContainerListener *containerListener;

  friend class javax_swing_plaf_basic_BasicScrollPaneUI$10;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$9;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$8;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$7;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$6;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$5;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$4;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$3;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$2;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$1;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$ViewportContainerListener;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$MouseWheelHandler;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$PropertyChangeHandler;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$ViewportChangeHandler;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$VSBChangeListener;
  friend class javax_swing_plaf_basic_BasicScrollPaneUI$HSBChangeListener;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicScrollPaneUI__ */
