// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_event_PrintJobListener__
#define __javax_print_event_PrintJobListener__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace event
      {
        class PrintJobListener;
        class PrintJobEvent;
      }
    }
  }
}

class javax::print::event::PrintJobListener : public ::java::lang::Object
{
public:
  virtual void printDataTransferCompleted (::javax::print::event::PrintJobEvent *) = 0;
  virtual void printJobCanceled (::javax::print::event::PrintJobEvent *) = 0;
  virtual void printJobCompleted (::javax::print::event::PrintJobEvent *) = 0;
  virtual void printJobFailed (::javax::print::event::PrintJobEvent *) = 0;
  virtual void printJobNoMoreEvents (::javax::print::event::PrintJobEvent *) = 0;
  virtual void printJobRequiresAttention (::javax::print::event::PrintJobEvent *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_print_event_PrintJobListener__ */
