// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_net_ssl_X509TrustManager__
#define __javax_net_ssl_X509TrustManager__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class X509TrustManager;
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class X509Certificate;
      }
    }
  }
}

class javax::net::ssl::X509TrustManager : public ::java::lang::Object
{
public:
  virtual void checkClientTrusted (JArray< ::java::security::cert::X509Certificate *> *, ::java::lang::String *) = 0;
  virtual void checkServerTrusted (JArray< ::java::security::cert::X509Certificate *> *, ::java::lang::String *) = 0;
  virtual JArray< ::java::security::cert::X509Certificate *> *getAcceptedIssuers () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_net_ssl_X509TrustManager__ */
