// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Signature__
#define __gnu_javax_net_ssl_provider_Signature__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class PublicKey;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class ProtocolVersion;
            class Signature;
            class CipherSuite;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Signature : public ::java::lang::Object
{
public: // actually package-private
  Signature (::java::lang::Object *, ::java::lang::String *);
  static ::gnu::javax::net::ssl::provider::Signature *read (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::CipherSuite *, ::java::security::PublicKey *);
public:
  virtual void write (::java::io::OutputStream *);
  virtual void write (::java::io::OutputStream *, ::gnu::javax::net::ssl::provider::ProtocolVersion *);
public: // actually package-private
  virtual ::java::lang::Object *getSigValue () { return sigValue; }
  virtual ::java::lang::String *getSigAlg () { return sigAlg; }
public:
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::Object * __attribute__((aligned(__alignof__( ::java::lang::Object )))) sigValue;
  ::java::lang::String *sigAlg;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Signature__ */
