// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_synth_SynthContext__
#define __javax_swing_plaf_synth_SynthContext__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace synth
        {
          class SynthContext;
          class SynthStyle;
          class Region;
        }
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::synth::SynthContext : public ::java::lang::Object
{
public:
  SynthContext (::javax::swing::JComponent *, ::javax::swing::plaf::synth::Region *, ::javax::swing::plaf::synth::SynthStyle *, jint);
  virtual ::javax::swing::JComponent *getComponent () { return component; }
  virtual ::javax::swing::plaf::synth::Region *getRegion () { return region; }
  virtual ::javax::swing::plaf::synth::SynthStyle *getStyle () { return style; }
  virtual jint getComponentState () { return state; }
private:
  ::javax::swing::JComponent * __attribute__((aligned(__alignof__( ::java::lang::Object )))) component;
  ::javax::swing::plaf::synth::Region *region;
  ::javax::swing::plaf::synth::SynthStyle *style;
  jint state;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_synth_SynthContext__ */
