// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_crammd5_CramMD5AuthInfoProvider__
#define __gnu_javax_crypto_sasl_crammd5_CramMD5AuthInfoProvider__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace crammd5
          {
            class CramMD5AuthInfoProvider;
            class PasswordFile;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::crammd5::CramMD5AuthInfoProvider : public ::java::lang::Object
{
public:
  virtual void activate (::java::util::Map *);
  virtual void passivate ();
  virtual jboolean contains (::java::lang::String *);
  virtual ::java::util::Map *lookup (::java::util::Map *);
  virtual void update (::java::util::Map *);
  virtual ::java::util::Map *getConfiguration (::java::lang::String *);
  CramMD5AuthInfoProvider ();
private:
  ::gnu::javax::crypto::sasl::crammd5::PasswordFile * __attribute__((aligned(__alignof__( ::java::lang::Object )))) passwordFile;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_crammd5_CramMD5AuthInfoProvider__ */
