// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_midi_VoiceStatus__
#define __javax_sound_midi_VoiceStatus__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace midi
      {
        class VoiceStatus;
      }
    }
  }
}

class javax::sound::midi::VoiceStatus : public ::java::lang::Object
{
public:
  VoiceStatus ();
  jboolean __attribute__((aligned(__alignof__( ::java::lang::Object ))))  active;
  jint channel;
  jint bank;
  jint program;
  jint note;
  jint volume;

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_midi_VoiceStatus__ */
