// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_EnvelopeEntry__
#define __gnu_javax_crypto_keyring_EnvelopeEntry__

#pragma interface

#include <gnu/javax/crypto/keyring/Entry.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class Entry;
          class Properties;
          class EnvelopeEntry;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::EnvelopeEntry : public ::gnu::javax::crypto::keyring::Entry
{
public:
  EnvelopeEntry (jint, ::gnu::javax::crypto::keyring::Properties *);
public:  // actually protected
  EnvelopeEntry (jint);
public:
  virtual void add (::gnu::javax::crypto::keyring::Entry *);
  virtual jboolean containsAlias (::java::lang::String *);
  virtual jboolean containsEntry (::gnu::javax::crypto::keyring::Entry *);
  virtual ::java::util::List *getEntries ();
  virtual ::java::util::List *get (::java::lang::String *);
  virtual ::java::lang::String *getAliasList ();
  virtual jboolean remove (::gnu::javax::crypto::keyring::Entry *);
  virtual jboolean remove (::java::lang::String *);
  virtual ::java::lang::String *toString ();
public:  // actually protected
  virtual void encodePayload ();
  virtual void setContainingEnvelope (::gnu::javax::crypto::keyring::EnvelopeEntry *);
  virtual void decodeEnvelope (::java::io::DataInputStream *);
private:
  void makeAliasList ();
  static ::java::util::logging::Logger *log;
public:  // actually protected
  ::gnu::javax::crypto::keyring::EnvelopeEntry * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::keyring::Entry )))) containingEnvelope;
  ::java::util::List *entries;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_EnvelopeEntry__ */
