// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_parser_support_low_Constants__
#define __gnu_javax_swing_text_html_parser_support_low_Constants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace parser
            {
              namespace support
              {
                namespace low
                {
                  class Constants;
                  class Token;
                  class Buffer;
                  class pattern;
                }
              }
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::parser::support::low::Constants : public ::java::lang::Object
{
public:
  virtual ::gnu::javax::swing::text::html::parser::support::low::Token *endMatches (::gnu::javax::swing::text::html::parser::support::low::Buffer *);
  Constants ();
  static const jint BEGIN = 60L;
  static const jint END = 62L;
  static const jint EXCLAMATION = 33L;
  static const jint SLASH = 47L;
  static const jint EQ = 61L;
  static const jint AP = 39L;
  static const jint QUOT = 34L;
  static const jint DOUBLE_DASH = 1000L;
  static const jint STYLE = 1001L;
  static const jint SCRIPT = 1002L;
  static const jint WS = 1003L;
  static const jint ENTITY = 1004L;
  static const jint NUMTOKEN = 1005L;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *COMMENT_OPEN;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *COMMENT_END;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *COMMENT_TRIPLEDASH_END;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *STYLE_OPEN;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *SCRIPT_OPEN;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *SGML;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *SCRIPT_CLOSE;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *STYLE_CLOSE;
  static ::gnu::javax::swing::text::html::parser::support::low::pattern *TAG;
  static const jint OTHER = 1999L;
public: // actually package-private
  static const jint ETX = 3L;
public:
  static const jint EOF = 3L;
  static ::java::util::BitSet *bSINGLE_CHAR_TOKEN;
  static ::java::util::BitSet *bSPECIAL;
  static ::java::util::BitSet *bLETTER;
  static ::java::util::BitSet *bDIGIT;
  static ::java::util::BitSet *bLINEBREAK;
  static ::java::util::BitSet *bWHITESPACE;
  static ::java::util::BitSet *bQUOTING;
  static ::java::util::BitSet *bNAME;
  static const jint ENTITY_NAMED = 1L;
  static const jint ENTITY_NUMERIC = 2L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_text_html_parser_support_low_Constants__ */
