// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_rtf_RTFParser__
#define __javax_swing_text_rtf_RTFParser__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class Document;
        namespace rtf
        {
          class RTFParser;
          class RTFScanner;
        }
      }
    }
  }
}

class javax::swing::text::rtf::RTFParser : public ::java::lang::Object
{
private:
  RTFParser (::javax::swing::text::Document *, jint);
public:
  RTFParser (::java::io::InputStream *, ::javax::swing::text::Document *, jint);
  RTFParser (::java::io::Reader *, ::javax::swing::text::Document *, jint);
  virtual ::javax::swing::text::Document *getDocument () { return doc; }
  virtual void parse ();
private:
  void parseFile ();
  void parseHeader () { }
  void parseDocument ();
  ::javax::swing::text::rtf::RTFScanner * __attribute__((aligned(__alignof__( ::java::lang::Object )))) scanner;
  ::javax::swing::text::Document *doc;
  jint pos;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_rtf_RTFParser__ */
