// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_Doc__
#define __javax_print_Doc__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class Doc;
      class DocFlavor;
      namespace attribute
      {
        class DocAttributeSet;
      }
    }
  }
}

class javax::print::Doc : public ::java::lang::Object
{
public:
  virtual ::javax::print::attribute::DocAttributeSet *getAttributes () = 0;
  virtual ::javax::print::DocFlavor *getDocFlavor () = 0;
  virtual ::java::lang::Object *getPrintData () = 0;
  virtual ::java::io::Reader *getReaderForText () = 0;
  virtual ::java::io::InputStream *getStreamForBytes () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_print_Doc__ */
