// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_ElementIterator__
#define __javax_swing_text_ElementIterator__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class ElementIterator;
        class Document;
        class Element;
      }
    }
  }
}

class javax::swing::text::ElementIterator : public ::java::lang::Object
{
public:
  ElementIterator (::javax::swing::text::Document *);
  ElementIterator (::javax::swing::text::Element *);
  virtual ::java::lang::Object *clone ();
  virtual ::javax::swing::text::Element *current () { return currentElement; }
  virtual jint depth () { return currentDepth; }
  virtual ::javax::swing::text::Element *first ();
  virtual ::javax::swing::text::Element *next ();
  virtual ::javax::swing::text::Element *previous ();
private:
  ::javax::swing::text::Element * __attribute__((aligned(__alignof__( ::java::lang::Object )))) root;
  ::javax::swing::text::Element *currentElement;
  jint currentDepth;
  jintArray state;
  ::javax::swing::text::Element *previousItem;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_ElementIterator__ */
