// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_openmbean_SimpleType__
#define __javax_management_openmbean_SimpleType__

#pragma interface

#include <javax/management/openmbean/OpenType.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      namespace openmbean
      {
        class SimpleType;
      }
    }
  }
}

class javax::management::openmbean::SimpleType : public ::javax::management::openmbean::OpenType
{
private:
  SimpleType (::java::lang::String *);
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual jboolean isValue (::java::lang::Object *);
  virtual ::java::lang::Object *readResolve ();
  virtual ::java::lang::String *toString ();
  static ::javax::management::openmbean::SimpleType *BIGDECIMAL;
  static ::javax::management::openmbean::SimpleType *BIGINTEGER;
  static ::javax::management::openmbean::SimpleType *BOOLEAN;
  static ::javax::management::openmbean::SimpleType *BYTE;
  static ::javax::management::openmbean::SimpleType *CHARACTER;
  static ::javax::management::openmbean::SimpleType *DATE;
  static ::javax::management::openmbean::SimpleType *DOUBLE;
  static ::javax::management::openmbean::SimpleType *FLOAT;
  static ::javax::management::openmbean::SimpleType *INTEGER;
  static ::javax::management::openmbean::SimpleType *LONG;
  static ::javax::management::openmbean::SimpleType *OBJECTNAME;
  static ::javax::management::openmbean::SimpleType *SHORT;
  static ::javax::management::openmbean::SimpleType *STRING;
  static ::javax::management::openmbean::SimpleType *VOID;
private:
  static const jlong serialVersionUID = 2215577471957694503LL;
  ::java::lang::Integer * __attribute__((aligned(__alignof__( ::javax::management::openmbean::OpenType )))) hashCode__;
  ::java::lang::String *string;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_openmbean_SimpleType__ */
