// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_id_ArrayReferenceTypeId__
#define __gnu_classpath_jdwp_id_ArrayReferenceTypeId__

#pragma interface

#include <gnu/classpath/jdwp/id/ReferenceTypeId.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        namespace id
        {
          class ArrayReferenceTypeId;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::id::ArrayReferenceTypeId : public ::gnu::classpath::jdwp::id::ReferenceTypeId
{
public:
  ArrayReferenceTypeId ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_id_ArrayReferenceTypeId__ */
