// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_VMInetAddress__
#define __java_net_VMInetAddress__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class VMInetAddress;
    }
  }
}

class java::net::VMInetAddress : public ::java::lang::Object
{
public:
  static ::java::lang::String *getLocalHostname ();
  static jbyteArray lookupInaddrAny ();
  static ::java::lang::String *getHostByAddr (jbyteArray);
  static JArray<jbyteArray> * getHostByName (::java::lang::String *);
  static jbyteArray aton (::java::lang::String *);
public: // actually package-private
  VMInetAddress ();
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_VMInetAddress__ */
