// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_ComponentView__
#define __javax_swing_text_ComponentView__

#pragma interface

#include <javax/swing/text/View.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class ComponentView;
        class View;
        class Position$Bias;
        class Element;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Shape;
      class Component;
    }
  }
}

class javax::swing::text::ComponentView : public ::javax::swing::text::View
{
public:
  ComponentView (::javax::swing::text::Element *);
public:  // actually protected
  virtual ::java::awt::Component *createComponent ();
public:
  virtual jfloat getAlignment (jint);
  virtual ::java::awt::Component *getComponent ();
  virtual jfloat getMaximumSpan (jint);
  virtual jfloat getMinimumSpan (jint);
  virtual jfloat getPreferredSpan (jint);
  virtual ::java::awt::Shape *modelToView (jint, ::java::awt::Shape *, ::javax::swing::text::Position$Bias *);
  virtual void paint (::java::awt::Graphics *, ::java::awt::Shape *);
  virtual void setParent (::javax::swing::text::View *);
private:
  void setParentImpl (::javax::swing::text::View *);
public:
  virtual jint viewToModel (jfloat, jfloat, ::java::awt::Shape *, JArray< ::javax::swing::text::Position$Bias *> *);
private:
  ::java::awt::Component * __attribute__((aligned(__alignof__( ::javax::swing::text::View )))) comp;

  friend class javax_swing_text_ComponentView$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_ComponentView__ */
