// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_ActionEvent__
#define __java_awt_event_ActionEvent__

#pragma interface

#include <java/awt/AWTEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class ActionEvent;
      }
    }
  }
}

class java::awt::event::ActionEvent : public ::java::awt::AWTEvent
{
public:
  ActionEvent (::java::lang::Object *, jint, ::java::lang::String *);
  ActionEvent (::java::lang::Object *, jint, ::java::lang::String *, jint);
  ActionEvent (::java::lang::Object *, jint, ::java::lang::String *, jlong, jint);
  virtual ::java::lang::String *getActionCommand () { return actionCommand; }
  virtual jlong getWhen () { return when; }
  virtual jint getModifiers () { return modifiers; }
  virtual ::java::lang::String *paramString ();
private:
  static const jlong serialVersionUID = -7671078796273832149LL;
public:
  static const jint SHIFT_MASK = 1L;
  static const jint CTRL_MASK = 2L;
  static const jint META_MASK = 4L;
  static const jint ALT_MASK = 8L;
  static const jint ACTION_FIRST = 1001L;
  static const jint ACTION_LAST = 1001L;
  static const jint ACTION_PERFORMED = 1001L;
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::awt::AWTEvent )))) actionCommand;
  jint modifiers;
  jlong when;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_ActionEvent__ */
