// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_png_PNGException__
#define __gnu_javax_imageio_png_PNGException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace png
        {
          class PNGException;
        }
      }
    }
  }
}

class gnu::javax::imageio::png::PNGException : public ::java::io::IOException
{
public:
  PNGException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_png_PNGException__ */
