// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_UnknownError__
#define __java_lang_UnknownError__

#pragma interface

#include <java/lang/VirtualMachineError.h>

class java::lang::UnknownError : public ::java::lang::VirtualMachineError
{
public:
  UnknownError ();
  UnknownError (::java::lang::String *);
private:
  static const jlong serialVersionUID = 2524784860676771849LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_UnknownError__ */
