// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_peer_ScrollPanePeer__
#define __java_awt_peer_ScrollPanePeer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace peer
      {
        class ScrollPanePeer;
      }
      class Adjustable;
    }
  }
}

class java::awt::peer::ScrollPanePeer : public ::java::lang::Object
{
public:
  virtual jint getHScrollbarHeight () = 0;
  virtual jint getVScrollbarWidth () = 0;
  virtual void setScrollPosition (jint, jint) = 0;
  virtual void childResized (jint, jint) = 0;
  virtual void setUnitIncrement (::java::awt::Adjustable *, jint) = 0;
  virtual void setValue (::java::awt::Adjustable *, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_peer_ScrollPanePeer__ */
