// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_FileReader__
#define __java_io_FileReader__

#pragma interface

#include <java/io/InputStreamReader.h>

class java::io::FileReader : public ::java::io::InputStreamReader
{
public:
  FileReader (::java::io::File *);
  FileReader (::java::io::FileDescriptor *);
  FileReader (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_io_FileReader__ */
