// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_interfaces_PBEKey__
#define __javax_crypto_interfaces_PBEKey__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      namespace interfaces
      {
        class PBEKey;
      }
    }
  }
}

class javax::crypto::interfaces::PBEKey : public ::java::lang::Object
{
public:
  virtual jint getIterationCount () = 0;
  virtual jcharArray getPassword () = 0;
  virtual jbyteArray getSalt () = 0;
  static const jlong serialVersionUID = -1430015993304333921LL;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_crypto_interfaces_PBEKey__ */
