// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_AWTError__
#define __java_awt_AWTError__

#pragma interface

#include <java/lang/Error.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class AWTError;
    }
  }
}

class java::awt::AWTError : public ::java::lang::Error
{
public:
  AWTError (::java::lang::String *);
private:
  static const jlong serialVersionUID = -1819846354050686206LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_AWTError__ */
