// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_plaf_gnu_GNULookAndFeel__
#define __gnu_javax_swing_plaf_gnu_GNULookAndFeel__

#pragma interface

#include <javax/swing/plaf/basic/BasicLookAndFeel.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace plaf
        {
          namespace gnu
          {
            class GNULookAndFeel;
          }
        }
      }
    }
  }
  namespace javax
  {
    namespace swing
    {
      class UIDefaults;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Color;
    }
  }
}

class gnu::javax::swing::plaf::gnu::GNULookAndFeel : public ::javax::swing::plaf::basic::BasicLookAndFeel
{
public:
  virtual jboolean isNativeLookAndFeel ();
  virtual jboolean isSupportedLookAndFeel ();
  virtual ::java::lang::String *getDescription ();
  virtual ::java::lang::String *getID ();
  virtual ::java::lang::String *getName ();
  virtual ::javax::swing::UIDefaults *getDefaults ();
  GNULookAndFeel ();
public: // actually package-private
  static ::java::awt::Color *blueGray;
  static ::javax::swing::UIDefaults *LAF_defaults;
private:
  static ::java::lang::String *iconspath;

  friend class gnu_javax_swing_plaf_gnu_GNULookAndFeel$RadioButtonIcon;
  friend class gnu_javax_swing_plaf_gnu_GNULookAndFeel$CheckBoxIcon;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_swing_plaf_gnu_GNULookAndFeel__ */
