// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_AttributeList__
#define __javax_management_AttributeList__

#pragma interface

#include <java/util/ArrayList.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      class Attribute;
      class AttributeList;
    }
  }
}

class javax::management::AttributeList : public ::java::util::ArrayList
{
public:
  AttributeList ();
  AttributeList (::javax::management::AttributeList *);
  AttributeList (jint);
  virtual void add (::javax::management::Attribute *);
  virtual void add (jint, ::javax::management::Attribute *);
  virtual jboolean addAll (::javax::management::AttributeList *);
  virtual jboolean addAll (jint, ::javax::management::AttributeList *);
  virtual void set (jint, ::javax::management::Attribute *);
private:
  static const jlong serialVersionUID = -4077085769279709076LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_AttributeList__ */
