// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_IconView__
#define __javax_swing_text_IconView__

#pragma interface

#include <javax/swing/text/View.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Shape;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class IconView;
        class Position$Bias;
        class Element;
      }
    }
  }
}

class javax::swing::text::IconView : public ::javax::swing::text::View
{
public:
  IconView (::javax::swing::text::Element *);
  virtual void paint (::java::awt::Graphics *, ::java::awt::Shape *);
  virtual jfloat getPreferredSpan (jint);
  virtual ::java::awt::Shape *modelToView (jint, ::java::awt::Shape *, ::javax::swing::text::Position$Bias *);
  virtual jint viewToModel (jfloat, jfloat, ::java::awt::Shape *, JArray< ::javax::swing::text::Position$Bias *> *);
  virtual jfloat getAlignment (jint);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_IconView__ */
