// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_srp6_SRPKey__
#define __gnu_javax_crypto_key_srp6_SRPKey__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          namespace srp6
          {
            class SRPKey;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::key::srp6::SRPKey : public ::java::lang::Object
{
public:  // actually protected
  SRPKey (::java::math::BigInteger *, ::java::math::BigInteger *);
public:
  virtual ::java::lang::String *getAlgorithm ();
  virtual jbyteArray getEncoded ();
  virtual ::java::lang::String *getFormat ();
  virtual ::java::math::BigInteger *getN () { return N; }
  virtual ::java::math::BigInteger *getG () { return g; }
  virtual jboolean equals (::java::lang::Object *);
  virtual jbyteArray getEncoded (jint) = 0;
public:  // actually protected
  ::java::math::BigInteger * __attribute__((aligned(__alignof__( ::java::lang::Object )))) N;
  ::java::math::BigInteger *g;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_key_srp6_SRPKey__ */
