// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_print_Pageable__
#define __java_awt_print_Pageable__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace print
      {
        class Pageable;
        class Printable;
        class PageFormat;
      }
    }
  }
}

class java::awt::print::Pageable : public ::java::lang::Object
{
public:
  virtual jint getNumberOfPages () = 0;
  virtual ::java::awt::print::PageFormat *getPageFormat (jint) = 0;
  virtual ::java::awt::print::Printable *getPrintable (jint) = 0;
  static const jint UNKNOWN_NUMBER_OF_PAGES = -1L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_print_Pageable__ */
