// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Number__
#define __java_lang_Number__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::lang::Number : public ::java::lang::Object
{
public:
  Number ();
  virtual jint intValue () = 0;
  virtual jlong longValue () = 0;
  virtual jfloat floatValue () = 0;
  virtual jdouble doubleValue () = 0;
  virtual jbyte byteValue ();
  virtual jshort shortValue ();
private:
  static const jlong serialVersionUID = -8742448824652078965LL;
public: // actually package-private
  static jcharArray digits;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Number__ */
