// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_srp6_SRP6SaslClient__
#define __gnu_javax_crypto_key_srp6_SRP6SaslClient__

#pragma interface

#include <gnu/javax/crypto/key/srp6/SRP6TLSClient.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          namespace srp6
          {
            class SRP6SaslClient;
          }
          class OutgoingMessage;
          class IncomingMessage;
        }
      }
    }
  }
}

class gnu::javax::crypto::key::srp6::SRP6SaslClient : public ::gnu::javax::crypto::key::srp6::SRP6TLSClient
{
public:  // actually protected
  virtual ::gnu::javax::crypto::key::OutgoingMessage *computeSharedSecret (::gnu::javax::crypto::key::IncomingMessage *);
public:
  SRP6SaslClient ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_key_srp6_SRP6SaslClient__ */
