// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_midi_MidiDevice__
#define __javax_sound_midi_MidiDevice__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace midi
      {
        class MidiDevice;
        class Transmitter;
        class Receiver;
        class MidiDevice$Info;
      }
    }
  }
}

class javax::sound::midi::MidiDevice : public ::java::lang::Object
{
public:
  virtual ::javax::sound::midi::MidiDevice$Info *getDeviceInfo () = 0;
  virtual void open () = 0;
  virtual void close () = 0;
  virtual jboolean isOpen () = 0;
  virtual jlong getMicrosecondPosition () = 0;
  virtual jint getMaxReceivers () = 0;
  virtual jint getMaxTransmitters () = 0;
  virtual ::javax::sound::midi::Receiver *getReceiver () = 0;
  virtual ::javax::sound::midi::Transmitter *getTransmitter () = 0;

  friend class javax_sound_midi_MidiDevice$Info;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_sound_midi_MidiDevice__ */
