// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_openmbean_OpenDataException__
#define __javax_management_openmbean_OpenDataException__

#pragma interface

#include <javax/management/JMException.h>

extern "Java"
{
  namespace javax
  {
    namespace management
    {
      namespace openmbean
      {
        class OpenDataException;
      }
    }
  }
}

class javax::management::openmbean::OpenDataException : public ::javax::management::JMException
{
public:
  OpenDataException ();
  OpenDataException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 8346311255433349870LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_management_openmbean_OpenDataException__ */
