// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalIconFactory__
#define __javax_swing_plaf_metal_MetalIconFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalIconFactory;
          class MetalIconFactory$RadioButtonIcon;
        }
      }
      class Icon;
    }
  }
}

class javax::swing::plaf::metal::MetalIconFactory : public ::java::lang::Object
{
public:
  MetalIconFactory ();
  static ::javax::swing::Icon *getCheckBoxIcon ();
  static ::javax::swing::Icon *getCheckBoxMenuItemIcon ();
  static ::javax::swing::Icon *getFileChooserDetailViewIcon ();
  static ::javax::swing::Icon *getFileChooserHomeFolderIcon ();
  static ::javax::swing::Icon *getFileChooserListViewIcon ();
  static ::javax::swing::Icon *getFileChooserNewFolderIcon ();
  static ::javax::swing::Icon *getFileChooserUpFolderIcon ();
  static ::javax::swing::Icon *getRadioButtonIcon ();
  static ::javax::swing::Icon *getRadioButtonMenuItemIcon ();
  static ::javax::swing::Icon *getHorizontalSliderThumbIcon ();
  static ::javax::swing::Icon *getInternalFrameCloseIcon (jint);
  static ::javax::swing::Icon *getInternalFrameDefaultMenuIcon ();
  static ::javax::swing::Icon *getInternalFrameMaximizeIcon (jint);
  static ::javax::swing::Icon *getInternalFrameMinimizeIcon (jint);
  static ::javax::swing::Icon *getInternalFrameAltMaximizeIcon (jint);
  static ::javax::swing::Icon *getVerticalSliderThumbIcon ();
  static ::javax::swing::Icon *getTreeFolderIcon ();
  static ::javax::swing::Icon *getTreeLeafIcon ();
  static ::javax::swing::Icon *getTreeControlIcon (jboolean);
  static ::javax::swing::Icon *getTreeComputerIcon ();
  static ::javax::swing::Icon *getTreeFloppyDriveIcon ();
  static ::javax::swing::Icon *getTreeHardDriveIcon ();
  static ::javax::swing::Icon *getMenuArrowIcon ();
  static ::javax::swing::Icon *getMenuItemArrowIcon ();
  static ::javax::swing::Icon *getMenuItemCheckIcon ();
  static const jint DARK = 0L;
  static const jint LIGHT = 1L;
private:
  static ::javax::swing::Icon *menuArrow;
  static ::javax::swing::Icon *menuItemArrow;
  static ::javax::swing::Icon *checkBoxIcon;
  static ::javax::swing::Icon *checkBoxMenuItemIcon;
  static ::javax::swing::Icon *fileChooserDetailViewIcon;
  static ::javax::swing::Icon *fileChooserHomeFolderIcon;
  static ::javax::swing::Icon *fileChooserListViewIcon;
  static ::javax::swing::Icon *fileChooserNewFolderIcon;
  static ::javax::swing::Icon *fileChooserUpFolderIcon;
  static ::javax::swing::plaf::metal::MetalIconFactory$RadioButtonIcon *radioButtonIcon;
  static ::javax::swing::Icon *radioButtonMenuItemIcon;
  static ::javax::swing::Icon *internalFrameDefaultMenuIcon;
  static ::javax::swing::Icon *treeComputerIcon;
  static ::javax::swing::Icon *treeFloppyDriveIcon;
  static ::javax::swing::Icon *treeHardDriveIcon;
  static ::javax::swing::Icon *horizontalSliderThumbIcon;
  static ::javax::swing::Icon *verticalSliderThumbIcon;

  friend class javax_swing_plaf_metal_MetalIconFactory$3;
  friend class javax_swing_plaf_metal_MetalIconFactory$2;
  friend class javax_swing_plaf_metal_MetalIconFactory$1;
  friend class javax_swing_plaf_metal_MetalIconFactory$TreeComputerIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$TreeFloppyDriveIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$TreeHardDriveIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$TreeLeafIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$TreeFolderIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$TreeControlIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$VerticalSliderThumbIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$InternalFrameMinimizeIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$InternalFrameMaximizeIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$InternalFrameAltMaximizeIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$InternalFrameDefaultMenuIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$InternalFrameCloseIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$HorizontalSliderThumbIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$RadioButtonMenuItemIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$RadioButtonIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$PaletteCloseIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$FolderIcon16;
  friend class javax_swing_plaf_metal_MetalIconFactory$FileIcon16;
  friend class javax_swing_plaf_metal_MetalIconFactory$FileChooserUpFolderIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$FileChooserNewFolderIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$FileChooserListViewIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$FileChooserHomeFolderIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$FileChooserDetailViewIcon;
  friend class javax_swing_plaf_metal_MetalIconFactory$CheckBoxMenuItemIcon;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalIconFactory__ */
