// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_transaction_Transaction__
#define __javax_transaction_Transaction__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace transaction
    {
      class Transaction;
      class Synchronization;
      namespace xa
      {
        class XAResource;
      }
    }
  }
}

class javax::transaction::Transaction : public ::java::lang::Object
{
public:
  virtual void commit () = 0;
  virtual jboolean delistResource (::javax::transaction::xa::XAResource *, jint) = 0;
  virtual jboolean enlistResource (::javax::transaction::xa::XAResource *) = 0;
  virtual jint getStatus () = 0;
  virtual void registerSynchronization (::javax::transaction::Synchronization *) = 0;
  virtual void rollback () = 0;
  virtual void setRollbackOnly () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_transaction_Transaction__ */
