// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_callback_TextOutputCallback__
#define __javax_security_auth_callback_TextOutputCallback__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace callback
        {
          class TextOutputCallback;
        }
      }
    }
  }
}

class javax::security::auth::callback::TextOutputCallback : public ::java::lang::Object
{
public:
  TextOutputCallback (jint, ::java::lang::String *);
  virtual jint getMessageType () { return messageType; }
  virtual ::java::lang::String *getMessage () { return message; }
private:
  void setMessage (::java::lang::String *);
public:
  static const jint INFORMATION = 0L;
  static const jint WARNING = 1L;
  static const jint ERROR = 2L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  messageType;
  ::java::lang::String *message;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_callback_TextOutputCallback__ */
