// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_Inet4Address__
#define __java_net_Inet4Address__

#pragma interface

#include <java/net/InetAddress.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class Inet4Address;
    }
  }
}

class java::net::Inet4Address : public ::java::net::InetAddress
{
private:
  ::java::lang::Object *writeReplace ();
public: // actually package-private
  Inet4Address (jbyteArray, ::java::lang::String *);
public:
  virtual jboolean isMulticastAddress ();
  virtual jboolean isLoopbackAddress ();
  virtual jboolean isAnyLocalAddress ();
  virtual jboolean isLinkLocalAddress ();
  virtual jboolean isSiteLocalAddress ();
  virtual jboolean isMCGlobal ();
  virtual jboolean isMCNodeLocal ();
  virtual jboolean isMCLinkLocal ();
  virtual jboolean isMCSiteLocal ();
  virtual jboolean isMCOrgLocal ();
  virtual jbyteArray getAddress ();
  virtual ::java::lang::String *getHostAddress ();
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
public: // actually package-private
  static const jlong serialVersionUID = 3286316764910316507LL;
private:
  static const jint FAMILY = 2L;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_Inet4Address__ */
