// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_ColorPaintContext__
#define __java_awt_ColorPaintContext__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class ColorPaintContext;
      class ColorPaintContext$ColorRaster;
      namespace image
      {
        class Raster;
        class ColorModel;
      }
    }
  }
}

class java::awt::ColorPaintContext : public ::java::lang::Object
{
public: // actually package-private
  ColorPaintContext (jint);
  ColorPaintContext (::java::awt::image::ColorModel *, jint);
public:
  virtual void dispose () { }
  virtual ::java::awt::image::ColorModel *getColorModel () { return colorModel; }
  virtual ::java::awt::image::Raster *getRaster (jint, jint, jint, jint);
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  color;
  ::java::awt::image::ColorModel *colorModel;
private:
  ::java::awt::ColorPaintContext$ColorRaster *cachedRaster;

  friend class java_awt_ColorPaintContext$ColorRaster;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_ColorPaintContext__ */
