// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_ShortBufferException__
#define __javax_crypto_ShortBufferException__

#pragma interface

#include <java/security/GeneralSecurityException.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      class ShortBufferException;
    }
  }
}

class javax::crypto::ShortBufferException : public ::java::security::GeneralSecurityException
{
public:
  ShortBufferException ();
  ShortBufferException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 8427718640832943747LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_ShortBufferException__ */
