// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JRootPane__
#define __javax_swing_JRootPane__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JRootPane;
      namespace plaf
      {
        class RootPaneUI;
      }
      class Action;
      class JButton;
      class JMenuBar;
      class JLayeredPane;
    }
  }
  namespace java
  {
    namespace awt
    {
      class LayoutManager;
      class Container;
      class Component;
    }
  }
}

class javax::swing::JRootPane : public ::javax::swing::JComponent
{
public:
  virtual void setJMenuBar (::javax::swing::JMenuBar *);
  virtual void setMenuBar (::javax::swing::JMenuBar *);
  virtual ::javax::swing::JMenuBar *getJMenuBar () { return menuBar; }
  virtual ::javax::swing::JMenuBar *getMenuBar ();
  virtual jboolean isValidateRoot ();
  virtual ::java::awt::Container *getContentPane ();
  virtual void setContentPane (::java::awt::Container *);
public:  // actually protected
  virtual void addImpl (::java::awt::Component *, ::java::lang::Object *, jint);
public:
  virtual ::java::awt::Component *getGlassPane ();
  virtual void setGlassPane (::java::awt::Component *);
  virtual ::javax::swing::JLayeredPane *getLayeredPane ();
  virtual void setLayeredPane (::javax::swing::JLayeredPane *);
  JRootPane ();
public:  // actually protected
  virtual ::java::awt::LayoutManager *createRootLayout ();
  virtual ::java::awt::Container *createContentPane ();
  virtual ::java::awt::Component *createGlassPane ();
  virtual ::javax::swing::JLayeredPane *createLayeredPane ();
public:
  virtual ::javax::swing::plaf::RootPaneUI *getUI ();
  virtual void setUI (::javax::swing::plaf::RootPaneUI *);
  virtual void updateUI ();
  virtual ::java::lang::String *getUIClassID ();
  virtual ::javax::swing::JButton *getDefaultButton () { return defaultButton; }
  virtual void setDefaultButton (::javax::swing::JButton *);
  virtual jint getWindowDecorationStyle () { return windowDecorationStyle; }
  virtual void setWindowDecorationStyle (jint);
  virtual jboolean isOptimizedDrawingEnable ();
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = 8690748000348575668LL;
public:
  static const jint NONE = 0L;
  static const jint FRAME = 1L;
  static const jint PLAIN_DIALOG = 2L;
  static const jint INFORMATION_DIALOG = 3L;
  static const jint ERROR_DIALOG = 4L;
  static const jint COLOR_CHOOSER_DIALOG = 5L;
  static const jint FILE_CHOOSER_DIALOG = 6L;
  static const jint QUESTION_DIALOG = 7L;
  static const jint WARNING_DIALOG = 8L;
public:  // actually protected
  ::java::awt::Component * __attribute__((aligned(__alignof__( ::javax::swing::JComponent )))) glassPane;
  ::javax::swing::JLayeredPane *layeredPane;
  ::javax::swing::JMenuBar *menuBar;
  ::java::awt::Container *contentPane;
  ::javax::swing::JButton *defaultButton;
  ::javax::swing::Action *defaultPressAction;
  ::javax::swing::Action *defaultReleaseAction;
private:
  jint windowDecorationStyle;

  friend class javax_swing_JRootPane$RootLayout;
  friend class javax_swing_JRootPane$AccessibleJRootPane;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JRootPane__ */
