// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_OptionalDataException__
#define __java_io_OptionalDataException__

#pragma interface

#include <java/io/ObjectStreamException.h>

class java::io::OptionalDataException : public ::java::io::ObjectStreamException
{
public: // actually package-private
  OptionalDataException (jboolean, jint);
private:
  static const jlong serialVersionUID = -8011121865681257820LL;
public:
  jboolean __attribute__((aligned(__alignof__( ::java::io::ObjectStreamException ))))  eof;
  jint length;

  static ::java::lang::Class class$;
};

#endif /* __java_io_OptionalDataException__ */
