// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_MacSpi__
#define __javax_crypto_MacSpi__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      class MacSpi;
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class Key;
    }
  }
}

class javax::crypto::MacSpi : public ::java::lang::Object
{
public:
  MacSpi ();
  virtual ::java::lang::Object *clone ();
public:  // actually protected
  virtual jbyteArray engineDoFinal () = 0;
  virtual jint engineGetMacLength () = 0;
  virtual void engineInit (::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *) = 0;
  virtual void engineReset () = 0;
  virtual void engineUpdate (jbyte) = 0;
  virtual void engineUpdate (jbyteArray, jint, jint) = 0;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_MacSpi__ */
