// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_ByteChannel__
#define __java_nio_channels_ByteChannel__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class ByteChannel;
      }
    }
  }
}

class java::nio::channels::ByteChannel : public ::java::lang::Object
{
public:

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_nio_channels_ByteChannel__ */
