// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_DefaultFocusTraversalPolicy__
#define __java_awt_DefaultFocusTraversalPolicy__

#pragma interface

#include <java/awt/ContainerOrderFocusTraversalPolicy.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class DefaultFocusTraversalPolicy;
      class Component;
    }
  }
}

class java::awt::DefaultFocusTraversalPolicy : public ::java::awt::ContainerOrderFocusTraversalPolicy
{
public:
  DefaultFocusTraversalPolicy ();
public:  // actually protected
  virtual jboolean accept (::java::awt::Component *);
private:
  static const jlong serialVersionUID = 8876966522510157497LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_DefaultFocusTraversalPolicy__ */
