// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_util_MethodResult__
#define __gnu_classpath_jdwp_util_MethodResult__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        namespace util
        {
          class MethodResult;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::util::MethodResult : public ::java::lang::Object
{
public:
  virtual ::java::lang::Object *getReturnedValue () { return returnedValue; }
  virtual void setReturnedValue (::java::lang::Object *);
  virtual ::java::lang::Exception *getThrownException () { return thrownException; }
  virtual void setThrownException (::java::lang::Exception *);
  MethodResult ();
private:
  ::java::lang::Object * __attribute__((aligned(__alignof__( ::java::lang::Object )))) returnedValue;
  ::java::lang::Exception *thrownException;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_util_MethodResult__ */
