// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_geom_GeneralPath__
#define __java_awt_geom_GeneralPath__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      namespace geom
      {
        class GeneralPath;
        class Rectangle2D;
        class AffineTransform;
        class Point2D;
        class PathIterator;
      }
      class Shape;
    }
  }
}

class java::awt::geom::GeneralPath : public ::java::lang::Object
{
public:
  GeneralPath ();
  GeneralPath (jint);
  GeneralPath (jint, jint);
  GeneralPath (::java::awt::Shape *);
  virtual void moveTo (jfloat, jfloat);
  virtual void lineTo (jfloat, jfloat);
  virtual void quadTo (jfloat, jfloat, jfloat, jfloat);
  virtual void curveTo (jfloat, jfloat, jfloat, jfloat, jfloat, jfloat);
  virtual void closePath ();
  virtual void append (::java::awt::Shape *, jboolean);
  virtual void append (::java::awt::geom::PathIterator *, jboolean);
  virtual jint getWindingRule () { return rule; }
  virtual void setWindingRule (jint);
  virtual ::java::awt::geom::Point2D *getCurrentPoint ();
  virtual void reset ();
  virtual void transform (::java::awt::geom::AffineTransform *);
  virtual ::java::awt::Shape *createTransformedShape (::java::awt::geom::AffineTransform *);
  virtual ::java::awt::Rectangle *getBounds ();
  virtual ::java::awt::geom::Rectangle2D *getBounds2D ();
  virtual jboolean contains (jdouble, jdouble);
  virtual jboolean contains (::java::awt::geom::Point2D *);
  virtual jboolean contains (jdouble, jdouble, jdouble, jdouble);
  virtual jboolean contains (::java::awt::geom::Rectangle2D *);
  virtual jboolean intersects (jdouble, jdouble, jdouble, jdouble);
  virtual jboolean intersects (::java::awt::geom::Rectangle2D *);
  virtual ::java::awt::geom::PathIterator *getPathIterator (::java::awt::geom::AffineTransform *);
  virtual ::java::awt::geom::PathIterator *getPathIterator (::java::awt::geom::AffineTransform *, jdouble);
  virtual ::java::lang::Object *clone ();
private:
  void ensureSize (jint);
  jint getAxisIntersections (jdouble, jdouble, jboolean, jdouble);
  jint getWindingNumber (jdouble, jdouble);
  jint evaluateCrossings (jdouble, jdouble, jboolean, jboolean, jdouble);
public:
  static const jint WIND_EVEN_ODD = 0L;
  static const jint WIND_NON_ZERO = 1L;
private:
  static const jint INIT_SIZE = 10L;
  static const jdouble BIG_VALUE;
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  rule;
  jbyteArray types;
  jfloatArray xpoints;
  jfloatArray ypoints;
private:
  jint subpath;
public: // actually package-private
  jint index;

  friend class java_awt_geom_GeneralPath$GeneralPathIterator;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_geom_GeneralPath__ */
