// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_DeleteFileHelper__
#define __java_io_DeleteFileHelper__

#pragma interface

#include <java/lang/Thread.h>

class java::io::DeleteFileHelper : public ::java::lang::Thread
{
public: // actually package-private
  static void add (::java::io::File *);
private:
  static void deleteFiles ();
public: // actually package-private
  DeleteFileHelper ();
public:
  virtual void run ();
private:
  static ::java::util::ArrayList *filesToDelete;

  friend class java_io_DeleteFileHelper$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_DeleteFileHelper__ */
