// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalLookAndFeel__
#define __javax_swing_plaf_metal_MetalLookAndFeel__

#pragma interface

#include <javax/swing/plaf/basic/BasicLookAndFeel.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class UIDefaults;
      namespace plaf
      {
        class FontUIResource;
        class ColorUIResource;
        namespace metal
        {
          class MetalLookAndFeel;
          class MetalTheme;
        }
      }
    }
  }
}

class javax::swing::plaf::metal::MetalLookAndFeel : public ::javax::swing::plaf::basic::BasicLookAndFeel
{
public:
  MetalLookAndFeel ();
public:  // actually protected
  virtual void createDefaultTheme ();
public:
  virtual jboolean isNativeLookAndFeel ();
  virtual jboolean isSupportedLookAndFeel ();
  virtual ::java::lang::String *getDescription ();
  virtual ::java::lang::String *getID ();
  virtual ::java::lang::String *getName ();
  virtual ::javax::swing::UIDefaults *getDefaults ();
  static ::javax::swing::plaf::ColorUIResource *getAcceleratorForeground ();
  static ::javax::swing::plaf::ColorUIResource *getAcceleratorSelectedForeground ();
  static ::javax::swing::plaf::ColorUIResource *getBlack ();
  static ::javax::swing::plaf::ColorUIResource *getControl ();
  static ::javax::swing::plaf::ColorUIResource *getControlDarkShadow ();
  static ::javax::swing::plaf::ColorUIResource *getControlDisabled ();
  static ::javax::swing::plaf::ColorUIResource *getControlHighlight ();
  static ::javax::swing::plaf::ColorUIResource *getControlInfo ();
  static ::javax::swing::plaf::ColorUIResource *getControlShadow ();
  static ::javax::swing::plaf::ColorUIResource *getControlTextColor ();
  static ::javax::swing::plaf::FontUIResource *getControlTextFont ();
  static ::javax::swing::plaf::ColorUIResource *getDesktopColor ();
  static ::javax::swing::plaf::ColorUIResource *getFocusColor ();
  static ::javax::swing::plaf::ColorUIResource *getHighlightedTextColor ();
  static ::javax::swing::plaf::ColorUIResource *getInactiveControlTextColor ();
  static ::javax::swing::plaf::ColorUIResource *getInactiveSystemTextColor ();
  static ::javax::swing::plaf::ColorUIResource *getMenuBackground ();
  static ::javax::swing::plaf::ColorUIResource *getMenuDisabledForeground ();
  static ::javax::swing::plaf::ColorUIResource *getMenuForeground ();
  static ::javax::swing::plaf::ColorUIResource *getMenuSelectedBackground ();
  static ::javax::swing::plaf::ColorUIResource *getMenuSelectedForeground ();
  static ::javax::swing::plaf::FontUIResource *getMenuTextFont ();
  static ::javax::swing::plaf::ColorUIResource *getPrimaryControl ();
  static ::javax::swing::plaf::ColorUIResource *getPrimaryControlDarkShadow ();
  static ::javax::swing::plaf::ColorUIResource *getPrimaryControlHighlight ();
  static ::javax::swing::plaf::ColorUIResource *getPrimaryControlInfo ();
  static ::javax::swing::plaf::ColorUIResource *getPrimaryControlShadow ();
  static ::javax::swing::plaf::ColorUIResource *getSeparatorBackground ();
  static ::javax::swing::plaf::ColorUIResource *getSeparatorForeground ();
  static ::javax::swing::plaf::FontUIResource *getSubTextFont ();
  static ::javax::swing::plaf::ColorUIResource *getSystemTextColor ();
  static ::javax::swing::plaf::FontUIResource *getSystemTextFont ();
  static ::javax::swing::plaf::ColorUIResource *getTextHighlightColor ();
  static ::javax::swing::plaf::ColorUIResource *getUserTextColor ();
  static ::javax::swing::plaf::FontUIResource *getUserTextFont ();
  static ::javax::swing::plaf::ColorUIResource *getWhite ();
  static ::javax::swing::plaf::ColorUIResource *getWindowBackground ();
  static ::javax::swing::plaf::ColorUIResource *getWindowTitleBackground ();
  static ::javax::swing::plaf::FontUIResource *getWindowTitleFont ();
  static ::javax::swing::plaf::ColorUIResource *getWindowTitleForeground ();
  static ::javax::swing::plaf::ColorUIResource *getWindowTitleInactiveBackground ();
  static ::javax::swing::plaf::ColorUIResource *getWindowTitleInactiveForeground ();
  static void setCurrentTheme (::javax::swing::plaf::metal::MetalTheme *);
public:  // actually protected
  virtual void initClassDefaults (::javax::swing::UIDefaults *);
  virtual void initComponentDefaults (::javax::swing::UIDefaults *);
  virtual void initSystemColorDefaults (::javax::swing::UIDefaults *);
public:
  static ::javax::swing::plaf::metal::MetalTheme *getCurrentTheme ();
  virtual jboolean getSupportsWindowDecorations ();
private:
  static const jlong serialVersionUID = 6680646159193457980LL;
  static ::javax::swing::plaf::metal::MetalTheme *theme;
  ::javax::swing::UIDefaults * __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicLookAndFeel )))) LAF_defaults;

  friend class javax_swing_plaf_metal_MetalLookAndFeel$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalLookAndFeel__ */
