// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_RSACipherImpl__
#define __gnu_javax_crypto_RSACipherImpl__

#pragma interface

#include <javax/crypto/CipherSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        class RSACipherImpl;
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class AlgorithmParameters;
      class Key;
      class SecureRandom;
      namespace interfaces
      {
        class RSAPublicKey;
        class RSAPrivateKey;
      }
    }
  }
}

class gnu::javax::crypto::RSACipherImpl : public ::javax::crypto::CipherSpi
{
public:  // actually protected
  virtual void engineSetMode (::java::lang::String *);
  virtual void engineSetPadding (::java::lang::String *);
  virtual jint engineGetBlockSize ();
  virtual jint engineGetOutputSize (jint);
  virtual jint engineGetKeySize (::java::security::Key *);
  virtual jbyteArray engineGetIV () { return 0; }
  virtual ::java::security::AlgorithmParameters *engineGetParameters () { return 0; }
  virtual void engineInit (jint, ::java::security::Key *, ::java::security::SecureRandom *);
  virtual void engineInit (jint, ::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *);
  virtual void engineInit (jint, ::java::security::Key *, ::java::security::AlgorithmParameters *, ::java::security::SecureRandom *);
  virtual jbyteArray engineUpdate (jbyteArray, jint, jint);
  virtual jint engineUpdate (jbyteArray, jint, jint, jbyteArray, jint);
  virtual jbyteArray engineDoFinal (jbyteArray, jint, jint);
  virtual jint engineDoFinal (jbyteArray, jint);
  virtual jint engineDoFinal (jbyteArray, jint, jint, jbyteArray, jint);
private:
  jbyteArray rsaDecrypt (::java::math::BigInteger *);
public:
  RSACipherImpl ();
private:
  static ::java::util::logging::Logger *logger;
  static jbyteArray EMPTY;
  jint __attribute__((aligned(__alignof__( ::javax::crypto::CipherSpi ))))  opmode;
  ::java::security::interfaces::RSAPrivateKey *decipherKey;
  ::java::security::interfaces::RSAPublicKey *blindingKey;
  ::java::security::interfaces::RSAPublicKey *encipherKey;
  ::java::security::SecureRandom *random;
  jbyteArray dataBuffer;
  jint pos;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_RSACipherImpl__ */
