// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_font_opentype_truetype_TrueTypeScaler__
#define __gnu_java_awt_font_opentype_truetype_TrueTypeScaler__

#pragma interface

#include <gnu/java/awt/font/opentype/Scaler.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace font
        {
          namespace opentype
          {
            namespace truetype
            {
              class TrueTypeScaler;
              class Zone;
              class GlyphMeasurer;
              class GlyphLoader;
            }
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace geom
      {
        class Point2D;
        class GeneralPath;
        class AffineTransform;
      }
    }
    namespace nio
    {
      class ByteBuffer;
    }
  }
}

class gnu::java::awt::font::opentype::truetype::TrueTypeScaler : public ::gnu::java::awt::font::opentype::Scaler
{
public:
  TrueTypeScaler (jint, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, jint, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *, ::java::nio::ByteBuffer *);
  virtual ::java::awt::geom::GeneralPath *getOutline (jint, jfloat, ::java::awt::geom::AffineTransform *, jboolean, jboolean);
  virtual void getAdvance (jint, jfloat, ::java::awt::geom::AffineTransform *, jboolean, jboolean, jboolean, ::java::awt::geom::Point2D *);
private:
  jfloat scaleFromFUnits (jint, jfloat, ::java::awt::geom::AffineTransform *, jboolean, jboolean);
public:
  virtual jfloat getAscent (jfloat, ::java::awt::geom::AffineTransform *, jboolean, jboolean, jboolean);
  virtual jfloat getDescent (jfloat, ::java::awt::geom::AffineTransform *, jboolean, jboolean, jboolean);
private:
  ::java::nio::ByteBuffer * __attribute__((aligned(__alignof__( ::gnu::java::awt::font::opentype::Scaler )))) glyfTable;
  ::gnu::java::awt::font::opentype::truetype::GlyphLoader *glyphLoader;
  ::gnu::java::awt::font::opentype::truetype::GlyphMeasurer *glyphMeasurer;
  ::gnu::java::awt::font::opentype::truetype::Zone *glyphZone;
  jint unitsPerEm;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_font_opentype_truetype_TrueTypeScaler__ */
