// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_PBKDF2SecretKeyFactory__
#define __gnu_javax_crypto_jce_PBKDF2SecretKeyFactory__

#pragma interface

#include <javax/crypto/SecretKeyFactorySpi.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          class PBKDF2SecretKeyFactory;
        }
      }
    }
  }
  namespace javax
  {
    namespace crypto
    {
      class SecretKey;
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class KeySpec;
      }
    }
  }
}

class gnu::javax::crypto::jce::PBKDF2SecretKeyFactory : public ::javax::crypto::SecretKeyFactorySpi
{
public:  // actually protected
  PBKDF2SecretKeyFactory (::java::lang::String *);
  virtual ::javax::crypto::SecretKey *engineGenerateSecret (::java::security::spec::KeySpec *);
  virtual ::java::security::spec::KeySpec *engineGetKeySpec (::javax::crypto::SecretKey *, ::java::lang::Class *);
  virtual ::javax::crypto::SecretKey *engineTranslateKey (::javax::crypto::SecretKey *);
  ::java::lang::String * __attribute__((aligned(__alignof__( ::javax::crypto::SecretKeyFactorySpi )))) macName;
private:
  static const jint DEFAULT_ITERATION_COUNT = 1000L;
  static const jint DEFAULT_KEY_LEN = 32L;

  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacWhirlpool;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacTiger;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA512;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA384;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA256;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA1;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacRipeMD160;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacRipeMD128;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacMD5;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacMD4;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacMD2;
  friend class gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacHaval;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_PBKDF2SecretKeyFactory__ */
