// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_RecordInput__
#define __gnu_javax_net_ssl_provider_RecordInput__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class RecordInput;
            class Session;
            class ContentType;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::RecordInput : public ::java::lang::Object
{
public: // actually package-private
  RecordInput (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::Session *);
  virtual jint available (::gnu::javax::net::ssl::provider::ContentType *);
  virtual void setSession (::gnu::javax::net::ssl::provider::Session *);
  virtual jint read (jbyteArray, jint, jint, ::gnu::javax::net::ssl::provider::ContentType *);
  virtual jboolean pollClose ();
private:
  void readRecord ();
  static const jint DEBUG_RECORD_LAYER = 1L;
  static ::java::util::logging::Logger *logger;
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  fragment;
  jint index;
  ::gnu::javax::net::ssl::provider::ContentType *type;
  ::java::io::DataInputStream *in;
  ::gnu::javax::net::ssl::provider::Session *session;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_RecordInput__ */
