// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_logging_Formatter__
#define __java_util_logging_Formatter__

#pragma interface

#include <java/lang/Object.h>

class java::util::logging::Formatter : public ::java::lang::Object
{
public:  // actually protected
  Formatter ();
public:
  virtual ::java::lang::String *format (::java::util::logging::LogRecord *) = 0;
  virtual ::java::lang::String *getHead (::java::util::logging::Handler *);
  virtual ::java::lang::String *getTail (::java::util::logging::Handler *);
  virtual ::java::lang::String *formatMessage (::java::util::logging::LogRecord *);

  static ::java::lang::Class class$;
};

#endif /* __java_util_logging_Formatter__ */
