// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_CupsPrintServiceLookup__
#define __gnu_javax_print_CupsPrintServiceLookup__

#pragma interface

#include <javax/print/PrintServiceLookup.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class MultiDocPrintService;
      namespace attribute
      {
        class AttributeSet;
      }
      class DocFlavor;
      class PrintService;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        class CupsPrintServiceLookup;
        class CupsServer;
      }
    }
  }
}

class gnu::javax::print::CupsPrintServiceLookup : public ::javax::print::PrintServiceLookup
{
public:
  CupsPrintServiceLookup ();
  virtual ::javax::print::PrintService *getDefaultPrintService ();
  virtual JArray< ::javax::print::MultiDocPrintService *> *getMultiDocPrintServices (JArray< ::javax::print::DocFlavor *> *, ::javax::print::attribute::AttributeSet *);
  virtual JArray< ::javax::print::PrintService *> *getPrintServices ();
  virtual JArray< ::javax::print::PrintService *> *getPrintServices (::javax::print::DocFlavor *, ::javax::print::attribute::AttributeSet *);
  virtual jboolean checkPrintService (::javax::print::DocFlavor *, ::javax::print::attribute::AttributeSet *, ::javax::print::PrintService *);
  virtual jboolean checkMultiDocPrintService (JArray< ::javax::print::DocFlavor *> *, ::javax::print::attribute::AttributeSet *, ::javax::print::PrintService *);
private:
  ::gnu::javax::print::CupsServer * __attribute__((aligned(__alignof__( ::javax::print::PrintServiceLookup )))) server;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_CupsPrintServiceLookup__ */
