// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicDesktopIconUI__
#define __javax_swing_plaf_basic_BasicDesktopIconUI__

#pragma interface

#include <javax/swing/plaf/DesktopIconUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Insets;
      class Dimension;
    }
    namespace beans
    {
      class PropertyChangeListener;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class JComponent;
      class Icon;
      namespace plaf
      {
        class ComponentUI;
        namespace basic
        {
          class BasicDesktopIconUI;
          class BasicDesktopIconUI$BoundButton;
        }
      }
      namespace event
      {
        class MouseInputListener;
      }
      class JInternalFrame;
      class JInternalFrame$JDesktopIcon;
    }
  }
}

class javax::swing::plaf::basic::BasicDesktopIconUI : public ::javax::swing::plaf::DesktopIconUI
{
public:
  BasicDesktopIconUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual void installUI (::javax::swing::JComponent *);
  virtual void uninstallUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual void installComponents ();
  virtual void uninstallComponents ();
  virtual void installListeners ();
  virtual void uninstallListeners ();
  virtual void installDefaults ();
  virtual void uninstallDefaults ();
  virtual ::javax::swing::event::MouseInputListener *createMouseInputListener ();
public:
  virtual ::java::awt::Dimension *getPreferredSize (::javax::swing::JComponent *);
  virtual ::java::awt::Dimension *getMinimumSize (::javax::swing::JComponent *);
  virtual ::java::awt::Dimension *getMaximumSize (::javax::swing::JComponent *);
  virtual ::java::awt::Insets *getInsets (::javax::swing::JComponent *);
  virtual void deiconize ();
private:
  static const jint iconSize = 16L;
  static const jint iconWidth = 160L;
  static const jint iconHeight = 35L;
public:  // actually protected
  ::javax::swing::JInternalFrame$JDesktopIcon * __attribute__((aligned(__alignof__( ::javax::swing::plaf::DesktopIconUI )))) desktopIcon;
  ::javax::swing::JInternalFrame *frame;
private:
  ::javax::swing::event::MouseInputListener *mouseHandler;
public: // actually package-private
  ::javax::swing::plaf::basic::BasicDesktopIconUI$BoundButton *button;
private:
  ::java::beans::PropertyChangeListener *propertyHandler;
public: // actually package-private
  static ::javax::swing::Icon *defaultIcon;

  friend class javax_swing_plaf_basic_BasicDesktopIconUI$2;
  friend class javax_swing_plaf_basic_BasicDesktopIconUI$1;
  friend class javax_swing_plaf_basic_BasicDesktopIconUI$BoundButton;
  friend class javax_swing_plaf_basic_BasicDesktopIconUI$InternalFrameDefaultMenuIcon;
  friend class javax_swing_plaf_basic_BasicDesktopIconUI$DesktopIconBorder;
  friend class javax_swing_plaf_basic_BasicDesktopIconUI$MouseInputHandler;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicDesktopIconUI__ */
