// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_awt_j2d_MappedRaster__
#define __gnu_awt_j2d_MappedRaster__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace awt
    {
      namespace j2d
      {
        class MappedRaster;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class ColorModel;
        class WritableRaster;
      }
    }
  }
}

class gnu::awt::j2d::MappedRaster : public ::java::lang::Object
{
public:
  MappedRaster (::java::awt::image::WritableRaster *, ::java::awt::image::ColorModel *);
  virtual ::java::awt::image::WritableRaster *getRaster () { return raster; }
  virtual ::java::awt::image::ColorModel *getColorModel () { return cm; }
public: // actually package-private
  ::java::awt::image::WritableRaster * __attribute__((aligned(__alignof__( ::java::lang::Object )))) raster;
  ::java::awt::image::ColorModel *cm;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_awt_j2d_MappedRaster__ */
