// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_PlainDatagramSocketImpl__
#define __gnu_java_net_PlainDatagramSocketImpl__

#pragma interface

#include <java/net/DatagramSocketImpl.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        class PlainDatagramSocketImpl;
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class SocketAddress;
      class NetworkInterface;
      class DatagramPacket;
      class InetAddress;
    }
  }
}

class gnu::java::net::PlainDatagramSocketImpl : public ::java::net::DatagramSocketImpl
{
public:
  PlainDatagramSocketImpl ();
public:  // actually protected
  virtual void finalize ();
public:
  virtual jint getNativeFD () { return native_fd; }
public:  // actually protected
  virtual void bind (jint, ::java::net::InetAddress *);
  virtual void connect (::java::net::InetAddress *, jint);
  virtual void disconnect ();
  virtual void create ();
  virtual jint peek (::java::net::InetAddress *);
  virtual jint peekData (::java::net::DatagramPacket *);
  virtual void setTimeToLive (jint);
  virtual jint getTimeToLive ();
  virtual void send (::java::net::DatagramPacket *);
  virtual void receive (::java::net::DatagramPacket *);
public:
  virtual void setOption (jint, ::java::lang::Object *);
  virtual ::java::lang::Object *getOption (jint);
private:
  void mcastGrp (::java::net::InetAddress *, ::java::net::NetworkInterface *, jboolean);
public:  // actually protected
  virtual void close ();
  virtual jbyte getTTL ();
  virtual void setTTL (jbyte);
  virtual void join (::java::net::InetAddress *);
  virtual void leave (::java::net::InetAddress *);
  virtual void joinGroup (::java::net::SocketAddress *, ::java::net::NetworkInterface *);
  virtual void leaveGroup (::java::net::SocketAddress *, ::java::net::NetworkInterface *);
public: // actually package-private
  static const jint _Jv_TCP_NODELAY_ = 1L;
  static const jint _Jv_SO_BINDADDR_ = 15L;
  static const jint _Jv_SO_REUSEADDR_ = 4L;
  static const jint _Jv_SO_BROADCAST_ = 32L;
  static const jint _Jv_SO_OOBINLINE_ = 4099L;
  static const jint _Jv_IP_MULTICAST_IF_ = 16L;
  static const jint _Jv_IP_MULTICAST_IF2_ = 31L;
  static const jint _Jv_IP_MULTICAST_LOOP_ = 18L;
  static const jint _Jv_IP_TOS_ = 3L;
  static const jint _Jv_SO_LINGER_ = 128L;
  static const jint _Jv_SO_TIMEOUT_ = 4102L;
  static const jint _Jv_SO_SNDBUF_ = 4097L;
  static const jint _Jv_SO_RCVBUF_ = 4098L;
  static const jint _Jv_SO_KEEPALIVE_ = 8L;
  jint __attribute__((aligned(__alignof__( ::java::net::DatagramSocketImpl ))))  native_fd;
private:
  ::java::lang::Object *RECEIVE_LOCK;
  ::java::lang::Object *SEND_LOCK;
public: // actually package-private
  ::java::net::InetAddress *localAddress;
  jint timeout;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_PlainDatagramSocketImpl__ */
