// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_Serializable__
#define __java_io_Serializable__

#pragma interface

#include <java/lang/Object.h>

class java::io::Serializable : public ::java::lang::Object
{
public:

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_io_Serializable__ */
