// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_AbstractSet__
#define __java_util_AbstractSet__

#pragma interface

#include <java/util/AbstractCollection.h>

class java::util::AbstractSet : public ::java::util::AbstractCollection
{
public:  // actually protected
  AbstractSet ();
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual jboolean removeAll (::java::util::Collection *);

  static ::java::lang::Class class$;
};

#endif /* __java_util_AbstractSet__ */
