// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_charset_UnsupportedCharsetException__
#define __java_nio_charset_UnsupportedCharsetException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace charset
      {
        class UnsupportedCharsetException;
      }
    }
  }
}

class java::nio::charset::UnsupportedCharsetException : public ::java::lang::IllegalArgumentException
{
public:
  UnsupportedCharsetException (::java::lang::String *);
  virtual ::java::lang::String *getCharsetName () { return charsetName; }
private:
  static const jlong serialVersionUID = 1490765524727386367LL;
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::IllegalArgumentException )))) charsetName;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_charset_UnsupportedCharsetException__ */
