// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_TimerTask__
#define __java_util_TimerTask__

#pragma interface

#include <java/lang/Object.h>

class java::util::TimerTask : public ::java::lang::Object
{
public:  // actually protected
  TimerTask ();
public:
  virtual jboolean cancel ();
  virtual void run () = 0;
  virtual jlong scheduledExecutionTime () { return lastExecutionTime; }
public: // actually package-private
  jlong __attribute__((aligned(__alignof__( ::java::lang::Object ))))  scheduled;
  jlong lastExecutionTime;
  jlong period;
  jboolean fixed;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_TimerTask__ */
