// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_util_ByteArray__
#define __gnu_java_security_util_ByteArray__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace util
        {
          class ByteArray;
        }
      }
    }
  }
}

class gnu::java::security::util::ByteArray : public ::java::lang::Object
{
public:
  ByteArray (jbyteArray);
  virtual jbyteArray getValue () { return value; }
  virtual ::java::lang::String *toString ();
  static ::java::lang::String *toHexString (jbyteArray, jint, jint, jchar);
  static ::java::lang::String *formatInt (jint, jint, jint);
private:
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  value;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_util_ByteArray__ */
