// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_Configuration__
#define __gnu_classpath_Configuration__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      class Configuration;
    }
  }
}

class gnu::classpath::Configuration : public ::java::lang::Object
{
public:
  static ::java::lang::String *CLASSPATH_HOME;
  static ::java::lang::String *CLASSPATH_VERSION;
  static const jint DEBUG = 0L;
  static const jint INIT_LOAD_LIBRARY = 0L;
  static ::java::lang::String *default_awt_peer_toolkit;
  static const jint JAVA_LANG_SYSTEM_EXPLICIT_INITIALIZATION = 0L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_classpath_Configuration__ */
