// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_URIException__
#define __javax_print_URIException__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class URIException;
    }
  }
  namespace java
  {
    namespace net
    {
      class URI;
    }
  }
}

class javax::print::URIException : public ::java::lang::Object
{
public:
  virtual jint getReason () = 0;
  virtual ::java::net::URI *getUnsupportedURI () = 0;
  static const jint URIInaccessible = 1L;
  static const jint URIOtherProblem = -1L;
  static const jint URISchemeNotSupported = 2L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_print_URIException__ */
