// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_rmi_server_ProtocolConstants__
#define __gnu_java_rmi_server_ProtocolConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace rmi
      {
        namespace server
        {
          class ProtocolConstants;
        }
      }
    }
  }
}

class gnu::java::rmi::server::ProtocolConstants : public ::java::lang::Object
{
public:
  static const jint PROTOCOL_HEADER = 1246907721L;
  static const jint PROTOCOL_VERSION = 2L;
  static const jint STREAM_PROTOCOL = 75L;
  static const jint SINGLE_OP_PROTOCOL = 76L;
  static const jint MULTIPLEX_PROTOCOL = 77L;
  static const jint PROTOCOL_ACK = 78L;
  static const jint PROTOCOL_NACK = 79L;
  static const jint MESSAGE_CALL = 80L;
  static const jint MESSAGE_CALL_ACK = 81L;
  static const jint MESSAGE_PING = 82L;
  static const jint MESSAGE_PING_ACK = 83L;
  static const jint MESSAGE_DGCACK = 84L;
  static const jint RETURN_ACK = 1L;
  static const jint RETURN_NACK = 2L;
  static const jint DEFAULT_PROTOCOL = 75L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_java_rmi_server_ProtocolConstants__ */
