// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_PixelInterleavedSampleModel__
#define __java_awt_image_PixelInterleavedSampleModel__

#pragma interface

#include <java/awt/image/ComponentSampleModel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class PixelInterleavedSampleModel;
        class SampleModel;
      }
    }
  }
}

class java::awt::image::PixelInterleavedSampleModel : public ::java::awt::image::ComponentSampleModel
{
public:
  PixelInterleavedSampleModel (jint, jint, jint, jint, jint, jintArray);
  virtual ::java::awt::image::SampleModel *createCompatibleSampleModel (jint, jint);
  virtual ::java::awt::image::SampleModel *createSubsetSampleModel (jintArray);

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_PixelInterleavedSampleModel__ */
