// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_Name__
#define __javax_naming_Name__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class Name;
    }
  }
}

class javax::naming::Name : public ::java::lang::Object
{
public:
  virtual jint size () = 0;
  virtual jboolean isEmpty () = 0;
  virtual ::java::util::Enumeration *getAll () = 0;
  virtual ::java::lang::String *get (jint) = 0;
  virtual ::javax::naming::Name *getPrefix (jint) = 0;
  virtual ::javax::naming::Name *getSuffix (jint) = 0;
  virtual ::javax::naming::Name *add (::java::lang::String *) = 0;
  virtual ::javax::naming::Name *add (jint, ::java::lang::String *) = 0;
  virtual ::javax::naming::Name *addAll (::javax::naming::Name *) = 0;
  virtual ::javax::naming::Name *addAll (jint, ::javax::naming::Name *) = 0;
  virtual ::java::lang::Object *remove (jint) = 0;
  virtual jboolean startsWith (::javax::naming::Name *) = 0;
  virtual jboolean endsWith (::javax::naming::Name *) = 0;
  virtual jint compareTo (::java::lang::Object *) = 0;
  virtual ::java::lang::Object *clone () = 0;
  static const jlong serialVersionUID = -3617482732056931635LL;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_naming_Name__ */
