// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_ProtocolException__
#define __java_net_ProtocolException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class ProtocolException;
    }
  }
}

class java::net::ProtocolException : public ::java::io::IOException
{
public:
  ProtocolException ();
  ProtocolException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -6098449442062388080LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_ProtocolException__ */
