// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_VMURLConnection__
#define __java_net_VMURLConnection__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class VMURLConnection;
    }
  }
}

class java::net::VMURLConnection : public ::java::lang::Object
{
private:
  static ::java::lang::String *guessContentTypeFromBuffer (jbyteArray, jint) { return 0; }
public: // actually package-private
  static ::java::lang::String *guessContentTypeFromStream (::java::io::InputStream *);
  VMURLConnection ();
public:
  static const jint LENGTH = 1024L;

  static ::java::lang::Class class$;
};

#endif /* __java_net_VMURLConnection__ */
