// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_ServerHello__
#define __gnu_javax_net_ssl_provider_ServerHello__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class ServerHello;
            class CompressionMethod;
            class CipherSuite;
            class Random;
            class ProtocolVersion;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::ServerHello : public ::java::lang::Object
{
public: // actually package-private
  ServerHello (::gnu::javax::net::ssl::provider::ProtocolVersion *, ::gnu::javax::net::ssl::provider::Random *, jbyteArray, ::gnu::javax::net::ssl::provider::CipherSuite *, ::gnu::javax::net::ssl::provider::CompressionMethod *);
  ServerHello (::gnu::javax::net::ssl::provider::ProtocolVersion *, ::gnu::javax::net::ssl::provider::Random *, jbyteArray, ::gnu::javax::net::ssl::provider::CipherSuite *, ::gnu::javax::net::ssl::provider::CompressionMethod *, ::java::util::List *);
  static ::gnu::javax::net::ssl::provider::ServerHello *read (::java::io::InputStream *);
public:
  virtual void write (::java::io::OutputStream *);
public: // actually package-private
  virtual ::gnu::javax::net::ssl::provider::ProtocolVersion *getVersion () { return version; }
  virtual ::gnu::javax::net::ssl::provider::Random *getRandom () { return random; }
  virtual jbyteArray getSessionId ();
  virtual ::gnu::javax::net::ssl::provider::CipherSuite *getCipherSuite () { return suite; }
  virtual ::gnu::javax::net::ssl::provider::CompressionMethod *getCompressionMethod () { return comp; }
  virtual ::java::util::List *getExtensions () { return extensions; }
public:
  virtual ::java::lang::String *toString ();
private:
  ::gnu::javax::net::ssl::provider::ProtocolVersion * __attribute__((aligned(__alignof__( ::java::lang::Object )))) version;
  ::gnu::javax::net::ssl::provider::Random *random;
  jbyteArray sessionId;
  ::gnu::javax::net::ssl::provider::CipherSuite *suite;
  ::gnu::javax::net::ssl::provider::CompressionMethod *comp;
  ::java::util::List *extensions;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_ServerHello__ */
