// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Handshake__
#define __gnu_javax_net_ssl_provider_Handshake__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class PublicKey;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
            class ProtocolVersion;
            class CertificateType;
            class CipherSuite;
            class Handshake;
            class Handshake$Body;
            class Handshake$Type;
            class Handshake$buffer;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Handshake : public ::java::lang::Object
{
public: // actually package-private
  Handshake (::gnu::javax::net::ssl::provider::Handshake$Type *, ::gnu::javax::net::ssl::provider::Handshake$Body *);
  static ::gnu::javax::net::ssl::provider::Handshake *read (jbyteArray);
  static ::gnu::javax::net::ssl::provider::Handshake *read (jbyteArray, ::gnu::javax::net::ssl::provider::CipherSuite *, ::java::security::PublicKey *);
  static ::gnu::javax::net::ssl::provider::Handshake *read (::java::io::InputStream *);
  static ::gnu::javax::net::ssl::provider::Handshake *read (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::CipherSuite *, ::java::security::PublicKey *);
  static ::gnu::javax::net::ssl::provider::Handshake *read (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::CertificateType *);
  static ::gnu::javax::net::ssl::provider::Handshake *read (::java::io::InputStream *, ::gnu::javax::net::ssl::provider::CipherSuite *, ::java::security::PublicKey *, ::gnu::javax::net::ssl::provider::CertificateType *);
public:
  virtual void write (::java::io::OutputStream *);
  virtual jint write (::java::io::OutputStream *, ::gnu::javax::net::ssl::provider::ProtocolVersion *);
public: // actually package-private
  virtual ::gnu::javax::net::ssl::provider::Handshake$Type *getType () { return type; }
  virtual ::gnu::javax::net::ssl::provider::Handshake$Body *getBody () { return body; }
public:
  virtual ::java::lang::String *toString ();
private:
  static ::gnu::javax::net::ssl::provider::Handshake$buffer *BUF;
  ::gnu::javax::net::ssl::provider::Handshake$Type * __attribute__((aligned(__alignof__( ::java::lang::Object )))) type;
  ::gnu::javax::net::ssl::provider::Handshake$Body *body;

  friend class gnu_javax_net_ssl_provider_Handshake$buffer;
  friend class gnu_javax_net_ssl_provider_Handshake$Type;
  friend class gnu_javax_net_ssl_provider_Handshake$Body;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_net_ssl_provider_Handshake__ */
