// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_peer_FramePeer__
#define __java_awt_peer_FramePeer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace peer
      {
        class FramePeer;
      }
      class Rectangle;
      class MenuBar;
      class Image;
    }
  }
}

class java::awt::peer::FramePeer : public ::java::lang::Object
{
public:
  virtual void setIconImage (::java::awt::Image *) = 0;
  virtual void setMenuBar (::java::awt::MenuBar *) = 0;
  virtual void setResizable (jboolean) = 0;
  virtual void setTitle (::java::lang::String *) = 0;
  virtual jint getState () = 0;
  virtual void setState (jint) = 0;
  virtual void setMaximizedBounds (::java::awt::Rectangle *) = 0;
  virtual jboolean isRestackSupported () = 0;
  virtual void setBoundsPrivate (jint, jint, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_peer_FramePeer__ */
