// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_transport_TransportFactory__
#define __gnu_classpath_jdwp_transport_TransportFactory__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        namespace transport
        {
          class TransportFactory;
          class ITransport;
          class TransportFactory$TransportMethod;
        }
      }
    }
  }
}

class gnu::classpath::jdwp::transport::TransportFactory : public ::java::lang::Object
{
public:
  static ::gnu::classpath::jdwp::transport::ITransport *newInstance (::java::util::HashMap *);
  TransportFactory ();
private:
  static ::java::lang::String *_TRANSPORT_PROPERTY;
  static JArray< ::gnu::classpath::jdwp::transport::TransportFactory$TransportMethod *> *_transportMethods;

  friend class gnu_classpath_jdwp_transport_TransportFactory$TransportMethod;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_transport_TransportFactory__ */
