// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_multi_MultiLookAndFeel__
#define __javax_swing_plaf_multi_MultiLookAndFeel__

#pragma interface

#include <javax/swing/LookAndFeel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JComponent;
      namespace plaf
      {
        namespace multi
        {
          class MultiLookAndFeel;
        }
        class ComponentUI;
      }
      class UIDefaults;
    }
  }
}

class javax::swing::plaf::multi::MultiLookAndFeel : public ::javax::swing::LookAndFeel
{
public:
  MultiLookAndFeel ();
  virtual ::java::lang::String *getName ();
  virtual ::java::lang::String *getID ();
  virtual ::java::lang::String *getDescription ();
  virtual jboolean isNativeLookAndFeel ();
  virtual jboolean isSupportedLookAndFeel ();
  virtual ::javax::swing::UIDefaults *getDefaults ();
  static ::javax::swing::plaf::ComponentUI *createUIs (::javax::swing::plaf::ComponentUI *, ::java::util::Vector *, ::javax::swing::JComponent *);
public:  // actually protected
  static JArray< ::javax::swing::plaf::ComponentUI *> *uisToArray (::java::util::Vector *);
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_multi_MultiLookAndFeel__ */
