// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_io_MimeTypes__
#define __gnu_gcj_io_MimeTypes__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace io
      {
        class MimeTypes;
      }
    }
  }
}

class gnu::gcj::io::MimeTypes : public ::java::lang::Object
{
public:
  static void fillFromFile (::java::util::Hashtable *, ::java::lang::String *);
  static ::java::lang::String *getMimeTypeFromExtension (::java::lang::String *);
  MimeTypes ();
private:
  static ::java::util::Hashtable *mime_types;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_io_MimeTypes__ */
