// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_JdwpConstants__
#define __gnu_classpath_jdwp_JdwpConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
        class JdwpConstants;
      }
    }
  }
}

class gnu::classpath::jdwp::JdwpConstants : public ::java::lang::Object
{
public:
  JdwpConstants ();

  friend class gnu_classpath_jdwp_JdwpConstants$InvokeOptions;
  friend class gnu_classpath_jdwp_JdwpConstants$SuspendPolicy;
  friend class gnu_classpath_jdwp_JdwpConstants$StepSize;
  friend class gnu_classpath_jdwp_JdwpConstants$StepDepth;
  friend class gnu_classpath_jdwp_JdwpConstants$Tag;
  friend class gnu_classpath_jdwp_JdwpConstants$TypeTag;
  friend class gnu_classpath_jdwp_JdwpConstants$ClassStatus;
  friend class gnu_classpath_jdwp_JdwpConstants$SuspendStatus;
  friend class gnu_classpath_jdwp_JdwpConstants$ThreadStatus;
  friend class gnu_classpath_jdwp_JdwpConstants$ModKind;
  friend class gnu_classpath_jdwp_JdwpConstants$EventKind;
  friend class gnu_classpath_jdwp_JdwpConstants$Error;
  friend class gnu_classpath_jdwp_JdwpConstants$CommandSet;
  friend class gnu_classpath_jdwp_JdwpConstants$Version;

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_jdwp_JdwpConstants__ */
