// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_Option__
#define __javax_swing_text_html_Option__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class Option;
        }
        class AttributeSet;
      }
    }
  }
}

class javax::swing::text::html::Option : public ::java::lang::Object
{
public:
  Option (::javax::swing::text::AttributeSet *);
  virtual void setLabel (::java::lang::String *);
  virtual ::java::lang::String *getLabel () { return label; }
  virtual ::javax::swing::text::AttributeSet *getAttributes () { return attributes; }
  virtual ::java::lang::String *toString () { return label; }
public:  // actually protected
  virtual void setSelection (jboolean);
public:
  virtual jboolean isSelected () { return selected; }
  virtual ::java::lang::String *getValue () { return label; }
private:
  ::javax::swing::text::AttributeSet * __attribute__((aligned(__alignof__( ::java::lang::Object )))) attributes;
  ::java::lang::String *label;
  jboolean selected;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_Option__ */
