// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_GnuPublicKeyring__
#define __gnu_javax_crypto_keyring_GnuPublicKeyring__

#pragma interface

#include <gnu/javax/crypto/keyring/BaseKeyring.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class GnuPublicKeyring;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class Certificate;
      }
    }
  }
}

class gnu::javax::crypto::keyring::GnuPublicKeyring : public ::gnu::javax::crypto::keyring::BaseKeyring
{
public:
  GnuPublicKeyring (::java::lang::String *, jint);
  GnuPublicKeyring ();
  virtual jboolean containsCertificate (::java::lang::String *);
  virtual ::java::security::cert::Certificate *getCertificate (::java::lang::String *);
  virtual void putCertificate (::java::lang::String *, ::java::security::cert::Certificate *);
public:  // actually protected
  virtual void load (::java::io::InputStream *, jcharArray);
  virtual void store (::java::io::OutputStream *, jcharArray);
private:
  static ::java::util::logging::Logger *log;
public:
  static const jint USAGE = 4L;

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_GnuPublicKeyring__ */
