// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_accessibility_AccessibleBundle__
#define __javax_accessibility_AccessibleBundle__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleBundle;
    }
  }
}

class javax::accessibility::AccessibleBundle : public ::java::lang::Object
{
public:
  AccessibleBundle ();
public:  // actually protected
  virtual ::java::lang::String *toDisplayString (::java::lang::String *, ::java::util::Locale *) { return key; }
public:
  virtual ::java::lang::String *toDisplayString (::java::util::Locale *) { return key; }
  virtual ::java::lang::String *toDisplayString ();
  virtual ::java::lang::String *toString ();
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) key;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_accessibility_AccessibleBundle__ */
