// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_mac_UMac32Spi__
#define __gnu_javax_crypto_jce_mac_UMac32Spi__

#pragma interface

#include <gnu/javax/crypto/jce/mac/MacAdapter.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
          namespace mac
          {
            class UMac32Spi;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class Key;
    }
  }
}

class gnu::javax::crypto::jce::mac::UMac32Spi : public ::gnu::javax::crypto::jce::mac::MacAdapter
{
public:
  UMac32Spi ();
public:  // actually protected
  virtual void engineInit (::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *);
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_jce_mac_UMac32Spi__ */
