// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Double__
#define __java_lang_Double__

#pragma interface

#include <java/lang/Number.h>

class java::lang::Double : public ::java::lang::Number
{
public:
  Double (jdouble);
  Double (::java::lang::String *);
  static ::java::lang::String *toString (jdouble);
  static ::java::lang::String *toHexString (jdouble);
  static ::java::lang::Double *valueOf (jdouble);
  static ::java::lang::Double *valueOf (::java::lang::String *);
  static jdouble parseDouble (::java::lang::String *);
  static jboolean isNaN (jdouble);
  static jboolean isInfinite (jdouble);
  virtual jboolean isNaN ();
  virtual jboolean isInfinite ();
  virtual ::java::lang::String *toString ();
  virtual jbyte byteValue ();
  virtual jshort shortValue ();
  virtual jint intValue ();
  virtual jlong longValue ();
  virtual jfloat floatValue ();
  virtual jdouble doubleValue () { return value; }
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  static jlong doubleToLongBits (jdouble);
  static jlong doubleToRawLongBits (jdouble);
  static jdouble longBitsToDouble (jlong);
  virtual jint compareTo (::java::lang::Double *);
  virtual jint compareTo (::java::lang::Object *);
  static jint compare (jdouble, jdouble);
private:
  static const jlong serialVersionUID = -9172774392245257468LL;
public:
  static const jdouble MAX_VALUE;
  static const jdouble MIN_VALUE;
  static const jdouble NEGATIVE_INFINITY;
  static const jdouble POSITIVE_INFINITY;
  static const jdouble NaN;
  static const jint SIZE = 64L;
  static ::java::lang::Class *TYPE;
private:
  jdouble __attribute__((aligned(__alignof__( ::java::lang::Number ))))  value;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Double__ */
