// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_VirtualMachineError__
#define __java_lang_VirtualMachineError__

#pragma interface

#include <java/lang/Error.h>

class java::lang::VirtualMachineError : public ::java::lang::Error
{
public:
  VirtualMachineError ();
  VirtualMachineError (::java::lang::String *);
private:
  static const jlong serialVersionUID = 4161983926571568670LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_VirtualMachineError__ */
