// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_math_MathContext__
#define __java_math_MathContext__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace math
    {
      class MathContext;
    }
  }
}

class java::math::MathContext : public ::java::lang::Object
{
public:
  MathContext (jint);
  MathContext (::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint getPrecision () { return precision; }
  virtual ::java::lang::String *toString ();
  virtual jint hashCode () { return precision; }
private:
  static const jlong serialVersionUID = 5579720004786848255LL;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  precision;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_math_MathContext__ */
