// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_IndexColorModel__
#define __java_awt_image_IndexColorModel__

#pragma interface

#include <java/awt/image/ColorModel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class IndexColorModel;
        class BufferedImage;
        class Raster;
      }
    }
    namespace math
    {
      class BigInteger;
    }
  }
}

class java::awt::image::IndexColorModel : public ::java::awt::image::ColorModel
{
public:
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray);
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray, jint);
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray, jbyteArray);
  IndexColorModel (jint, jint, jbyteArray, jint, jboolean);
  IndexColorModel (jint, jint, jbyteArray, jint, jboolean, jint);
  IndexColorModel (jint, jint, jintArray, jint, jboolean, jint, jint);
  IndexColorModel (jint, jint, jintArray, jint, jint, ::java::math::BigInteger *);
  virtual jint getMapSize () { return map_size; }
  virtual jint getTransparentPixel () { return trans; }
  virtual void getReds (jbyteArray);
  virtual void getGreens (jbyteArray);
  virtual void getBlues (jbyteArray);
  virtual void getAlphas (jbyteArray);
  virtual jint getRed (jint);
  virtual jint getGreen (jint);
  virtual jint getBlue (jint);
  virtual jint getAlpha (jint);
  virtual jint getRGB (jint);
  virtual void getRGBs (jintArray);
  virtual jboolean isValid (jint);
  virtual jboolean isValid ();
  virtual ::java::math::BigInteger *getValidPixels () { return validBits; }
  virtual ::java::awt::image::BufferedImage *convertToIntDiscrete (::java::awt::image::Raster *, jboolean);
private:
  jint __attribute__((aligned(__alignof__( ::java::awt::image::ColorModel ))))  map_size;
  jboolean opaque;
  jint trans;
  jintArray rgb;
  ::java::math::BigInteger *validBits;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_IndexColorModel__ */
