// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_UnsatisfiedLinkError__
#define __java_lang_UnsatisfiedLinkError__

#pragma interface

#include <java/lang/LinkageError.h>

class java::lang::UnsatisfiedLinkError : public ::java::lang::LinkageError
{
public:
  UnsatisfiedLinkError ();
  UnsatisfiedLinkError (::java::lang::String *);
private:
  static const jlong serialVersionUID = -4019343241616879428LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_UnsatisfiedLinkError__ */
