// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JScrollBar__
#define __javax_swing_JScrollBar__

#pragma interface

#include <javax/swing/JComponent.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Dimension;
      namespace event
      {
        class AdjustmentListener;
      }
    }
  }
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JScrollBar;
      namespace plaf
      {
        class ScrollBarUI;
      }
      class BoundedRangeModel;
    }
  }
}

class javax::swing::JScrollBar : public ::javax::swing::JComponent
{
public:
  JScrollBar ();
  JScrollBar (jint);
  JScrollBar (jint, jint, jint, jint, jint);
  virtual void setUI (::javax::swing::plaf::ScrollBarUI *);
  virtual ::javax::swing::plaf::ScrollBarUI *getUI ();
  virtual void updateUI ();
  virtual ::java::lang::String *getUIClassID ();
  virtual jint getOrientation () { return orientation; }
  virtual void setOrientation (jint);
  virtual ::javax::swing::BoundedRangeModel *getModel () { return model; }
  virtual void setModel (::javax::swing::BoundedRangeModel *);
  virtual jint getUnitIncrement (jint);
  virtual void setUnitIncrement (jint);
  virtual jint getBlockIncrement (jint);
  virtual void setBlockIncrement (jint);
  virtual jint getUnitIncrement () { return unitIncrement; }
  virtual jint getBlockIncrement () { return blockIncrement; }
  virtual jint getValue ();
  virtual void setValue (jint);
  virtual jint getVisibleAmount ();
  virtual void setVisibleAmount (jint);
  virtual jint getMinimum ();
  virtual void setMinimum (jint);
  virtual jint getMaximum ();
  virtual void setMaximum (jint);
  virtual jboolean getValueIsAdjusting ();
  virtual void setValueIsAdjusting (jboolean);
  virtual void setValues (jint, jint, jint, jint);
  virtual void addAdjustmentListener (::java::awt::event::AdjustmentListener *);
  virtual void removeAdjustmentListener (::java::awt::event::AdjustmentListener *);
  virtual JArray< ::java::awt::event::AdjustmentListener *> *getAdjustmentListeners ();
public:  // actually protected
  virtual void fireAdjustmentValueChanged (jint, jint, jint);
public:
  virtual ::java::awt::Dimension *getMinimumSize ();
  virtual ::java::awt::Dimension *getMaximumSize ();
  virtual void setEnabled (jboolean);
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = -8195169869225066566LL;
public:  // actually protected
  jint __attribute__((aligned(__alignof__( ::javax::swing::JComponent ))))  blockIncrement;
  ::javax::swing::BoundedRangeModel *model;
  jint orientation;
  jint unitIncrement;

  friend class javax_swing_JScrollBar$AccessibleJScrollBar;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JScrollBar__ */
