// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Exception__
#define __java_lang_Exception__

#pragma interface

#include <java/lang/Throwable.h>

class java::lang::Exception : public ::java::lang::Throwable
{
public:
  Exception ();
  Exception (::java::lang::String *);
  Exception (::java::lang::String *, ::java::lang::Throwable *);
  Exception (::java::lang::Throwable *);
private:
  static const jlong serialVersionUID = -3387516993124229948LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Exception__ */
