// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_spec_DHGenParameterSpec__
#define __javax_crypto_spec_DHGenParameterSpec__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      namespace spec
      {
        class DHGenParameterSpec;
      }
    }
  }
}

class javax::crypto::spec::DHGenParameterSpec : public ::java::lang::Object
{
public:
  DHGenParameterSpec (jint, jint);
  virtual jint getExponentSize () { return exponentSize; }
  virtual jint getPrimeSize () { return primeSize; }
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  primeSize;
  jint exponentSize;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_spec_DHGenParameterSpec__ */
