// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_hash_BaseHash__
#define __gnu_java_security_hash_BaseHash__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace hash
        {
          class BaseHash;
        }
      }
    }
  }
}

class gnu::java::security::hash::BaseHash : public ::java::lang::Object
{
public:  // actually protected
  BaseHash (::java::lang::String *, jint, jint);
public:
  virtual ::java::lang::String *name () { return name__; }
  virtual jint hashSize () { return hashSize__; }
  virtual jint blockSize () { return blockSize__; }
  virtual void update (jbyte);
  virtual void update (jbyteArray);
  virtual void update (jbyteArray, jint, jint);
  virtual jbyteArray digest ();
  virtual void reset ();
  virtual ::java::lang::Object *clone () = 0;
  virtual jboolean selfTest () = 0;
public:  // actually protected
  virtual jbyteArray padBuffer () = 0;
  virtual jbyteArray getResult () = 0;
  virtual void resetContext () = 0;
  virtual void transform (jbyteArray, jint) = 0;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name__;
  jint hashSize__;
  jint blockSize__;
  jlong count;
  jbyteArray buffer;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_hash_BaseHash__ */
