// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_BufferUnderflowException__
#define __java_nio_BufferUnderflowException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      class BufferUnderflowException;
    }
  }
}

class java::nio::BufferUnderflowException : public ::java::lang::RuntimeException
{
public:
  BufferUnderflowException ();
private:
  static const jlong serialVersionUID = -1713313658691622206LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_nio_BufferUnderflowException__ */
