// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_EmptyAttributeSet__
#define __javax_swing_text_EmptyAttributeSet__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class EmptyAttributeSet;
        class AttributeSet;
      }
    }
  }
}

class javax::swing::text::EmptyAttributeSet : public ::java::lang::Object
{
public:
  virtual jboolean containsAttribute (::java::lang::Object *, ::java::lang::Object *);
  virtual jboolean containsAttributes (::javax::swing::text::AttributeSet *);
  virtual ::javax::swing::text::AttributeSet *copyAttributes () { return reinterpret_cast< ::javax::swing::text::AttributeSet *> (this); }
  virtual ::java::lang::Object *getAttribute (::java::lang::Object *) { return 0; }
  virtual jint getAttributeCount ();
  virtual ::java::util::Enumeration *getAttributeNames ();
  virtual ::javax::swing::text::AttributeSet *getResolveParent () { return 0; }
  virtual jboolean isDefined (::java::lang::Object *);
  virtual jboolean isEqual (::javax::swing::text::AttributeSet *);
  virtual jboolean equals (::java::lang::Object *);
public: // actually package-private
  EmptyAttributeSet ();

  friend class javax_swing_text_EmptyAttributeSet$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_EmptyAttributeSet__ */
