// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_PrintJobAttribute__
#define __javax_print_attribute_PrintJobAttribute__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class PrintJobAttribute;
      }
    }
  }
}

class javax::print::attribute::PrintJobAttribute : public ::java::lang::Object
{
public:

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_print_attribute_PrintJobAttribute__ */
