// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_DefaultListSelectionModel__
#define __javax_swing_DefaultListSelectionModel__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class DefaultListSelectionModel;
      namespace event
      {
        class ListSelectionListener;
        class EventListenerList;
      }
    }
  }
}

class javax::swing::DefaultListSelectionModel : public ::java::lang::Object
{
public:
  virtual jint getSelectionMode () { return selectionMode; }
  virtual void setSelectionMode (jint);
  virtual jint getAnchorSelectionIndex () { return anchorSelectionIndex; }
  virtual void setAnchorSelectionIndex (jint);
  virtual jint getLeadSelectionIndex () { return leadSelectionIndex; }
  virtual void setLeadSelectionIndex (jint);
  virtual void moveLeadSelectionIndex (jint);
  virtual jboolean isLeadAnchorNotificationEnabled () { return leadAnchorNotificationEnabled; }
  virtual void setLeadAnchorNotificationEnabled (jboolean);
  virtual jboolean getValueIsAdjusting () { return valueIsAdjusting; }
  virtual void setValueIsAdjusting (jboolean);
  virtual jboolean isSelectionEmpty ();
  virtual jint getMinSelectionIndex ();
  virtual jint getMaxSelectionIndex ();
  virtual jboolean isSelectedIndex (jint);
  virtual void addSelectionInterval (jint, jint);
  virtual void removeSelectionInterval (jint, jint);
  virtual void clearSelection ();
private:
  void fireDifference (::java::util::BitSet *, ::java::util::BitSet *);
public:
  virtual void setSelectionInterval (jint, jint);
  virtual void insertIndexInterval (jint, jint, jboolean);
  virtual void removeIndexInterval (jint, jint);
public:  // actually protected
  virtual void fireValueChanged (jboolean);
  virtual void fireValueChanged (jint, jint);
  virtual void fireValueChanged (jint, jint, jboolean);
public:
  virtual void addListSelectionListener (::javax::swing::event::ListSelectionListener *);
  virtual void removeListSelectionListener (::javax::swing::event::ListSelectionListener *);
  virtual JArray< ::java::util::EventListener *> *getListeners (::java::lang::Class *);
  virtual JArray< ::javax::swing::event::ListSelectionListener *> *getListSelectionListeners ();
  virtual ::java::lang::Object *clone ();
  DefaultListSelectionModel ();
private:
  static const jlong serialVersionUID = -5718799865110415860LL;
public:  // actually protected
  ::javax::swing::event::EventListenerList * __attribute__((aligned(__alignof__( ::java::lang::Object )))) listenerList;
public: // actually package-private
  jint selectionMode;
  jint leadSelectionIndex;
  jint anchorSelectionIndex;
public:  // actually protected
  jboolean leadAnchorNotificationEnabled;
public: // actually package-private
  jboolean valueIsAdjusting;
  ::java::util::BitSet *sel;
  ::java::lang::Object *oldSel;
  jboolean setLeadCalledFromAdd;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_DefaultListSelectionModel__ */
