// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalSplitPaneUI__
#define __javax_swing_plaf_metal_MetalSplitPaneUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicSplitPaneUI.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalSplitPaneUI;
        }
        namespace basic
        {
          class BasicSplitPaneDivider;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::metal::MetalSplitPaneUI : public ::javax::swing::plaf::basic::BasicSplitPaneUI
{
public:
  MetalSplitPaneUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual ::javax::swing::plaf::basic::BasicSplitPaneDivider *createDefaultDivider ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalSplitPaneUI__ */
