// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_convert_Input_iconv__
#define __gnu_gcj_convert_Input_iconv__

#pragma interface

#include <gnu/gcj/convert/BytesToUnicode.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace convert
      {
        class Input_iconv;
      }
      class RawData;
    }
  }
}

class gnu::gcj::convert::Input_iconv : public ::gnu::gcj::convert::BytesToUnicode
{
public:
  Input_iconv (::java::lang::String *);
  virtual ::java::lang::String *getName () { return encoding; }
  virtual void finalize ();
private:
  void init (::java::lang::String *);
public:
  virtual jint read (jcharArray, jint, jint);
  virtual void done ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::gnu::gcj::convert::BytesToUnicode )))) encoding;
  ::gnu::gcj::RawData *handle;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_convert_Input_iconv__ */
