// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalComboBoxEditor__
#define __javax_swing_plaf_metal_MetalComboBoxEditor__

#pragma interface

#include <javax/swing/plaf/basic/BasicComboBoxEditor.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalComboBoxEditor;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      class Insets;
    }
  }
}

class javax::swing::plaf::metal::MetalComboBoxEditor : public ::javax::swing::plaf::basic::BasicComboBoxEditor
{
public:
  MetalComboBoxEditor ();
public:  // actually protected
  static ::java::awt::Insets *editorBorderInsets;

  friend class javax_swing_plaf_metal_MetalComboBoxEditor$EditorTextField;
  friend class javax_swing_plaf_metal_MetalComboBoxEditor$UIResource;
  friend class javax_swing_plaf_metal_MetalComboBoxEditor$MetalComboBoxEditorBorder;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalComboBoxEditor__ */
