// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_MouseInputAdapter__
#define __javax_swing_event_MouseInputAdapter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class MouseInputAdapter;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class MouseEvent;
      }
    }
  }
}

class javax::swing::event::MouseInputAdapter : public ::java::lang::Object
{
public:
  MouseInputAdapter ();
  virtual void mouseClicked (::java::awt::event::MouseEvent *) { }
  virtual void mouseDragged (::java::awt::event::MouseEvent *) { }
  virtual void mouseEntered (::java::awt::event::MouseEvent *) { }
  virtual void mouseExited (::java::awt::event::MouseEvent *) { }
  virtual void mouseMoved (::java::awt::event::MouseEvent *) { }
  virtual void mousePressed (::java::awt::event::MouseEvent *) { }
  virtual void mouseReleased (::java::awt::event::MouseEvent *) { }

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_MouseInputAdapter__ */
