// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_FontFormatException__
#define __java_awt_FontFormatException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class FontFormatException;
    }
  }
}

class java::awt::FontFormatException : public ::java::lang::Exception
{
public:
  FontFormatException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -4481290147811361272LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_FontFormatException__ */
