// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_IllegalStateException__
#define __java_lang_IllegalStateException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::lang::IllegalStateException : public ::java::lang::RuntimeException
{
public:
  IllegalStateException ();
  IllegalStateException (::java::lang::String *);
  IllegalStateException (::java::lang::String *, ::java::lang::Throwable *);
  IllegalStateException (::java::lang::Throwable *);
private:
  static const jlong serialVersionUID = -1848914673093119416LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_IllegalStateException__ */
