// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_net_ssl_SSLContext__
#define __javax_net_ssl_SSLContext__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class SecureRandom;
      class Provider;
    }
  }
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class TrustManager;
        class KeyManager;
        class SSLSocketFactory;
        class SSLServerSocketFactory;
        class SSLSessionContext;
        class SSLContext;
        class SSLContextSpi;
      }
    }
  }
}

class javax::net::ssl::SSLContext : public ::java::lang::Object
{
public:  // actually protected
  SSLContext (::javax::net::ssl::SSLContextSpi *, ::java::security::Provider *, ::java::lang::String *);
public:
  static ::javax::net::ssl::SSLContext *getInstance (::java::lang::String *);
  static ::javax::net::ssl::SSLContext *getInstance (::java::lang::String *, ::java::lang::String *);
  static ::javax::net::ssl::SSLContext *getInstance (::java::lang::String *, ::java::security::Provider *);
  virtual ::javax::net::ssl::SSLSessionContext *getClientSessionContext ();
  virtual ::java::lang::String *getProtocol () { return protocol; }
  virtual ::java::security::Provider *getProvider () { return provider; }
  virtual ::javax::net::ssl::SSLSessionContext *getServerSessionContext ();
  virtual ::javax::net::ssl::SSLServerSocketFactory *getServerSocketFactory ();
  virtual ::javax::net::ssl::SSLSocketFactory *getSocketFactory ();
  virtual void init (JArray< ::javax::net::ssl::KeyManager *> *, JArray< ::javax::net::ssl::TrustManager *> *, ::java::security::SecureRandom *);
private:
  static ::java::lang::String *SSL_CONTEXT;
  ::javax::net::ssl::SSLContextSpi * __attribute__((aligned(__alignof__( ::java::lang::Object )))) ctxSpi;
  ::java::security::Provider *provider;
  ::java::lang::String *protocol;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_net_ssl_SSLContext__ */
