// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_pkcs_PKCS7Data__
#define __gnu_java_security_pkcs_PKCS7Data__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace pkcs
        {
          class PKCS7Data;
        }
        class OID;
      }
    }
  }
}

class gnu::java::security::pkcs::PKCS7Data : public ::java::lang::Object
{
public:
  PKCS7Data (jbyteArray);
  virtual jbyteArray getEncoded () { return content; }
  static ::gnu::java::security::OID *PKCS7_DATA;
private:
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  content;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_pkcs_PKCS7Data__ */
