// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_java2d_PolyEdgeComparator__
#define __gnu_java_awt_java2d_PolyEdgeComparator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace java2d
        {
          class PolyEdgeComparator;
        }
      }
    }
  }
}

class gnu::java::awt::java2d::PolyEdgeComparator : public ::java::lang::Object
{
public:
  virtual jint compare (::java::lang::Object *, ::java::lang::Object *);
  PolyEdgeComparator ();
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  y;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_java2d_PolyEdgeComparator__ */
