// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_NotImplementedException__
#define __gnu_classpath_NotImplementedException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      class NotImplementedException;
    }
  }
}

class gnu::classpath::NotImplementedException : public ::java::lang::RuntimeException
{
private:
  NotImplementedException ();
  static const jlong serialVersionUID = 5112972057211125814LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_NotImplementedException__ */
