// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_security_auth_login_ConfigFileParser__
#define __gnu_javax_security_auth_login_ConfigFileParser__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace security
      {
        namespace auth
        {
          namespace login
          {
            class ConfigFileParser;
            class ConfigFileTokenizer;
          }
        }
      }
    }
  }
}

class gnu::javax::security::auth::login::ConfigFileParser : public ::java::lang::Object
{
public:
  virtual ::java::util::Map *getLoginModulesMap () { return map; }
  virtual void parse (::java::io::Reader *);
private:
  void initParser (::java::io::Reader *);
  jboolean parseAppOrOtherEntry ();
  jboolean parseACE (::java::util::List *);
  void abort (::java::lang::String *);
  ::java::lang::String *validateClassName (::java::lang::String *);
  ::java::lang::String *expandParamValue (::java::lang::String *);
public:
  ConfigFileParser ();
private:
  static ::java::util::logging::Logger *log;
  ::gnu::javax::security::auth::login::ConfigFileTokenizer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) cft;
  ::java::util::Map *map;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_security_auth_login_ConfigFileParser__ */
