// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_mac_OMAC__
#define __gnu_javax_crypto_mac_OMAC__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace mac
        {
          class OMAC;
        }
        namespace mode
        {
          class IMode;
        }
        namespace cipher
        {
          class IBlockCipher;
        }
      }
    }
  }
}

class gnu::javax::crypto::mac::OMAC : public ::java::lang::Object
{
public:
  OMAC (::gnu::javax::crypto::cipher::IBlockCipher *);
  virtual ::java::lang::Object *clone ();
  virtual ::java::lang::String *name () { return name__; }
  virtual jint macSize () { return outputSize; }
  virtual void init (::java::util::Map *);
  virtual void update (jbyte);
  virtual void update (jbyteArray, jint, jint);
  virtual jbyteArray digest ();
  virtual void digest (jbyteArray, jint);
  virtual void reset ();
  virtual jboolean selfTest ();
private:
  void process ();
  static ::java::util::logging::Logger *log;
  static const jint C1 = -121L;
  static const jint C2 = 27L;
  static jbyteArray KEY0;
  static jbyteArray DIGEST0;
  static ::java::lang::Boolean *valid;
  ::gnu::javax::crypto::cipher::IBlockCipher * __attribute__((aligned(__alignof__( ::java::lang::Object )))) cipher;
  ::java::lang::String *name__;
  ::gnu::javax::crypto::mode::IMode *mode;
  jint blockSize;
  jint outputSize;
  jbyteArray Lu;
  jbyteArray Lu2;
  jbyteArray M;
  jbyteArray Y;
  jboolean init__;
  jint index;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_mac_OMAC__ */
