// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_ListIterator__
#define __java_util_ListIterator__

#pragma interface

#include <java/lang/Object.h>

class java::util::ListIterator : public ::java::lang::Object
{
public:
  virtual jboolean hasNext () = 0;
  virtual jboolean hasPrevious () = 0;
  virtual ::java::lang::Object *next () = 0;
  virtual ::java::lang::Object *previous () = 0;
  virtual jint nextIndex () = 0;
  virtual jint previousIndex () = 0;
  virtual void add (::java::lang::Object *) = 0;
  virtual void remove () = 0;
  virtual void set (::java::lang::Object *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_ListIterator__ */
