// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_srp_ServerStore__
#define __gnu_javax_crypto_sasl_srp_ServerStore__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace srp
          {
            class SecurityContext;
            class ServerStore;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::srp::ServerStore : public ::java::lang::Object
{
private:
  ServerStore ();
public: // actually package-private
  static ::gnu::javax::crypto::sasl::srp::ServerStore *instance ();
  static jbyteArray getNewSessionID ();
  virtual jboolean isAlive (jbyteArray);
  virtual void cacheSession (jint, ::gnu::javax::crypto::sasl::srp::SecurityContext *);
  virtual ::gnu::javax::crypto::sasl::srp::SecurityContext *restoreSession (jbyteArray);
  virtual void invalidateSession (jbyteArray);
private:
  static ::gnu::javax::crypto::sasl::srp::ServerStore *singleton;
  static ::java::util::HashMap *sid2ssc;
  static ::java::util::HashMap *sid2ttl;
  static ::java::lang::Object *lock;
  static jint counter;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_srp_ServerStore__ */
