// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_PrinterDialog__
#define __gnu_javax_print_PrinterDialog__

#pragma interface

#include <javax/swing/JDialog.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class ActionEvent;
      }
      class GraphicsConfiguration;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        class PrinterDialog;
        class PrinterDialog$AppearancePanel;
        class PrinterDialog$PageSetupPanel;
        class PrinterDialog$GeneralPanel;
      }
    }
  }
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class Attribute;
        class PrintRequestAttributeSet;
      }
      class DocFlavor;
      class PrintService;
    }
    namespace swing
    {
      class JButton;
    }
  }
}

class gnu::javax::print::PrinterDialog : public ::javax::swing::JDialog
{
private:
  PrinterDialog (::java::awt::GraphicsConfiguration *, JArray< ::javax::print::PrintService *> *, ::javax::print::PrintService *, ::javax::print::DocFlavor *, ::javax::print::attribute::PrintRequestAttributeSet *, jboolean, ::java::lang::String *);
public:
  PrinterDialog (::java::awt::GraphicsConfiguration *, ::javax::print::PrintService *, ::javax::print::DocFlavor *, ::javax::print::attribute::PrintRequestAttributeSet *);
  PrinterDialog (::java::awt::GraphicsConfiguration *, JArray< ::javax::print::PrintService *> *, ::javax::print::PrintService *, ::javax::print::DocFlavor *, ::javax::print::attribute::PrintRequestAttributeSet *);
private:
  void initUI (jboolean);
public:
  virtual ::javax::print::attribute::PrintRequestAttributeSet *getAttributes () { return attributes; }
  virtual ::javax::print::PrintService *getSelectedPrintService () { return selectedService; }
public:  // actually protected
  virtual void setSelectedPrintService (::javax::print::PrintService *);
  virtual JArray< ::javax::print::PrintService *> *getPrintServices () { return services; }
public: // actually package-private
  virtual void updateAll ();
  virtual jboolean categorySupported (::java::lang::Class *);
  virtual ::java::lang::Object *defaultValue (::java::lang::Class *);
  virtual ::javax::print::attribute::Attribute *attribute (::java::lang::Class *);
public:
  virtual void actionPerformed (::java::awt::event::ActionEvent *);
public: // actually package-private
  static ::java::lang::String *getLocalizedString (::java::lang::String *);
private:
  ::javax::swing::JButton * __attribute__((aligned(__alignof__( ::javax::swing::JDialog )))) ok_bt;
  ::javax::swing::JButton *cancel_bt;
  ::gnu::javax::print::PrinterDialog$GeneralPanel *general_panel;
  ::gnu::javax::print::PrinterDialog$PageSetupPanel *pagesetup_panel;
  ::gnu::javax::print::PrinterDialog$AppearancePanel *appearance_panel;
  JArray< ::javax::print::PrintService *> *services;
  ::javax::print::PrintService *defaultService;
  ::javax::print::PrintService *selectedService;
  ::javax::print::DocFlavor *flavor;
  ::javax::print::attribute::PrintRequestAttributeSet *attributes;
  jboolean onlyPageDialog;
  ::javax::print::attribute::PrintRequestAttributeSet *atts;
  static ::java::util::ResourceBundle *messages;

  friend class gnu_javax_print_PrinterDialog$AppearancePanel;
  friend class gnu_javax_print_PrinterDialog$PageSetupPanel;
  friend class gnu_javax_print_PrinterDialog$GeneralPanel;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_print_PrinterDialog__ */
