// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_plain_PlainServer__
#define __gnu_javax_crypto_sasl_plain_PlainServer__

#pragma interface

#include <gnu/javax/crypto/sasl/ServerMechanism.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          namespace plain
          {
            class PlainServer;
          }
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::plain::PlainServer : public ::gnu::javax::crypto::sasl::ServerMechanism
{
public:
  PlainServer ();
public:  // actually protected
  virtual void initMechanism () { }
  virtual void resetMechanism () { }
public:
  virtual jbyteArray evaluateResponse (jbyteArray);
public:  // actually protected
  virtual ::java::lang::String *getNegotiatedQOP ();
private:
  jcharArray lookupPassword (::java::lang::String *);
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_plain_PlainServer__ */
