// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_VMNetworkInterface__
#define __java_net_VMNetworkInterface__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class VMNetworkInterface;
    }
  }
}

class java::net::VMNetworkInterface : public ::java::lang::Object
{
public:
  static ::java::util::Vector *getInterfaces ();
public: // actually package-private
  VMNetworkInterface ();
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_VMNetworkInterface__ */
