// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_provider_Gnu__
#define __gnu_java_security_provider_Gnu__

#pragma interface

#include <java/security/Provider.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace provider
        {
          class Gnu;
        }
      }
    }
  }
}

class gnu::java::security::provider::Gnu : public ::java::security::Provider
{
public:
  Gnu ();

  friend class gnu_java_security_provider_Gnu$1;

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_provider_Gnu__ */
