// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_ConvolveOp__
#define __java_awt_image_ConvolveOp__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace geom
      {
        class Point2D;
        class Rectangle2D;
      }
      class RenderingHints;
      namespace image
      {
        class ConvolveOp;
        class WritableRaster;
        class Raster;
        class ColorModel;
        class BufferedImage;
        class Kernel;
      }
    }
  }
}

class java::awt::image::ConvolveOp : public ::java::lang::Object
{
public:
  ConvolveOp (::java::awt::image::Kernel *, jint, ::java::awt::RenderingHints *);
  ConvolveOp (::java::awt::image::Kernel *);
  virtual ::java::awt::image::BufferedImage *filter (::java::awt::image::BufferedImage *, ::java::awt::image::BufferedImage *);
  virtual ::java::awt::image::BufferedImage *createCompatibleDestImage (::java::awt::image::BufferedImage *, ::java::awt::image::ColorModel *);
  virtual ::java::awt::RenderingHints *getRenderingHints () { return hints; }
  virtual jint getEdgeCondition () { return edge; }
  virtual ::java::awt::image::Kernel *getKernel ();
  virtual ::java::awt::image::WritableRaster *filter (::java::awt::image::Raster *, ::java::awt::image::WritableRaster *);
private:
  void fillEdge (::java::awt::image::Raster *, ::java::awt::image::WritableRaster *, jint, jint, jint, jint, jint);
public:
  virtual ::java::awt::image::WritableRaster *createCompatibleDestRaster (::java::awt::image::Raster *);
  virtual ::java::awt::geom::Rectangle2D *getBounds2D (::java::awt::image::BufferedImage *);
  virtual ::java::awt::geom::Rectangle2D *getBounds2D (::java::awt::image::Raster *);
  virtual ::java::awt::geom::Point2D *getPoint2D (::java::awt::geom::Point2D *, ::java::awt::geom::Point2D *);
  static const jint EDGE_ZERO_FILL = 0L;
  static const jint EDGE_NO_OP = 1L;
private:
  ::java::awt::image::Kernel * __attribute__((aligned(__alignof__( ::java::lang::Object )))) kernel;
  jint edge;
  ::java::awt::RenderingHints *hints;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_ConvolveOp__ */
