// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_event_PrintJobEvent__
#define __javax_print_event_PrintJobEvent__

#pragma interface

#include <javax/print/event/PrintEvent.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace event
      {
        class PrintJobEvent;
      }
      class DocPrintJob;
    }
  }
}

class javax::print::event::PrintJobEvent : public ::javax::print::event::PrintEvent
{
public:
  PrintJobEvent (::javax::print::DocPrintJob *, jint);
  virtual jint getPrintEventType () { return reason; }
  virtual ::javax::print::DocPrintJob *getPrintJob ();
private:
  static const jlong serialVersionUID = -1711656903622072997LL;
public:
  static const jint DATA_TRANSFER_COMPLETE = 106L;
  static const jint JOB_CANCELED = 101L;
  static const jint JOB_COMPLETE = 102L;
  static const jint JOB_FAILED = 103L;
  static const jint NO_MORE_EVENTS = 105L;
  static const jint REQUIRES_ATTENTION = 104L;
private:
  jint __attribute__((aligned(__alignof__( ::javax::print::event::PrintEvent ))))  reason;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_event_PrintJobEvent__ */
