// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_crypto_EncryptedPrivateKeyInfo__
#define __javax_crypto_EncryptedPrivateKeyInfo__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace crypto
    {
      class EncryptedPrivateKeyInfo;
      class Cipher;
    }
  }
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class PKCS8EncodedKeySpec;
      }
      class AlgorithmParameters;
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        class OID;
      }
    }
  }
}

class javax::crypto::EncryptedPrivateKeyInfo : public ::java::lang::Object
{
public:
  EncryptedPrivateKeyInfo (::java::security::AlgorithmParameters *, jbyteArray);
  EncryptedPrivateKeyInfo (jbyteArray);
  EncryptedPrivateKeyInfo (::java::lang::String *, jbyteArray);
private:
  static ::gnu::java::security::OID *getOid (::java::lang::String *);
public:
  virtual ::java::lang::String *getAlgName ();
  virtual ::java::security::AlgorithmParameters *getAlgParameters ();
  virtual jbyteArray getEncoded ();
  virtual jbyteArray getEncryptedData () { return encryptedData; }
  virtual ::java::security::spec::PKCS8EncodedKeySpec *getKeySpec (::javax::crypto::Cipher *);
private:
  void decode ();
  void encode ();
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  encryptedData;
  jbyteArray encoded;
  ::gnu::java::security::OID *algOid;
  ::java::lang::String *algName;
  ::java::security::AlgorithmParameters *params;
  jbyteArray encodedParams;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_crypto_EncryptedPrivateKeyInfo__ */
