// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_kerberos_DelegationPermission__
#define __javax_security_auth_kerberos_DelegationPermission__

#pragma interface

#include <java/security/BasicPermission.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace kerberos
        {
          class DelegationPermission;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      class PermissionCollection;
      class Permission;
    }
  }
}

class javax::security::auth::kerberos::DelegationPermission : public ::java::security::BasicPermission
{
public:
  DelegationPermission (::java::lang::String *);
  DelegationPermission (::java::lang::String *, ::java::lang::String *);
private:
  static void checkSyntax (::java::lang::String *);
public:
  virtual jboolean implies (::java::security::Permission *);
  virtual ::java::security::PermissionCollection *newPermissionCollection ();

  friend class javax_security_auth_kerberos_DelegationPermission$1;

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_kerberos_DelegationPermission__ */
