// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_DefaultListCellRenderer__
#define __javax_swing_DefaultListCellRenderer__

#pragma interface

#include <javax/swing/JLabel.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      class Component;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class DefaultListCellRenderer;
      class JList;
      namespace border
      {
        class Border;
      }
    }
  }
}

class javax::swing::DefaultListCellRenderer : public ::javax::swing::JLabel
{
public:
  virtual ::java::awt::Component *getListCellRendererComponent (::javax::swing::JList *, ::java::lang::Object *, jint, jboolean, jboolean);
  virtual void validate () { }
  virtual void revalidate () { }
  virtual void repaint (jlong, jint, jint, jint, jint) { }
  virtual void repaint (::java::awt::Rectangle *) { }
public:  // actually protected
  virtual void firePropertyChange (::java::lang::String *, ::java::lang::Object *, ::java::lang::Object *) { }
public:
  virtual void firePropertyChange (::java::lang::String *, jbyte, jbyte) { }
  virtual void firePropertyChange (::java::lang::String *, jchar, jchar) { }
  virtual void firePropertyChange (::java::lang::String *, jshort, jshort) { }
  virtual void firePropertyChange (::java::lang::String *, jint, jint) { }
  virtual void firePropertyChange (::java::lang::String *, jlong, jlong) { }
  virtual void firePropertyChange (::java::lang::String *, jfloat, jfloat) { }
  virtual void firePropertyChange (::java::lang::String *, jdouble, jdouble) { }
  virtual void firePropertyChange (::java::lang::String *, jboolean, jboolean) { }
  DefaultListCellRenderer ();
private:
  static const jlong serialVersionUID = 7708947179685189462LL;
public:  // actually protected
  static ::javax::swing::border::Border *noFocusBorder;

  friend class javax_swing_DefaultListCellRenderer$UIResource;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_DefaultListCellRenderer__ */
