// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipEntry__
#define __java_util_zip_ZipEntry__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::util::zip::ZipEntry : public ::java::lang::Object
{
public:
  ZipEntry (::java::lang::String *);
  ZipEntry (::java::util::zip::ZipEntry *);
public: // actually package-private
  ZipEntry (::java::util::zip::ZipEntry *, ::java::lang::String *);
  virtual void setDOSTime (jint);
  virtual jint getDOSTime ();
public:
  virtual ::java::lang::Object *clone ();
  virtual ::java::lang::String *getName () { return name; }
  virtual void setTime (jlong);
  virtual jlong getTime ();
private:
  static ::java::util::Calendar *getCalendar ();
public:
  virtual void setSize (jlong);
  virtual jlong getSize ();
  virtual void setCompressedSize (jlong);
  virtual jlong getCompressedSize () { return compressedSize; }
  virtual void setCrc (jlong);
  virtual jlong getCrc ();
  virtual void setMethod (jint);
  virtual jint getMethod () { return method; }
  virtual void setExtra (jbyteArray);
private:
  void parseExtra ();
public:
  virtual jbyteArray getExtra () { return extra; }
  virtual void setComment (::java::lang::String *);
  virtual ::java::lang::String *getComment () { return comment; }
  virtual jboolean isDirectory ();
  virtual ::java::lang::String *toString () { return name; }
  virtual jint hashCode ();
private:
  static const jint KNOWN_SIZE = 1L;
  static const jint KNOWN_CSIZE = 2L;
  static const jint KNOWN_CRC = 4L;
  static const jint KNOWN_TIME = 8L;
  static const jint KNOWN_EXTRA = 16L;
  static ::java::util::Calendar *cal;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  jint size;
  jlong compressedSize;
  jint crc;
  jint dostime;
  jshort known;
  jshort method;
  jbyteArray extra;
  ::java::lang::String *comment;
public: // actually package-private
  jint flags;
  jint offset;
public:
  static const jint STORED = 0L;
  static const jint DEFLATED = 8L;

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_ZipEntry__ */
