// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_png_PNGChunk__
#define __gnu_javax_imageio_png_PNGChunk__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace png
        {
          class PNGChunk;
        }
      }
    }
  }
}

class gnu::javax::imageio::png::PNGChunk : public ::java::lang::Object
{
public:  // actually protected
  PNGChunk (jint, jbyteArray, jint);
  PNGChunk (jint);
public:
  static ::gnu::javax::imageio::png::PNGChunk *readChunk (::java::io::InputStream *, jboolean);
private:
  static ::gnu::javax::imageio::png::PNGChunk *getChunk (jint, jbyteArray, jint);
  static jboolean isEssentialChunk (jint);
public:
  virtual jboolean isValidChunk ();
  virtual jint getType () { return type; }
  virtual void writeChunk (::java::io::OutputStream *);
  virtual jboolean isEmpty ();
  static jbyteArray getInt (jint);
private:
  jint calcCRC ();
public:
  virtual ::java::lang::String *toString ();
private:
  static jlongArray crcTable;
public:
  static const jint TYPE_HEADER = 1229472850L;
  static const jint TYPE_PALETTE = 1347179589L;
  static const jint TYPE_DATA = 1229209940L;
  static const jint TYPE_TIME = 1950960965L;
  static const jint TYPE_END = 1229278788L;
  static const jint TYPE_PHYS = 1883789683L;
  static const jint TYPE_GAMMA = 1732332865L;
  static const jint TYPE_PROFILE = 1766015824L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  type;
public:  // actually protected
  jbyteArray data;
private:
  jint crc;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_imageio_png_PNGChunk__ */
