// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_peer_TextAreaPeer__
#define __java_awt_peer_TextAreaPeer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace peer
      {
        class TextAreaPeer;
      }
      class Dimension;
    }
  }
}

class java::awt::peer::TextAreaPeer : public ::java::lang::Object
{
public:
  virtual void insert (::java::lang::String *, jint) = 0;
  virtual void insertText (::java::lang::String *, jint) = 0;
  virtual ::java::awt::Dimension *minimumSize (jint, jint) = 0;
  virtual ::java::awt::Dimension *getMinimumSize (jint, jint) = 0;
  virtual ::java::awt::Dimension *preferredSize (jint, jint) = 0;
  virtual ::java::awt::Dimension *getPreferredSize (jint, jint) = 0;
  virtual void replaceRange (::java::lang::String *, jint, jint) = 0;
  virtual void replaceText (::java::lang::String *, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_peer_TextAreaPeer__ */
