// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_Entry__
#define __gnu_javax_crypto_keyring_Entry__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class Entry;
          class Properties;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::Entry : public ::java::lang::Object
{
public:  // actually protected
  Entry (jint, ::gnu::javax::crypto::keyring::Properties *);
  Entry (jint);
public:
  virtual ::gnu::javax::crypto::keyring::Properties *getProperties ();
  virtual jbyteArray getPayload ();
  virtual void encode (::java::io::DataOutputStream *);
  virtual ::java::lang::String *toString ();
public:  // actually protected
  virtual void defaultDecode (::java::io::DataInputStream *);
  virtual void encodePayload () = 0;
private:
  static ::java::util::logging::Logger *log;
  static JArray< ::java::lang::String *> *TYPES;
public:  // actually protected
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  type;
  ::gnu::javax::crypto::keyring::Properties *properties;
  jbyteArray payload;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_Entry__ */
