// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_net_protocol_ftp_CompressedOutputStream__
#define __gnu_java_net_protocol_ftp_CompressedOutputStream__

#pragma interface

#include <gnu/java/net/protocol/ftp/DTPOutputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace net
      {
        namespace protocol
        {
          namespace ftp
          {
            class CompressedOutputStream;
            class DTP;
          }
        }
      }
    }
  }
}

class gnu::java::net::protocol::ftp::CompressedOutputStream : public ::gnu::java::net::protocol::ftp::DTPOutputStream
{
public: // actually package-private
  CompressedOutputStream (::gnu::java::net::protocol::ftp::DTP *, ::java::io::OutputStream *);
public:
  virtual void write (jint);
  virtual void write (jbyteArray);
  virtual void write (jbyteArray, jint, jint);
public: // actually package-private
  virtual jbyteArray compress (jbyteArray, jint, jint);
  virtual jint flush_compressed (jbyteArray, jint, jint, jbyte);
  virtual jint flush_raw (jbyteArray, jint, jbyteArray, jint, jint);
  virtual jbyteArray realloc (jbyteArray, jint);
public:
  virtual void close ();
public: // actually package-private
  static const jint RECORD = -128L;
  static const jint EOF = 64L;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_net_protocol_ftp_CompressedOutputStream__ */
