// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_InterruptedIOException__
#define __java_io_InterruptedIOException__

#pragma interface

#include <java/io/IOException.h>

class java::io::InterruptedIOException : public ::java::io::IOException
{
public:
  InterruptedIOException ();
  InterruptedIOException (::java::lang::String *);
public: // actually package-private
  InterruptedIOException (::java::lang::String *, jint);
private:
  static const jlong serialVersionUID = 4020568460727500567LL;
public:
  jint __attribute__((aligned(__alignof__( ::java::io::IOException ))))  bytesTransferred;

  static ::java::lang::Class class$;
};

#endif /* __java_io_InterruptedIOException__ */
