// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_ietf_jgss_GSSName__
#define __org_ietf_jgss_GSSName__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace ietf
    {
      namespace jgss
      {
        class GSSName;
        class Oid;
      }
    }
  }
}

class org::ietf::jgss::GSSName : public ::java::lang::Object
{
public:
  virtual jboolean equals (::org::ietf::jgss::GSSName *) = 0;
  virtual jboolean equals (::java::lang::Object *) = 0;
  virtual jint hashCode () = 0;
  virtual ::org::ietf::jgss::GSSName *canonicalize (::org::ietf::jgss::Oid *) = 0;
  virtual jbyteArray export$ () = 0;
  virtual ::java::lang::String *toString () = 0;
  virtual ::org::ietf::jgss::Oid *getStringNameType () = 0;
  virtual jboolean isAnonymous () = 0;
  virtual jboolean isMN () = 0;
  static ::org::ietf::jgss::Oid *NT_ANONYMOUS;
  static ::org::ietf::jgss::Oid *NT_EXPORT_NAME;
  static ::org::ietf::jgss::Oid *NT_HOSTBASED_SERVICE;
  static ::org::ietf::jgss::Oid *NT_MACHINE_UID_NAME;
  static ::org::ietf::jgss::Oid *NT_STRING_UID_NAME;
  static ::org::ietf::jgss::Oid *NT_USER_NAME;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_ietf_jgss_GSSName__ */
