// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_prng_LimitReachedException__
#define __gnu_java_security_prng_LimitReachedException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace prng
        {
          class LimitReachedException;
        }
      }
    }
  }
}

class gnu::java::security::prng::LimitReachedException : public ::java::lang::Exception
{
public:
  LimitReachedException ();
  LimitReachedException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_prng_LimitReachedException__ */
