// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_MenuEvent__
#define __javax_swing_event_MenuEvent__

#pragma interface

#include <java/util/EventObject.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class MenuEvent;
      }
    }
  }
}

class javax::swing::event::MenuEvent : public ::java::util::EventObject
{
public:
  MenuEvent (::java::lang::Object *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_MenuEvent__ */
