// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_colorchooser_DefaultRGBChooserPanel__
#define __javax_swing_colorchooser_DefaultRGBChooserPanel__

#pragma interface

#include <javax/swing/colorchooser/AbstractColorChooserPanel.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace colorchooser
      {
        class DefaultRGBChooserPanel;
      }
      class Icon;
      class JColorChooser;
      class JSpinner;
      class JLabel;
      class JSlider;
      namespace event
      {
        class ChangeListener;
      }
    }
  }
}

class javax::swing::colorchooser::DefaultRGBChooserPanel : public ::javax::swing::colorchooser::AbstractColorChooserPanel
{
public:
  DefaultRGBChooserPanel ();
  virtual ::java::lang::String *getDisplayName ();
  virtual void updateChooser ();
public:  // actually protected
  virtual void buildChooser ();
public:
  virtual void uninstallChooserPanel (::javax::swing::JColorChooser *);
private:
  void uninstallListeners ();
  void installListeners ();
public:
  virtual ::javax::swing::Icon *getSmallDisplayIcon () { return 0; }
  virtual ::javax::swing::Icon *getLargeDisplayIcon () { return 0; }
  virtual void paint (::java::awt::Graphics *);
public: // actually package-private
  jboolean __attribute__((aligned(__alignof__( ::javax::swing::colorchooser::AbstractColorChooserPanel ))))  spinnerChange;
  jboolean sliderChange;
  jboolean updateChange;
private:
  ::javax::swing::event::ChangeListener *colorChanger;
  ::javax::swing::event::ChangeListener *spinnerHandler;
public: // actually package-private
  ::javax::swing::JSlider *R;
  ::javax::swing::JSlider *G;
  ::javax::swing::JSlider *B;
private:
  ::javax::swing::JLabel *RLabel;
  ::javax::swing::JLabel *GLabel;
  ::javax::swing::JLabel *BLabel;
public: // actually package-private
  ::javax::swing::JSpinner *RSpinner;
  ::javax::swing::JSpinner *GSpinner;
  ::javax::swing::JSpinner *BSpinner;

  friend class javax_swing_colorchooser_DefaultRGBChooserPanel$SpinnerHandler;
  friend class javax_swing_colorchooser_DefaultRGBChooserPanel$SliderHandler;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_colorchooser_DefaultRGBChooserPanel__ */
