// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_security_auth_login_GnuConfiguration__
#define __gnu_javax_security_auth_login_GnuConfiguration__

#pragma interface

#include <javax/security/auth/login/Configuration.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace login
        {
          class AppConfigurationEntry;
        }
      }
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace security
      {
        namespace auth
        {
          namespace login
          {
            class GnuConfiguration;
            class ConfigFileParser;
          }
        }
      }
    }
  }
}

class gnu::javax::security::auth::login::GnuConfiguration : public ::javax::security::auth::login::Configuration
{
public:
  GnuConfiguration ();
  virtual JArray< ::javax::security::auth::login::AppConfigurationEntry *> *getAppConfigurationEntry (::java::lang::String *);
  virtual void refresh ();
private:
  void init ();
  jboolean processSecurityProperties ();
  ::java::io::InputStream *getInputStreamFromURL (::java::lang::String *);
  jboolean processSystemProperty ();
  jboolean processUserHome ();
  void parseConfig (::java::io::InputStream *);
  void mergeLoginModules (::java::util::Map *);
  ::java::io::File *getUserHome ();
  ::java::io::File *getConfigFromUserHome (::java::io::File *, ::java::lang::String *);
  static ::java::util::logging::Logger *log;
  ::java::util::Map * __attribute__((aligned(__alignof__( ::javax::security::auth::login::Configuration )))) loginModulesMap;
  ::gnu::javax::security::auth::login::ConfigFileParser *cp;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_security_auth_login_GnuConfiguration__ */
