// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Polygon__
#define __java_awt_Polygon__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Polygon;
      namespace geom
      {
        class PathIterator;
        class AffineTransform;
        class Point2D;
        class Rectangle2D;
      }
      class Point;
      class Rectangle;
    }
  }
}

class java::awt::Polygon : public ::java::lang::Object
{
public:
  Polygon ();
  Polygon (jintArray, jintArray, jint);
  virtual void reset ();
  virtual void invalidate ();
  virtual void translate (jint, jint);
  virtual void addPoint (jint, jint);
  virtual ::java::awt::Rectangle *getBounds ();
  virtual ::java::awt::Rectangle *getBoundingBox ();
  virtual jboolean contains (::java::awt::Point *);
  virtual jboolean contains (jint, jint);
  virtual jboolean inside (jint, jint);
  virtual ::java::awt::geom::Rectangle2D *getBounds2D ();
  virtual jboolean contains (jdouble, jdouble);
  virtual jboolean contains (::java::awt::geom::Point2D *);
  virtual jboolean intersects (jdouble, jdouble, jdouble, jdouble);
  virtual jboolean intersects (::java::awt::geom::Rectangle2D *);
  virtual jboolean contains (jdouble, jdouble, jdouble, jdouble);
  virtual jboolean contains (::java::awt::geom::Rectangle2D *);
  virtual ::java::awt::geom::PathIterator *getPathIterator (::java::awt::geom::AffineTransform *);
  virtual ::java::awt::geom::PathIterator *getPathIterator (::java::awt::geom::AffineTransform *, jdouble);
private:
  jint evaluateCrossings (jdouble, jdouble, jboolean, jdouble);
  static const jlong serialVersionUID = -6460061437900069969LL;
public:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  npoints;
  jintArray xpoints;
  jintArray ypoints;
public:  // actually protected
  ::java::awt::Rectangle *bounds;
private:
  static const jdouble BIG_VALUE;

  friend class java_awt_Polygon$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Polygon__ */
