// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_InputEvent__
#define __java_awt_event_InputEvent__

#pragma interface

#include <java/awt/event/ComponentEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class InputEvent;
      }
      class Component;
    }
  }
}

class java::awt::event::InputEvent : public ::java::awt::event::ComponentEvent
{
public: // actually package-private
  InputEvent (::java::awt::Component *, jint, jlong, jint);
public:
  virtual jboolean isShiftDown ();
  virtual jboolean isControlDown ();
  virtual jboolean isMetaDown ();
  virtual jboolean isAltDown ();
  virtual jboolean isAltGraphDown ();
  virtual jlong getWhen () { return when; }
  virtual jint getModifiers () { return modifiers; }
  virtual jint getModifiersEx () { return modifiersEx; }
  virtual void consume ();
  virtual jboolean isConsumed () { return consumed; }
  static ::java::lang::String *getModifiersExText (jint);
private:
  static const jlong serialVersionUID = -2482525981698309786LL;
public:
  static const jint SHIFT_MASK = 1L;
  static const jint CTRL_MASK = 2L;
  static const jint META_MASK = 4L;
  static const jint ALT_MASK = 8L;
  static const jint ALT_GRAPH_MASK = 32L;
  static const jint BUTTON1_MASK = 16L;
  static const jint BUTTON2_MASK = 8L;
  static const jint BUTTON3_MASK = 4L;
  static const jint SHIFT_DOWN_MASK = 64L;
  static const jint CTRL_DOWN_MASK = 128L;
  static const jint META_DOWN_MASK = 256L;
  static const jint ALT_DOWN_MASK = 512L;
  static const jint BUTTON1_DOWN_MASK = 1024L;
  static const jint BUTTON2_DOWN_MASK = 2048L;
  static const jint BUTTON3_DOWN_MASK = 4096L;
  static const jint ALT_GRAPH_DOWN_MASK = 8192L;
public: // actually package-private
  static const jint CONVERT_MASK = 10176L;
private:
  jlong __attribute__((aligned(__alignof__( ::java::awt::event::ComponentEvent ))))  when;
public: // actually package-private
  jint modifiers;
  jint modifiersEx;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_InputEvent__ */
