// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_RETokenOneOf__
#define __gnu_java_util_regex_RETokenOneOf__

#pragma interface

#include <gnu/java/util/regex/REToken.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class RETokenOneOf;
          class REMatch;
          class CharIndexed;
        }
      }
    }
  }
}

class gnu::java::util::regex::RETokenOneOf : public ::gnu::java::util::regex::REToken
{
public: // actually package-private
  RETokenOneOf (jint, ::java::lang::String *, jboolean, jboolean);
  RETokenOneOf (jint, ::java::util::Vector *, jboolean);
  RETokenOneOf (jint, ::java::util::Vector *, ::java::util::Vector *, jboolean);
  virtual jint getMinimumLength ();
  virtual jint getMaximumLength ();
  virtual jboolean match (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
  virtual jboolean matchOneChar (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
private:
  jboolean matchN (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, jboolean);
  jboolean matchP (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, jboolean);
  jboolean matchOneRE (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
public: // actually package-private
  virtual ::gnu::java::util::regex::REMatch *findMatch (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
  virtual ::gnu::java::util::regex::REMatch *backtrack (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, ::java::lang::Object *);
private:
  ::gnu::java::util::regex::REMatch *findMatch (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, jint);
public: // actually package-private
  virtual jboolean returnsFixedLengthMatches () { return matchesOneChar; }
  virtual jint findFixedLengthMatches (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, jint);
  virtual void dump (::java::lang::StringBuffer *);
private:
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::gnu::java::util::regex::REToken )))) options;
  jboolean negative;
  jboolean matchesOneChar;
  ::java::util::Vector *addition;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_RETokenOneOf__ */
