// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_attribute_standard_MediaSizeName__
#define __javax_print_attribute_standard_MediaSizeName__

#pragma interface

#include <javax/print/attribute/standard/Media.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      namespace attribute
      {
        class EnumSyntax;
        namespace standard
        {
          class MediaSizeName;
        }
      }
    }
  }
}

class javax::print::attribute::standard::MediaSizeName : public ::javax::print::attribute::standard::Media
{
public:  // actually protected
  MediaSizeName (jint);
  virtual JArray< ::java::lang::String *> *getStringTable ();
  virtual JArray< ::javax::print::attribute::EnumSyntax *> *getEnumValueTable ();
private:
  static const jlong serialVersionUID = 2778798329756942747LL;
public:
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A0;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A1;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A2;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A3;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A4;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A5;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A6;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A7;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A8;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A9;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_A10;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B0;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B1;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B2;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B3;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B4;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B5;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B6;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B7;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B8;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B9;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_B10;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B0;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B1;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B2;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B3;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B4;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B5;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B6;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B7;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B8;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B9;
  static ::javax::print::attribute::standard::MediaSizeName *JIS_B10;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C0;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C1;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C2;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C3;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C4;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C5;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_C6;
  static ::javax::print::attribute::standard::MediaSizeName *NA_LETTER;
  static ::javax::print::attribute::standard::MediaSizeName *NA_LEGAL;
  static ::javax::print::attribute::standard::MediaSizeName *EXECUTIVE;
  static ::javax::print::attribute::standard::MediaSizeName *LEDGER;
  static ::javax::print::attribute::standard::MediaSizeName *TABLOID;
  static ::javax::print::attribute::standard::MediaSizeName *INVOICE;
  static ::javax::print::attribute::standard::MediaSizeName *FOLIO;
  static ::javax::print::attribute::standard::MediaSizeName *QUARTO;
  static ::javax::print::attribute::standard::MediaSizeName *JAPANESE_POSTCARD;
  static ::javax::print::attribute::standard::MediaSizeName *JAPANESE_DOUBLE_POSTCARD;
  static ::javax::print::attribute::standard::MediaSizeName *A;
  static ::javax::print::attribute::standard::MediaSizeName *B;
  static ::javax::print::attribute::standard::MediaSizeName *C;
  static ::javax::print::attribute::standard::MediaSizeName *D;
  static ::javax::print::attribute::standard::MediaSizeName *E;
  static ::javax::print::attribute::standard::MediaSizeName *ISO_DESIGNATED_LONG;
  static ::javax::print::attribute::standard::MediaSizeName *ITALY_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *MONARCH_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *PERSONAL_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_NUMBER_9_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_NUMBER_10_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_NUMBER_11_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_NUMBER_12_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_NUMBER_14_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_6X9_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_7X9_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_9X11_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_9X12_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_10X13_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_10X14_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_10X15_ENVELOPE;
  static ::javax::print::attribute::standard::MediaSizeName *NA_5X7;
  static ::javax::print::attribute::standard::MediaSizeName *NA_8X10;
private:
  static JArray< ::java::lang::String *> *stringTable;
  static JArray< ::javax::print::attribute::standard::MediaSizeName *> *enumValueTable;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_print_attribute_standard_MediaSizeName__ */
