// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_im_spi_InputMethodContext__
#define __java_awt_im_spi_InputMethodContext__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JFrame;
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace im
      {
        namespace spi
        {
          class InputMethodContext;
          class InputMethod;
        }
      }
      class Window;
      namespace font
      {
        class TextHitInfo;
      }
    }
    namespace text
    {
      class AttributedCharacterIterator;
    }
  }
}

class java::awt::im::spi::InputMethodContext : public ::java::lang::Object
{
public:
  virtual void dispatchInputMethodEvent (jint, ::java::text::AttributedCharacterIterator *, jint, ::java::awt::font::TextHitInfo *, ::java::awt::font::TextHitInfo *) = 0;
  virtual ::java::awt::Window *createInputMethodWindow (::java::lang::String *, jboolean) = 0;
  virtual ::javax::swing::JFrame *createInputMethodJFrame (::java::lang::String *, jboolean) = 0;
  virtual void enableClientWindowNotification (::java::awt::im::spi::InputMethod *, jboolean) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_im_spi_InputMethodContext__ */
