// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_SerializablePermission__
#define __java_io_SerializablePermission__

#pragma interface

#include <java/security/BasicPermission.h>
#include <gcj/array.h>

class java::io::SerializablePermission : public ::java::security::BasicPermission
{
public:
  SerializablePermission (::java::lang::String *);
  SerializablePermission (::java::lang::String *, ::java::lang::String *);
public: // actually package-private
  static const jlong serialVersionUID = 8537212141160296410LL;
private:
  static JArray< ::java::lang::String *> *legal_names;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_SerializablePermission__ */
