// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_directory_InvalidAttributeIdentifierException__
#define __javax_naming_directory_InvalidAttributeIdentifierException__

#pragma interface

#include <javax/naming/NamingException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace directory
      {
        class InvalidAttributeIdentifierException;
      }
    }
  }
}

class javax::naming::directory::InvalidAttributeIdentifierException : public ::javax::naming::NamingException
{
public:
  InvalidAttributeIdentifierException ();
  InvalidAttributeIdentifierException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -9036920266322999923LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_directory_InvalidAttributeIdentifierException__ */
