// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ThreadLocal__
#define __java_lang_ThreadLocal__

#pragma interface

#include <java/lang/Object.h>

class java::lang::ThreadLocal : public ::java::lang::Object
{
public:
  ThreadLocal ();
public:  // actually protected
  virtual ::java::lang::Object *initialValue () { return 0; }
public:
  virtual ::java::lang::Object *get ();
  virtual void set (::java::lang::Object *);
  virtual void remove ();
public: // actually package-private
  static ::java::lang::Object *NULL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ThreadLocal__ */
