// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_net_ssl_TrustManager__
#define __javax_net_ssl_TrustManager__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
        class TrustManager;
      }
    }
  }
}

class javax::net::ssl::TrustManager : public ::java::lang::Object
{
public:

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_net_ssl_TrustManager__ */
