// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_RETokenNamedProperty__
#define __gnu_java_util_regex_RETokenNamedProperty__

#pragma interface

#include <gnu/java/util/regex/REToken.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class RETokenNamedProperty;
          class REMatch;
          class CharIndexed;
          class RETokenNamedProperty$Handler;
        }
      }
    }
  }
}

class gnu::java::util::regex::RETokenNamedProperty : public ::gnu::java::util::regex::REToken
{
public: // actually package-private
  RETokenNamedProperty (jint, ::java::lang::String *, jboolean, jboolean);
  virtual jint getMinimumLength ();
  virtual jint getMaximumLength ();
  virtual ::gnu::java::util::regex::REMatch *matchThis (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *);
private:
  jboolean matchOneChar (jchar);
public: // actually package-private
  virtual jboolean returnsFixedLengthMatches ();
  virtual jint findFixedLengthMatches (::gnu::java::util::regex::CharIndexed *, ::gnu::java::util::regex::REMatch *, jint);
  virtual void dump (::java::lang::StringBuffer *);
private:
  ::gnu::java::util::regex::RETokenNamedProperty$Handler *getHandler (::java::lang::String *);
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::gnu::java::util::regex::REToken )))) name;
  jboolean insens;
  jboolean negate;
  ::gnu::java::util::regex::RETokenNamedProperty$Handler *handler;
  static jbyteArray LETTER;
  static jbyteArray MARK;
  static jbyteArray SEPARATOR;
  static jbyteArray SYMBOL;
  static jbyteArray NUMBER;
  static jbyteArray PUNCTUATION;
  static jbyteArray OTHER;

  friend class gnu_java_util_regex_RETokenNamedProperty$UnicodeBlockHandler;
  friend class gnu_java_util_regex_RETokenNamedProperty$UnicodeCategoriesHandler;
  friend class gnu_java_util_regex_RETokenNamedProperty$UnicodeCategoryHandler;
  friend class gnu_java_util_regex_RETokenNamedProperty$POSIXHandler;
  friend class gnu_java_util_regex_RETokenNamedProperty$Handler;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_RETokenNamedProperty__ */
