// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_Currency__
#define __java_util_Currency__

#pragma interface

#include <java/lang/Object.h>

class java::util::Currency : public ::java::lang::Object
{
private:
  Currency ();
  Currency (::java::util::Locale *);
public:
  virtual ::java::lang::String *getCurrencyCode () { return currencyCode; }
  virtual jint getDefaultFractionDigits ();
  static ::java::util::Currency *getInstance (::java::util::Locale *);
  static ::java::util::Currency *getInstance (::java::lang::String *);
  virtual ::java::lang::String *getSymbol ();
  virtual ::java::lang::String *getSymbol (::java::util::Locale *);
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::Object *readResolve ();
public: // actually package-private
  static const jlong serialVersionUID = -158308464356906721LL;
private:
  ::java::util::Locale * __attribute__((aligned(__alignof__( ::java::lang::Object )))) locale;
  ::java::util::ResourceBundle *res;
  ::java::lang::String *currencyCode;
  static ::java::util::Map *cache;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_Currency__ */
