// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_rmi_rmic_Compiler__
#define __gnu_java_rmi_rmic_Compiler__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace rmi
      {
        namespace rmic
        {
          class Compiler;
        }
      }
    }
  }
}

class gnu::java::rmi::rmic::Compiler : public ::java::lang::Object
{
public:  // actually protected
  Compiler ();
public:
  static ::gnu::java::rmi::rmic::Compiler *getInstance ();
  static ::gnu::java::rmi::rmic::Compiler *getInstance (::java::lang::String *);
  virtual ::java::lang::String *getDestination () { return dest; }
  virtual void setDestination (::java::lang::String *);
  virtual ::java::lang::String *getClasspath () { return classpath; }
  virtual void setClasspath (::java::lang::String *);
  virtual void compile (::java::lang::String *) = 0;
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) dest;
private:
  ::java::lang::String *classpath;
  static ::java::lang::String *classPrefix;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_rmi_rmic_Compiler__ */
