// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_REFilterInputStream__
#define __gnu_java_util_regex_REFilterInputStream__

#pragma interface

#include <java/io/FilterInputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
          class REFilterInputStream;
          class CharIndexedInputStream;
          class RE;
        }
      }
    }
  }
}

class gnu::java::util::regex::REFilterInputStream : public ::java::io::FilterInputStream
{
public:
  REFilterInputStream (::java::io::InputStream *, ::gnu::java::util::regex::RE *, ::java::lang::String *);
  virtual jint read ();
  virtual jboolean markSupported ();
  virtual jint read (jbyteArray, jint, jint);
  virtual jint read (jbyteArray);
private:
  ::gnu::java::util::regex::RE * __attribute__((aligned(__alignof__( ::java::io::FilterInputStream )))) expr;
  ::java::lang::String *replace;
  ::java::lang::String *buffer;
  jint bufpos;
  jint offset;
  ::gnu::java::util::regex::CharIndexedInputStream *stream;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_util_regex_REFilterInputStream__ */
