// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_WindowConstants__
#define __javax_swing_WindowConstants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class WindowConstants;
    }
  }
}

class javax::swing::WindowConstants : public ::java::lang::Object
{
public:
  static const jint DO_NOTHING_ON_CLOSE = 0L;
  static const jint HIDE_ON_CLOSE = 1L;
  static const jint DISPOSE_ON_CLOSE = 2L;
  static const jint EXIT_ON_CLOSE = 3L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_WindowConstants__ */
