// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_LinkedHashSet__
#define __java_util_LinkedHashSet__

#pragma interface

#include <java/util/HashSet.h>

class java::util::LinkedHashSet : public ::java::util::HashSet
{
public:
  LinkedHashSet ();
  LinkedHashSet (jint);
  LinkedHashSet (jint, jfloat);
  LinkedHashSet (::java::util::Collection *);
public: // actually package-private
  virtual ::java::util::HashMap *init (jint, jfloat);
private:
  static const jlong serialVersionUID = -2851667679971038690LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_LinkedHashSet__ */
