// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_sound_midi_spi_SoundbankReader__
#define __javax_sound_midi_spi_SoundbankReader__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace sound
    {
      namespace midi
      {
        namespace spi
        {
          class SoundbankReader;
        }
        class Soundbank;
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URL;
    }
  }
}

class javax::sound::midi::spi::SoundbankReader : public ::java::lang::Object
{
public:
  virtual ::javax::sound::midi::Soundbank *getSoundbank (::java::net::URL *) = 0;
  virtual ::javax::sound::midi::Soundbank *getSoundbank (::java::io::InputStream *) = 0;
  virtual ::javax::sound::midi::Soundbank *getSoundbank (::java::io::File *) = 0;
  SoundbankReader ();

  static ::java::lang::Class class$;
};

#endif /* __javax_sound_midi_spi_SoundbankReader__ */
