// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Process__
#define __java_lang_Process__

#pragma interface

#include <java/lang/Object.h>

class java::lang::Process : public ::java::lang::Object
{
public:
  Process ();
  virtual ::java::io::OutputStream *getOutputStream () = 0;
  virtual ::java::io::InputStream *getInputStream () = 0;
  virtual ::java::io::InputStream *getErrorStream () = 0;
  virtual jint waitFor () = 0;
  virtual jint exitValue () = 0;
  virtual void destroy () = 0;

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Process__ */
