// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_security_auth_x500_X500PrivateCredential__
#define __javax_security_auth_x500_X500PrivateCredential__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace x500
        {
          class X500PrivateCredential;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class X509Certificate;
      }
      class PrivateKey;
    }
  }
}

class javax::security::auth::x500::X500PrivateCredential : public ::java::lang::Object
{
public:
  X500PrivateCredential (::java::security::cert::X509Certificate *, ::java::security::PrivateKey *);
  X500PrivateCredential (::java::security::cert::X509Certificate *, ::java::security::PrivateKey *, ::java::lang::String *);
  virtual ::java::security::cert::X509Certificate *getCertificate () { return certificate; }
  virtual ::java::security::PrivateKey *getPrivateKey () { return key; }
  virtual ::java::lang::String *getAlias () { return alias; }
  virtual void destroy ();
  virtual jboolean isDestroyed ();
private:
  ::java::security::PrivateKey * __attribute__((aligned(__alignof__( ::java::lang::Object )))) key;
  ::java::security::cert::X509Certificate *certificate;
  ::java::lang::String *alias;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_security_auth_x500_X500PrivateCredential__ */
