// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_reflect_GenericSignatureFormatError__
#define __java_lang_reflect_GenericSignatureFormatError__

#pragma interface

#include <java/lang/ClassFormatError.h>

class java::lang::reflect::GenericSignatureFormatError : public ::java::lang::ClassFormatError
{
public:
  GenericSignatureFormatError ();
private:
  static const jlong serialVersionUID = 6709919147137911034LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_reflect_GenericSignatureFormatError__ */
