// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_CertPath__
#define __java_security_cert_CertPath__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class CertPath;
      }
    }
  }
}

class java::security::cert::CertPath : public ::java::lang::Object
{
public:  // actually protected
  CertPath (::java::lang::String *);
public:
  virtual ::java::lang::String *getType () { return type; }
  virtual ::java::util::Iterator *getEncodings () = 0;
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
  virtual jbyteArray getEncoded () = 0;
  virtual jbyteArray getEncoded (::java::lang::String *) = 0;
  virtual ::java::util::List *getCertificates () = 0;
public:  // actually protected
  virtual ::java::lang::Object *writeReplace ();
private:
  static const jlong serialVersionUID = 6068470306649138683LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) type;

  friend class java_security_cert_CertPath$CertPathRep;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_cert_CertPath__ */
