// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_PaintEvent__
#define __java_awt_event_PaintEvent__

#pragma interface

#include <java/awt/event/ComponentEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class PaintEvent;
      }
      class Component;
      class Rectangle;
    }
  }
}

class java::awt::event::PaintEvent : public ::java::awt::event::ComponentEvent
{
public:
  PaintEvent (::java::awt::Component *, jint, ::java::awt::Rectangle *);
  virtual ::java::awt::Rectangle *getUpdateRect () { return updateRect; }
  virtual void setUpdateRect (::java::awt::Rectangle *);
  virtual ::java::lang::String *paramString ();
private:
  static const jlong serialVersionUID = 1267492026433337593LL;
public:
  static const jint PAINT_FIRST = 800L;
  static const jint PAINT_LAST = 801L;
  static const jint PAINT = 800L;
  static const jint UPDATE = 801L;
private:
  ::java::awt::Rectangle * __attribute__((aligned(__alignof__( ::java::awt::event::ComponentEvent )))) updateRect;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_PaintEvent__ */
