// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_VMSecureRandom__
#define __java_security_VMSecureRandom__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class VMSecureRandom;
    }
  }
}

class java::security::VMSecureRandom : public ::java::lang::Object
{
public: // actually package-private
  static jint generateSeed (jbyteArray, jint, jint);
  VMSecureRandom ();

  friend class java_security_VMSecureRandom$Spinner;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_VMSecureRandom__ */
