// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_color_ColorLookUpTable__
#define __gnu_java_awt_color_ColorLookUpTable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace color
        {
          class ColorLookUpTable;
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class ICC_Profile;
      }
    }
  }
}

class gnu::java::awt::color::ColorLookUpTable : public ::java::lang::Object
{
public:
  ColorLookUpTable (::java::awt::color::ICC_Profile *, jint);
private:
  void readClut16 (jbyteArray);
  void readClut8 (jbyteArray);
public: // actually package-private
  virtual jfloatArray lookup (jfloatArray);
private:
  jfloatArray LabtoXYZ (jfloatArray);
  jfloatArray XYZtoLab (jfloatArray);
  static jfloatArray D50;
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  nIn;
  jint nOut;
  jint nInTableEntries;
  jint nOutTableEntries;
  jint gridpoints;
  jint nClut;
  JArray<jdoubleArray> * inTable;
  JArray<jshortArray> * outTable;
  jdoubleArray clut;
  JArray<jfloatArray> * inMatrix;
  jboolean useMatrix;
  jintArray multiplier;
  jintArray offsets;
  jboolean inputLab;
  jboolean outputLab;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_color_ColorLookUpTable__ */
