// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_sig_rsa_EME_PKCS1_V1_5__
#define __gnu_java_security_sig_rsa_EME_PKCS1_V1_5__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace interfaces
      {
        class RSAKey;
      }
    }
  }
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace prng
        {
          class IRandom;
        }
        namespace sig
        {
          namespace rsa
          {
            class EME_PKCS1_V1_5;
          }
        }
        namespace util
        {
          class PRNG;
        }
      }
    }
  }
}

class gnu::java::security::sig::rsa::EME_PKCS1_V1_5 : public ::java::lang::Object
{
private:
  EME_PKCS1_V1_5 (jint);
public:
  static ::gnu::java::security::sig::rsa::EME_PKCS1_V1_5 *getInstance (jint);
  static ::gnu::java::security::sig::rsa::EME_PKCS1_V1_5 *getInstance (::java::security::interfaces::RSAKey *);
  virtual jbyteArray encode (jbyteArray);
  virtual jbyteArray encode (jbyteArray, ::gnu::java::security::prng::IRandom *);
  virtual jbyteArray encode (jbyteArray, ::java::util::Random *);
  virtual jbyteArray decode (jbyteArray);
private:
  jbyteArray assembleEM (jbyteArray, jbyteArray);
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  k;
  ::java::io::ByteArrayOutputStream *baos;
  ::gnu::java::security::util::PRNG *prng;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_sig_rsa_EME_PKCS1_V1_5__ */
