// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_util_Debug__
#define __gnu_gcj_util_Debug__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace util
      {
        class Debug;
      }
    }
  }
}

class gnu::gcj::util::Debug : public ::java::lang::Object
{
public: // actually package-private
  Debug (::java::io::PrintStream *, jint, jint, jboolean);
  Debug (::java::io::PrintStream *);
  Debug (jint, jboolean);
  Debug (jint);
  Debug ();
private:
  void indent ();
  static JArray< ::java::lang::reflect::Field *> *getDeclaredFields (::java::lang::Class *);
  static ::java::lang::Object *getField (::java::lang::Object *, ::java::lang::reflect::Field *);
  static jlong getAddr (::java::lang::Object *);
  JArray< ::java::lang::reflect::Field *> *internalGetFields (::java::lang::Class *);
  static ::java::lang::Class *getItsClass (::java::lang::Object *);
  void print (::java::lang::Object *);
  void print0 (::java::lang::Object *, ::java::lang::Class *);
public:
  virtual void write (::java::lang::Object *);
private:
  ::java::io::PrintStream * __attribute__((aligned(__alignof__( ::java::lang::Object )))) p;
  jint maxdepth;
  jint maxArrayLength;
  jboolean printStaticFields;
  jint depth;
  ::java::util::IdentityHashMap *h;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_util_Debug__ */
