// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_sql_Types__
#define __java_sql_Types__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace sql
    {
      class Types;
    }
  }
}

class java::sql::Types : public ::java::lang::Object
{
private:
  Types ();
public:
  static const jint BIT = -7L;
  static const jint TINYINT = -6L;
  static const jint SMALLINT = 5L;
  static const jint INTEGER = 4L;
  static const jint BIGINT = -5L;
  static const jint FLOAT = 6L;
  static const jint REAL = 7L;
  static const jint DOUBLE = 8L;
  static const jint NUMERIC = 2L;
  static const jint DECIMAL = 3L;
  static const jint CHAR = 1L;
  static const jint VARCHAR = 12L;
  static const jint LONGVARCHAR = -1L;
  static const jint DATE = 91L;
  static const jint TIME = 92L;
  static const jint TIMESTAMP = 93L;
  static const jint BINARY = -2L;
  static const jint VARBINARY = -3L;
  static const jint LONGVARBINARY = -4L;
  static const jint NULL = 0L;
  static const jint OTHER = 1111L;
  static const jint JAVA_OBJECT = 2000L;
  static const jint DISTINCT = 2001L;
  static const jint STRUCT = 2002L;
  static const jint ARRAY = 2003L;
  static const jint BLOB = 2004L;
  static const jint CLOB = 2005L;
  static const jint REF = 2006L;
  static const jint DATALINK = 70L;
  static const jint BOOLEAN = 16L;

  static ::java::lang::Class class$;
};

#endif /* __java_sql_Types__ */
