// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JSeparator__
#define __javax_swing_JSeparator__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JSeparator;
      namespace plaf
      {
        class SeparatorUI;
      }
    }
  }
}

class javax::swing::JSeparator : public ::javax::swing::JComponent
{
public:
  JSeparator ();
  JSeparator (jint);
  virtual ::javax::swing::plaf::SeparatorUI *getUI ();
  virtual void setUI (::javax::swing::plaf::SeparatorUI *);
  virtual void updateUI ();
  virtual ::java::lang::String *getUIClassID ();
  virtual jint getOrientation () { return orientation; }
  virtual void setOrientation (jint);
public:  // actually protected
  virtual ::java::lang::String *paramString ();
public:
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext ();
private:
  static const jlong serialVersionUID = 125301223445282357LL;
  jint __attribute__((aligned(__alignof__( ::javax::swing::JComponent ))))  orientation;

  friend class javax_swing_JSeparator$AccessibleJSeparator;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JSeparator__ */
