// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalComboBoxButton__
#define __javax_swing_plaf_metal_MetalComboBoxButton__

#pragma interface

#include <javax/swing/JButton.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalComboBoxButton;
        }
      }
      class Icon;
      class CellRendererPane;
      class JList;
      class JComboBox;
    }
  }
}

class javax::swing::plaf::metal::MetalComboBoxButton : public ::javax::swing::JButton
{
public:
  MetalComboBoxButton (::javax::swing::JComboBox *, ::javax::swing::Icon *, ::javax::swing::CellRendererPane *, ::javax::swing::JList *);
  MetalComboBoxButton (::javax::swing::JComboBox *, ::javax::swing::Icon *, jboolean, ::javax::swing::CellRendererPane *, ::javax::swing::JList *);
  virtual ::javax::swing::JComboBox *getComboBox () { return comboBox; }
  virtual void setComboBox (::javax::swing::JComboBox *);
  virtual ::javax::swing::Icon *getComboIcon () { return comboIcon; }
  virtual void setComboIcon (::javax::swing::Icon *);
  virtual jboolean isIconOnly () { return iconOnly; }
  virtual void setIconOnly (jboolean);
  virtual jboolean isFocusTraversable ();
  virtual void setEnabled (jboolean);
  virtual void paintComponent (::java::awt::Graphics *);
public:  // actually protected
  ::javax::swing::JComboBox * __attribute__((aligned(__alignof__( ::javax::swing::JButton )))) comboBox;
  ::javax::swing::JList *listBox;
  ::javax::swing::CellRendererPane *rendererPane;
  ::javax::swing::Icon *comboIcon;
  jboolean iconOnly;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalComboBoxButton__ */
