// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_NoSuchElementException__
#define __java_util_NoSuchElementException__

#pragma interface

#include <java/lang/RuntimeException.h>

class java::util::NoSuchElementException : public ::java::lang::RuntimeException
{
public:
  NoSuchElementException ();
  NoSuchElementException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 6769829250639411880LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_NoSuchElementException__ */
