// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_sql_SQLPermission__
#define __java_sql_SQLPermission__

#pragma interface

#include <java/security/BasicPermission.h>

extern "Java"
{
  namespace java
  {
    namespace sql
    {
      class SQLPermission;
    }
  }
}

class java::sql::SQLPermission : public ::java::security::BasicPermission
{
public:
  SQLPermission (::java::lang::String *);
  SQLPermission (::java::lang::String *, ::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_sql_SQLPermission__ */
