// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_HelperClassLoader__
#define __gnu_gcj_runtime_HelperClassLoader__

#pragma interface

#include <java/net/URLClassLoader.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class HelperClassLoader;
      }
    }
  }
}

class gnu::gcj::runtime::HelperClassLoader : public ::java::net::URLClassLoader
{
public: // actually package-private
  HelperClassLoader ();
  HelperClassLoader (::java::lang::ClassLoader *);
  virtual void addDirectoriesFromProperty (::java::lang::String *);

  friend class gnu_gcj_runtime_HelperClassLoader$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_HelperClassLoader__ */
