// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Composite__
#define __java_awt_Composite__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Composite;
      class CompositeContext;
      class RenderingHints;
      namespace image
      {
        class ColorModel;
      }
    }
  }
}

class java::awt::Composite : public ::java::lang::Object
{
public:
  virtual ::java::awt::CompositeContext *createContext (::java::awt::image::ColorModel *, ::java::awt::image::ColorModel *, ::java::awt::RenderingHints *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_Composite__ */
