// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_DefaultFocusManager__
#define __javax_swing_DefaultFocusManager__

#pragma interface

#include <javax/swing/FocusManager.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class DefaultFocusManager;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Container;
      namespace event
      {
        class KeyEvent;
      }
      class Component;
    }
  }
}

class javax::swing::DefaultFocusManager : public ::javax::swing::FocusManager
{
public:
  DefaultFocusManager ();
  virtual void processKeyEvent (::java::awt::Component *, ::java::awt::event::KeyEvent *) { }
  virtual void focusNextComponent (::java::awt::Component *) { }
  virtual void focusPreviousComponent (::java::awt::Component *) { }
  virtual ::java::awt::Component *getFirstComponent (::java::awt::Container *) { return 0; }
  virtual ::java::awt::Component *getLastComponent (::java::awt::Container *) { return 0; }
  virtual ::java::awt::Component *getComponentBefore (::java::awt::Container *, ::java::awt::Component *) { return 0; }
  virtual ::java::awt::Component *getComponentAfter (::java::awt::Container *, ::java::awt::Component *) { return 0; }
  virtual jboolean compareTabOrder (::java::awt::Component *, ::java::awt::Component *);
private:
  ::java::util::Stack * __attribute__((aligned(__alignof__( ::javax::swing::FocusManager )))) historyStack;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_DefaultFocusManager__ */
