// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalButtonUI__
#define __javax_swing_plaf_metal_MetalButtonUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicButtonUI.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class AbstractButton;
      namespace plaf
      {
        namespace metal
        {
          class MetalButtonUI;
        }
        namespace basic
        {
          class BasicButtonListener;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Component;
      class Rectangle;
      class Graphics;
      class Color;
    }
  }
}

class javax::swing::plaf::metal::MetalButtonUI : public ::javax::swing::plaf::basic::BasicButtonUI
{
public:
  MetalButtonUI ();
public:  // actually protected
  virtual ::java::awt::Color *getFocusColor () { return focusColor; }
  virtual ::java::awt::Color *getSelectColor () { return selectColor; }
  virtual ::java::awt::Color *getDisabledTextColor () { return disabledTextColor; }
public:
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual void installDefaults (::javax::swing::AbstractButton *);
  virtual void uninstallDefaults (::javax::swing::AbstractButton *);
public:  // actually protected
  virtual ::javax::swing::plaf::basic::BasicButtonListener *createButtonListener (::javax::swing::AbstractButton *);
  virtual void paintButtonPressed (::java::awt::Graphics *, ::javax::swing::AbstractButton *);
  virtual void paintFocus (::java::awt::Graphics *, ::javax::swing::AbstractButton *, ::java::awt::Rectangle *, ::java::awt::Rectangle *, ::java::awt::Rectangle *);
  virtual void paintText (::java::awt::Graphics *, ::javax::swing::JComponent *, ::java::awt::Rectangle *, ::java::lang::String *);
public:
  virtual void update (::java::awt::Graphics *, ::javax::swing::JComponent *);
private:
  jboolean isToolbarButton (::java::awt::Component *);
  jboolean isDrawingGradient (::java::lang::String *);
public:  // actually protected
  ::java::awt::Color * __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicButtonUI )))) focusColor;
  ::java::awt::Color *selectColor;
  ::java::awt::Color *disabledTextColor;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalButtonUI__ */
