// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_applet_AudioClip__
#define __java_applet_AudioClip__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace applet
    {
      class AudioClip;
    }
  }
}

class java::applet::AudioClip : public ::java::lang::Object
{
public:
  virtual void play () = 0;
  virtual void stop () = 0;
  virtual void loop () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_applet_AudioClip__ */
