// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_CertificateExpiredException__
#define __java_security_cert_CertificateExpiredException__

#pragma interface

#include <java/security/cert/CertificateException.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class CertificateExpiredException;
      }
    }
  }
}

class java::security::cert::CertificateExpiredException : public ::java::security::cert::CertificateException
{
public:
  CertificateExpiredException ();
  CertificateExpiredException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 9071001339691533771LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_cert_CertificateExpiredException__ */
