// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_synth_Region__
#define __javax_swing_plaf_synth_Region__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace synth
        {
          class Region;
        }
      }
    }
  }
}

class javax::swing::plaf::synth::Region : public ::java::lang::Object
{
public:  // actually protected
  Region (::java::lang::String *, ::java::lang::String *, jboolean);
public:
  virtual jboolean isSubregion () { return subregion; }
  virtual ::java::lang::String *getName () { return name; }
  virtual ::java::lang::String *toString () { return name; }
  static ::javax::swing::plaf::synth::Region *ARROW_BUTTON;
  static ::javax::swing::plaf::synth::Region *BUTTON;
  static ::javax::swing::plaf::synth::Region *CHECK_BOX;
  static ::javax::swing::plaf::synth::Region *CHECK_BOX_MENU_ITEM;
  static ::javax::swing::plaf::synth::Region *COLOR_CHOOSER;
  static ::javax::swing::plaf::synth::Region *COMBO_BOX;
  static ::javax::swing::plaf::synth::Region *DESKTOP_PANE;
  static ::javax::swing::plaf::synth::Region *DESKTOP_ICON;
  static ::javax::swing::plaf::synth::Region *EDITOR_PANE;
  static ::javax::swing::plaf::synth::Region *FILE_CHOOSER;
  static ::javax::swing::plaf::synth::Region *FORMATTED_TEXT_FIELD;
  static ::javax::swing::plaf::synth::Region *INTERNAL_FRAME;
  static ::javax::swing::plaf::synth::Region *INTERNAL_FRAME_TITLE_PANE;
  static ::javax::swing::plaf::synth::Region *LABEL;
  static ::javax::swing::plaf::synth::Region *LIST;
  static ::javax::swing::plaf::synth::Region *MENU;
  static ::javax::swing::plaf::synth::Region *MENU_BAR;
  static ::javax::swing::plaf::synth::Region *MENU_ITEM;
  static ::javax::swing::plaf::synth::Region *MENU_ITEM_ACCELERATOR;
  static ::javax::swing::plaf::synth::Region *OPTION_PANE;
  static ::javax::swing::plaf::synth::Region *PANEL;
  static ::javax::swing::plaf::synth::Region *PASSWORD_FIELD;
  static ::javax::swing::plaf::synth::Region *POPUP_MENU;
  static ::javax::swing::plaf::synth::Region *POPUP_MENU_SEPARATOR;
  static ::javax::swing::plaf::synth::Region *PROGRESS_BAR;
  static ::javax::swing::plaf::synth::Region *RADIO_BUTTON;
  static ::javax::swing::plaf::synth::Region *RADIO_BUTTON_MENU_ITEM;
  static ::javax::swing::plaf::synth::Region *ROOT_PANE;
  static ::javax::swing::plaf::synth::Region *SCROLL_BAR;
  static ::javax::swing::plaf::synth::Region *SCROLL_BAR_TRACK;
  static ::javax::swing::plaf::synth::Region *SCROLL_BAR_THUMB;
  static ::javax::swing::plaf::synth::Region *SCROLL_PANE;
  static ::javax::swing::plaf::synth::Region *SEPARATOR;
  static ::javax::swing::plaf::synth::Region *SLIDER;
  static ::javax::swing::plaf::synth::Region *SLIDER_TRACK;
  static ::javax::swing::plaf::synth::Region *SLIDER_THUMB;
  static ::javax::swing::plaf::synth::Region *SPINNER;
  static ::javax::swing::plaf::synth::Region *SPLIT_PANE;
  static ::javax::swing::plaf::synth::Region *SPLIT_PANE_DIVIDER;
  static ::javax::swing::plaf::synth::Region *TABBED_PANE;
  static ::javax::swing::plaf::synth::Region *TABBED_PANE_TAB;
  static ::javax::swing::plaf::synth::Region *TABBED_PANE_TAB_AREA;
  static ::javax::swing::plaf::synth::Region *TABBED_PANE_CONTENT;
  static ::javax::swing::plaf::synth::Region *TABLE;
  static ::javax::swing::plaf::synth::Region *TABLE_HEADER;
  static ::javax::swing::plaf::synth::Region *TEXT_AREA;
  static ::javax::swing::plaf::synth::Region *TEXT_FIELD;
  static ::javax::swing::plaf::synth::Region *TEXT_PANE;
  static ::javax::swing::plaf::synth::Region *TOGGLE_BUTTON;
  static ::javax::swing::plaf::synth::Region *TOOL_BAR;
  static ::javax::swing::plaf::synth::Region *TOOL_BAR_CONTENT;
  static ::javax::swing::plaf::synth::Region *TOOL_BAR_DRAG_WINDOW;
  static ::javax::swing::plaf::synth::Region *TOOL_TIP;
  static ::javax::swing::plaf::synth::Region *TOOL_BAR_SEPARATOR;
  static ::javax::swing::plaf::synth::Region *TREE;
  static ::javax::swing::plaf::synth::Region *TREE_CELL;
  static ::javax::swing::plaf::synth::Region *VIEWPORT;
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) ui;
private:
  ::java::lang::String *name;
  jboolean subregion;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_synth_Region__ */
