// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_print_PrintException__
#define __javax_print_PrintException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace print
    {
      class PrintException;
    }
  }
}

class javax::print::PrintException : public ::java::lang::Exception
{
public:
  PrintException ();
  PrintException (::java::lang::Exception *);
  PrintException (::java::lang::String *);
  PrintException (::java::lang::String *, ::java::lang::Exception *);

  static ::java::lang::Class class$;
};

#endif /* __javax_print_PrintException__ */
