// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_accessibility_AccessibleRole__
#define __javax_accessibility_AccessibleRole__

#pragma interface

#include <javax/accessibility/AccessibleBundle.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleRole;
    }
  }
}

class javax::accessibility::AccessibleRole : public ::javax::accessibility::AccessibleBundle
{
public:  // actually protected
  AccessibleRole (::java::lang::String *);
public:
  static ::javax::accessibility::AccessibleRole *ALERT;
  static ::javax::accessibility::AccessibleRole *COLUMN_HEADER;
  static ::javax::accessibility::AccessibleRole *CANVAS;
  static ::javax::accessibility::AccessibleRole *COMBO_BOX;
  static ::javax::accessibility::AccessibleRole *DESKTOP_ICON;
  static ::javax::accessibility::AccessibleRole *INTERNAL_FRAME;
  static ::javax::accessibility::AccessibleRole *DESKTOP_PANE;
  static ::javax::accessibility::AccessibleRole *OPTION_PANE;
  static ::javax::accessibility::AccessibleRole *WINDOW;
  static ::javax::accessibility::AccessibleRole *FRAME;
  static ::javax::accessibility::AccessibleRole *DIALOG;
  static ::javax::accessibility::AccessibleRole *COLOR_CHOOSER;
  static ::javax::accessibility::AccessibleRole *DIRECTORY_PANE;
  static ::javax::accessibility::AccessibleRole *FILE_CHOOSER;
  static ::javax::accessibility::AccessibleRole *FILLER;
  static ::javax::accessibility::AccessibleRole *HYPERLINK;
  static ::javax::accessibility::AccessibleRole *ICON;
  static ::javax::accessibility::AccessibleRole *LABEL;
  static ::javax::accessibility::AccessibleRole *ROOT_PANE;
  static ::javax::accessibility::AccessibleRole *GLASS_PANE;
  static ::javax::accessibility::AccessibleRole *LAYERED_PANE;
  static ::javax::accessibility::AccessibleRole *LIST;
  static ::javax::accessibility::AccessibleRole *LIST_ITEM;
  static ::javax::accessibility::AccessibleRole *MENU_BAR;
  static ::javax::accessibility::AccessibleRole *POPUP_MENU;
  static ::javax::accessibility::AccessibleRole *MENU;
  static ::javax::accessibility::AccessibleRole *MENU_ITEM;
  static ::javax::accessibility::AccessibleRole *SEPARATOR;
  static ::javax::accessibility::AccessibleRole *PAGE_TAB_LIST;
  static ::javax::accessibility::AccessibleRole *PAGE_TAB;
  static ::javax::accessibility::AccessibleRole *PANEL;
  static ::javax::accessibility::AccessibleRole *PROGRESS_BAR;
  static ::javax::accessibility::AccessibleRole *PASSWORD_TEXT;
  static ::javax::accessibility::AccessibleRole *PUSH_BUTTON;
  static ::javax::accessibility::AccessibleRole *TOGGLE_BUTTON;
  static ::javax::accessibility::AccessibleRole *CHECK_BOX;
  static ::javax::accessibility::AccessibleRole *RADIO_BUTTON;
  static ::javax::accessibility::AccessibleRole *ROW_HEADER;
  static ::javax::accessibility::AccessibleRole *SCROLL_PANE;
  static ::javax::accessibility::AccessibleRole *SCROLL_BAR;
  static ::javax::accessibility::AccessibleRole *VIEWPORT;
  static ::javax::accessibility::AccessibleRole *SLIDER;
  static ::javax::accessibility::AccessibleRole *SPLIT_PANE;
  static ::javax::accessibility::AccessibleRole *TABLE;
  static ::javax::accessibility::AccessibleRole *TEXT;
  static ::javax::accessibility::AccessibleRole *TREE;
  static ::javax::accessibility::AccessibleRole *TOOL_BAR;
  static ::javax::accessibility::AccessibleRole *TOOL_TIP;
  static ::javax::accessibility::AccessibleRole *AWT_COMPONENT;
  static ::javax::accessibility::AccessibleRole *SWING_COMPONENT;
  static ::javax::accessibility::AccessibleRole *UNKNOWN;
  static ::javax::accessibility::AccessibleRole *STATUS_BAR;
  static ::javax::accessibility::AccessibleRole *DATE_EDITOR;
  static ::javax::accessibility::AccessibleRole *SPIN_BOX;
  static ::javax::accessibility::AccessibleRole *FONT_CHOOSER;
  static ::javax::accessibility::AccessibleRole *GROUP_BOX;
  static ::javax::accessibility::AccessibleRole *EDITBAR;
  static ::javax::accessibility::AccessibleRole *FOOTER;
  static ::javax::accessibility::AccessibleRole *HEADER;
  static ::javax::accessibility::AccessibleRole *PARAGRAPH;
  static ::javax::accessibility::AccessibleRole *PROGRESS_MONITOR;
  static ::javax::accessibility::AccessibleRole *RULER;

  static ::java::lang::Class class$;
};

#endif /* __javax_accessibility_AccessibleRole__ */
