// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_MalformedKeyringException__
#define __gnu_javax_crypto_keyring_MalformedKeyringException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
          class MalformedKeyringException;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::MalformedKeyringException : public ::java::io::IOException
{
public:
  MalformedKeyringException ();
  MalformedKeyringException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_keyring_MalformedKeyringException__ */
