// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_FocusEvent__
#define __java_awt_event_FocusEvent__

#pragma interface

#include <java/awt/event/ComponentEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class FocusEvent;
      }
      class Component;
    }
  }
}

class java::awt::event::FocusEvent : public ::java::awt::event::ComponentEvent
{
public:
  FocusEvent (::java::awt::Component *, jint, jboolean, ::java::awt::Component *);
  FocusEvent (::java::awt::Component *, jint, jboolean);
  FocusEvent (::java::awt::Component *, jint);
  virtual jboolean isTemporary () { return temporary; }
  virtual ::java::awt::Component *getOppositeComponent () { return opposite; }
  virtual ::java::lang::String *paramString ();
private:
  static const jlong serialVersionUID = 523753786457416396LL;
public:
  static const jint FOCUS_FIRST = 1004L;
  static const jint FOCUS_LAST = 1005L;
  static const jint FOCUS_GAINED = 1004L;
  static const jint FOCUS_LOST = 1005L;
private:
  jboolean __attribute__((aligned(__alignof__( ::java::awt::event::ComponentEvent ))))  temporary;
  ::java::awt::Component *opposite;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_FocusEvent__ */
