// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_ComponentInputMapUIResource__
#define __javax_swing_plaf_ComponentInputMapUIResource__

#pragma interface

#include <javax/swing/ComponentInputMap.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class ComponentInputMapUIResource;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::ComponentInputMapUIResource : public ::javax::swing::ComponentInputMap
{
public:
  ComponentInputMapUIResource (::javax::swing::JComponent *);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_ComponentInputMapUIResource__ */
