// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_Pointer__
#define __gnu_classpath_Pointer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      class Pointer;
    }
  }
}

class gnu::classpath::Pointer : public ::java::lang::Object
{
public:
  Pointer ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_classpath_Pointer__ */
