// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_ObjectInput__
#define __java_io_ObjectInput__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class java::io::ObjectInput : public ::java::lang::Object
{
public:
  virtual jint available () = 0;
  virtual jint read () = 0;
  virtual jint read (jbyteArray) = 0;
  virtual jint read (jbyteArray, jint, jint) = 0;
  virtual ::java::lang::Object *readObject () = 0;
  virtual jlong skip (jlong) = 0;
  virtual void close () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_io_ObjectInput__ */
