// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipConstants__
#define __java_util_zip_ZipConstants__

#pragma interface

#include <java/lang/Object.h>

class java::util::zip::ZipConstants : public ::java::lang::Object
{
public:
  static const jint LOCHDR = 30L;
  static const jlong LOCSIG = 67324752LL;
  static const jint LOCVER = 4L;
  static const jint LOCFLG = 6L;
  static const jint LOCHOW = 8L;
  static const jint LOCTIM = 10L;
  static const jint LOCCRC = 14L;
  static const jint LOCSIZ = 18L;
  static const jint LOCLEN = 22L;
  static const jint LOCNAM = 26L;
  static const jint LOCEXT = 28L;
  static const jlong EXTSIG = 134695760LL;
  static const jint EXTHDR = 16L;
  static const jint EXTCRC = 4L;
  static const jint EXTSIZ = 8L;
  static const jint EXTLEN = 12L;
  static const jlong CENSIG = 33639248LL;
  static const jint CENHDR = 46L;
  static const jint CENVEM = 4L;
  static const jint CENVER = 6L;
  static const jint CENFLG = 8L;
  static const jint CENHOW = 10L;
  static const jint CENTIM = 12L;
  static const jint CENCRC = 16L;
  static const jint CENSIZ = 20L;
  static const jint CENLEN = 24L;
  static const jint CENNAM = 28L;
  static const jint CENEXT = 30L;
  static const jint CENCOM = 32L;
  static const jint CENDSK = 34L;
  static const jint CENATT = 36L;
  static const jint CENATX = 38L;
  static const jint CENOFF = 42L;
  static const jlong ENDSIG = 101010256LL;
  static const jint ENDHDR = 22L;
  static const jint ENDSUB = 8L;
  static const jint ENDTOT = 10L;
  static const jint ENDSIZ = 12L;
  static const jint ENDOFF = 16L;
  static const jint ENDCOM = 20L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_zip_ZipConstants__ */
