// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_srp6_SRPAlgorithm__
#define __gnu_javax_crypto_key_srp6_SRPAlgorithm__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
          namespace srp6
          {
            class SRPAlgorithm;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
}

class gnu::javax::crypto::key::srp6::SRPAlgorithm : public ::java::lang::Object
{
private:
  SRPAlgorithm ();
public:
  static void checkParams (::java::math::BigInteger *, ::java::math::BigInteger *);
  static ::java::math::BigInteger *N_2048;
  static ::java::math::BigInteger *N_1536;
  static ::java::math::BigInteger *N_1280;
  static ::java::math::BigInteger *N_1024;
  static ::java::math::BigInteger *N_768;
  static ::java::math::BigInteger *N_640;
  static ::java::math::BigInteger *N_512;
  static ::java::math::BigInteger *N_384;
  static ::java::math::BigInteger *N_264;
private:
  static ::java::math::BigInteger *ZERO;
  static ::java::math::BigInteger *ONE;
  static ::java::math::BigInteger *TWO;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_key_srp6_SRPAlgorithm__ */
