// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalTreeUI__
#define __javax_swing_plaf_metal_MetalTreeUI__

#pragma interface

#include <javax/swing/plaf/basic/BasicTreeUI.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Insets;
      class Rectangle;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace tree
      {
        class TreePath;
      }
      namespace plaf
      {
        namespace metal
        {
          class MetalTreeUI;
        }
        class ComponentUI;
      }
      class JComponent;
    }
  }
}

class javax::swing::plaf::metal::MetalTreeUI : public ::javax::swing::plaf::basic::BasicTreeUI
{
public:
  MetalTreeUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual jint getHorizontalLegBuffer ();
public:
  virtual void installUI (::javax::swing::JComponent *);
  virtual void uninstallUI (::javax::swing::JComponent *);
public:  // actually protected
  virtual void decodeLineStyle (::java::lang::Object *) { }
  virtual jboolean isLocationInExpandControl (jint, jint, jint, jint);
public:
  virtual void paint (::java::awt::Graphics *, ::javax::swing::JComponent *);
public:  // actually protected
  virtual void paintHorizontalSeparators (::java::awt::Graphics *, ::javax::swing::JComponent *) { }
  virtual void paintVerticalPartOfLeg (::java::awt::Graphics *, ::java::awt::Rectangle *, ::java::awt::Insets *, ::javax::swing::tree::TreePath *);
  virtual void paintHorizontalPartOfLeg (::java::awt::Graphics *, ::java::awt::Rectangle *, ::java::awt::Insets *, ::java::awt::Rectangle *, ::javax::swing::tree::TreePath *, jint, jboolean, jboolean, jboolean);
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalTreeUI__ */
