// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_InputBuffer__
#define __gnu_javax_crypto_sasl_InputBuffer__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
  }
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
          class InputBuffer;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::InputBuffer : public ::java::lang::Object
{
public:
  InputBuffer (jbyteArray);
private:
  InputBuffer ();
public:
  static ::gnu::javax::crypto::sasl::InputBuffer *getInstance (jbyteArray);
  static ::gnu::javax::crypto::sasl::InputBuffer *getInstance (jbyteArray, jint, jint);
  static jint twoBytesToLength (jbyteArray);
  virtual jboolean hasMoreElements ();
  virtual jlong getScalar (jint);
  virtual jbyteArray getOS ();
  virtual jbyteArray getEOS ();
  virtual ::java::math::BigInteger *getMPI ();
  virtual ::java::lang::String *getText ();
public:  // actually protected
  ::java::io::ByteArrayInputStream * __attribute__((aligned(__alignof__( ::java::lang::Object )))) in;
  jint length;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_crypto_sasl_InputBuffer__ */
