// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_InputMapUIResource__
#define __javax_swing_plaf_InputMapUIResource__

#pragma interface

#include <javax/swing/InputMap.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        class InputMapUIResource;
      }
    }
  }
}

class javax::swing::plaf::InputMapUIResource : public ::javax::swing::InputMap
{
public:
  InputMapUIResource ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_InputMapUIResource__ */
